(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[   3630040,     227219]*)
(*NotebookOutlinePosition[   3633858,     227307]*)
(*  CellTagsIndexPosition[   3632968,     227287]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Systems of Differential Equations", "Title"],

Cell["A Predator-Prey Model", "Subtitle"],

Cell[CellGroupData[{

Cell["\<\
The traditional \"predator-prey\" model involves modelling the \
populations of predators and their prey.  The changes in populations are \
related: more prey feed more predators, but an overpopulation of predators \
can lead to depletion of prey, causing a depopulation of predators...  The \
problem simulated below is a take-off on the traditional one.\
\>", "Section"],

Cell["\<\
This is a model for what fraction of the MIT population would know \
a particular joke, the joke is told a fraction of the time when a person who \
has heard it meets someone who hasn't. The rate of joke spreading is \
proportional to how funny it is.\
\>", "Text",
  CellTags->"mmtag:24:the_MIT_joke_model"],

Cell["\<\
It is a closely held secret that Susan Hockfield, MIT's president, \
has an odd sense of humor--she will not let anyone graduate who cannot tell \
him the joke on graduation day.  This often is a source of embarassment and \
confusion to the happy families.\
\>", "Text",
  CellTags->"mmtag:24:predator_prey_models"],

Cell[BoxData[{
    \(\(JokeFunniness\  = \ 0.66;\)\), "\n", 
    \(JokeSpreadRate[Naive_\ , \ Jaded_]\  := 
      JokeFunniness*Naive*Jaded\)}], "Input",
  CellTags->"mmtag:24:JokeFunniness"],

Cell["\<\
Some people who have heard the joke forget it, depending on how \
forgetful they are:\
\>", "Text"],

Cell[BoxData[{
    \(\(PopulationForgetfullness\  = \ 0.2;\)\), "\n", 
    \(ForgotJoke[Naive_\ , \ Jaded_]\  := 
      PopulationForgetfullness*Jaded\)}], "Input",
  CellTags->"mmtag:24:PolulationForgetFullness"],

Cell["\<\
A certain fraction of new students added to the population each day \
who presumably don't know the joke, the graduation rate is proportional to \
the entrance rate and the fraction of those who know the joke.\
\>", "Text"],

Cell[BoxData[{
    \(\(FreshmanEntranceRate\  = 0.24;\)\), "\[IndentingNewLine]", 
    \(\(GraduationRate[Naive_\ , \ Jaded_]\ \  = \ 
        FreshmanEntranceRate*Jaded;\)\)}], "Input"],

Cell["The fraction of students who remain naive tomorrow is", "Text"],

Cell[BoxData[
    \(TomorrowsNaive[TodaysNaive_, 
        TodaysJaded_]\  := \ \(\(TodaysNaive\)\(\ \)\(+\)\(\ \
\)\(FreshmanEntranceRate\/365\)\(\ \)\(-\)\(\ \)\(JokeSpreadRate[
              TodaysNaive\ , \ TodaysJaded]\/365\)\(\ \)\)\)], "Input"],

Cell["The fraction of students who will know the joke tomorrow is", "Text"],

Cell[BoxData[
    \(TomorrowsJaded[TodaysNaive_, TodaysJaded_]\  := \ 
      TodaysJaded\  + \ 
        JokeSpreadRate[TodaysNaive\ , \ TodaysJaded]\/365\  - \ 
        ForgotJoke[TodaysNaive\ , \ TodaysJaded]\/365\ \  - \ 
        GraduationRate[TodaysNaive\ , \ TodaysJaded]\/365\)], "Input"],

Cell["The population evolves each day as", "Text"],

Cell[BoxData[
    \(TomorrowsPopulation[{TodaysNaive_, TodaysJaded_}] := {TomorrowsNaive[
          TodaysNaive\ , \ TodaysJaded], 
        TomorrowsJaded[TodaysNaive\ , \ TodaysJaded]}\)], "Input"],

Cell["\<\
Calculate the population after 5000 days from now if currently 1/5 \
of the students are naive and 4/5 of the students are in the know.\
\>", \
"Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(NestList[TomorrowsPopulation, { .2,  .8}, 5000] // Short\)], "Input",
  CellTags->"mmtag:24:NestList[]"],

Cell[BoxData[
    TagBox[\({{0.2`, 
          0.8`}, \[LeftSkeleton]4999\[RightSkeleton], {0.6675982286750961`, 
          0.580752958296795`}}\),
      Short]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Now do a longer calculation with the initial naive fraction 0.24 and the \
jaded fraction 0.76, and use ListPlot to display the trajectory on the naive\
\[Dash]jaded plane. Note how the trajectory spirals in to a specific point in \
the plane. This is an example of a ",
  StyleBox["critical point",
    FontWeight->"Bold"],
  " at which the rates of change of each population become zero. "
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ListPlot[NestList[TomorrowsPopulation, { .24,  .76}, 20000], 
      PlotRange \[Rule] All, PlotJoined \[Rule] True, 
      PlotStyle \[Rule] {Hue[Random[]], Thickness[0.005]}, 
      AxesLabel \[Rule] {"\<Naive\>", "\<Jaded\>"}]\)], "Input",
  CellTags->"mmtag:24:the_MIT_joke_model__fixed_point_visualized"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.412355 1.81735 -0.683471 1.69315 [
[.31459 .1506 -14.5 -20 ]
[.31459 .1506 14.5 0 ]
[.49632 .1506 -14.5 -20 ]
[.49632 .1506 14.5 0 ]
[.67806 .1506 -14.5 -20 ]
[.67806 .1506 14.5 0 ]
[.85979 .1506 -14.5 -20 ]
[.85979 .1506 14.5 0 ]
[1.025 .1631 0 -10 ]
[1.025 .1631 51.9375 10 ]
[.12035 .07844 -39 -10 ]
[.12035 .07844 0 10 ]
[.12035 .24776 -39 -10 ]
[.12035 .24776 0 10 ]
[.12035 .33242 -29 -10 ]
[.12035 .33242 0 10 ]
[.12035 .41707 -39 -10 ]
[.12035 .41707 0 10 ]
[.12035 .50173 -29 -10 ]
[.12035 .50173 0 10 ]
[.12035 .58639 -39 -10 ]
[.12035 .58639 0 10 ]
[.13285 .64303 -27.9375 0 ]
[.13285 .64303 27.9375 20 ]
[ -0.005 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.31459 .1631 m
.31459 .16935 L
s
gsave
.31459 .1506 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.49632 .1631 m
.49632 .16935 L
s
gsave
.49632 .1506 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67806 .1631 m
.67806 .16935 L
s
gsave
.67806 .1506 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.85979 .1631 m
.85979 .16935 L
s
gsave
.85979 .1506 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.125 Mabswid
.1692 .1631 m
.1692 .16685 L
s
.20554 .1631 m
.20554 .16685 L
s
.24189 .1631 m
.24189 .16685 L
s
.27824 .1631 m
.27824 .16685 L
s
.35093 .1631 m
.35093 .16685 L
s
.38728 .1631 m
.38728 .16685 L
s
.42363 .1631 m
.42363 .16685 L
s
.45997 .1631 m
.45997 .16685 L
s
.53267 .1631 m
.53267 .16685 L
s
.56902 .1631 m
.56902 .16685 L
s
.60536 .1631 m
.60536 .16685 L
s
.64171 .1631 m
.64171 .16685 L
s
.7144 .1631 m
.7144 .16685 L
s
.75075 .1631 m
.75075 .16685 L
s
.7871 .1631 m
.7871 .16685 L
s
.82344 .1631 m
.82344 .16685 L
s
.0965 .1631 m
.0965 .16685 L
s
.06016 .1631 m
.06016 .16685 L
s
.02381 .1631 m
.02381 .16685 L
s
.89614 .1631 m
.89614 .16685 L
s
.93249 .1631 m
.93249 .16685 L
s
.96883 .1631 m
.96883 .16685 L
s
.01 w
0 .1631 m
1 .1631 L
s
gsave
1.025 .1631 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Naive) show
110.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.13285 .07844 m
.1391 .07844 L
s
gsave
.12035 .07844 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.45) show
1.000 setlinewidth
grestore
.13285 .24776 m
.1391 .24776 L
s
gsave
.12035 .24776 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.55) show
1.000 setlinewidth
grestore
.13285 .33242 m
.1391 .33242 L
s
gsave
.12035 .33242 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.13285 .41707 m
.1391 .41707 L
s
gsave
.12035 .41707 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.65) show
1.000 setlinewidth
grestore
.13285 .50173 m
.1391 .50173 L
s
gsave
.12035 .50173 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.7) show
1.000 setlinewidth
grestore
.13285 .58639 m
.1391 .58639 L
s
gsave
.12035 .58639 -100 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.75) show
1.000 setlinewidth
grestore
.125 Mabswid
.13285 .09538 m
.1366 .09538 L
s
.13285 .11231 m
.1366 .11231 L
s
.13285 .12924 m
.1366 .12924 L
s
.13285 .14617 m
.1366 .14617 L
s
.13285 .18003 m
.1366 .18003 L
s
.13285 .19696 m
.1366 .19696 L
s
.13285 .2139 m
.1366 .2139 L
s
.13285 .23083 m
.1366 .23083 L
s
.13285 .26469 m
.1366 .26469 L
s
.13285 .28162 m
.1366 .28162 L
s
.13285 .29855 m
.1366 .29855 L
s
.13285 .31548 m
.1366 .31548 L
s
.13285 .34935 m
.1366 .34935 L
s
.13285 .36628 m
.1366 .36628 L
s
.13285 .38321 m
.1366 .38321 L
s
.13285 .40014 m
.1366 .40014 L
s
.13285 .434 m
.1366 .434 L
s
.13285 .45094 m
.1366 .45094 L
s
.13285 .46787 m
.1366 .46787 L
s
.13285 .4848 m
.1366 .4848 L
s
.13285 .51866 m
.1366 .51866 L
s
.13285 .53559 m
.1366 .53559 L
s
.13285 .55252 m
.1366 .55252 L
s
.13285 .56946 m
.1366 .56946 L
s
.13285 .06151 m
.1366 .06151 L
s
.13285 .04458 m
.1366 .04458 L
s
.13285 .02765 m
.1366 .02765 L
s
.13285 .01072 m
.1366 .01072 L
s
.13285 .60332 m
.1366 .60332 L
s
.01 w
.13285 0 m
.13285 .61803 L
s
gsave
.13285 .64303 -88.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Jaded) show
114.875 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.192 0 1 r
.005 w
.02381 .60332 m
.02441 .60233 L
.025 .60133 L
.0256 .60035 L
.02619 .59936 L
.02678 .59837 L
.02738 .59739 L
.02797 .5964 L
.02856 .59542 L
.02916 .59444 L
.02975 .59346 L
.03034 .59248 L
.03093 .59151 L
.03152 .59053 L
.03212 .58956 L
.03271 .58859 L
.0333 .58762 L
.03389 .58665 L
.03448 .58568 L
.03507 .58471 L
.03565 .58375 L
.03624 .58279 L
.03683 .58183 L
.03742 .58087 L
.03801 .57991 L
.03859 .57895 L
.03918 .578 L
.03977 .57704 L
.04035 .57609 L
.04094 .57514 L
.04153 .57419 L
.04211 .57324 L
.0427 .57229 L
.04328 .57135 L
.04387 .57041 L
.04445 .56946 L
.04503 .56852 L
.04562 .56758 L
.0462 .56664 L
.04678 .56571 L
.04737 .56477 L
.04795 .56384 L
.04853 .56291 L
.04911 .56198 L
.04969 .56105 L
.05027 .56012 L
.05085 .55919 L
.05143 .55827 L
.05201 .55734 L
.05259 .55642 L
Mistroke
.05317 .5555 L
.05375 .55458 L
.05433 .55366 L
.05491 .55274 L
.05549 .55183 L
.05606 .55091 L
.05664 .55 L
.05722 .54909 L
.0578 .54818 L
.05837 .54727 L
.05895 .54636 L
.05952 .54546 L
.0601 .54455 L
.06068 .54365 L
.06125 .54275 L
.06183 .54185 L
.0624 .54095 L
.06297 .54005 L
.06355 .53916 L
.06412 .53826 L
.06469 .53737 L
.06527 .53648 L
.06584 .53558 L
.06641 .53469 L
.06698 .53381 L
.06756 .53292 L
.06813 .53203 L
.0687 .53115 L
.06927 .53027 L
.06984 .52939 L
.07041 .52851 L
.07098 .52763 L
.07155 .52675 L
.07212 .52587 L
.07269 .525 L
.07326 .52412 L
.07383 .52325 L
.0744 .52238 L
.07496 .52151 L
.07553 .52064 L
.0761 .51978 L
.07667 .51891 L
.07723 .51805 L
.0778 .51718 L
.07837 .51632 L
.07893 .51546 L
.0795 .5146 L
.08007 .51374 L
.08063 .51289 L
.0812 .51203 L
Mistroke
.08176 .51118 L
.08232 .51032 L
.08289 .50947 L
.08345 .50862 L
.08402 .50777 L
.08458 .50693 L
.08514 .50608 L
.08571 .50523 L
.08627 .50439 L
.08683 .50355 L
.08739 .50271 L
.08796 .50187 L
.08852 .50103 L
.08908 .50019 L
.08964 .49935 L
.0902 .49852 L
.09076 .49769 L
.09132 .49685 L
.09188 .49602 L
.09244 .49519 L
.093 .49436 L
.09356 .49353 L
.09412 .49271 L
.09468 .49188 L
.09524 .49106 L
.09579 .49024 L
.09635 .48942 L
.09691 .48859 L
.09747 .48778 L
.09803 .48696 L
.09858 .48614 L
.09914 .48533 L
.0997 .48451 L
.10025 .4837 L
.10081 .48289 L
.10136 .48208 L
.10192 .48127 L
.10247 .48046 L
.10303 .47965 L
.10358 .47885 L
.10414 .47804 L
.10469 .47724 L
.10525 .47644 L
.1058 .47564 L
.10635 .47484 L
.10691 .47404 L
.10746 .47324 L
.10801 .47244 L
.10857 .47165 L
.10912 .47086 L
Mistroke
.10967 .47006 L
.11022 .46927 L
.11077 .46848 L
.11133 .46769 L
.11188 .4669 L
.11243 .46612 L
.11298 .46533 L
.11353 .46455 L
.11408 .46376 L
.11463 .46298 L
.11518 .4622 L
.11573 .46142 L
.11628 .46064 L
.11683 .45987 L
.11738 .45909 L
.11792 .45831 L
.11847 .45754 L
.11902 .45677 L
.11957 .456 L
.12012 .45523 L
.12066 .45446 L
.12121 .45369 L
.12176 .45292 L
.1223 .45215 L
.12285 .45139 L
.1234 .45063 L
.12394 .44986 L
.12449 .4491 L
.12503 .44834 L
.12558 .44758 L
.12613 .44682 L
.12667 .44607 L
.12722 .44531 L
.12776 .44456 L
.1283 .4438 L
.12885 .44305 L
.12939 .4423 L
.12994 .44155 L
.13048 .4408 L
.13102 .44005 L
.13157 .43931 L
.13211 .43856 L
.13265 .43781 L
.13319 .43707 L
.13373 .43633 L
.13428 .43559 L
.13482 .43485 L
.13536 .43411 L
.1359 .43337 L
.13644 .43263 L
Mistroke
.13698 .4319 L
.13752 .43116 L
.13806 .43043 L
.1386 .42969 L
.13914 .42896 L
.13968 .42823 L
.14022 .4275 L
.14076 .42677 L
.1413 .42605 L
.14184 .42532 L
.14238 .4246 L
.14292 .42387 L
.14346 .42315 L
.14399 .42243 L
.14453 .42171 L
.14507 .42099 L
.14561 .42027 L
.14614 .41955 L
.14668 .41883 L
.14722 .41812 L
.14776 .4174 L
.14829 .41669 L
.14883 .41598 L
.14936 .41526 L
.1499 .41455 L
.15044 .41384 L
.15097 .41314 L
.15151 .41243 L
.15204 .41172 L
.15258 .41102 L
.15311 .41031 L
.15365 .40961 L
.15418 .40891 L
.15471 .40821 L
.15525 .40751 L
.15578 .40681 L
.15631 .40611 L
.15685 .40541 L
.15738 .40472 L
.15791 .40402 L
.15845 .40333 L
.15898 .40263 L
.15951 .40194 L
.16004 .40125 L
.16058 .40056 L
.16111 .39987 L
.16164 .39919 L
.16217 .3985 L
.1627 .39781 L
.16323 .39713 L
Mistroke
.16376 .39644 L
.16429 .39576 L
.16482 .39508 L
.16535 .3944 L
.16588 .39372 L
.16641 .39304 L
.16694 .39236 L
.16747 .39169 L
.168 .39101 L
.16853 .39034 L
.16906 .38966 L
.16959 .38899 L
.17012 .38832 L
.17064 .38765 L
.17117 .38698 L
.1717 .38631 L
.17223 .38564 L
.17276 .38497 L
.17328 .38431 L
.17381 .38364 L
.17434 .38298 L
.17486 .38231 L
.17539 .38165 L
.17592 .38099 L
.17644 .38033 L
.17697 .37967 L
.17749 .37901 L
.17802 .37836 L
.17855 .3777 L
.17907 .37704 L
.1796 .37639 L
.18012 .37574 L
.18065 .37508 L
.18117 .37443 L
.1817 .37378 L
.18222 .37313 L
.18274 .37248 L
.18327 .37184 L
.18379 .37119 L
.18431 .37054 L
.18484 .3699 L
.18536 .36926 L
.18588 .36861 L
.18641 .36797 L
.18693 .36733 L
.18745 .36669 L
.18797 .36605 L
.1885 .36541 L
.18902 .36477 L
.18954 .36414 L
Mistroke
.19006 .3635 L
.19058 .36287 L
.1911 .36223 L
.19163 .3616 L
.19215 .36097 L
.19267 .36034 L
.19319 .35971 L
.19371 .35908 L
.19423 .35845 L
.19475 .35782 L
.19527 .3572 L
.19579 .35657 L
.19631 .35595 L
.19683 .35532 L
.19735 .3547 L
.19786 .35408 L
.19838 .35346 L
.1989 .35284 L
.19942 .35222 L
.19994 .3516 L
.20046 .35099 L
.20097 .35037 L
.20149 .34975 L
.20201 .34914 L
.20253 .34853 L
.20304 .34791 L
.20356 .3473 L
.20408 .34669 L
.2046 .34608 L
.20511 .34547 L
.20563 .34486 L
.20614 .34426 L
.20666 .34365 L
.20718 .34304 L
.20769 .34244 L
.20821 .34184 L
.20872 .34123 L
.20924 .34063 L
.20975 .34003 L
.21027 .33943 L
.21078 .33883 L
.2113 .33823 L
.21181 .33763 L
.21233 .33704 L
.21284 .33644 L
.21336 .33585 L
.21387 .33525 L
.21438 .33466 L
.2149 .33407 L
.21541 .33347 L
Mistroke
.21592 .33288 L
.21644 .33229 L
.21695 .3317 L
.21746 .33112 L
.21797 .33053 L
.21849 .32994 L
.219 .32936 L
.21951 .32877 L
.22002 .32819 L
.22053 .32761 L
.22105 .32702 L
.22156 .32644 L
.22207 .32586 L
.22258 .32528 L
.22309 .3247 L
.2236 .32413 L
.22411 .32355 L
.22462 .32297 L
.22513 .3224 L
.22564 .32182 L
.22615 .32125 L
.22666 .32068 L
.22717 .3201 L
.22768 .31953 L
.22819 .31896 L
.2287 .31839 L
.22921 .31782 L
.22972 .31726 L
.23023 .31669 L
.23074 .31612 L
.23124 .31556 L
.23175 .31499 L
.23226 .31443 L
.23277 .31387 L
.23328 .3133 L
.23378 .31274 L
.23429 .31218 L
.2348 .31162 L
.23531 .31106 L
.23581 .31051 L
.23632 .30995 L
.23683 .30939 L
.23733 .30884 L
.23784 .30828 L
.23835 .30773 L
.23885 .30717 L
.23936 .30662 L
.23986 .30607 L
.24037 .30552 L
.24088 .30497 L
Mistroke
.24138 .30442 L
.24189 .30387 L
.24239 .30333 L
.2429 .30278 L
.2434 .30223 L
.24391 .30169 L
.24441 .30114 L
.24492 .3006 L
.24542 .30006 L
.24592 .29952 L
.24643 .29897 L
.24693 .29843 L
.24743 .29789 L
.24794 .29736 L
.24844 .29682 L
.24894 .29628 L
.24945 .29574 L
.24995 .29521 L
.25045 .29467 L
.25096 .29414 L
.25146 .29361 L
.25196 .29307 L
.25246 .29254 L
.25296 .29201 L
.25347 .29148 L
.25397 .29095 L
.25447 .29042 L
.25497 .28989 L
.25547 .28937 L
.25597 .28884 L
.25647 .28832 L
.25698 .28779 L
.25748 .28727 L
.25798 .28674 L
.25848 .28622 L
.25898 .2857 L
.25948 .28518 L
.25998 .28466 L
.26048 .28414 L
.26098 .28362 L
.26148 .2831 L
.26198 .28259 L
.26248 .28207 L
.26297 .28155 L
.26347 .28104 L
.26397 .28052 L
.26447 .28001 L
.26497 .2795 L
.26547 .27899 L
.26597 .27848 L
Mistroke
.26646 .27796 L
.26696 .27746 L
.26746 .27695 L
.26796 .27644 L
.26846 .27593 L
.26895 .27542 L
.26945 .27492 L
.26995 .27441 L
.27044 .27391 L
.27094 .2734 L
.27144 .2729 L
.27193 .2724 L
.27243 .2719 L
.27293 .2714 L
.27342 .2709 L
.27392 .2704 L
.27441 .2699 L
.27491 .2694 L
.27541 .2689 L
.2759 .26841 L
.2764 .26791 L
.27689 .26742 L
.27739 .26692 L
.27788 .26643 L
.27838 .26594 L
.27887 .26545 L
.27937 .26495 L
.27986 .26446 L
.28035 .26397 L
.28085 .26348 L
.28134 .263 L
.28184 .26251 L
.28233 .26202 L
.28282 .26154 L
.28332 .26105 L
.28381 .26057 L
.2843 .26008 L
.2848 .2596 L
.28529 .25911 L
.28578 .25863 L
.28627 .25815 L
.28677 .25767 L
.28726 .25719 L
.28775 .25671 L
.28824 .25623 L
.28873 .25576 L
.28923 .25528 L
.28972 .2548 L
.29021 .25433 L
.2907 .25385 L
Mistroke
.29119 .25338 L
.29168 .2529 L
.29217 .25243 L
.29266 .25196 L
.29316 .25149 L
.29365 .25102 L
.29414 .25055 L
.29463 .25008 L
.29512 .24961 L
.29561 .24914 L
.2961 .24867 L
.29659 .24821 L
.29708 .24774 L
.29757 .24728 L
.29805 .24681 L
.29854 .24635 L
.29903 .24588 L
.29952 .24542 L
.30001 .24496 L
.3005 .2445 L
.30099 .24404 L
.30148 .24358 L
.30196 .24312 L
.30245 .24266 L
.30294 .2422 L
.30343 .24175 L
.30392 .24129 L
.3044 .24083 L
.30489 .24038 L
.30538 .23992 L
.30587 .23947 L
.30635 .23902 L
.30684 .23857 L
.30733 .23811 L
.30781 .23766 L
.3083 .23721 L
.30879 .23676 L
.30927 .23631 L
.30976 .23586 L
.31024 .23542 L
.31073 .23497 L
.31122 .23452 L
.3117 .23408 L
.31219 .23363 L
.31267 .23319 L
.31316 .23274 L
.31364 .2323 L
.31413 .23186 L
.31461 .23142 L
.3151 .23098 L
Mistroke
.31558 .23054 L
.31607 .2301 L
.31655 .22966 L
.31703 .22922 L
.31752 .22878 L
.318 .22834 L
.31849 .22791 L
.31897 .22747 L
.31945 .22704 L
.31994 .2266 L
.32042 .22617 L
.3209 .22573 L
.32139 .2253 L
.32187 .22487 L
.32235 .22444 L
.32283 .22401 L
.32332 .22358 L
.3238 .22315 L
.32428 .22272 L
.32476 .22229 L
.32524 .22186 L
.32573 .22144 L
.32621 .22101 L
.32669 .22058 L
.32717 .22016 L
.32765 .21973 L
.32813 .21931 L
.32861 .21889 L
.3291 .21846 L
.32958 .21804 L
.33006 .21762 L
.33054 .2172 L
.33102 .21678 L
.3315 .21636 L
.33198 .21594 L
.33246 .21552 L
.33294 .21511 L
.33342 .21469 L
.3339 .21427 L
.33438 .21386 L
.33486 .21344 L
.33534 .21303 L
.33581 .21262 L
.33629 .2122 L
.33677 .21179 L
.33725 .21138 L
.33773 .21097 L
.33821 .21056 L
.33869 .21015 L
.33916 .20974 L
Mistroke
.33964 .20933 L
.34012 .20892 L
.3406 .20851 L
.34108 .2081 L
.34155 .2077 L
.34203 .20729 L
.34251 .20689 L
.34299 .20648 L
.34346 .20608 L
.34394 .20567 L
.34442 .20527 L
.34489 .20487 L
.34537 .20447 L
.34585 .20407 L
.34632 .20367 L
.3468 .20327 L
.34728 .20287 L
.34775 .20247 L
.34823 .20207 L
.3487 .20167 L
.34918 .20128 L
.34965 .20088 L
.35013 .20049 L
.3506 .20009 L
.35108 .1997 L
.35155 .1993 L
.35203 .19891 L
.3525 .19852 L
.35298 .19812 L
.35345 .19773 L
.35393 .19734 L
.3544 .19695 L
.35487 .19656 L
.35535 .19617 L
.35582 .19579 L
.3563 .1954 L
.35677 .19501 L
.35724 .19462 L
.35772 .19424 L
.35819 .19385 L
.35866 .19347 L
.35914 .19308 L
.35961 .1927 L
.36008 .19231 L
.36055 .19193 L
.36103 .19155 L
.3615 .19117 L
.36197 .19079 L
.36244 .19041 L
.36291 .19003 L
Mistroke
.36339 .18965 L
.36386 .18927 L
.36433 .18889 L
.3648 .18851 L
.36527 .18814 L
.36574 .18776 L
.36621 .18739 L
.36668 .18701 L
.36715 .18664 L
.36763 .18626 L
.3681 .18589 L
.36857 .18552 L
.36904 .18514 L
.36951 .18477 L
.36998 .1844 L
.37045 .18403 L
.37092 .18366 L
.37139 .18329 L
.37186 .18292 L
.37232 .18255 L
.37279 .18218 L
.37326 .18182 L
.37373 .18145 L
.3742 .18108 L
.37467 .18072 L
.37514 .18035 L
.37561 .17999 L
.37608 .17963 L
.37654 .17926 L
.37701 .1789 L
.37748 .17854 L
.37795 .17817 L
.37842 .17781 L
.37888 .17745 L
.37935 .17709 L
.37982 .17673 L
.38028 .17637 L
.38075 .17602 L
.38122 .17566 L
.38169 .1753 L
.38215 .17494 L
.38262 .17459 L
.38309 .17423 L
.38355 .17388 L
.38402 .17352 L
.38448 .17317 L
.38495 .17282 L
.38542 .17246 L
.38588 .17211 L
.38635 .17176 L
Mistroke
.38681 .17141 L
.38728 .17106 L
.38774 .17071 L
.38821 .17036 L
.38867 .17001 L
.38914 .16966 L
.3896 .16931 L
.39007 .16896 L
.39053 .16862 L
.391 .16827 L
.39146 .16792 L
.39192 .16758 L
.39239 .16723 L
.39285 .16689 L
.39332 .16654 L
.39378 .1662 L
.39424 .16586 L
.39471 .16552 L
.39517 .16517 L
.39563 .16483 L
.3961 .16449 L
.39656 .16415 L
.39702 .16381 L
.39748 .16347 L
.39795 .16314 L
.39841 .1628 L
.39887 .16246 L
.39933 .16212 L
.3998 .16179 L
.40026 .16145 L
.40072 .16112 L
.40118 .16078 L
.40164 .16045 L
.4021 .16011 L
.40256 .15978 L
.40303 .15945 L
.40349 .15911 L
.40395 .15878 L
.40441 .15845 L
.40487 .15812 L
.40533 .15779 L
.40579 .15746 L
.40625 .15713 L
.40671 .1568 L
.40717 .15647 L
.40763 .15615 L
.40809 .15582 L
.40855 .15549 L
.40901 .15517 L
.40947 .15484 L
Mistroke
.40993 .15452 L
.41039 .15419 L
.41084 .15387 L
.4113 .15354 L
.41176 .15322 L
.41222 .1529 L
.41268 .15258 L
.41314 .15225 L
.4136 .15193 L
.41405 .15161 L
.41451 .15129 L
.41497 .15097 L
.41543 .15065 L
.41588 .15034 L
.41634 .15002 L
.4168 .1497 L
.41726 .14938 L
.41771 .14907 L
.41817 .14875 L
.41863 .14844 L
.41908 .14812 L
.41954 .14781 L
.42 .14749 L
.42045 .14718 L
.42091 .14687 L
.42137 .14655 L
.42182 .14624 L
.42228 .14593 L
.42273 .14562 L
.42319 .14531 L
.42364 .145 L
.4241 .14469 L
.42455 .14438 L
.42501 .14407 L
.42546 .14376 L
.42592 .14345 L
.42637 .14315 L
.42683 .14284 L
.42728 .14253 L
.42774 .14223 L
.42819 .14192 L
.42865 .14162 L
.4291 .14131 L
.42955 .14101 L
.43001 .14071 L
.43046 .14041 L
.43091 .1401 L
.43137 .1398 L
.43182 .1395 L
.43227 .1392 L
Mistroke
.43273 .1389 L
.43318 .1386 L
.43363 .1383 L
.43408 .138 L
.43454 .1377 L
.43499 .1374 L
.43544 .13711 L
.43589 .13681 L
.43634 .13651 L
.4368 .13622 L
.43725 .13592 L
.4377 .13563 L
.43815 .13533 L
.4386 .13504 L
.43905 .13474 L
.4395 .13445 L
.43996 .13416 L
.44041 .13387 L
.44086 .13357 L
.44131 .13328 L
.44176 .13299 L
.44221 .1327 L
.44266 .13241 L
.44311 .13212 L
.44356 .13183 L
.44401 .13154 L
.44446 .13126 L
.44491 .13097 L
.44536 .13068 L
.4458 .13039 L
.44625 .13011 L
.4467 .12982 L
.44715 .12954 L
.4476 .12925 L
.44805 .12897 L
.4485 .12868 L
.44895 .1284 L
.44939 .12812 L
.44984 .12784 L
.45029 .12755 L
.45074 .12727 L
.45119 .12699 L
.45163 .12671 L
.45208 .12643 L
.45253 .12615 L
.45297 .12587 L
.45342 .12559 L
.45387 .12531 L
.45432 .12504 L
.45476 .12476 L
Mistroke
.45521 .12448 L
.45565 .12421 L
.4561 .12393 L
.45655 .12365 L
.45699 .12338 L
.45744 .1231 L
.45788 .12283 L
.45833 .12256 L
.45878 .12228 L
.45922 .12201 L
.45967 .12174 L
.46011 .12146 L
.46056 .12119 L
.461 .12092 L
.46145 .12065 L
.46189 .12038 L
.46234 .12011 L
.46278 .11984 L
.46322 .11957 L
.46367 .1193 L
.46411 .11904 L
.46456 .11877 L
.465 .1185 L
.46544 .11824 L
.46589 .11797 L
.46633 .1177 L
.46677 .11744 L
.46722 .11717 L
.46766 .11691 L
.4681 .11664 L
.46854 .11638 L
.46899 .11612 L
.46943 .11585 L
.46987 .11559 L
.47031 .11533 L
.47075 .11507 L
.4712 .11481 L
.47164 .11455 L
.47208 .11429 L
.47252 .11403 L
.47296 .11377 L
.4734 .11351 L
.47384 .11325 L
.47429 .11299 L
.47473 .11274 L
.47517 .11248 L
.47561 .11222 L
.47605 .11197 L
.47649 .11171 L
.47693 .11146 L
Mistroke
.47737 .1112 L
.47781 .11095 L
.47825 .11069 L
.47869 .11044 L
.47913 .11019 L
.47957 .10993 L
.48001 .10968 L
.48045 .10943 L
.48088 .10918 L
.48132 .10893 L
.48176 .10868 L
.4822 .10842 L
.48264 .10818 L
.48308 .10793 L
.48352 .10768 L
.48395 .10743 L
.48439 .10718 L
.48483 .10693 L
.48527 .10669 L
.4857 .10644 L
.48614 .10619 L
.48658 .10595 L
.48702 .1057 L
.48745 .10546 L
.48789 .10521 L
.48833 .10497 L
.48876 .10472 L
.4892 .10448 L
.48964 .10424 L
.49007 .10399 L
.49051 .10375 L
.49094 .10351 L
.49138 .10327 L
.49182 .10303 L
.49225 .10279 L
.49269 .10255 L
.49312 .10231 L
.49356 .10207 L
.49399 .10183 L
.49443 .10159 L
.49486 .10135 L
.4953 .10111 L
.49573 .10088 L
.49616 .10064 L
.4966 .1004 L
.49703 .10017 L
.49747 .09993 L
.4979 .0997 L
.49833 .09946 L
.49877 .09923 L
Mistroke
.4992 .09899 L
.49963 .09876 L
.50007 .09853 L
.5005 .09829 L
.50093 .09806 L
.50137 .09783 L
.5018 .0976 L
.50223 .09737 L
.50266 .09714 L
.50309 .09691 L
.50353 .09668 L
.50396 .09645 L
.50439 .09622 L
.50482 .09599 L
.50525 .09576 L
.50568 .09553 L
.50612 .09531 L
.50655 .09508 L
.50698 .09485 L
.50741 .09462 L
.50784 .0944 L
.50827 .09417 L
.5087 .09395 L
.50913 .09372 L
.50956 .0935 L
.50999 .09328 L
.51042 .09305 L
.51085 .09283 L
.51128 .09261 L
.51171 .09238 L
.51214 .09216 L
.51257 .09194 L
.513 .09172 L
.51343 .0915 L
.51385 .09128 L
.51428 .09106 L
.51471 .09084 L
.51514 .09062 L
.51557 .0904 L
.516 .09018 L
.51642 .08996 L
.51685 .08975 L
.51728 .08953 L
.51771 .08931 L
.51813 .0891 L
.51856 .08888 L
.51899 .08866 L
.51942 .08845 L
.51984 .08823 L
.52027 .08802 L
Mistroke
.5207 .08781 L
.52112 .08759 L
.52155 .08738 L
.52197 .08717 L
.5224 .08695 L
.52283 .08674 L
.52325 .08653 L
.52368 .08632 L
.5241 .08611 L
.52453 .0859 L
.52495 .08569 L
.52538 .08548 L
.5258 .08527 L
.52623 .08506 L
.52665 .08485 L
.52708 .08464 L
.5275 .08443 L
.52793 .08422 L
.52835 .08402 L
.52877 .08381 L
.5292 .0836 L
.52962 .0834 L
.53005 .08319 L
.53047 .08299 L
.53089 .08278 L
.53132 .08258 L
.53174 .08237 L
.53216 .08217 L
.53258 .08197 L
.53301 .08176 L
.53343 .08156 L
.53385 .08136 L
.53427 .08116 L
.53469 .08095 L
.53512 .08075 L
.53554 .08055 L
.53596 .08035 L
.53638 .08015 L
.5368 .07995 L
.53722 .07975 L
.53764 .07955 L
.53807 .07935 L
.53849 .07916 L
.53891 .07896 L
.53933 .07876 L
.53975 .07856 L
.54017 .07837 L
.54059 .07817 L
.54101 .07798 L
.54143 .07778 L
Mistroke
.54185 .07758 L
.54227 .07739 L
.54269 .07719 L
.5431 .077 L
.54352 .07681 L
.54394 .07661 L
.54436 .07642 L
.54478 .07623 L
.5452 .07604 L
.54562 .07584 L
.54603 .07565 L
.54645 .07546 L
.54687 .07527 L
.54729 .07508 L
.54771 .07489 L
.54812 .0747 L
.54854 .07451 L
.54896 .07432 L
.54937 .07413 L
.54979 .07394 L
.55021 .07376 L
.55062 .07357 L
.55104 .07338 L
.55146 .07319 L
.55187 .07301 L
.55229 .07282 L
.5527 .07264 L
.55312 .07245 L
.55354 .07227 L
.55395 .07208 L
.55437 .0719 L
.55478 .07171 L
.5552 .07153 L
.55561 .07135 L
.55603 .07116 L
.55644 .07098 L
.55686 .0708 L
.55727 .07062 L
.55768 .07043 L
.5581 .07025 L
.55851 .07007 L
.55892 .06989 L
.55934 .06971 L
.55975 .06953 L
.56016 .06935 L
.56058 .06917 L
.56099 .06899 L
.5614 .06882 L
.56182 .06864 L
.56223 .06846 L
Mistroke
.56264 .06828 L
.56305 .06811 L
.56347 .06793 L
.56388 .06775 L
.56429 .06758 L
.5647 .0674 L
.56511 .06723 L
.56552 .06705 L
.56593 .06688 L
.56635 .0667 L
.56676 .06653 L
.56717 .06636 L
.56758 .06618 L
.56799 .06601 L
.5684 .06584 L
.56881 .06567 L
.56922 .06549 L
.56963 .06532 L
.57004 .06515 L
.57045 .06498 L
.57086 .06481 L
.57127 .06464 L
.57168 .06447 L
.57208 .0643 L
.57249 .06413 L
.5729 .06396 L
.57331 .0638 L
.57372 .06363 L
.57413 .06346 L
.57454 .06329 L
.57494 .06313 L
.57535 .06296 L
.57576 .06279 L
.57617 .06263 L
.57657 .06246 L
.57698 .0623 L
.57739 .06213 L
.57779 .06197 L
.5782 .0618 L
.57861 .06164 L
.57901 .06147 L
.57942 .06131 L
.57983 .06115 L
.58023 .06099 L
.58064 .06082 L
.58104 .06066 L
.58145 .0605 L
.58185 .06034 L
.58226 .06018 L
.58266 .06002 L
Mistroke
.58307 .05986 L
.58347 .0597 L
.58388 .05954 L
.58428 .05938 L
.58469 .05922 L
.58509 .05906 L
.5855 .0589 L
.5859 .05875 L
.5863 .05859 L
.58671 .05843 L
.58711 .05827 L
.58751 .05812 L
.58792 .05796 L
.58832 .05781 L
.58872 .05765 L
.58913 .05749 L
.58953 .05734 L
.58993 .05719 L
.59033 .05703 L
.59073 .05688 L
.59114 .05672 L
.59154 .05657 L
.59194 .05642 L
.59234 .05626 L
.59274 .05611 L
.59314 .05596 L
.59354 .05581 L
.59394 .05566 L
.59435 .05551 L
.59475 .05536 L
.59515 .05521 L
.59555 .05506 L
.59595 .05491 L
.59635 .05476 L
.59675 .05461 L
.59715 .05446 L
.59754 .05431 L
.59794 .05416 L
.59834 .05402 L
.59874 .05387 L
.59914 .05372 L
.59954 .05357 L
.59994 .05343 L
.60034 .05328 L
.60073 .05314 L
.60113 .05299 L
.60153 .05284 L
.60193 .0527 L
.60233 .05256 L
.60272 .05241 L
Mistroke
.60312 .05227 L
.60352 .05212 L
.60391 .05198 L
.60431 .05184 L
.60471 .0517 L
.6051 .05155 L
.6055 .05141 L
.6059 .05127 L
.60629 .05113 L
.60669 .05099 L
.60708 .05085 L
.60748 .05071 L
.60787 .05057 L
.60827 .05043 L
.60866 .05029 L
.60906 .05015 L
.60945 .05001 L
.60985 .04987 L
.61024 .04973 L
.61064 .04959 L
.61103 .04946 L
.61143 .04932 L
.61182 .04918 L
.61221 .04905 L
.61261 .04891 L
.613 .04877 L
.61339 .04864 L
.61379 .0485 L
.61418 .04837 L
.61457 .04823 L
.61496 .0481 L
.61536 .04796 L
.61575 .04783 L
.61614 .0477 L
.61653 .04756 L
.61692 .04743 L
.61732 .0473 L
.61771 .04717 L
.6181 .04703 L
.61849 .0469 L
.61888 .04677 L
.61927 .04664 L
.61966 .04651 L
.62005 .04638 L
.62044 .04625 L
.62083 .04612 L
.62122 .04599 L
.62161 .04586 L
.622 .04573 L
.62239 .0456 L
Mistroke
.62278 .04547 L
.62317 .04535 L
.62356 .04522 L
.62395 .04509 L
.62434 .04496 L
.62472 .04484 L
.62511 .04471 L
.6255 .04459 L
.62589 .04446 L
.62628 .04433 L
.62666 .04421 L
.62705 .04408 L
.62744 .04396 L
.62783 .04384 L
.62821 .04371 L
.6286 .04359 L
.62899 .04346 L
.62937 .04334 L
.62976 .04322 L
.63015 .0431 L
.63053 .04297 L
.63092 .04285 L
.6313 .04273 L
.63169 .04261 L
.63207 .04249 L
.63246 .04237 L
.63284 .04225 L
.63323 .04213 L
.63361 .04201 L
.634 .04189 L
.63438 .04177 L
.63477 .04165 L
.63515 .04153 L
.63554 .04141 L
.63592 .04129 L
.6363 .04118 L
.63669 .04106 L
.63707 .04094 L
.63745 .04082 L
.63784 .04071 L
.63822 .04059 L
.6386 .04048 L
.63898 .04036 L
.63937 .04024 L
.63975 .04013 L
.64013 .04001 L
.64051 .0399 L
.64089 .03979 L
.64127 .03967 L
.64166 .03956 L
Mistroke
.64204 .03944 L
.64242 .03933 L
.6428 .03922 L
.64318 .03911 L
.64356 .03899 L
.64394 .03888 L
.64432 .03877 L
.6447 .03866 L
.64508 .03855 L
.64546 .03844 L
.64584 .03833 L
.64622 .03822 L
.6466 .03811 L
.64698 .038 L
.64735 .03789 L
.64773 .03778 L
.64811 .03767 L
.64849 .03756 L
.64887 .03745 L
.64925 .03735 L
.64962 .03724 L
.65 .03713 L
.65038 .03702 L
.65076 .03692 L
.65113 .03681 L
.65151 .03671 L
.65189 .0366 L
.65226 .03649 L
.65264 .03639 L
.65302 .03628 L
.65339 .03618 L
.65377 .03607 L
.65414 .03597 L
.65452 .03587 L
.65489 .03576 L
.65527 .03566 L
.65564 .03556 L
.65602 .03545 L
.65639 .03535 L
.65677 .03525 L
.65714 .03515 L
.65752 .03505 L
.65789 .03494 L
.65826 .03484 L
.65864 .03474 L
.65901 .03464 L
.65939 .03454 L
.65976 .03444 L
.66013 .03434 L
.6605 .03424 L
Mistroke
.66088 .03414 L
.66125 .03405 L
.66162 .03395 L
.66199 .03385 L
.66237 .03375 L
.66274 .03365 L
.66311 .03356 L
.66348 .03346 L
.66385 .03336 L
.66422 .03327 L
.66459 .03317 L
.66496 .03307 L
.66534 .03298 L
.66571 .03288 L
.66608 .03279 L
.66645 .03269 L
.66682 .0326 L
.66719 .0325 L
.66755 .03241 L
.66792 .03232 L
.66829 .03222 L
.66866 .03213 L
.66903 .03204 L
.6694 .03194 L
.66977 .03185 L
.67014 .03176 L
.6705 .03167 L
.67087 .03157 L
.67124 .03148 L
.67161 .03139 L
.67198 .0313 L
.67234 .03121 L
.67271 .03112 L
.67308 .03103 L
.67344 .03094 L
.67381 .03085 L
.67418 .03076 L
.67454 .03067 L
.67491 .03059 L
.67527 .0305 L
.67564 .03041 L
.67601 .03032 L
.67637 .03023 L
.67674 .03015 L
.6771 .03006 L
.67747 .02997 L
.67783 .02989 L
.67819 .0298 L
.67856 .02971 L
.67892 .02963 L
Mistroke
.67929 .02954 L
.67965 .02946 L
.68001 .02937 L
.68038 .02929 L
.68074 .0292 L
.6811 .02912 L
.68147 .02904 L
.68183 .02895 L
.68219 .02887 L
.68255 .02879 L
.68292 .0287 L
.68328 .02862 L
.68364 .02854 L
.684 .02846 L
.68436 .02838 L
.68472 .0283 L
.68508 .02821 L
.68545 .02813 L
.68581 .02805 L
.68617 .02797 L
.68653 .02789 L
.68689 .02781 L
.68725 .02773 L
.68761 .02765 L
.68797 .02758 L
.68833 .0275 L
.68869 .02742 L
.68904 .02734 L
.6894 .02726 L
.68976 .02718 L
.69012 .02711 L
.69048 .02703 L
.69084 .02695 L
.69119 .02688 L
.69155 .0268 L
.69191 .02672 L
.69227 .02665 L
.69263 .02657 L
.69298 .0265 L
.69334 .02642 L
.6937 .02635 L
.69405 .02627 L
.69441 .0262 L
.69476 .02612 L
.69512 .02605 L
.69548 .02598 L
.69583 .0259 L
.69619 .02583 L
.69654 .02576 L
.6969 .02569 L
Mistroke
.69725 .02561 L
.69761 .02554 L
.69796 .02547 L
.69832 .0254 L
.69867 .02533 L
.69902 .02526 L
.69938 .02519 L
.69973 .02512 L
.70008 .02505 L
.70044 .02498 L
.70079 .02491 L
.70114 .02484 L
.7015 .02477 L
.70185 .0247 L
.7022 .02463 L
.70255 .02456 L
.70291 .02449 L
.70326 .02443 L
.70361 .02436 L
.70396 .02429 L
.70431 .02422 L
.70466 .02416 L
.70501 .02409 L
.70536 .02402 L
.70571 .02396 L
.70606 .02389 L
.70641 .02383 L
.70676 .02376 L
.70711 .0237 L
.70746 .02363 L
.70781 .02357 L
.70816 .0235 L
.70851 .02344 L
.70886 .02337 L
.70921 .02331 L
.70956 .02325 L
.70991 .02318 L
.71025 .02312 L
.7106 .02306 L
.71095 .023 L
.7113 .02294 L
.71164 .02287 L
.71199 .02281 L
.71234 .02275 L
.71268 .02269 L
.71303 .02263 L
.71338 .02257 L
.71372 .02251 L
.71407 .02245 L
.71441 .02239 L
Mistroke
.71476 .02233 L
.71511 .02227 L
.71545 .02221 L
.7158 .02215 L
.71614 .02209 L
.71649 .02203 L
.71683 .02198 L
.71717 .02192 L
.71752 .02186 L
.71786 .0218 L
.71821 .02175 L
.71855 .02169 L
.71889 .02163 L
.71924 .02158 L
.71958 .02152 L
.71992 .02146 L
.72026 .02141 L
.72061 .02135 L
.72095 .0213 L
.72129 .02124 L
.72163 .02119 L
.72197 .02113 L
.72232 .02108 L
.72266 .02103 L
.723 .02097 L
.72334 .02092 L
.72368 .02087 L
.72402 .02081 L
.72436 .02076 L
.7247 .02071 L
.72504 .02066 L
.72538 .0206 L
.72572 .02055 L
.72606 .0205 L
.7264 .02045 L
.72674 .0204 L
.72707 .02035 L
.72741 .0203 L
.72775 .02025 L
.72809 .0202 L
.72843 .02015 L
.72877 .0201 L
.7291 .02005 L
.72944 .02 L
.72978 .01995 L
.73011 .0199 L
.73045 .01985 L
.73079 .01981 L
.73112 .01976 L
.73146 .01971 L
Mistroke
.7318 .01966 L
.73213 .01962 L
.73247 .01957 L
.7328 .01952 L
.73314 .01948 L
.73347 .01943 L
.73381 .01938 L
.73414 .01934 L
.73448 .01929 L
.73481 .01925 L
.73515 .0192 L
.73548 .01916 L
.73581 .01911 L
.73615 .01907 L
.73648 .01902 L
.73681 .01898 L
.73715 .01894 L
.73748 .01889 L
.73781 .01885 L
.73814 .01881 L
.73848 .01876 L
.73881 .01872 L
.73914 .01868 L
.73947 .01864 L
.7398 .0186 L
.74013 .01855 L
.74046 .01851 L
.74079 .01847 L
.74112 .01843 L
.74145 .01839 L
.74179 .01835 L
.74211 .01831 L
.74244 .01827 L
.74277 .01823 L
.7431 .01819 L
.74343 .01815 L
.74376 .01811 L
.74409 .01807 L
.74442 .01804 L
.74475 .018 L
.74508 .01796 L
.7454 .01792 L
.74573 .01788 L
.74606 .01785 L
.74639 .01781 L
.74671 .01777 L
.74704 .01774 L
.74737 .0177 L
.74769 .01766 L
.74802 .01763 L
Mistroke
.74835 .01759 L
.74867 .01756 L
.749 .01752 L
.74932 .01749 L
.74965 .01745 L
.74997 .01742 L
.7503 .01738 L
.75062 .01735 L
.75095 .01732 L
.75127 .01728 L
.7516 .01725 L
.75192 .01721 L
.75224 .01718 L
.75257 .01715 L
.75289 .01712 L
.75321 .01708 L
.75354 .01705 L
.75386 .01702 L
.75418 .01699 L
.7545 .01696 L
.75483 .01693 L
.75515 .0169 L
.75547 .01686 L
.75579 .01683 L
.75611 .0168 L
.75643 .01677 L
.75675 .01674 L
.75708 .01671 L
.7574 .01669 L
.75772 .01666 L
.75804 .01663 L
.75836 .0166 L
.75868 .01657 L
.759 .01654 L
.75931 .01651 L
.75963 .01649 L
.75995 .01646 L
.76027 .01643 L
.76059 .0164 L
.76091 .01638 L
.76123 .01635 L
.76154 .01632 L
.76186 .0163 L
.76218 .01627 L
.7625 .01625 L
.76281 .01622 L
.76313 .01619 L
.76345 .01617 L
.76376 .01614 L
.76408 .01612 L
Mistroke
.7644 .0161 L
.76471 .01607 L
.76503 .01605 L
.76534 .01602 L
.76566 .016 L
.76597 .01598 L
.76629 .01595 L
.7666 .01593 L
.76692 .01591 L
.76723 .01589 L
.76754 .01586 L
.76786 .01584 L
.76817 .01582 L
.76849 .0158 L
.7688 .01578 L
.76911 .01576 L
.76942 .01573 L
.76974 .01571 L
.77005 .01569 L
.77036 .01567 L
.77067 .01565 L
.77098 .01563 L
.7713 .01561 L
.77161 .01559 L
.77192 .01557 L
.77223 .01556 L
.77254 .01554 L
.77285 .01552 L
.77316 .0155 L
.77347 .01548 L
.77378 .01546 L
.77409 .01545 L
.7744 .01543 L
.77471 .01541 L
.77502 .01539 L
.77533 .01538 L
.77563 .01536 L
.77594 .01534 L
.77625 .01533 L
.77656 .01531 L
.77687 .0153 L
.77717 .01528 L
.77748 .01527 L
.77779 .01525 L
.7781 .01524 L
.7784 .01522 L
.77871 .01521 L
.77901 .01519 L
.77932 .01518 L
.77963 .01516 L
Mistroke
.77993 .01515 L
.78024 .01514 L
.78054 .01512 L
.78085 .01511 L
.78115 .0151 L
.78146 .01509 L
.78176 .01507 L
.78207 .01506 L
.78237 .01505 L
.78267 .01504 L
.78298 .01503 L
.78328 .01502 L
.78358 .015 L
.78389 .01499 L
.78419 .01498 L
.78449 .01497 L
.78479 .01496 L
.7851 .01495 L
.7854 .01494 L
.7857 .01493 L
.786 .01492 L
.7863 .01491 L
.7866 .01491 L
.7869 .0149 L
.7872 .01489 L
.7875 .01488 L
.7878 .01487 L
.7881 .01486 L
.7884 .01486 L
.7887 .01485 L
.789 .01484 L
.7893 .01483 L
.7896 .01483 L
.7899 .01482 L
.7902 .01481 L
.7905 .01481 L
.79079 .0148 L
.79109 .0148 L
.79139 .01479 L
.79169 .01478 L
.79198 .01478 L
.79228 .01477 L
.79258 .01477 L
.79287 .01476 L
.79317 .01476 L
.79346 .01476 L
.79376 .01475 L
.79406 .01475 L
.79435 .01474 L
.79465 .01474 L
Mistroke
.79494 .01474 L
.79524 .01474 L
.79553 .01473 L
.79583 .01473 L
.79612 .01473 L
.79641 .01473 L
.79671 .01472 L
.797 .01472 L
.79729 .01472 L
.79759 .01472 L
.79788 .01472 L
.79817 .01472 L
.79846 .01472 L
.79876 .01472 L
.79905 .01472 L
.79934 .01472 L
.79963 .01472 L
.79992 .01472 L
.80021 .01472 L
.8005 .01472 L
.8008 .01472 L
.80109 .01472 L
.80138 .01472 L
.80167 .01472 L
.80196 .01472 L
.80225 .01473 L
.80253 .01473 L
.80282 .01473 L
.80311 .01473 L
.8034 .01473 L
.80369 .01474 L
.80398 .01474 L
.80427 .01474 L
.80455 .01475 L
.80484 .01475 L
.80513 .01476 L
.80542 .01476 L
.8057 .01476 L
.80599 .01477 L
.80628 .01477 L
.80656 .01478 L
.80685 .01478 L
.80713 .01479 L
.80742 .01479 L
.8077 .0148 L
.80799 .01481 L
.80827 .01481 L
.80856 .01482 L
.80884 .01482 L
.80913 .01483 L
Mistroke
.80941 .01484 L
.8097 .01484 L
.80998 .01485 L
.81026 .01486 L
.81055 .01487 L
.81083 .01488 L
.81111 .01488 L
.81139 .01489 L
.81168 .0149 L
.81196 .01491 L
.81224 .01492 L
.81252 .01493 L
.8128 .01494 L
.81308 .01495 L
.81337 .01495 L
.81365 .01496 L
.81393 .01497 L
.81421 .01498 L
.81449 .015 L
.81477 .01501 L
.81505 .01502 L
.81533 .01503 L
.8156 .01504 L
.81588 .01505 L
.81616 .01506 L
.81644 .01507 L
.81672 .01509 L
.817 .0151 L
.81728 .01511 L
.81755 .01512 L
.81783 .01514 L
.81811 .01515 L
.81838 .01516 L
.81866 .01517 L
.81894 .01519 L
.81921 .0152 L
.81949 .01522 L
.81977 .01523 L
.82004 .01524 L
.82032 .01526 L
.82059 .01527 L
.82087 .01529 L
.82114 .0153 L
.82142 .01532 L
.82169 .01533 L
.82196 .01535 L
.82224 .01537 L
.82251 .01538 L
.82278 .0154 L
.82306 .01541 L
Mistroke
.82333 .01543 L
.8236 .01545 L
.82388 .01546 L
.82415 .01548 L
.82442 .0155 L
.82469 .01552 L
.82496 .01553 L
.82523 .01555 L
.82551 .01557 L
.82578 .01559 L
.82605 .01561 L
.82632 .01563 L
.82659 .01564 L
.82686 .01566 L
.82713 .01568 L
.8274 .0157 L
.82767 .01572 L
.82793 .01574 L
.8282 .01576 L
.82847 .01578 L
.82874 .0158 L
.82901 .01582 L
.82928 .01584 L
.82954 .01586 L
.82981 .01589 L
.83008 .01591 L
.83035 .01593 L
.83061 .01595 L
.83088 .01597 L
.83115 .01599 L
.83141 .01602 L
.83168 .01604 L
.83194 .01606 L
.83221 .01608 L
.83247 .01611 L
.83274 .01613 L
.833 .01615 L
.83327 .01618 L
.83353 .0162 L
.8338 .01622 L
.83406 .01625 L
.83432 .01627 L
.83459 .0163 L
.83485 .01632 L
.83511 .01635 L
.83538 .01637 L
.83564 .0164 L
.8359 .01642 L
.83616 .01645 L
.83642 .01647 L
Mistroke
.83668 .0165 L
.83695 .01653 L
.83721 .01655 L
.83747 .01658 L
.83773 .0166 L
.83799 .01663 L
.83825 .01666 L
.83851 .01669 L
.83877 .01671 L
.83903 .01674 L
.83929 .01677 L
.83955 .0168 L
.8398 .01682 L
.84006 .01685 L
.84032 .01688 L
.84058 .01691 L
.84084 .01694 L
.84109 .01697 L
.84135 .017 L
.84161 .01703 L
.84187 .01706 L
.84212 .01709 L
.84238 .01712 L
.84264 .01715 L
.84289 .01718 L
.84315 .01721 L
.8434 .01724 L
.84366 .01727 L
.84391 .0173 L
.84417 .01733 L
.84442 .01736 L
.84468 .01739 L
.84493 .01742 L
.84518 .01746 L
.84544 .01749 L
.84569 .01752 L
.84594 .01755 L
.8462 .01759 L
.84645 .01762 L
.8467 .01765 L
.84695 .01768 L
.84721 .01772 L
.84746 .01775 L
.84771 .01778 L
.84796 .01782 L
.84821 .01785 L
.84846 .01789 L
.84871 .01792 L
.84896 .01796 L
.84921 .01799 L
Mistroke
.84946 .01803 L
.84971 .01806 L
.84996 .0181 L
.85021 .01813 L
.85046 .01817 L
.85071 .0182 L
.85096 .01824 L
.85121 .01827 L
.85145 .01831 L
.8517 .01835 L
.85195 .01838 L
.8522 .01842 L
.85244 .01846 L
.85269 .0185 L
.85294 .01853 L
.85318 .01857 L
.85343 .01861 L
.85368 .01865 L
.85392 .01868 L
.85417 .01872 L
.85441 .01876 L
.85466 .0188 L
.8549 .01884 L
.85515 .01888 L
.85539 .01892 L
.85563 .01895 L
.85588 .01899 L
.85612 .01903 L
.85637 .01907 L
.85661 .01911 L
.85685 .01915 L
.85709 .01919 L
.85734 .01923 L
.85758 .01928 L
.85782 .01932 L
.85806 .01936 L
.8583 .0194 L
.85854 .01944 L
.85879 .01948 L
.85903 .01952 L
.85927 .01956 L
.85951 .01961 L
.85975 .01965 L
.85999 .01969 L
.86023 .01973 L
.86047 .01978 L
.8607 .01982 L
.86094 .01986 L
.86118 .01991 L
.86142 .01995 L
Mistroke
.86166 .01999 L
.8619 .02004 L
.86213 .02008 L
.86237 .02012 L
.86261 .02017 L
.86284 .02021 L
.86308 .02026 L
.86332 .0203 L
.86355 .02035 L
.86379 .02039 L
.86403 .02044 L
.86426 .02048 L
.8645 .02053 L
.86473 .02057 L
.86497 .02062 L
.8652 .02067 L
.86543 .02071 L
.86567 .02076 L
.8659 .0208 L
.86614 .02085 L
.86637 .0209 L
.8666 .02095 L
.86684 .02099 L
.86707 .02104 L
.8673 .02109 L
.86753 .02114 L
.86776 .02118 L
.868 .02123 L
.86823 .02128 L
.86846 .02133 L
.86869 .02138 L
.86892 .02143 L
.86915 .02147 L
.86938 .02152 L
.86961 .02157 L
.86984 .02162 L
.87007 .02167 L
.8703 .02172 L
.87053 .02177 L
.87076 .02182 L
.87099 .02187 L
.87121 .02192 L
.87144 .02197 L
.87167 .02202 L
.8719 .02207 L
.87212 .02212 L
.87235 .02218 L
.87258 .02223 L
.8728 .02228 L
.87303 .02233 L
Mistroke
.87326 .02238 L
.87348 .02243 L
.87371 .02249 L
.87393 .02254 L
.87416 .02259 L
.87438 .02264 L
.87461 .0227 L
.87483 .02275 L
.87506 .0228 L
.87528 .02286 L
.8755 .02291 L
.87573 .02296 L
.87595 .02302 L
.87617 .02307 L
.8764 .02312 L
.87662 .02318 L
.87684 .02323 L
.87706 .02329 L
.87729 .02334 L
.87751 .0234 L
.87773 .02345 L
.87795 .02351 L
.87817 .02356 L
.87839 .02362 L
.87861 .02367 L
.87883 .02373 L
.87905 .02379 L
.87927 .02384 L
.87949 .0239 L
.87971 .02396 L
.87993 .02401 L
.88015 .02407 L
.88036 .02413 L
.88058 .02418 L
.8808 .02424 L
.88102 .0243 L
.88123 .02436 L
.88145 .02441 L
.88167 .02447 L
.88189 .02453 L
.8821 .02459 L
.88232 .02465 L
.88253 .0247 L
.88275 .02476 L
.88296 .02482 L
.88318 .02488 L
.88339 .02494 L
.88361 .025 L
.88382 .02506 L
.88404 .02512 L
Mistroke
.88425 .02518 L
.88447 .02524 L
.88468 .0253 L
.88489 .02536 L
.88511 .02542 L
.88532 .02548 L
.88553 .02554 L
.88574 .0256 L
.88595 .02566 L
.88617 .02572 L
.88638 .02579 L
.88659 .02585 L
.8868 .02591 L
.88701 .02597 L
.88722 .02603 L
.88743 .02609 L
.88764 .02616 L
.88785 .02622 L
.88806 .02628 L
.88827 .02634 L
.88848 .02641 L
.88869 .02647 L
.8889 .02653 L
.8891 .0266 L
.88931 .02666 L
.88952 .02672 L
.88973 .02679 L
.88994 .02685 L
.89014 .02692 L
.89035 .02698 L
.89056 .02704 L
.89076 .02711 L
.89097 .02717 L
.89117 .02724 L
.89138 .0273 L
.89158 .02737 L
.89179 .02743 L
.89199 .0275 L
.8922 .02757 L
.8924 .02763 L
.89261 .0277 L
.89281 .02776 L
.89302 .02783 L
.89322 .0279 L
.89342 .02796 L
.89362 .02803 L
.89383 .0281 L
.89403 .02816 L
.89423 .02823 L
.89443 .0283 L
Mistroke
.89463 .02836 L
.89484 .02843 L
.89504 .0285 L
.89524 .02857 L
.89544 .02864 L
.89564 .0287 L
.89584 .02877 L
.89604 .02884 L
.89624 .02891 L
.89644 .02898 L
.89664 .02905 L
.89684 .02912 L
.89704 .02919 L
.89723 .02925 L
.89743 .02932 L
.89763 .02939 L
.89783 .02946 L
.89802 .02953 L
.89822 .0296 L
.89842 .02967 L
.89862 .02974 L
.89881 .02982 L
.89901 .02989 L
.8992 .02996 L
.8994 .03003 L
.8996 .0301 L
.89979 .03017 L
.89999 .03024 L
.90018 .03031 L
.90037 .03038 L
.90057 .03046 L
.90076 .03053 L
.90096 .0306 L
.90115 .03067 L
.90134 .03075 L
.90154 .03082 L
.90173 .03089 L
.90192 .03096 L
.90211 .03104 L
.9023 .03111 L
.9025 .03118 L
.90269 .03126 L
.90288 .03133 L
.90307 .0314 L
.90326 .03148 L
.90345 .03155 L
.90364 .03163 L
.90383 .0317 L
.90402 .03177 L
.90421 .03185 L
Mistroke
.9044 .03192 L
.90459 .032 L
.90478 .03207 L
.90497 .03215 L
.90515 .03222 L
.90534 .0323 L
.90553 .03238 L
.90572 .03245 L
.9059 .03253 L
.90609 .0326 L
.90628 .03268 L
.90646 .03276 L
.90665 .03283 L
.90684 .03291 L
.90702 .03298 L
.90721 .03306 L
.90739 .03314 L
.90758 .03322 L
.90776 .03329 L
.90795 .03337 L
.90813 .03345 L
.90832 .03353 L
.9085 .0336 L
.90868 .03368 L
.90887 .03376 L
.90905 .03384 L
.90923 .03392 L
.90941 .03399 L
.9096 .03407 L
.90978 .03415 L
.90996 .03423 L
.91014 .03431 L
.91032 .03439 L
.9105 .03447 L
.91068 .03455 L
.91086 .03463 L
.91104 .03471 L
.91122 .03479 L
.9114 .03487 L
.91158 .03495 L
.91176 .03503 L
.91194 .03511 L
.91212 .03519 L
.9123 .03527 L
.91248 .03535 L
.91265 .03543 L
.91283 .03551 L
.91301 .03559 L
.91319 .03568 L
.91336 .03576 L
Mistroke
.91354 .03584 L
.91372 .03592 L
.91389 .036 L
.91407 .03609 L
.91424 .03617 L
.91442 .03625 L
.9146 .03633 L
.91477 .03641 L
.91494 .0365 L
.91512 .03658 L
.91529 .03666 L
.91547 .03675 L
.91564 .03683 L
.91581 .03691 L
.91599 .037 L
.91616 .03708 L
.91633 .03716 L
.91651 .03725 L
.91668 .03733 L
.91685 .03742 L
.91702 .0375 L
.91719 .03759 L
.91736 .03767 L
.91753 .03776 L
.91771 .03784 L
.91788 .03793 L
.91805 .03801 L
.91822 .0381 L
.91839 .03818 L
.91855 .03827 L
.91872 .03835 L
.91889 .03844 L
.91906 .03852 L
.91923 .03861 L
.9194 .0387 L
.91957 .03878 L
.91973 .03887 L
.9199 .03896 L
.92007 .03904 L
.92023 .03913 L
.9204 .03922 L
.92057 .0393 L
.92073 .03939 L
.9209 .03948 L
.92106 .03957 L
.92123 .03965 L
.9214 .03974 L
.92156 .03983 L
.92172 .03992 L
.92189 .04001 L
Mistroke
.92205 .04009 L
.92222 .04018 L
.92238 .04027 L
.92254 .04036 L
.92271 .04045 L
.92287 .04054 L
.92303 .04063 L
.92319 .04072 L
.92336 .0408 L
.92352 .04089 L
.92368 .04098 L
.92384 .04107 L
.924 .04116 L
.92416 .04125 L
.92432 .04134 L
.92448 .04143 L
.92464 .04152 L
.9248 .04161 L
.92496 .04171 L
.92512 .0418 L
.92528 .04189 L
.92544 .04198 L
.9256 .04207 L
.92576 .04216 L
.92592 .04225 L
.92607 .04234 L
.92623 .04243 L
.92639 .04253 L
.92654 .04262 L
.9267 .04271 L
.92686 .0428 L
.92701 .04289 L
.92717 .04299 L
.92733 .04308 L
.92748 .04317 L
.92764 .04326 L
.92779 .04336 L
.92795 .04345 L
.9281 .04354 L
.92825 .04364 L
.92841 .04373 L
.92856 .04382 L
.92872 .04392 L
.92887 .04401 L
.92902 .0441 L
.92917 .0442 L
.92933 .04429 L
.92948 .04439 L
.92963 .04448 L
.92978 .04458 L
Mistroke
.92993 .04467 L
.93009 .04477 L
.93024 .04486 L
.93039 .04496 L
.93054 .04505 L
.93069 .04515 L
.93084 .04524 L
.93099 .04534 L
.93114 .04543 L
.93129 .04553 L
.93143 .04562 L
.93158 .04572 L
.93173 .04582 L
.93188 .04591 L
.93203 .04601 L
.93218 .0461 L
.93232 .0462 L
.93247 .0463 L
.93262 .04639 L
.93276 .04649 L
.93291 .04659 L
.93306 .04668 L
.9332 .04678 L
.93335 .04688 L
.93349 .04698 L
.93364 .04707 L
.93378 .04717 L
.93393 .04727 L
.93407 .04737 L
.93422 .04747 L
.93436 .04756 L
.9345 .04766 L
.93465 .04776 L
.93479 .04786 L
.93493 .04796 L
.93507 .04806 L
.93522 .04816 L
.93536 .04825 L
.9355 .04835 L
.93564 .04845 L
.93578 .04855 L
.93592 .04865 L
.93607 .04875 L
.93621 .04885 L
.93635 .04895 L
.93649 .04905 L
.93663 .04915 L
.93677 .04925 L
.9369 .04935 L
.93704 .04945 L
Mistroke
.93718 .04955 L
.93732 .04965 L
.93746 .04975 L
.9376 .04985 L
.93773 .04996 L
.93787 .05006 L
.93801 .05016 L
.93815 .05026 L
.93828 .05036 L
.93842 .05046 L
.93856 .05056 L
.93869 .05067 L
.93883 .05077 L
.93896 .05087 L
.9391 .05097 L
.93923 .05107 L
.93937 .05118 L
.9395 .05128 L
.93964 .05138 L
.93977 .05148 L
.9399 .05159 L
.94004 .05169 L
.94017 .05179 L
.9403 .0519 L
.94044 .052 L
.94057 .0521 L
.9407 .05221 L
.94083 .05231 L
.94096 .05241 L
.9411 .05252 L
.94123 .05262 L
.94136 .05272 L
.94149 .05283 L
.94162 .05293 L
.94175 .05304 L
.94188 .05314 L
.94201 .05325 L
.94214 .05335 L
.94227 .05346 L
.9424 .05356 L
.94252 .05367 L
.94265 .05377 L
.94278 .05388 L
.94291 .05398 L
.94304 .05409 L
.94316 .05419 L
.94329 .0543 L
.94342 .0544 L
.94354 .05451 L
.94367 .05462 L
Mistroke
.9438 .05472 L
.94392 .05483 L
.94405 .05493 L
.94417 .05504 L
.9443 .05515 L
.94442 .05525 L
.94455 .05536 L
.94467 .05547 L
.9448 .05557 L
.94492 .05568 L
.94504 .05579 L
.94517 .0559 L
.94529 .056 L
.94541 .05611 L
.94554 .05622 L
.94566 .05633 L
.94578 .05643 L
.9459 .05654 L
.94602 .05665 L
.94614 .05676 L
.94627 .05687 L
.94639 .05697 L
.94651 .05708 L
.94663 .05719 L
.94675 .0573 L
.94687 .05741 L
.94699 .05752 L
.94711 .05763 L
.94722 .05774 L
.94734 .05784 L
.94746 .05795 L
.94758 .05806 L
.9477 .05817 L
.94782 .05828 L
.94793 .05839 L
.94805 .0585 L
.94817 .05861 L
.94828 .05872 L
.9484 .05883 L
.94852 .05894 L
.94863 .05905 L
.94875 .05916 L
.94886 .05927 L
.94898 .05938 L
.94909 .05949 L
.94921 .0596 L
.94932 .05972 L
.94944 .05983 L
.94955 .05994 L
.94967 .06005 L
Mistroke
.94978 .06016 L
.94989 .06027 L
.95 .06038 L
.95012 .06049 L
.95023 .06061 L
.95034 .06072 L
.95045 .06083 L
.95057 .06094 L
.95068 .06105 L
.95079 .06117 L
.9509 .06128 L
.95101 .06139 L
.95112 .0615 L
.95123 .06162 L
.95134 .06173 L
.95145 .06184 L
.95156 .06195 L
.95167 .06207 L
.95178 .06218 L
.95189 .06229 L
.95199 .06241 L
.9521 .06252 L
.95221 .06263 L
.95232 .06275 L
.95243 .06286 L
.95253 .06298 L
.95264 .06309 L
.95275 .0632 L
.95285 .06332 L
.95296 .06343 L
.95307 .06355 L
.95317 .06366 L
.95328 .06377 L
.95338 .06389 L
.95349 .064 L
.95359 .06412 L
.9537 .06423 L
.9538 .06435 L
.9539 .06446 L
.95401 .06458 L
.95411 .06469 L
.95421 .06481 L
.95432 .06492 L
.95442 .06504 L
.95452 .06516 L
.95462 .06527 L
.95473 .06539 L
.95483 .0655 L
.95493 .06562 L
.95503 .06573 L
Mistroke
.95513 .06585 L
.95523 .06597 L
.95533 .06608 L
.95543 .0662 L
.95553 .06632 L
.95563 .06643 L
.95573 .06655 L
.95583 .06667 L
.95593 .06678 L
.95603 .0669 L
.95613 .06702 L
.95622 .06713 L
.95632 .06725 L
.95642 .06737 L
.95652 .06749 L
.95661 .0676 L
.95671 .06772 L
.95681 .06784 L
.9569 .06796 L
.957 .06808 L
.9571 .06819 L
.95719 .06831 L
.95729 .06843 L
.95738 .06855 L
.95748 .06867 L
.95757 .06878 L
.95767 .0689 L
.95776 .06902 L
.95785 .06914 L
.95795 .06926 L
.95804 .06938 L
.95813 .0695 L
.95823 .06962 L
.95832 .06974 L
.95841 .06985 L
.9585 .06997 L
.9586 .07009 L
.95869 .07021 L
.95878 .07033 L
.95887 .07045 L
.95896 .07057 L
.95905 .07069 L
.95914 .07081 L
.95923 .07093 L
.95932 .07105 L
.95941 .07117 L
.9595 .07129 L
.95959 .07141 L
.95968 .07153 L
.95977 .07165 L
Mistroke
.95986 .07177 L
.95995 .07189 L
.96003 .07202 L
.96012 .07214 L
.96021 .07226 L
.9603 .07238 L
.96038 .0725 L
.96047 .07262 L
.96056 .07274 L
.96064 .07286 L
.96073 .07298 L
.96081 .07311 L
.9609 .07323 L
.96098 .07335 L
.96107 .07347 L
.96115 .07359 L
.96124 .07372 L
.96132 .07384 L
.96141 .07396 L
.96149 .07408 L
.96157 .0742 L
.96166 .07433 L
.96174 .07445 L
.96182 .07457 L
.9619 .07469 L
.96199 .07482 L
.96207 .07494 L
.96215 .07506 L
.96223 .07519 L
.96231 .07531 L
.96239 .07543 L
.96248 .07556 L
.96256 .07568 L
.96264 .0758 L
.96272 .07593 L
.9628 .07605 L
.96288 .07617 L
.96295 .0763 L
.96303 .07642 L
.96311 .07654 L
.96319 .07667 L
.96327 .07679 L
.96335 .07692 L
.96343 .07704 L
.9635 .07716 L
.96358 .07729 L
.96366 .07741 L
.96373 .07754 L
.96381 .07766 L
.96389 .07779 L
Mistroke
.96396 .07791 L
.96404 .07804 L
.96411 .07816 L
.96419 .07829 L
.96426 .07841 L
.96434 .07854 L
.96441 .07866 L
.96449 .07879 L
.96456 .07891 L
.96464 .07904 L
.96471 .07916 L
.96478 .07929 L
.96486 .07941 L
.96493 .07954 L
.965 .07967 L
.96507 .07979 L
.96515 .07992 L
.96522 .08004 L
.96529 .08017 L
.96536 .0803 L
.96543 .08042 L
.9655 .08055 L
.96558 .08068 L
.96565 .0808 L
.96572 .08093 L
.96579 .08105 L
.96586 .08118 L
.96593 .08131 L
.96599 .08144 L
.96606 .08156 L
.96613 .08169 L
.9662 .08182 L
.96627 .08194 L
.96634 .08207 L
.9664 .0822 L
.96647 .08233 L
.96654 .08245 L
.96661 .08258 L
.96667 .08271 L
.96674 .08284 L
.96681 .08296 L
.96687 .08309 L
.96694 .08322 L
.967 .08335 L
.96707 .08347 L
.96713 .0836 L
.9672 .08373 L
.96726 .08386 L
.96733 .08399 L
.96739 .08412 L
Mistroke
.96746 .08424 L
.96752 .08437 L
.96758 .0845 L
.96765 .08463 L
.96771 .08476 L
.96777 .08489 L
.96783 .08502 L
.9679 .08515 L
.96796 .08527 L
.96802 .0854 L
.96808 .08553 L
.96814 .08566 L
.9682 .08579 L
.96827 .08592 L
.96833 .08605 L
.96839 .08618 L
.96845 .08631 L
.96851 .08644 L
.96857 .08657 L
.96862 .0867 L
.96868 .08683 L
.96874 .08696 L
.9688 .08709 L
.96886 .08722 L
.96892 .08735 L
.96898 .08748 L
.96903 .08761 L
.96909 .08774 L
.96915 .08787 L
.96921 .088 L
.96926 .08813 L
.96932 .08826 L
.96937 .08839 L
.96943 .08852 L
.96949 .08865 L
.96954 .08878 L
.9696 .08891 L
.96965 .08904 L
.96971 .08918 L
.96976 .08931 L
.96982 .08944 L
.96987 .08957 L
.96992 .0897 L
.96998 .08983 L
.97003 .08996 L
.97008 .09009 L
.97014 .09023 L
.97019 .09036 L
.97024 .09049 L
.97029 .09062 L
Mistroke
.97035 .09075 L
.9704 .09088 L
.97045 .09102 L
.9705 .09115 L
.97055 .09128 L
.9706 .09141 L
.97065 .09154 L
.9707 .09168 L
.97075 .09181 L
.9708 .09194 L
.97085 .09207 L
.9709 .09221 L
.97095 .09234 L
.971 .09247 L
.97105 .0926 L
.9711 .09274 L
.97114 .09287 L
.97119 .093 L
.97124 .09314 L
.97129 .09327 L
.97133 .0934 L
.97138 .09353 L
.97143 .09367 L
.97147 .0938 L
.97152 .09393 L
.97157 .09407 L
.97161 .0942 L
.97166 .09433 L
.9717 .09447 L
.97175 .0946 L
.97179 .09473 L
.97184 .09487 L
.97188 .095 L
.97193 .09514 L
.97197 .09527 L
.97201 .0954 L
.97206 .09554 L
.9721 .09567 L
.97214 .0958 L
.97219 .09594 L
.97223 .09607 L
.97227 .09621 L
.97231 .09634 L
.97236 .09648 L
.9724 .09661 L
.97244 .09674 L
.97248 .09688 L
.97252 .09701 L
.97256 .09715 L
.9726 .09728 L
Mistroke
.97264 .09742 L
.97268 .09755 L
.97272 .09769 L
.97276 .09782 L
.9728 .09796 L
.97284 .09809 L
.97288 .09823 L
.97292 .09836 L
.97295 .0985 L
.97299 .09863 L
.97303 .09877 L
.97307 .0989 L
.97311 .09904 L
.97314 .09917 L
.97318 .09931 L
.97322 .09944 L
.97325 .09958 L
.97329 .09972 L
.97332 .09985 L
.97336 .09999 L
.9734 .10012 L
.97343 .10026 L
.97347 .10039 L
.9735 .10053 L
.97354 .10067 L
.97357 .1008 L
.9736 .10094 L
.97364 .10107 L
.97367 .10121 L
.97371 .10135 L
.97374 .10148 L
.97377 .10162 L
.9738 .10176 L
.97384 .10189 L
.97387 .10203 L
.9739 .10216 L
.97393 .1023 L
.97396 .10244 L
.974 .10257 L
.97403 .10271 L
.97406 .10285 L
.97409 .10299 L
.97412 .10312 L
.97415 .10326 L
.97418 .1034 L
.97421 .10353 L
.97424 .10367 L
.97427 .10381 L
.9743 .10394 L
.97433 .10408 L
Mistroke
.97436 .10422 L
.97438 .10436 L
.97441 .10449 L
.97444 .10463 L
.97447 .10477 L
.9745 .10491 L
.97452 .10504 L
.97455 .10518 L
.97458 .10532 L
.9746 .10546 L
.97463 .10559 L
.97466 .10573 L
.97468 .10587 L
.97471 .10601 L
.97473 .10614 L
.97476 .10628 L
.97478 .10642 L
.97481 .10656 L
.97483 .1067 L
.97486 .10683 L
.97488 .10697 L
.9749 .10711 L
.97493 .10725 L
.97495 .10739 L
.97498 .10753 L
.975 .10766 L
.97502 .1078 L
.97504 .10794 L
.97507 .10808 L
.97509 .10822 L
.97511 .10836 L
.97513 .10849 L
.97515 .10863 L
.97517 .10877 L
.9752 .10891 L
.97522 .10905 L
.97524 .10919 L
.97526 .10933 L
.97528 .10947 L
.9753 .1096 L
.97532 .10974 L
.97534 .10988 L
.97536 .11002 L
.97537 .11016 L
.97539 .1103 L
.97541 .11044 L
.97543 .11058 L
.97545 .11072 L
.97547 .11086 L
.97548 .111 L
Mistroke
.9755 .11113 L
.97552 .11127 L
.97554 .11141 L
.97555 .11155 L
.97557 .11169 L
.97558 .11183 L
.9756 .11197 L
.97562 .11211 L
.97563 .11225 L
.97565 .11239 L
.97566 .11253 L
.97568 .11267 L
.97569 .11281 L
.97571 .11295 L
.97572 .11309 L
.97574 .11323 L
.97575 .11337 L
.97576 .11351 L
.97578 .11365 L
.97579 .11379 L
.9758 .11393 L
.97582 .11407 L
.97583 .11421 L
.97584 .11435 L
.97585 .11449 L
.97587 .11463 L
.97588 .11477 L
.97589 .11491 L
.9759 .11505 L
.97591 .11519 L
.97592 .11533 L
.97593 .11547 L
.97594 .11561 L
.97595 .11575 L
.97596 .11589 L
.97597 .11603 L
.97598 .11618 L
.97599 .11632 L
.976 .11646 L
.97601 .1166 L
.97602 .11674 L
.97603 .11688 L
.97604 .11702 L
.97604 .11716 L
.97605 .1173 L
.97606 .11744 L
.97607 .11758 L
.97607 .11772 L
.97608 .11787 L
.97609 .11801 L
Mistroke
.97609 .11815 L
.9761 .11829 L
.97611 .11843 L
.97611 .11857 L
.97612 .11871 L
.97612 .11885 L
.97613 .11899 L
.97613 .11914 L
.97614 .11928 L
.97614 .11942 L
.97615 .11956 L
.97615 .1197 L
.97616 .11984 L
.97616 .11998 L
.97616 .12012 L
.97617 .12027 L
.97617 .12041 L
.97617 .12055 L
.97617 .12069 L
.97618 .12083 L
.97618 .12097 L
.97618 .12112 L
.97618 .12126 L
.97618 .1214 L
.97619 .12154 L
.97619 .12168 L
.97619 .12182 L
.97619 .12197 L
.97619 .12211 L
.97619 .12225 L
.97619 .12239 L
.97619 .12253 L
.97619 .12268 L
.97619 .12282 L
.97619 .12296 L
.97619 .1231 L
.97619 .12324 L
.97619 .12339 L
.97618 .12353 L
.97618 .12367 L
.97618 .12381 L
.97618 .12395 L
.97618 .1241 L
.97617 .12424 L
.97617 .12438 L
.97617 .12452 L
.97616 .12467 L
.97616 .12481 L
.97616 .12495 L
.97615 .12509 L
Mistroke
.97615 .12523 L
.97615 .12538 L
.97614 .12552 L
.97614 .12566 L
.97613 .1258 L
.97613 .12595 L
.97612 .12609 L
.97612 .12623 L
.97611 .12637 L
.9761 .12652 L
.9761 .12666 L
.97609 .1268 L
.97609 .12694 L
.97608 .12709 L
.97607 .12723 L
.97606 .12737 L
.97606 .12751 L
.97605 .12766 L
.97604 .1278 L
.97603 .12794 L
.97603 .12809 L
.97602 .12823 L
.97601 .12837 L
.976 .12851 L
.97599 .12866 L
.97598 .1288 L
.97597 .12894 L
.97596 .12909 L
.97595 .12923 L
.97594 .12937 L
.97593 .12951 L
.97592 .12966 L
.97591 .1298 L
.9759 .12994 L
.97589 .13009 L
.97588 .13023 L
.97587 .13037 L
.97586 .13052 L
.97584 .13066 L
.97583 .1308 L
.97582 .13094 L
.97581 .13109 L
.97579 .13123 L
.97578 .13137 L
.97577 .13152 L
.97576 .13166 L
.97574 .1318 L
.97573 .13195 L
.97571 .13209 L
.9757 .13223 L
Mistroke
.97569 .13238 L
.97567 .13252 L
.97566 .13266 L
.97564 .13281 L
.97563 .13295 L
.97561 .13309 L
.9756 .13324 L
.97558 .13338 L
.97557 .13352 L
.97555 .13367 L
.97553 .13381 L
.97552 .13395 L
.9755 .1341 L
.97548 .13424 L
.97547 .13438 L
.97545 .13453 L
.97543 .13467 L
.97541 .13481 L
.9754 .13496 L
.97538 .1351 L
.97536 .13524 L
.97534 .13539 L
.97532 .13553 L
.9753 .13567 L
.97529 .13582 L
.97527 .13596 L
.97525 .1361 L
.97523 .13625 L
.97521 .13639 L
.97519 .13654 L
.97517 .13668 L
.97515 .13682 L
.97513 .13697 L
.97511 .13711 L
.97508 .13725 L
.97506 .1374 L
.97504 .13754 L
.97502 .13768 L
.975 .13783 L
.97498 .13797 L
.97496 .13812 L
.97493 .13826 L
.97491 .1384 L
.97489 .13855 L
.97486 .13869 L
.97484 .13883 L
.97482 .13898 L
.9748 .13912 L
.97477 .13926 L
.97475 .13941 L
Mistroke
.97472 .13955 L
.9747 .1397 L
.97468 .13984 L
.97465 .13998 L
.97463 .14013 L
.9746 .14027 L
.97458 .14041 L
.97455 .14056 L
.97452 .1407 L
.9745 .14085 L
.97447 .14099 L
.97445 .14113 L
.97442 .14128 L
.97439 .14142 L
.97437 .14156 L
.97434 .14171 L
.97431 .14185 L
.97429 .142 L
.97426 .14214 L
.97423 .14228 L
.9742 .14243 L
.97418 .14257 L
.97415 .14271 L
.97412 .14286 L
.97409 .143 L
.97406 .14315 L
.97403 .14329 L
.974 .14343 L
.97397 .14358 L
.97394 .14372 L
.97391 .14387 L
.97388 .14401 L
.97385 .14415 L
.97382 .1443 L
.97379 .14444 L
.97376 .14458 L
.97373 .14473 L
.9737 .14487 L
.97367 .14502 L
.97364 .14516 L
.97361 .1453 L
.97358 .14545 L
.97354 .14559 L
.97351 .14573 L
.97348 .14588 L
.97345 .14602 L
.97341 .14617 L
.97338 .14631 L
.97335 .14645 L
.97331 .1466 L
Mistroke
.97328 .14674 L
.97325 .14689 L
.97321 .14703 L
.97318 .14717 L
.97315 .14732 L
.97311 .14746 L
.97308 .1476 L
.97304 .14775 L
.97301 .14789 L
.97297 .14804 L
.97294 .14818 L
.9729 .14832 L
.97287 .14847 L
.97283 .14861 L
.97279 .14875 L
.97276 .1489 L
.97272 .14904 L
.97269 .14919 L
.97265 .14933 L
.97261 .14947 L
.97258 .14962 L
.97254 .14976 L
.9725 .1499 L
.97246 .15005 L
.97243 .15019 L
.97239 .15033 L
.97235 .15048 L
.97231 .15062 L
.97227 .15077 L
.97223 .15091 L
.9722 .15105 L
.97216 .1512 L
.97212 .15134 L
.97208 .15148 L
.97204 .15163 L
.972 .15177 L
.97196 .15191 L
.97192 .15206 L
.97188 .1522 L
.97184 .15235 L
.9718 .15249 L
.97176 .15263 L
.97172 .15278 L
.97167 .15292 L
.97163 .15306 L
.97159 .15321 L
.97155 .15335 L
.97151 .15349 L
.97147 .15364 L
.97142 .15378 L
Mistroke
.97138 .15392 L
.97134 .15407 L
.9713 .15421 L
.97125 .15435 L
.97121 .1545 L
.97117 .15464 L
.97112 .15478 L
.97108 .15493 L
.97104 .15507 L
.97099 .15521 L
.97095 .15536 L
.9709 .1555 L
.97086 .15564 L
.97082 .15579 L
.97077 .15593 L
.97073 .15607 L
.97068 .15622 L
.97064 .15636 L
.97059 .1565 L
.97054 .15665 L
.9705 .15679 L
.97045 .15693 L
.97041 .15708 L
.97036 .15722 L
.97031 .15736 L
.97027 .15751 L
.97022 .15765 L
.97017 .15779 L
.97013 .15794 L
.97008 .15808 L
.97003 .15822 L
.96998 .15837 L
.96994 .15851 L
.96989 .15865 L
.96984 .15879 L
.96979 .15894 L
.96974 .15908 L
.96969 .15922 L
.96965 .15937 L
.9696 .15951 L
.96955 .15965 L
.9695 .15979 L
.96945 .15994 L
.9694 .16008 L
.96935 .16022 L
.9693 .16037 L
.96925 .16051 L
.9692 .16065 L
.96915 .16079 L
.9691 .16094 L
Mistroke
.96905 .16108 L
.969 .16122 L
.96894 .16137 L
.96889 .16151 L
.96884 .16165 L
.96879 .16179 L
.96874 .16194 L
.96869 .16208 L
.96863 .16222 L
.96858 .16236 L
.96853 .16251 L
.96848 .16265 L
.96842 .16279 L
.96837 .16293 L
.96832 .16308 L
.96826 .16322 L
.96821 .16336 L
.96816 .1635 L
.9681 .16365 L
.96805 .16379 L
.968 .16393 L
.96794 .16407 L
.96789 .16422 L
.96783 .16436 L
.96778 .1645 L
.96772 .16464 L
.96767 .16478 L
.96761 .16493 L
.96756 .16507 L
.9675 .16521 L
.96745 .16535 L
.96739 .16549 L
.96733 .16564 L
.96728 .16578 L
.96722 .16592 L
.96717 .16606 L
.96711 .1662 L
.96705 .16635 L
.96699 .16649 L
.96694 .16663 L
.96688 .16677 L
.96682 .16691 L
.96677 .16706 L
.96671 .1672 L
.96665 .16734 L
.96659 .16748 L
.96653 .16762 L
.96648 .16776 L
.96642 .16791 L
.96636 .16805 L
Mistroke
.9663 .16819 L
.96624 .16833 L
.96618 .16847 L
.96612 .16861 L
.96606 .16876 L
.966 .1689 L
.96594 .16904 L
.96588 .16918 L
.96582 .16932 L
.96576 .16946 L
.9657 .1696 L
.96564 .16975 L
.96558 .16989 L
.96552 .17003 L
.96546 .17017 L
.9654 .17031 L
.96534 .17045 L
.96528 .17059 L
.96521 .17073 L
.96515 .17088 L
.96509 .17102 L
.96503 .17116 L
.96497 .1713 L
.9649 .17144 L
.96484 .17158 L
.96478 .17172 L
.96472 .17186 L
.96465 .172 L
.96459 .17214 L
.96453 .17228 L
.96446 .17243 L
.9644 .17257 L
.96434 .17271 L
.96427 .17285 L
.96421 .17299 L
.96414 .17313 L
.96408 .17327 L
.96402 .17341 L
.96395 .17355 L
.96389 .17369 L
.96382 .17383 L
.96376 .17397 L
.96369 .17411 L
.96363 .17425 L
.96356 .17439 L
.96349 .17453 L
.96343 .17467 L
.96336 .17481 L
.9633 .17495 L
.96323 .17509 L
Mistroke
.96316 .17523 L
.9631 .17537 L
.96303 .17551 L
.96296 .17565 L
.9629 .17579 L
.96283 .17593 L
.96276 .17607 L
.9627 .17621 L
.96263 .17635 L
.96256 .17649 L
.96249 .17663 L
.96243 .17677 L
.96236 .17691 L
.96229 .17705 L
.96222 .17719 L
.96215 .17733 L
.96208 .17747 L
.96202 .17761 L
.96195 .17775 L
.96188 .17789 L
.96181 .17803 L
.96174 .17817 L
.96167 .17831 L
.9616 .17845 L
.96153 .17859 L
.96146 .17873 L
.96139 .17886 L
.96132 .179 L
.96125 .17914 L
.96118 .17928 L
.96111 .17942 L
.96104 .17956 L
.96097 .1797 L
.9609 .17984 L
.96082 .17998 L
.96075 .18012 L
.96068 .18025 L
.96061 .18039 L
.96054 .18053 L
.96047 .18067 L
.96039 .18081 L
.96032 .18095 L
.96025 .18109 L
.96018 .18122 L
.96011 .18136 L
.96003 .1815 L
.95996 .18164 L
.95989 .18178 L
.95981 .18192 L
.95974 .18205 L
Mistroke
.95967 .18219 L
.95959 .18233 L
.95952 .18247 L
.95945 .18261 L
.95937 .18275 L
.9593 .18288 L
.95922 .18302 L
.95915 .18316 L
.95908 .1833 L
.959 .18344 L
.95893 .18357 L
.95885 .18371 L
.95878 .18385 L
.9587 .18399 L
.95863 .18412 L
.95855 .18426 L
.95848 .1844 L
.9584 .18454 L
.95832 .18467 L
.95825 .18481 L
.95817 .18495 L
.9581 .18509 L
.95802 .18522 L
.95794 .18536 L
.95787 .1855 L
.95779 .18564 L
.95771 .18577 L
.95764 .18591 L
.95756 .18605 L
.95748 .18618 L
.95741 .18632 L
.95733 .18646 L
.95725 .18659 L
.95717 .18673 L
.9571 .18687 L
.95702 .187 L
.95694 .18714 L
.95686 .18728 L
.95678 .18741 L
.9567 .18755 L
.95663 .18769 L
.95655 .18782 L
.95647 .18796 L
.95639 .1881 L
.95631 .18823 L
.95623 .18837 L
.95615 .18851 L
.95607 .18864 L
.95599 .18878 L
.95591 .18891 L
Mistroke
.95583 .18905 L
.95575 .18919 L
.95567 .18932 L
.95559 .18946 L
.95551 .18959 L
.95543 .18973 L
.95535 .18987 L
.95527 .19 L
.95519 .19014 L
.95511 .19027 L
.95503 .19041 L
.95495 .19054 L
.95487 .19068 L
.95479 .19081 L
.9547 .19095 L
.95462 .19108 L
.95454 .19122 L
.95446 .19135 L
.95438 .19149 L
.95429 .19163 L
.95421 .19176 L
.95413 .1919 L
.95405 .19203 L
.95396 .19216 L
.95388 .1923 L
.9538 .19243 L
.95372 .19257 L
.95363 .1927 L
.95355 .19284 L
.95347 .19297 L
.95338 .19311 L
.9533 .19324 L
.95322 .19338 L
.95313 .19351 L
.95305 .19365 L
.95296 .19378 L
.95288 .19391 L
.9528 .19405 L
.95271 .19418 L
.95263 .19432 L
.95254 .19445 L
.95246 .19458 L
.95237 .19472 L
.95229 .19485 L
.9522 .19499 L
.95212 .19512 L
.95203 .19525 L
.95195 .19539 L
.95186 .19552 L
.95177 .19565 L
Mistroke
.95169 .19579 L
.9516 .19592 L
.95152 .19605 L
.95143 .19619 L
.95134 .19632 L
.95126 .19645 L
.95117 .19659 L
.95109 .19672 L
.951 .19685 L
.95091 .19699 L
.95082 .19712 L
.95074 .19725 L
.95065 .19738 L
.95056 .19752 L
.95048 .19765 L
.95039 .19778 L
.9503 .19791 L
.95021 .19805 L
.95013 .19818 L
.95004 .19831 L
.94995 .19844 L
.94986 .19858 L
.94977 .19871 L
.94969 .19884 L
.9496 .19897 L
.94951 .1991 L
.94942 .19924 L
.94933 .19937 L
.94924 .1995 L
.94915 .19963 L
.94906 .19976 L
.94897 .1999 L
.94889 .20003 L
.9488 .20016 L
.94871 .20029 L
.94862 .20042 L
.94853 .20055 L
.94844 .20068 L
.94835 .20082 L
.94826 .20095 L
.94817 .20108 L
.94808 .20121 L
.94799 .20134 L
.9479 .20147 L
.94781 .2016 L
.94771 .20173 L
.94762 .20186 L
.94753 .20199 L
.94744 .20213 L
.94735 .20226 L
Mistroke
.94726 .20239 L
.94717 .20252 L
.94708 .20265 L
.94699 .20278 L
.94689 .20291 L
.9468 .20304 L
.94671 .20317 L
.94662 .2033 L
.94653 .20343 L
.94643 .20356 L
.94634 .20369 L
.94625 .20382 L
.94616 .20395 L
.94606 .20408 L
.94597 .20421 L
.94588 .20434 L
.94579 .20447 L
.94569 .2046 L
.9456 .20473 L
.94551 .20486 L
.94541 .20498 L
.94532 .20511 L
.94523 .20524 L
.94513 .20537 L
.94504 .2055 L
.94495 .20563 L
.94485 .20576 L
.94476 .20589 L
.94466 .20602 L
.94457 .20615 L
.94448 .20627 L
.94438 .2064 L
.94429 .20653 L
.94419 .20666 L
.9441 .20679 L
.944 .20692 L
.94391 .20704 L
.94381 .20717 L
.94372 .2073 L
.94362 .20743 L
.94353 .20756 L
.94343 .20768 L
.94334 .20781 L
.94324 .20794 L
.94315 .20807 L
.94305 .2082 L
.94296 .20832 L
.94286 .20845 L
.94276 .20858 L
.94267 .20871 L
Mistroke
.94257 .20883 L
.94248 .20896 L
.94238 .20909 L
.94228 .20922 L
.94219 .20934 L
.94209 .20947 L
.94199 .2096 L
.9419 .20972 L
.9418 .20985 L
.9417 .20998 L
.94161 .2101 L
.94151 .21023 L
.94141 .21036 L
.94131 .21048 L
.94122 .21061 L
.94112 .21074 L
.94102 .21086 L
.94092 .21099 L
.94083 .21111 L
.94073 .21124 L
.94063 .21137 L
.94053 .21149 L
.94043 .21162 L
.94034 .21174 L
.94024 .21187 L
.94014 .21199 L
.94004 .21212 L
.93994 .21225 L
.93984 .21237 L
.93974 .2125 L
.93965 .21262 L
.93955 .21275 L
.93945 .21287 L
.93935 .213 L
.93925 .21312 L
.93915 .21325 L
.93905 .21337 L
.93895 .2135 L
.93885 .21362 L
.93875 .21375 L
.93865 .21387 L
.93855 .214 L
.93845 .21412 L
.93835 .21424 L
.93825 .21437 L
.93815 .21449 L
.93805 .21462 L
.93795 .21474 L
.93785 .21486 L
.93775 .21499 L
Mistroke
.93765 .21511 L
.93755 .21524 L
.93745 .21536 L
.93735 .21548 L
.93725 .21561 L
.93715 .21573 L
.93705 .21585 L
.93695 .21598 L
.93685 .2161 L
.93674 .21622 L
.93664 .21635 L
.93654 .21647 L
.93644 .21659 L
.93634 .21672 L
.93624 .21684 L
.93614 .21696 L
.93603 .21708 L
.93593 .21721 L
.93583 .21733 L
.93573 .21745 L
.93563 .21757 L
.93552 .2177 L
.93542 .21782 L
.93532 .21794 L
.93522 .21806 L
.93511 .21818 L
.93501 .21831 L
.93491 .21843 L
.93481 .21855 L
.9347 .21867 L
.9346 .21879 L
.9345 .21892 L
.93439 .21904 L
.93429 .21916 L
.93419 .21928 L
.93408 .2194 L
.93398 .21952 L
.93388 .21964 L
.93377 .21976 L
.93367 .21988 L
.93357 .22001 L
.93346 .22013 L
.93336 .22025 L
.93326 .22037 L
.93315 .22049 L
.93305 .22061 L
.93294 .22073 L
.93284 .22085 L
.93274 .22097 L
.93263 .22109 L
Mistroke
.93253 .22121 L
.93242 .22133 L
.93232 .22145 L
.93221 .22157 L
.93211 .22169 L
.932 .22181 L
.9319 .22193 L
.9318 .22205 L
.93169 .22217 L
.93159 .22229 L
.93148 .22241 L
.93138 .22253 L
.93127 .22264 L
.93116 .22276 L
.93106 .22288 L
.93095 .223 L
.93085 .22312 L
.93074 .22324 L
.93064 .22336 L
.93053 .22348 L
.93043 .2236 L
.93032 .22371 L
.93021 .22383 L
.93011 .22395 L
.93 .22407 L
.9299 .22419 L
.92979 .2243 L
.92968 .22442 L
.92958 .22454 L
.92947 .22466 L
.92936 .22478 L
.92926 .22489 L
.92915 .22501 L
.92905 .22513 L
.92894 .22525 L
.92883 .22536 L
.92873 .22548 L
.92862 .2256 L
.92851 .22571 L
.9284 .22583 L
.9283 .22595 L
.92819 .22606 L
.92808 .22618 L
.92798 .2263 L
.92787 .22641 L
.92776 .22653 L
.92765 .22665 L
.92755 .22676 L
.92744 .22688 L
.92733 .227 L
Mistroke
.92722 .22711 L
.92712 .22723 L
.92701 .22734 L
.9269 .22746 L
.92679 .22758 L
.92668 .22769 L
.92658 .22781 L
.92647 .22792 L
.92636 .22804 L
.92625 .22815 L
.92614 .22827 L
.92604 .22838 L
.92593 .2285 L
.92582 .22861 L
.92571 .22873 L
.9256 .22884 L
.92549 .22896 L
.92538 .22907 L
.92528 .22919 L
.92517 .2293 L
.92506 .22942 L
.92495 .22953 L
.92484 .22964 L
.92473 .22976 L
.92462 .22987 L
.92451 .22999 L
.9244 .2301 L
.92429 .23021 L
.92418 .23033 L
.92408 .23044 L
.92397 .23056 L
.92386 .23067 L
.92375 .23078 L
.92364 .2309 L
.92353 .23101 L
.92342 .23112 L
.92331 .23123 L
.9232 .23135 L
.92309 .23146 L
.92298 .23157 L
.92287 .23169 L
.92276 .2318 L
.92265 .23191 L
.92254 .23202 L
.92243 .23214 L
.92232 .23225 L
.92221 .23236 L
.9221 .23247 L
.92199 .23258 L
.92188 .2327 L
Mistroke
.92177 .23281 L
.92166 .23292 L
.92154 .23303 L
.92143 .23314 L
.92132 .23325 L
.92121 .23337 L
.9211 .23348 L
.92099 .23359 L
.92088 .2337 L
.92077 .23381 L
.92066 .23392 L
.92055 .23403 L
.92044 .23414 L
.92033 .23425 L
.92021 .23436 L
.9201 .23447 L
.91999 .23459 L
.91988 .2347 L
.91977 .23481 L
.91966 .23492 L
.91955 .23503 L
.91943 .23514 L
.91932 .23525 L
.91921 .23536 L
.9191 .23547 L
.91899 .23558 L
.91888 .23568 L
.91876 .23579 L
.91865 .2359 L
.91854 .23601 L
.91843 .23612 L
.91832 .23623 L
.9182 .23634 L
.91809 .23645 L
.91798 .23656 L
.91787 .23667 L
.91776 .23677 L
.91764 .23688 L
.91753 .23699 L
.91742 .2371 L
.91731 .23721 L
.91719 .23732 L
.91708 .23742 L
.91697 .23753 L
.91686 .23764 L
.91674 .23775 L
.91663 .23786 L
.91652 .23796 L
.91641 .23807 L
.91629 .23818 L
Mistroke
.91618 .23829 L
.91607 .23839 L
.91595 .2385 L
.91584 .23861 L
.91573 .23871 L
.91562 .23882 L
.9155 .23893 L
.91539 .23904 L
.91528 .23914 L
.91516 .23925 L
.91505 .23935 L
.91494 .23946 L
.91482 .23957 L
.91471 .23967 L
.9146 .23978 L
.91448 .23989 L
.91437 .23999 L
.91426 .2401 L
.91414 .2402 L
.91403 .24031 L
.91392 .24041 L
.9138 .24052 L
.91369 .24063 L
.91358 .24073 L
.91346 .24084 L
.91335 .24094 L
.91323 .24105 L
.91312 .24115 L
.91301 .24126 L
.91289 .24136 L
.91278 .24146 L
.91266 .24157 L
.91255 .24167 L
.91244 .24178 L
.91232 .24188 L
.91221 .24199 L
.91209 .24209 L
.91198 .24219 L
.91187 .2423 L
.91175 .2424 L
.91164 .24251 L
.91152 .24261 L
.91141 .24271 L
.91129 .24282 L
.91118 .24292 L
.91106 .24302 L
.91095 .24313 L
.91084 .24323 L
.91072 .24333 L
.91061 .24343 L
Mistroke
.91049 .24354 L
.91038 .24364 L
.91026 .24374 L
.91015 .24384 L
.91003 .24395 L
.90992 .24405 L
.9098 .24415 L
.90969 .24425 L
.90957 .24436 L
.90946 .24446 L
.90934 .24456 L
.90923 .24466 L
.90911 .24476 L
.909 .24486 L
.90888 .24497 L
.90877 .24507 L
.90865 .24517 L
.90854 .24527 L
.90842 .24537 L
.90831 .24547 L
.90819 .24557 L
.90808 .24567 L
.90796 .24577 L
.90785 .24587 L
.90773 .24597 L
.90762 .24607 L
.9075 .24617 L
.90739 .24627 L
.90727 .24638 L
.90715 .24647 L
.90704 .24657 L
.90692 .24667 L
.90681 .24677 L
.90669 .24687 L
.90658 .24697 L
.90646 .24707 L
.90635 .24717 L
.90623 .24727 L
.90611 .24737 L
.906 .24747 L
.90588 .24757 L
.90577 .24767 L
.90565 .24777 L
.90554 .24786 L
.90542 .24796 L
.9053 .24806 L
.90519 .24816 L
.90507 .24826 L
.90496 .24836 L
.90484 .24845 L
Mistroke
.90472 .24855 L
.90461 .24865 L
.90449 .24875 L
.90438 .24885 L
.90426 .24894 L
.90414 .24904 L
.90403 .24914 L
.90391 .24923 L
.9038 .24933 L
.90368 .24943 L
.90356 .24953 L
.90345 .24962 L
.90333 .24972 L
.90321 .24982 L
.9031 .24991 L
.90298 .25001 L
.90287 .25011 L
.90275 .2502 L
.90263 .2503 L
.90252 .25039 L
.9024 .25049 L
.90228 .25059 L
.90217 .25068 L
.90205 .25078 L
.90193 .25087 L
.90182 .25097 L
.9017 .25106 L
.90158 .25116 L
.90147 .25125 L
.90135 .25135 L
.90123 .25144 L
.90112 .25154 L
.901 .25163 L
.90088 .25173 L
.90077 .25182 L
.90065 .25192 L
.90053 .25201 L
.90042 .25211 L
.9003 .2522 L
.90018 .2523 L
.90007 .25239 L
.89995 .25248 L
.89983 .25258 L
.89972 .25267 L
.8996 .25276 L
.89948 .25286 L
.89937 .25295 L
.89925 .25304 L
.89913 .25314 L
.89902 .25323 L
Mistroke
.8989 .25332 L
.89878 .25342 L
.89867 .25351 L
.89855 .2536 L
.89843 .2537 L
.89832 .25379 L
.8982 .25388 L
.89808 .25397 L
.89796 .25406 L
.89785 .25416 L
.89773 .25425 L
.89761 .25434 L
.8975 .25443 L
.89738 .25452 L
.89726 .25462 L
.89715 .25471 L
.89703 .2548 L
.89691 .25489 L
.89679 .25498 L
.89668 .25507 L
.89656 .25516 L
.89644 .25525 L
.89633 .25535 L
.89621 .25544 L
.89609 .25553 L
.89597 .25562 L
.89586 .25571 L
.89574 .2558 L
.89562 .25589 L
.89551 .25598 L
.89539 .25607 L
.89527 .25616 L
.89515 .25625 L
.89504 .25634 L
.89492 .25643 L
.8948 .25652 L
.89468 .25661 L
.89457 .2567 L
.89445 .25678 L
.89433 .25687 L
.89422 .25696 L
.8941 .25705 L
.89398 .25714 L
.89386 .25723 L
.89375 .25732 L
.89363 .25741 L
.89351 .25749 L
.89339 .25758 L
.89328 .25767 L
.89316 .25776 L
Mistroke
.89304 .25785 L
.89293 .25793 L
.89281 .25802 L
.89269 .25811 L
.89257 .2582 L
.89246 .25829 L
.89234 .25837 L
.89222 .25846 L
.8921 .25855 L
.89199 .25863 L
.89187 .25872 L
.89175 .25881 L
.89163 .25889 L
.89152 .25898 L
.8914 .25907 L
.89128 .25915 L
.89116 .25924 L
.89105 .25933 L
.89093 .25941 L
.89081 .2595 L
.8907 .25959 L
.89058 .25967 L
.89046 .25976 L
.89034 .25984 L
.89023 .25993 L
.89011 .26001 L
.88999 .2601 L
.88987 .26018 L
.88976 .26027 L
.88964 .26035 L
.88952 .26044 L
.8894 .26052 L
.88929 .26061 L
.88917 .26069 L
.88905 .26078 L
.88893 .26086 L
.88882 .26095 L
.8887 .26103 L
.88858 .26111 L
.88846 .2612 L
.88835 .26128 L
.88823 .26137 L
.88811 .26145 L
.88799 .26153 L
.88788 .26162 L
.88776 .2617 L
.88764 .26178 L
.88753 .26187 L
.88741 .26195 L
.88729 .26203 L
Mistroke
.88717 .26212 L
.88706 .2622 L
.88694 .26228 L
.88682 .26236 L
.8867 .26245 L
.88659 .26253 L
.88647 .26261 L
.88635 .26269 L
.88623 .26277 L
.88612 .26286 L
.886 .26294 L
.88588 .26302 L
.88577 .2631 L
.88565 .26318 L
.88553 .26326 L
.88541 .26335 L
.8853 .26343 L
.88518 .26351 L
.88506 .26359 L
.88494 .26367 L
.88483 .26375 L
.88471 .26383 L
.88459 .26391 L
.88448 .26399 L
.88436 .26407 L
.88424 .26415 L
.88412 .26423 L
.88401 .26431 L
.88389 .26439 L
.88377 .26447 L
.88365 .26455 L
.88354 .26463 L
.88342 .26471 L
.8833 .26479 L
.88319 .26487 L
.88307 .26495 L
.88295 .26503 L
.88283 .26511 L
.88272 .26519 L
.8826 .26527 L
.88248 .26535 L
.88237 .26542 L
.88225 .2655 L
.88213 .26558 L
.88201 .26566 L
.8819 .26574 L
.88178 .26582 L
.88166 .26589 L
.88155 .26597 L
.88143 .26605 L
Mistroke
.88131 .26613 L
.8812 .2662 L
.88108 .26628 L
.88096 .26636 L
.88084 .26644 L
.88073 .26651 L
.88061 .26659 L
.88049 .26667 L
.88038 .26674 L
.88026 .26682 L
.88014 .2669 L
.88003 .26697 L
.87991 .26705 L
.87979 .26713 L
.87968 .2672 L
.87956 .26728 L
.87944 .26736 L
.87933 .26743 L
.87921 .26751 L
.87909 .26758 L
.87898 .26766 L
.87886 .26773 L
.87874 .26781 L
.87863 .26788 L
.87851 .26796 L
.87839 .26803 L
.87828 .26811 L
.87816 .26818 L
.87804 .26826 L
.87793 .26833 L
.87781 .26841 L
.87769 .26848 L
.87758 .26856 L
.87746 .26863 L
.87734 .26871 L
.87723 .26878 L
.87711 .26885 L
.87699 .26893 L
.87688 .269 L
.87676 .26907 L
.87664 .26915 L
.87653 .26922 L
.87641 .26929 L
.87629 .26937 L
.87618 .26944 L
.87606 .26951 L
.87595 .26959 L
.87583 .26966 L
.87571 .26973 L
.8756 .2698 L
Mistroke
.87548 .26988 L
.87536 .26995 L
.87525 .27002 L
.87513 .27009 L
.87502 .27017 L
.8749 .27024 L
.87478 .27031 L
.87467 .27038 L
.87455 .27045 L
.87444 .27052 L
.87432 .2706 L
.8742 .27067 L
.87409 .27074 L
.87397 .27081 L
.87386 .27088 L
.87374 .27095 L
.87362 .27102 L
.87351 .27109 L
.87339 .27116 L
.87328 .27123 L
.87316 .2713 L
.87304 .27137 L
.87293 .27144 L
.87281 .27151 L
.8727 .27158 L
.87258 .27165 L
.87247 .27172 L
.87235 .27179 L
.87223 .27186 L
.87212 .27193 L
.872 .272 L
.87189 .27207 L
.87177 .27214 L
.87166 .27221 L
.87154 .27228 L
.87142 .27235 L
.87131 .27242 L
.87119 .27248 L
.87108 .27255 L
.87096 .27262 L
.87085 .27269 L
.87073 .27276 L
.87062 .27283 L
.8705 .27289 L
.87039 .27296 L
.87027 .27303 L
.87016 .2731 L
.87004 .27316 L
.86993 .27323 L
.86981 .2733 L
Mistroke
.86969 .27337 L
.86958 .27343 L
.86946 .2735 L
.86935 .27357 L
.86923 .27363 L
.86912 .2737 L
.869 .27377 L
.86889 .27383 L
.86877 .2739 L
.86866 .27397 L
.86855 .27403 L
.86843 .2741 L
.86832 .27416 L
.8682 .27423 L
.86809 .2743 L
.86797 .27436 L
.86786 .27443 L
.86774 .27449 L
.86763 .27456 L
.86751 .27462 L
.8674 .27469 L
.86728 .27475 L
.86717 .27482 L
.86705 .27488 L
.86694 .27495 L
.86683 .27501 L
.86671 .27508 L
.8666 .27514 L
.86648 .27521 L
.86637 .27527 L
.86625 .27533 L
.86614 .2754 L
.86602 .27546 L
.86591 .27552 L
.8658 .27559 L
.86568 .27565 L
.86557 .27572 L
.86545 .27578 L
.86534 .27584 L
.86523 .27591 L
.86511 .27597 L
.865 .27603 L
.86488 .27609 L
.86477 .27616 L
.86466 .27622 L
.86454 .27628 L
.86443 .27634 L
.86431 .27641 L
.8642 .27647 L
.86409 .27653 L
Mistroke
.86397 .27659 L
.86386 .27665 L
.86375 .27672 L
.86363 .27678 L
.86352 .27684 L
.86341 .2769 L
.86329 .27696 L
.86318 .27702 L
.86306 .27708 L
.86295 .27715 L
.86284 .27721 L
.86272 .27727 L
.86261 .27733 L
.8625 .27739 L
.86239 .27745 L
.86227 .27751 L
.86216 .27757 L
.86205 .27763 L
.86193 .27769 L
.86182 .27775 L
.86171 .27781 L
.86159 .27787 L
.86148 .27793 L
.86137 .27799 L
.86125 .27805 L
.86114 .27811 L
.86103 .27817 L
.86092 .27823 L
.8608 .27829 L
.86069 .27834 L
.86058 .2784 L
.86047 .27846 L
.86035 .27852 L
.86024 .27858 L
.86013 .27864 L
.86002 .2787 L
.8599 .27875 L
.85979 .27881 L
.85968 .27887 L
.85957 .27893 L
.85945 .27899 L
.85934 .27904 L
.85923 .2791 L
.85912 .27916 L
.859 .27922 L
.85889 .27927 L
.85878 .27933 L
.85867 .27939 L
.85856 .27944 L
.85844 .2795 L
Mistroke
.85833 .27956 L
.85822 .27961 L
.85811 .27967 L
.858 .27973 L
.85788 .27978 L
.85777 .27984 L
.85766 .2799 L
.85755 .27995 L
.85744 .28001 L
.85733 .28006 L
.85721 .28012 L
.8571 .28018 L
.85699 .28023 L
.85688 .28029 L
.85677 .28034 L
.85666 .2804 L
.85655 .28045 L
.85643 .28051 L
.85632 .28056 L
.85621 .28062 L
.8561 .28067 L
.85599 .28073 L
.85588 .28078 L
.85577 .28083 L
.85566 .28089 L
.85555 .28094 L
.85544 .281 L
.85532 .28105 L
.85521 .2811 L
.8551 .28116 L
.85499 .28121 L
.85488 .28127 L
.85477 .28132 L
.85466 .28137 L
.85455 .28143 L
.85444 .28148 L
.85433 .28153 L
.85422 .28158 L
.85411 .28164 L
.854 .28169 L
.85389 .28174 L
.85378 .2818 L
.85367 .28185 L
.85356 .2819 L
.85345 .28195 L
.85334 .282 L
.85323 .28206 L
.85312 .28211 L
.85301 .28216 L
.8529 .28221 L
Mistroke
.85279 .28226 L
.85268 .28231 L
.85257 .28237 L
.85246 .28242 L
.85235 .28247 L
.85224 .28252 L
.85213 .28257 L
.85202 .28262 L
.85191 .28267 L
.8518 .28272 L
.85169 .28277 L
.85158 .28282 L
.85147 .28287 L
.85136 .28292 L
.85125 .28297 L
.85114 .28302 L
.85103 .28307 L
.85092 .28312 L
.85082 .28317 L
.85071 .28322 L
.8506 .28327 L
.85049 .28332 L
.85038 .28337 L
.85027 .28342 L
.85016 .28347 L
.85005 .28352 L
.84994 .28357 L
.84984 .28362 L
.84973 .28367 L
.84962 .28371 L
.84951 .28376 L
.8494 .28381 L
.84929 .28386 L
.84918 .28391 L
.84908 .28396 L
.84897 .284 L
.84886 .28405 L
.84875 .2841 L
.84864 .28415 L
.84853 .28419 L
.84843 .28424 L
.84832 .28429 L
.84821 .28434 L
.8481 .28438 L
.84799 .28443 L
.84789 .28448 L
.84778 .28453 L
.84767 .28457 L
.84756 .28462 L
.84746 .28467 L
Mistroke
.84735 .28471 L
.84724 .28476 L
.84713 .2848 L
.84703 .28485 L
.84692 .2849 L
.84681 .28494 L
.8467 .28499 L
.8466 .28503 L
.84649 .28508 L
.84638 .28513 L
.84628 .28517 L
.84617 .28522 L
.84606 .28526 L
.84595 .28531 L
.84585 .28535 L
.84574 .2854 L
.84563 .28544 L
.84553 .28549 L
.84542 .28553 L
.84531 .28558 L
.84521 .28562 L
.8451 .28566 L
.84499 .28571 L
.84489 .28575 L
.84478 .2858 L
.84467 .28584 L
.84457 .28588 L
.84446 .28593 L
.84436 .28597 L
.84425 .28602 L
.84414 .28606 L
.84404 .2861 L
.84393 .28615 L
.84383 .28619 L
.84372 .28623 L
.84361 .28627 L
.84351 .28632 L
.8434 .28636 L
.8433 .2864 L
.84319 .28645 L
.84309 .28649 L
.84298 .28653 L
.84287 .28657 L
.84277 .28661 L
.84266 .28666 L
.84256 .2867 L
.84245 .28674 L
.84235 .28678 L
.84224 .28682 L
.84214 .28687 L
Mistroke
.84203 .28691 L
.84193 .28695 L
.84182 .28699 L
.84172 .28703 L
.84161 .28707 L
.84151 .28711 L
.8414 .28715 L
.8413 .28719 L
.84119 .28723 L
.84109 .28728 L
.84099 .28732 L
.84088 .28736 L
.84078 .2874 L
.84067 .28744 L
.84057 .28748 L
.84046 .28752 L
.84036 .28756 L
.84026 .2876 L
.84015 .28764 L
.84005 .28768 L
.83994 .28771 L
.83984 .28775 L
.83974 .28779 L
.83963 .28783 L
.83953 .28787 L
.83942 .28791 L
.83932 .28795 L
.83922 .28799 L
.83911 .28803 L
.83901 .28807 L
.83891 .2881 L
.8388 .28814 L
.8387 .28818 L
.8386 .28822 L
.83849 .28826 L
.83839 .28829 L
.83829 .28833 L
.83818 .28837 L
.83808 .28841 L
.83798 .28845 L
.83788 .28848 L
.83777 .28852 L
.83767 .28856 L
.83757 .28859 L
.83747 .28863 L
.83736 .28867 L
.83726 .28871 L
.83716 .28874 L
.83706 .28878 L
.83695 .28882 L
Mistroke
.83685 .28885 L
.83675 .28889 L
.83665 .28893 L
.83654 .28896 L
.83644 .289 L
.83634 .28903 L
.83624 .28907 L
.83614 .28911 L
.83603 .28914 L
.83593 .28918 L
.83583 .28921 L
.83573 .28925 L
.83563 .28928 L
.83553 .28932 L
.83542 .28935 L
.83532 .28939 L
.83522 .28942 L
.83512 .28946 L
.83502 .28949 L
.83492 .28953 L
.83482 .28956 L
.83472 .2896 L
.83462 .28963 L
.83451 .28967 L
.83441 .2897 L
.83431 .28973 L
.83421 .28977 L
.83411 .2898 L
.83401 .28984 L
.83391 .28987 L
.83381 .2899 L
.83371 .28994 L
.83361 .28997 L
.83351 .29 L
.83341 .29004 L
.83331 .29007 L
.83321 .2901 L
.83311 .29014 L
.83301 .29017 L
.83291 .2902 L
.83281 .29023 L
.83271 .29027 L
.83261 .2903 L
.83251 .29033 L
.83241 .29036 L
.83231 .2904 L
.83221 .29043 L
.83211 .29046 L
.83201 .29049 L
.83191 .29052 L
Mistroke
.83181 .29055 L
.83171 .29059 L
.83161 .29062 L
.83151 .29065 L
.83142 .29068 L
.83132 .29071 L
.83122 .29074 L
.83112 .29077 L
.83102 .2908 L
.83092 .29084 L
.83082 .29087 L
.83072 .2909 L
.83063 .29093 L
.83053 .29096 L
.83043 .29099 L
.83033 .29102 L
.83023 .29105 L
.83013 .29108 L
.83004 .29111 L
.82994 .29114 L
.82984 .29117 L
.82974 .2912 L
.82964 .29123 L
.82955 .29126 L
.82945 .29129 L
.82935 .29132 L
.82925 .29135 L
.82915 .29137 L
.82906 .2914 L
.82896 .29143 L
.82886 .29146 L
.82876 .29149 L
.82867 .29152 L
.82857 .29155 L
.82847 .29158 L
.82838 .2916 L
.82828 .29163 L
.82818 .29166 L
.82808 .29169 L
.82799 .29172 L
.82789 .29174 L
.82779 .29177 L
.8277 .2918 L
.8276 .29183 L
.8275 .29186 L
.82741 .29188 L
.82731 .29191 L
.82721 .29194 L
.82712 .29196 L
.82702 .29199 L
Mistroke
.82693 .29202 L
.82683 .29205 L
.82673 .29207 L
.82664 .2921 L
.82654 .29213 L
.82645 .29215 L
.82635 .29218 L
.82625 .2922 L
.82616 .29223 L
.82606 .29226 L
.82597 .29228 L
.82587 .29231 L
.82578 .29234 L
.82568 .29236 L
.82559 .29239 L
.82549 .29241 L
.8254 .29244 L
.8253 .29246 L
.82521 .29249 L
.82511 .29251 L
.82502 .29254 L
.82492 .29256 L
.82483 .29259 L
.82473 .29261 L
.82464 .29264 L
.82454 .29266 L
.82445 .29269 L
.82435 .29271 L
.82426 .29274 L
.82417 .29276 L
.82407 .29279 L
.82398 .29281 L
.82388 .29283 L
.82379 .29286 L
.8237 .29288 L
.8236 .29291 L
.82351 .29293 L
.82341 .29295 L
.82332 .29298 L
.82323 .293 L
.82313 .29302 L
.82304 .29305 L
.82295 .29307 L
.82285 .29309 L
.82276 .29312 L
.82267 .29314 L
.82257 .29316 L
.82248 .29318 L
.82239 .29321 L
.82229 .29323 L
Mistroke
.8222 .29325 L
.82211 .29327 L
.82202 .2933 L
.82192 .29332 L
.82183 .29334 L
.82174 .29336 L
.82165 .29338 L
.82155 .29341 L
.82146 .29343 L
.82137 .29345 L
.82128 .29347 L
.82118 .29349 L
.82109 .29351 L
.821 .29353 L
.82091 .29356 L
.82082 .29358 L
.82072 .2936 L
.82063 .29362 L
.82054 .29364 L
.82045 .29366 L
.82036 .29368 L
.82027 .2937 L
.82018 .29372 L
.82008 .29374 L
.81999 .29376 L
.8199 .29378 L
.81981 .2938 L
.81972 .29382 L
.81963 .29384 L
.81954 .29386 L
.81945 .29388 L
.81936 .2939 L
.81927 .29392 L
.81917 .29394 L
.81908 .29396 L
.81899 .29398 L
.8189 .294 L
.81881 .29402 L
.81872 .29404 L
.81863 .29406 L
.81854 .29408 L
.81845 .29409 L
.81836 .29411 L
.81827 .29413 L
.81818 .29415 L
.81809 .29417 L
.818 .29419 L
.81791 .29421 L
.81782 .29422 L
.81773 .29424 L
Mistroke
.81765 .29426 L
.81756 .29428 L
.81747 .2943 L
.81738 .29431 L
.81729 .29433 L
.8172 .29435 L
.81711 .29437 L
.81702 .29438 L
.81693 .2944 L
.81684 .29442 L
.81675 .29443 L
.81667 .29445 L
.81658 .29447 L
.81649 .29449 L
.8164 .2945 L
.81631 .29452 L
.81622 .29454 L
.81614 .29455 L
.81605 .29457 L
.81596 .29459 L
.81587 .2946 L
.81578 .29462 L
.8157 .29463 L
.81561 .29465 L
.81552 .29467 L
.81543 .29468 L
.81534 .2947 L
.81526 .29471 L
.81517 .29473 L
.81508 .29474 L
.81499 .29476 L
.81491 .29478 L
.81482 .29479 L
.81473 .29481 L
.81465 .29482 L
.81456 .29484 L
.81447 .29485 L
.81439 .29487 L
.8143 .29488 L
.81421 .2949 L
.81412 .29491 L
.81404 .29492 L
.81395 .29494 L
.81387 .29495 L
.81378 .29497 L
.81369 .29498 L
.81361 .295 L
.81352 .29501 L
.81343 .29502 L
.81335 .29504 L
Mistroke
.81326 .29505 L
.81318 .29506 L
.81309 .29508 L
.81301 .29509 L
.81292 .29511 L
.81283 .29512 L
.81275 .29513 L
.81266 .29515 L
.81258 .29516 L
.81249 .29517 L
.81241 .29518 L
.81232 .2952 L
.81224 .29521 L
.81215 .29522 L
.81207 .29524 L
.81198 .29525 L
.8119 .29526 L
.81181 .29527 L
.81173 .29528 L
.81164 .2953 L
.81156 .29531 L
.81148 .29532 L
.81139 .29533 L
.81131 .29534 L
.81122 .29536 L
.81114 .29537 L
.81105 .29538 L
.81097 .29539 L
.81089 .2954 L
.8108 .29541 L
.81072 .29543 L
.81064 .29544 L
.81055 .29545 L
.81047 .29546 L
.81038 .29547 L
.8103 .29548 L
.81022 .29549 L
.81013 .2955 L
.81005 .29551 L
.80997 .29552 L
.80989 .29553 L
.8098 .29554 L
.80972 .29555 L
.80964 .29556 L
.80955 .29558 L
.80947 .29559 L
.80939 .2956 L
.80931 .29561 L
.80922 .29561 L
.80914 .29562 L
Mistroke
.80906 .29563 L
.80898 .29564 L
.8089 .29565 L
.80881 .29566 L
.80873 .29567 L
.80865 .29568 L
.80857 .29569 L
.80849 .2957 L
.8084 .29571 L
.80832 .29572 L
.80824 .29573 L
.80816 .29574 L
.80808 .29574 L
.808 .29575 L
.80792 .29576 L
.80783 .29577 L
.80775 .29578 L
.80767 .29579 L
.80759 .29579 L
.80751 .2958 L
.80743 .29581 L
.80735 .29582 L
.80727 .29583 L
.80719 .29583 L
.80711 .29584 L
.80703 .29585 L
.80695 .29586 L
.80687 .29587 L
.80679 .29587 L
.80671 .29588 L
.80663 .29589 L
.80655 .29589 L
.80647 .2959 L
.80639 .29591 L
.80631 .29592 L
.80623 .29592 L
.80615 .29593 L
.80607 .29594 L
.80599 .29594 L
.80591 .29595 L
.80583 .29596 L
.80575 .29596 L
.80567 .29597 L
.80559 .29598 L
.80551 .29598 L
.80543 .29599 L
.80535 .29599 L
.80528 .296 L
.8052 .29601 L
.80512 .29601 L
Mistroke
.80504 .29602 L
.80496 .29602 L
.80488 .29603 L
.8048 .29603 L
.80473 .29604 L
.80465 .29604 L
.80457 .29605 L
.80449 .29606 L
.80441 .29606 L
.80434 .29607 L
.80426 .29607 L
.80418 .29608 L
.8041 .29608 L
.80403 .29609 L
.80395 .29609 L
.80387 .29609 L
.80379 .2961 L
.80372 .2961 L
.80364 .29611 L
.80356 .29611 L
.80348 .29612 L
.80341 .29612 L
.80333 .29612 L
.80325 .29613 L
.80318 .29613 L
.8031 .29614 L
.80302 .29614 L
.80295 .29614 L
.80287 .29615 L
.80279 .29615 L
.80272 .29615 L
.80264 .29616 L
.80257 .29616 L
.80249 .29616 L
.80241 .29617 L
.80234 .29617 L
.80226 .29617 L
.80219 .29618 L
.80211 .29618 L
.80203 .29618 L
.80196 .29619 L
.80188 .29619 L
.80181 .29619 L
.80173 .29619 L
.80166 .2962 L
.80158 .2962 L
.80151 .2962 L
.80143 .2962 L
.80136 .2962 L
.80128 .29621 L
Mistroke
.80121 .29621 L
.80113 .29621 L
.80106 .29621 L
.80098 .29621 L
.80091 .29622 L
.80083 .29622 L
.80076 .29622 L
.80069 .29622 L
.80061 .29622 L
.80054 .29622 L
.80046 .29623 L
.80039 .29623 L
.80032 .29623 L
.80024 .29623 L
.80017 .29623 L
.80009 .29623 L
.80002 .29623 L
.79995 .29623 L
.79987 .29623 L
.7998 .29623 L
.79973 .29623 L
.79965 .29623 L
.79958 .29623 L
.79951 .29624 L
.79943 .29624 L
.79936 .29624 L
.79929 .29624 L
.79922 .29624 L
.79914 .29624 L
.79907 .29624 L
.799 .29624 L
.79893 .29624 L
.79885 .29624 L
.79878 .29624 L
.79871 .29623 L
.79864 .29623 L
.79856 .29623 L
.79849 .29623 L
.79842 .29623 L
.79835 .29623 L
.79828 .29623 L
.79821 .29623 L
.79813 .29623 L
.79806 .29623 L
.79799 .29623 L
.79792 .29623 L
.79785 .29622 L
.79778 .29622 L
.79771 .29622 L
.79763 .29622 L
Mistroke
.79756 .29622 L
.79749 .29622 L
.79742 .29622 L
.79735 .29621 L
.79728 .29621 L
.79721 .29621 L
.79714 .29621 L
.79707 .29621 L
.797 .2962 L
.79693 .2962 L
.79686 .2962 L
.79679 .2962 L
.79672 .29619 L
.79665 .29619 L
.79658 .29619 L
.79651 .29619 L
.79644 .29618 L
.79637 .29618 L
.7963 .29618 L
.79623 .29618 L
.79616 .29617 L
.79609 .29617 L
.79602 .29617 L
.79595 .29616 L
.79588 .29616 L
.79581 .29616 L
.79574 .29615 L
.79568 .29615 L
.79561 .29615 L
.79554 .29614 L
.79547 .29614 L
.7954 .29614 L
.79533 .29613 L
.79526 .29613 L
.79519 .29613 L
.79513 .29612 L
.79506 .29612 L
.79499 .29611 L
.79492 .29611 L
.79485 .29611 L
.79479 .2961 L
.79472 .2961 L
.79465 .29609 L
.79458 .29609 L
.79451 .29608 L
.79445 .29608 L
.79438 .29607 L
.79431 .29607 L
.79424 .29606 L
.79418 .29606 L
Mistroke
.79411 .29605 L
.79404 .29605 L
.79398 .29604 L
.79391 .29604 L
.79384 .29603 L
.79378 .29603 L
.79371 .29602 L
.79364 .29602 L
.79358 .29601 L
.79351 .29601 L
.79344 .296 L
.79338 .296 L
.79331 .29599 L
.79324 .29598 L
.79318 .29598 L
.79311 .29597 L
.79305 .29597 L
.79298 .29596 L
.79291 .29596 L
.79285 .29595 L
.79278 .29594 L
.79272 .29594 L
.79265 .29593 L
.79259 .29592 L
.79252 .29592 L
.79246 .29591 L
.79239 .2959 L
.79233 .2959 L
.79226 .29589 L
.7922 .29588 L
.79213 .29588 L
.79207 .29587 L
.792 .29586 L
.79194 .29586 L
.79187 .29585 L
.79181 .29584 L
.79174 .29584 L
.79168 .29583 L
.79161 .29582 L
.79155 .29581 L
.79149 .29581 L
.79142 .2958 L
.79136 .29579 L
.79129 .29578 L
.79123 .29578 L
.79117 .29577 L
.7911 .29576 L
.79104 .29575 L
.79098 .29574 L
.79091 .29574 L
Mistroke
.79085 .29573 L
.79079 .29572 L
.79072 .29571 L
.79066 .2957 L
.7906 .29569 L
.79053 .29569 L
.79047 .29568 L
.79041 .29567 L
.79034 .29566 L
.79028 .29565 L
.79022 .29564 L
.79016 .29563 L
.79009 .29563 L
.79003 .29562 L
.78997 .29561 L
.78991 .2956 L
.78985 .29559 L
.78978 .29558 L
.78972 .29557 L
.78966 .29556 L
.7896 .29555 L
.78954 .29554 L
.78947 .29553 L
.78941 .29552 L
.78935 .29551 L
.78929 .29551 L
.78923 .2955 L
.78917 .29549 L
.78911 .29548 L
.78904 .29547 L
.78898 .29546 L
.78892 .29545 L
.78886 .29544 L
.7888 .29543 L
.78874 .29542 L
.78868 .29541 L
.78862 .2954 L
.78856 .29539 L
.7885 .29538 L
.78844 .29536 L
.78838 .29535 L
.78832 .29534 L
.78826 .29533 L
.7882 .29532 L
.78814 .29531 L
.78808 .2953 L
.78802 .29529 L
.78796 .29528 L
.7879 .29527 L
.78784 .29526 L
Mistroke
.78778 .29525 L
.78772 .29523 L
.78766 .29522 L
.7876 .29521 L
.78754 .2952 L
.78748 .29519 L
.78742 .29518 L
.78736 .29517 L
.78731 .29516 L
.78725 .29514 L
.78719 .29513 L
.78713 .29512 L
.78707 .29511 L
.78701 .2951 L
.78695 .29508 L
.78689 .29507 L
.78684 .29506 L
.78678 .29505 L
.78672 .29504 L
.78666 .29502 L
.7866 .29501 L
.78655 .295 L
.78649 .29499 L
.78643 .29498 L
.78637 .29496 L
.78632 .29495 L
.78626 .29494 L
.7862 .29493 L
.78614 .29491 L
.78609 .2949 L
.78603 .29489 L
.78597 .29487 L
.78591 .29486 L
.78586 .29485 L
.7858 .29484 L
.78574 .29482 L
.78569 .29481 L
.78563 .2948 L
.78557 .29478 L
.78552 .29477 L
.78546 .29476 L
.7854 .29474 L
.78535 .29473 L
.78529 .29472 L
.78523 .2947 L
.78518 .29469 L
.78512 .29468 L
.78507 .29466 L
.78501 .29465 L
.78496 .29463 L
Mistroke
.7849 .29462 L
.78484 .29461 L
.78479 .29459 L
.78473 .29458 L
.78468 .29456 L
.78462 .29455 L
.78457 .29454 L
.78451 .29452 L
.78446 .29451 L
.7844 .29449 L
.78435 .29448 L
.78429 .29446 L
.78424 .29445 L
.78418 .29443 L
.78413 .29442 L
.78407 .29441 L
.78402 .29439 L
.78396 .29438 L
.78391 .29436 L
.78386 .29435 L
.7838 .29433 L
.78375 .29432 L
.78369 .2943 L
.78364 .29429 L
.78359 .29427 L
.78353 .29426 L
.78348 .29424 L
.78342 .29423 L
.78337 .29421 L
.78332 .29419 L
.78326 .29418 L
.78321 .29416 L
.78316 .29415 L
.7831 .29413 L
.78305 .29412 L
.783 .2941 L
.78294 .29409 L
.78289 .29407 L
.78284 .29405 L
.78279 .29404 L
.78273 .29402 L
.78268 .29401 L
.78263 .29399 L
.78258 .29397 L
.78252 .29396 L
.78247 .29394 L
.78242 .29392 L
.78237 .29391 L
.78231 .29389 L
.78226 .29388 L
Mistroke
.78221 .29386 L
.78216 .29384 L
.78211 .29383 L
.78205 .29381 L
.782 .29379 L
.78195 .29378 L
.7819 .29376 L
.78185 .29374 L
.7818 .29373 L
.78175 .29371 L
.78169 .29369 L
.78164 .29367 L
.78159 .29366 L
.78154 .29364 L
.78149 .29362 L
.78144 .29361 L
.78139 .29359 L
.78134 .29357 L
.78129 .29355 L
.78124 .29354 L
.78119 .29352 L
.78114 .2935 L
.78109 .29348 L
.78104 .29347 L
.78099 .29345 L
.78094 .29343 L
.78089 .29341 L
.78084 .2934 L
.78079 .29338 L
.78074 .29336 L
.78069 .29334 L
.78064 .29332 L
.78059 .29331 L
.78054 .29329 L
.78049 .29327 L
.78044 .29325 L
.78039 .29323 L
.78034 .29321 L
.78029 .2932 L
.78024 .29318 L
.78019 .29316 L
.78015 .29314 L
.7801 .29312 L
.78005 .2931 L
.78 .29308 L
.77995 .29307 L
.7799 .29305 L
.77985 .29303 L
.77981 .29301 L
.77976 .29299 L
Mistroke
.77971 .29297 L
.77966 .29295 L
.77961 .29293 L
.77956 .29292 L
.77952 .2929 L
.77947 .29288 L
.77942 .29286 L
.77937 .29284 L
.77933 .29282 L
.77928 .2928 L
.77923 .29278 L
.77918 .29276 L
.77914 .29274 L
.77909 .29272 L
.77904 .2927 L
.77899 .29268 L
.77895 .29266 L
.7789 .29264 L
.77885 .29262 L
.77881 .2926 L
.77876 .29258 L
.77871 .29256 L
.77867 .29254 L
.77862 .29252 L
.77857 .2925 L
.77853 .29248 L
.77848 .29246 L
.77844 .29244 L
.77839 .29242 L
.77834 .2924 L
.7783 .29238 L
.77825 .29236 L
.77821 .29234 L
.77816 .29232 L
.77811 .2923 L
.77807 .29228 L
.77802 .29226 L
.77798 .29224 L
.77793 .29222 L
.77789 .2922 L
.77784 .29218 L
.7778 .29216 L
.77775 .29214 L
.77771 .29212 L
.77766 .2921 L
.77762 .29207 L
.77757 .29205 L
.77753 .29203 L
.77748 .29201 L
.77744 .29199 L
Mistroke
.77739 .29197 L
.77735 .29195 L
.7773 .29193 L
.77726 .29191 L
.77722 .29188 L
.77717 .29186 L
.77713 .29184 L
.77708 .29182 L
.77704 .2918 L
.777 .29178 L
.77695 .29176 L
.77691 .29173 L
.77687 .29171 L
.77682 .29169 L
.77678 .29167 L
.77673 .29165 L
.77669 .29163 L
.77665 .2916 L
.7766 .29158 L
.77656 .29156 L
.77652 .29154 L
.77648 .29152 L
.77643 .29149 L
.77639 .29147 L
.77635 .29145 L
.7763 .29143 L
.77626 .29141 L
.77622 .29138 L
.77618 .29136 L
.77613 .29134 L
.77609 .29132 L
.77605 .29129 L
.77601 .29127 L
.77597 .29125 L
.77592 .29123 L
.77588 .2912 L
.77584 .29118 L
.7758 .29116 L
.77576 .29114 L
.77571 .29111 L
.77567 .29109 L
.77563 .29107 L
.77559 .29104 L
.77555 .29102 L
.77551 .291 L
.77547 .29098 L
.77542 .29095 L
.77538 .29093 L
.77534 .29091 L
.7753 .29088 L
Mistroke
.77526 .29086 L
.77522 .29084 L
.77518 .29081 L
.77514 .29079 L
.7751 .29077 L
.77506 .29074 L
.77502 .29072 L
.77498 .2907 L
.77494 .29067 L
.7749 .29065 L
.77486 .29063 L
.77482 .2906 L
.77478 .29058 L
.77474 .29055 L
.7747 .29053 L
.77466 .29051 L
.77462 .29048 L
.77458 .29046 L
.77454 .29044 L
.7745 .29041 L
.77446 .29039 L
.77442 .29036 L
.77438 .29034 L
.77434 .29032 L
.7743 .29029 L
.77426 .29027 L
.77422 .29024 L
.77418 .29022 L
.77415 .2902 L
.77411 .29017 L
.77407 .29015 L
.77403 .29012 L
.77399 .2901 L
.77395 .29007 L
.77391 .29005 L
.77388 .29002 L
.77384 .29 L
.7738 .28998 L
.77376 .28995 L
.77372 .28993 L
.77368 .2899 L
.77365 .28988 L
.77361 .28985 L
.77357 .28983 L
.77353 .2898 L
.7735 .28978 L
.77346 .28975 L
.77342 .28973 L
.77338 .2897 L
.77335 .28968 L
Mistroke
.77331 .28965 L
.77327 .28963 L
.77323 .2896 L
.7732 .28958 L
.77316 .28955 L
.77312 .28953 L
.77309 .2895 L
.77305 .28948 L
.77301 .28945 L
.77298 .28943 L
.77294 .2894 L
.7729 .28937 L
.77287 .28935 L
.77283 .28932 L
.77279 .2893 L
.77276 .28927 L
.77272 .28925 L
.77268 .28922 L
.77265 .2892 L
.77261 .28917 L
.77258 .28914 L
.77254 .28912 L
.77251 .28909 L
.77247 .28907 L
.77243 .28904 L
.7724 .28901 L
.77236 .28899 L
.77233 .28896 L
.77229 .28894 L
.77226 .28891 L
.77222 .28888 L
.77219 .28886 L
.77215 .28883 L
.77212 .28881 L
.77208 .28878 L
.77205 .28875 L
.77201 .28873 L
.77198 .2887 L
.77194 .28867 L
.77191 .28865 L
.77187 .28862 L
.77184 .2886 L
.7718 .28857 L
.77177 .28854 L
.77174 .28852 L
.7717 .28849 L
.77167 .28846 L
.77163 .28844 L
.7716 .28841 L
.77157 .28838 L
Mistroke
.77153 .28836 L
.7715 .28833 L
.77146 .2883 L
.77143 .28828 L
.7714 .28825 L
.77136 .28822 L
.77133 .2882 L
.7713 .28817 L
.77126 .28814 L
.77123 .28811 L
.7712 .28809 L
.77116 .28806 L
.77113 .28803 L
.7711 .28801 L
.77107 .28798 L
.77103 .28795 L
.771 .28792 L
.77097 .2879 L
.77093 .28787 L
.7709 .28784 L
.77087 .28781 L
.77084 .28779 L
.77081 .28776 L
.77077 .28773 L
.77074 .28771 L
.77071 .28768 L
.77068 .28765 L
.77064 .28762 L
.77061 .2876 L
.77058 .28757 L
.77055 .28754 L
.77052 .28751 L
.77049 .28748 L
.77045 .28746 L
.77042 .28743 L
.77039 .2874 L
.77036 .28737 L
.77033 .28735 L
.7703 .28732 L
.77027 .28729 L
.77023 .28726 L
.7702 .28723 L
.77017 .28721 L
.77014 .28718 L
.77011 .28715 L
.77008 .28712 L
.77005 .28709 L
.77002 .28706 L
.76999 .28704 L
.76996 .28701 L
Mistroke
.76993 .28698 L
.7699 .28695 L
.76987 .28692 L
.76984 .2869 L
.76981 .28687 L
.76978 .28684 L
.76975 .28681 L
.76972 .28678 L
.76969 .28675 L
.76966 .28672 L
.76963 .2867 L
.7696 .28667 L
.76957 .28664 L
.76954 .28661 L
.76951 .28658 L
.76948 .28655 L
.76945 .28652 L
.76942 .2865 L
.76939 .28647 L
.76936 .28644 L
.76933 .28641 L
.7693 .28638 L
.76928 .28635 L
.76925 .28632 L
.76922 .28629 L
.76919 .28626 L
.76916 .28624 L
.76913 .28621 L
.7691 .28618 L
.76907 .28615 L
.76905 .28612 L
.76902 .28609 L
.76899 .28606 L
.76896 .28603 L
.76893 .286 L
.7689 .28597 L
.76888 .28594 L
.76885 .28592 L
.76882 .28589 L
.76879 .28586 L
.76877 .28583 L
.76874 .2858 L
.76871 .28577 L
.76868 .28574 L
.76866 .28571 L
.76863 .28568 L
.7686 .28565 L
.76857 .28562 L
.76855 .28559 L
.76852 .28556 L
Mistroke
.76849 .28553 L
.76846 .2855 L
.76844 .28547 L
.76841 .28544 L
.76838 .28541 L
.76836 .28538 L
.76833 .28535 L
.7683 .28532 L
.76828 .2853 L
.76825 .28527 L
.76822 .28524 L
.7682 .28521 L
.76817 .28518 L
.76815 .28515 L
.76812 .28512 L
.76809 .28509 L
.76807 .28506 L
.76804 .28503 L
.76801 .285 L
.76799 .28497 L
.76796 .28494 L
.76794 .28491 L
.76791 .28488 L
.76789 .28485 L
.76786 .28482 L
.76783 .28478 L
.76781 .28475 L
.76778 .28472 L
.76776 .28469 L
.76773 .28466 L
.76771 .28463 L
.76768 .2846 L
.76766 .28457 L
.76763 .28454 L
.76761 .28451 L
.76758 .28448 L
.76756 .28445 L
.76753 .28442 L
.76751 .28439 L
.76748 .28436 L
.76746 .28433 L
.76744 .2843 L
.76741 .28427 L
.76739 .28424 L
.76736 .28421 L
.76734 .28418 L
.76731 .28415 L
.76729 .28411 L
.76727 .28408 L
.76724 .28405 L
Mistroke
.76722 .28402 L
.76719 .28399 L
.76717 .28396 L
.76715 .28393 L
.76712 .2839 L
.7671 .28387 L
.76708 .28384 L
.76705 .28381 L
.76703 .28378 L
.76701 .28374 L
.76698 .28371 L
.76696 .28368 L
.76694 .28365 L
.76691 .28362 L
.76689 .28359 L
.76687 .28356 L
.76685 .28353 L
.76682 .2835 L
.7668 .28346 L
.76678 .28343 L
.76675 .2834 L
.76673 .28337 L
.76671 .28334 L
.76669 .28331 L
.76666 .28328 L
.76664 .28325 L
.76662 .28321 L
.7666 .28318 L
.76658 .28315 L
.76655 .28312 L
.76653 .28309 L
.76651 .28306 L
.76649 .28303 L
.76647 .28299 L
.76644 .28296 L
.76642 .28293 L
.7664 .2829 L
.76638 .28287 L
.76636 .28284 L
.76634 .28281 L
.76631 .28277 L
.76629 .28274 L
.76627 .28271 L
.76625 .28268 L
.76623 .28265 L
.76621 .28262 L
.76619 .28258 L
.76617 .28255 L
.76615 .28252 L
.76613 .28249 L
Mistroke
.7661 .28246 L
.76608 .28242 L
.76606 .28239 L
.76604 .28236 L
.76602 .28233 L
.766 .2823 L
.76598 .28227 L
.76596 .28223 L
.76594 .2822 L
.76592 .28217 L
.7659 .28214 L
.76588 .28211 L
.76586 .28207 L
.76584 .28204 L
.76582 .28201 L
.7658 .28198 L
.76578 .28195 L
.76576 .28191 L
.76574 .28188 L
.76572 .28185 L
.7657 .28182 L
.76568 .28178 L
.76566 .28175 L
.76564 .28172 L
.76562 .28169 L
.76561 .28166 L
.76559 .28162 L
.76557 .28159 L
.76555 .28156 L
.76553 .28153 L
.76551 .28149 L
.76549 .28146 L
.76547 .28143 L
.76545 .2814 L
.76543 .28136 L
.76542 .28133 L
.7654 .2813 L
.76538 .28127 L
.76536 .28123 L
.76534 .2812 L
.76532 .28117 L
.76531 .28114 L
.76529 .2811 L
.76527 .28107 L
.76525 .28104 L
.76523 .28101 L
.76522 .28097 L
.7652 .28094 L
.76518 .28091 L
.76516 .28088 L
Mistroke
.76514 .28084 L
.76513 .28081 L
.76511 .28078 L
.76509 .28075 L
.76507 .28071 L
.76506 .28068 L
.76504 .28065 L
.76502 .28061 L
.765 .28058 L
.76499 .28055 L
.76497 .28052 L
.76495 .28048 L
.76494 .28045 L
.76492 .28042 L
.7649 .28038 L
.76488 .28035 L
.76487 .28032 L
.76485 .28029 L
.76483 .28025 L
.76482 .28022 L
.7648 .28019 L
.76478 .28015 L
.76477 .28012 L
.76475 .28009 L
.76474 .28005 L
.76472 .28002 L
.7647 .27999 L
.76469 .27996 L
.76467 .27992 L
.76466 .27989 L
.76464 .27986 L
.76462 .27982 L
.76461 .27979 L
.76459 .27976 L
.76458 .27972 L
.76456 .27969 L
.76454 .27966 L
.76453 .27962 L
.76451 .27959 L
.7645 .27956 L
.76448 .27952 L
.76447 .27949 L
.76445 .27946 L
.76444 .27942 L
.76442 .27939 L
.76441 .27936 L
.76439 .27932 L
.76438 .27929 L
.76436 .27926 L
.76435 .27922 L
Mistroke
.76433 .27919 L
.76432 .27916 L
.7643 .27912 L
.76429 .27909 L
.76427 .27906 L
.76426 .27902 L
.76424 .27899 L
.76423 .27896 L
.76422 .27892 L
.7642 .27889 L
.76419 .27886 L
.76417 .27882 L
.76416 .27879 L
.76414 .27876 L
.76413 .27872 L
.76412 .27869 L
.7641 .27865 L
.76409 .27862 L
.76407 .27859 L
.76406 .27855 L
.76405 .27852 L
.76403 .27849 L
.76402 .27845 L
.76401 .27842 L
.76399 .27839 L
.76398 .27835 L
.76397 .27832 L
.76395 .27828 L
.76394 .27825 L
.76393 .27822 L
.76391 .27818 L
.7639 .27815 L
.76389 .27812 L
.76387 .27808 L
.76386 .27805 L
.76385 .27801 L
.76384 .27798 L
.76382 .27795 L
.76381 .27791 L
.7638 .27788 L
.76379 .27785 L
.76377 .27781 L
.76376 .27778 L
.76375 .27774 L
.76374 .27771 L
.76372 .27768 L
.76371 .27764 L
.7637 .27761 L
.76369 .27757 L
.76367 .27754 L
Mistroke
.76366 .27751 L
.76365 .27747 L
.76364 .27744 L
.76363 .2774 L
.76361 .27737 L
.7636 .27734 L
.76359 .2773 L
.76358 .27727 L
.76357 .27723 L
.76356 .2772 L
.76355 .27717 L
.76353 .27713 L
.76352 .2771 L
.76351 .27706 L
.7635 .27703 L
.76349 .27699 L
.76348 .27696 L
.76347 .27693 L
.76346 .27689 L
.76344 .27686 L
.76343 .27682 L
.76342 .27679 L
.76341 .27676 L
.7634 .27672 L
.76339 .27669 L
.76338 .27665 L
.76337 .27662 L
.76336 .27658 L
.76335 .27655 L
.76334 .27652 L
.76333 .27648 L
.76332 .27645 L
.76331 .27641 L
.7633 .27638 L
.76329 .27634 L
.76328 .27631 L
.76327 .27628 L
.76326 .27624 L
.76325 .27621 L
.76324 .27617 L
.76323 .27614 L
.76322 .2761 L
.76321 .27607 L
.7632 .27604 L
.76319 .276 L
.76318 .27597 L
.76317 .27593 L
.76316 .2759 L
.76315 .27586 L
.76314 .27583 L
Mistroke
.76313 .27579 L
.76312 .27576 L
.76311 .27573 L
.7631 .27569 L
.76309 .27566 L
.76308 .27562 L
.76308 .27559 L
.76307 .27555 L
.76306 .27552 L
.76305 .27548 L
.76304 .27545 L
.76303 .27542 L
.76302 .27538 L
.76301 .27535 L
.76301 .27531 L
.763 .27528 L
.76299 .27524 L
.76298 .27521 L
.76297 .27517 L
.76296 .27514 L
.76296 .2751 L
.76295 .27507 L
.76294 .27504 L
.76293 .275 L
.76292 .27497 L
.76291 .27493 L
.76291 .2749 L
.7629 .27486 L
.76289 .27483 L
.76288 .27479 L
.76288 .27476 L
.76287 .27472 L
.76286 .27469 L
.76285 .27465 L
.76284 .27462 L
.76284 .27459 L
.76283 .27455 L
.76282 .27452 L
.76282 .27448 L
.76281 .27445 L
.7628 .27441 L
.76279 .27438 L
.76279 .27434 L
.76278 .27431 L
.76277 .27427 L
.76277 .27424 L
.76276 .2742 L
.76275 .27417 L
.76274 .27413 L
.76274 .2741 L
Mistroke
.76273 .27406 L
.76272 .27403 L
.76272 .27399 L
.76271 .27396 L
.7627 .27393 L
.7627 .27389 L
.76269 .27386 L
.76269 .27382 L
.76268 .27379 L
.76267 .27375 L
.76267 .27372 L
.76266 .27368 L
.76265 .27365 L
.76265 .27361 L
.76264 .27358 L
.76264 .27354 L
.76263 .27351 L
.76262 .27347 L
.76262 .27344 L
.76261 .2734 L
.76261 .27337 L
.7626 .27333 L
.7626 .2733 L
.76259 .27326 L
.76258 .27323 L
.76258 .27319 L
.76257 .27316 L
.76257 .27312 L
.76256 .27309 L
.76256 .27305 L
.76255 .27302 L
.76255 .27298 L
.76254 .27295 L
.76254 .27291 L
.76253 .27288 L
.76253 .27285 L
.76252 .27281 L
.76252 .27278 L
.76251 .27274 L
.76251 .27271 L
.7625 .27267 L
.7625 .27264 L
.76249 .2726 L
.76249 .27257 L
.76248 .27253 L
.76248 .2725 L
.76247 .27246 L
.76247 .27243 L
.76247 .27239 L
.76246 .27236 L
Mistroke
.76246 .27232 L
.76245 .27229 L
.76245 .27225 L
.76244 .27222 L
.76244 .27218 L
.76244 .27215 L
.76243 .27211 L
.76243 .27208 L
.76243 .27204 L
.76242 .27201 L
.76242 .27197 L
.76241 .27194 L
.76241 .2719 L
.76241 .27187 L
.7624 .27183 L
.7624 .2718 L
.7624 .27176 L
.76239 .27173 L
.76239 .27169 L
.76239 .27166 L
.76238 .27162 L
.76238 .27159 L
.76238 .27155 L
.76237 .27152 L
.76237 .27148 L
.76237 .27145 L
.76236 .27141 L
.76236 .27138 L
.76236 .27134 L
.76235 .27131 L
.76235 .27127 L
.76235 .27124 L
.76235 .2712 L
.76234 .27117 L
.76234 .27113 L
.76234 .2711 L
.76234 .27106 L
.76233 .27103 L
.76233 .27099 L
.76233 .27096 L
.76233 .27092 L
.76232 .27089 L
.76232 .27085 L
.76232 .27082 L
.76232 .27078 L
.76231 .27075 L
.76231 .27071 L
.76231 .27068 L
.76231 .27064 L
.76231 .27061 L
Mistroke
.7623 .27057 L
.7623 .27054 L
.7623 .2705 L
.7623 .27047 L
.7623 .27043 L
.7623 .2704 L
.76229 .27036 L
.76229 .27033 L
.76229 .27029 L
.76229 .27026 L
.76229 .27022 L
.76229 .27019 L
.76229 .27015 L
.76228 .27012 L
.76228 .27008 L
.76228 .27005 L
.76228 .27001 L
.76228 .26998 L
.76228 .26994 L
.76228 .26991 L
.76228 .26987 L
.76227 .26984 L
.76227 .2698 L
.76227 .26977 L
.76227 .26973 L
.76227 .2697 L
.76227 .26966 L
.76227 .26962 L
.76227 .26959 L
.76227 .26955 L
.76227 .26952 L
.76227 .26948 L
.76227 .26945 L
.76227 .26941 L
.76227 .26938 L
.76227 .26934 L
.76227 .26931 L
.76227 .26927 L
.76227 .26924 L
.76227 .2692 L
.76227 .26917 L
.76226 .26913 L
.76226 .2691 L
.76226 .26906 L
.76227 .26903 L
.76227 .26899 L
.76227 .26896 L
.76227 .26892 L
.76227 .26889 L
.76227 .26885 L
Mistroke
.76227 .26882 L
.76227 .26878 L
.76227 .26875 L
.76227 .26871 L
.76227 .26868 L
.76227 .26864 L
.76227 .26861 L
.76227 .26857 L
.76227 .26854 L
.76227 .2685 L
.76227 .26847 L
.76227 .26843 L
.76227 .2684 L
.76227 .26836 L
.76228 .26833 L
.76228 .26829 L
.76228 .26826 L
.76228 .26822 L
.76228 .26819 L
.76228 .26815 L
.76228 .26812 L
.76228 .26808 L
.76228 .26805 L
.76229 .26801 L
.76229 .26798 L
.76229 .26794 L
.76229 .26791 L
.76229 .26787 L
.76229 .26784 L
.76229 .26781 L
.7623 .26777 L
.7623 .26774 L
.7623 .2677 L
.7623 .26767 L
.7623 .26763 L
.7623 .2676 L
.76231 .26756 L
.76231 .26753 L
.76231 .26749 L
.76231 .26746 L
.76231 .26742 L
.76232 .26739 L
.76232 .26735 L
.76232 .26732 L
.76232 .26728 L
.76233 .26725 L
.76233 .26721 L
.76233 .26718 L
.76233 .26714 L
.76233 .26711 L
Mistroke
.76234 .26707 L
.76234 .26704 L
.76234 .267 L
.76234 .26697 L
.76235 .26693 L
.76235 .2669 L
.76235 .26686 L
.76236 .26683 L
.76236 .26679 L
.76236 .26676 L
.76236 .26672 L
.76237 .26669 L
.76237 .26665 L
.76237 .26662 L
.76238 .26658 L
.76238 .26655 L
.76238 .26651 L
.76238 .26648 L
.76239 .26644 L
.76239 .26641 L
.76239 .26638 L
.7624 .26634 L
.7624 .26631 L
.7624 .26627 L
.76241 .26624 L
.76241 .2662 L
.76241 .26617 L
.76242 .26613 L
.76242 .2661 L
.76243 .26606 L
.76243 .26603 L
.76243 .26599 L
.76244 .26596 L
.76244 .26592 L
.76244 .26589 L
.76245 .26585 L
.76245 .26582 L
.76246 .26578 L
.76246 .26575 L
.76246 .26571 L
.76247 .26568 L
.76247 .26565 L
.76248 .26561 L
.76248 .26558 L
.76248 .26554 L
.76249 .26551 L
.76249 .26547 L
.7625 .26544 L
.7625 .2654 L
.76251 .26537 L
Mistroke
.76251 .26533 L
.76252 .2653 L
.76252 .26526 L
.76252 .26523 L
.76253 .26519 L
.76253 .26516 L
.76254 .26513 L
.76254 .26509 L
.76255 .26506 L
.76255 .26502 L
.76256 .26499 L
.76256 .26495 L
.76257 .26492 L
.76257 .26488 L
.76258 .26485 L
.76258 .26481 L
.76259 .26478 L
.76259 .26474 L
.7626 .26471 L
.7626 .26468 L
.76261 .26464 L
.76261 .26461 L
.76262 .26457 L
.76262 .26454 L
.76263 .2645 L
.76263 .26447 L
.76264 .26443 L
.76265 .2644 L
.76265 .26437 L
.76266 .26433 L
.76266 .2643 L
.76267 .26426 L
.76267 .26423 L
.76268 .26419 L
.76269 .26416 L
.76269 .26412 L
.7627 .26409 L
.7627 .26406 L
.76271 .26402 L
.76271 .26399 L
.76272 .26395 L
.76273 .26392 L
.76273 .26388 L
.76274 .26385 L
.76274 .26381 L
.76275 .26378 L
.76276 .26375 L
.76276 .26371 L
.76277 .26368 L
.76278 .26364 L
Mistroke
.76278 .26361 L
.76279 .26357 L
.7628 .26354 L
.7628 .26351 L
.76281 .26347 L
.76281 .26344 L
.76282 .2634 L
.76283 .26337 L
.76283 .26333 L
.76284 .2633 L
.76285 .26327 L
.76285 .26323 L
.76286 .2632 L
.76287 .26316 L
.76288 .26313 L
.76288 .26309 L
.76289 .26306 L
.7629 .26303 L
.7629 .26299 L
.76291 .26296 L
.76292 .26292 L
.76292 .26289 L
.76293 .26285 L
.76294 .26282 L
.76295 .26279 L
.76295 .26275 L
.76296 .26272 L
.76297 .26268 L
.76297 .26265 L
.76298 .26262 L
.76299 .26258 L
.763 .26255 L
.763 .26251 L
.76301 .26248 L
.76302 .26245 L
.76303 .26241 L
.76303 .26238 L
.76304 .26234 L
.76305 .26231 L
.76306 .26228 L
.76307 .26224 L
.76307 .26221 L
.76308 .26217 L
.76309 .26214 L
.7631 .26211 L
.76311 .26207 L
.76311 .26204 L
.76312 .262 L
.76313 .26197 L
.76314 .26194 L
Mistroke
.76315 .2619 L
.76315 .26187 L
.76316 .26183 L
.76317 .2618 L
.76318 .26177 L
.76319 .26173 L
.76319 .2617 L
.7632 .26166 L
.76321 .26163 L
.76322 .2616 L
.76323 .26156 L
.76324 .26153 L
.76325 .26149 L
.76325 .26146 L
.76326 .26143 L
.76327 .26139 L
.76328 .26136 L
.76329 .26133 L
.7633 .26129 L
.76331 .26126 L
.76332 .26122 L
.76332 .26119 L
.76333 .26116 L
.76334 .26112 L
.76335 .26109 L
.76336 .26106 L
.76337 .26102 L
.76338 .26099 L
.76339 .26095 L
.7634 .26092 L
.7634 .26089 L
.76341 .26085 L
.76342 .26082 L
.76343 .26079 L
.76344 .26075 L
.76345 .26072 L
.76346 .26069 L
.76347 .26065 L
.76348 .26062 L
.76349 .26059 L
.7635 .26055 L
.76351 .26052 L
.76352 .26048 L
.76353 .26045 L
.76354 .26042 L
.76355 .26038 L
.76356 .26035 L
.76357 .26032 L
.76357 .26028 L
.76358 .26025 L
Mistroke
.76359 .26022 L
.7636 .26018 L
.76361 .26015 L
.76362 .26012 L
.76363 .26008 L
.76364 .26005 L
.76365 .26002 L
.76366 .25998 L
.76367 .25995 L
.76368 .25992 L
.76369 .25988 L
.7637 .25985 L
.76371 .25982 L
.76372 .25978 L
.76373 .25975 L
.76375 .25972 L
.76376 .25968 L
.76377 .25965 L
.76378 .25962 L
.76379 .25958 L
.7638 .25955 L
.76381 .25952 L
.76382 .25948 L
.76383 .25945 L
.76384 .25942 L
.76385 .25938 L
.76386 .25935 L
.76387 .25932 L
.76388 .25928 L
.76389 .25925 L
.7639 .25922 L
.76391 .25918 L
.76392 .25915 L
.76394 .25912 L
.76395 .25909 L
.76396 .25905 L
.76397 .25902 L
.76398 .25899 L
.76399 .25895 L
.764 .25892 L
.76401 .25889 L
.76402 .25885 L
.76403 .25882 L
.76405 .25879 L
.76406 .25876 L
.76407 .25872 L
.76408 .25869 L
.76409 .25866 L
.7641 .25862 L
.76411 .25859 L
Mistroke
.76412 .25856 L
.76414 .25852 L
.76415 .25849 L
.76416 .25846 L
.76417 .25843 L
.76418 .25839 L
.76419 .25836 L
.7642 .25833 L
.76422 .25829 L
.76423 .25826 L
.76424 .25823 L
.76425 .2582 L
.76426 .25816 L
.76427 .25813 L
.76429 .2581 L
.7643 .25807 L
.76431 .25803 L
.76432 .258 L
.76433 .25797 L
.76435 .25793 L
.76436 .2579 L
.76437 .25787 L
.76438 .25784 L
.76439 .2578 L
.7644 .25777 L
.76442 .25774 L
.76443 .25771 L
.76444 .25767 L
.76445 .25764 L
.76447 .25761 L
.76448 .25758 L
.76449 .25754 L
.7645 .25751 L
.76451 .25748 L
.76453 .25745 L
.76454 .25741 L
.76455 .25738 L
.76456 .25735 L
.76458 .25732 L
.76459 .25728 L
.7646 .25725 L
.76461 .25722 L
.76463 .25719 L
.76464 .25715 L
.76465 .25712 L
.76466 .25709 L
.76468 .25706 L
.76469 .25703 L
.7647 .25699 L
.76472 .25696 L
Mistroke
.76473 .25693 L
.76474 .2569 L
.76475 .25686 L
.76477 .25683 L
.76478 .2568 L
.76479 .25677 L
.76481 .25673 L
.76482 .2567 L
.76483 .25667 L
.76484 .25664 L
.76486 .25661 L
.76487 .25657 L
.76488 .25654 L
.7649 .25651 L
.76491 .25648 L
.76492 .25645 L
.76494 .25641 L
.76495 .25638 L
.76496 .25635 L
.76498 .25632 L
.76499 .25629 L
.765 .25625 L
.76502 .25622 L
.76503 .25619 L
.76504 .25616 L
.76506 .25613 L
.76507 .25609 L
.76508 .25606 L
.7651 .25603 L
.76511 .256 L
.76512 .25597 L
.76514 .25593 L
.76515 .2559 L
.76517 .25587 L
.76518 .25584 L
.76519 .25581 L
.76521 .25577 L
.76522 .25574 L
.76523 .25571 L
.76525 .25568 L
.76526 .25565 L
.76528 .25562 L
.76529 .25558 L
.7653 .25555 L
.76532 .25552 L
.76533 .25549 L
.76535 .25546 L
.76536 .25543 L
.76537 .25539 L
.76539 .25536 L
Mistroke
.7654 .25533 L
.76542 .2553 L
.76543 .25527 L
.76544 .25524 L
.76546 .25521 L
.76547 .25517 L
.76549 .25514 L
.7655 .25511 L
.76552 .25508 L
.76553 .25505 L
.76554 .25502 L
.76556 .25498 L
.76557 .25495 L
.76559 .25492 L
.7656 .25489 L
.76562 .25486 L
.76563 .25483 L
.76565 .2548 L
.76566 .25477 L
.76567 .25473 L
.76569 .2547 L
.7657 .25467 L
.76572 .25464 L
.76573 .25461 L
.76575 .25458 L
.76576 .25455 L
.76578 .25451 L
.76579 .25448 L
.76581 .25445 L
.76582 .25442 L
.76584 .25439 L
.76585 .25436 L
.76587 .25433 L
.76588 .2543 L
.7659 .25427 L
.76591 .25423 L
.76593 .2542 L
.76594 .25417 L
.76596 .25414 L
.76597 .25411 L
.76599 .25408 L
.766 .25405 L
.76602 .25402 L
.76603 .25399 L
.76605 .25396 L
.76606 .25392 L
.76608 .25389 L
.76609 .25386 L
.76611 .25383 L
.76612 .2538 L
Mistroke
.76614 .25377 L
.76615 .25374 L
.76617 .25371 L
.76619 .25368 L
.7662 .25365 L
.76622 .25362 L
.76623 .25359 L
.76625 .25355 L
.76626 .25352 L
.76628 .25349 L
.76629 .25346 L
.76631 .25343 L
.76633 .2534 L
.76634 .25337 L
.76636 .25334 L
.76637 .25331 L
.76639 .25328 L
.7664 .25325 L
.76642 .25322 L
.76644 .25319 L
.76645 .25316 L
.76647 .25313 L
.76648 .2531 L
.7665 .25306 L
.76651 .25303 L
.76653 .253 L
.76655 .25297 L
.76656 .25294 L
.76658 .25291 L
.76659 .25288 L
.76661 .25285 L
.76663 .25282 L
.76664 .25279 L
.76666 .25276 L
.76667 .25273 L
.76669 .2527 L
.76671 .25267 L
.76672 .25264 L
.76674 .25261 L
.76676 .25258 L
.76677 .25255 L
.76679 .25252 L
.7668 .25249 L
.76682 .25246 L
.76684 .25243 L
.76685 .2524 L
.76687 .25237 L
.76689 .25234 L
.7669 .25231 L
.76692 .25228 L
Mistroke
.76694 .25225 L
.76695 .25222 L
.76697 .25219 L
.76699 .25216 L
.767 .25213 L
.76702 .2521 L
.76703 .25207 L
.76705 .25204 L
.76707 .25201 L
.76708 .25198 L
.7671 .25195 L
.76712 .25192 L
.76714 .25189 L
.76715 .25186 L
.76717 .25183 L
.76719 .2518 L
.7672 .25177 L
.76722 .25174 L
.76724 .25171 L
.76725 .25168 L
.76727 .25165 L
.76729 .25162 L
.7673 .25159 L
.76732 .25156 L
.76734 .25153 L
.76735 .2515 L
.76737 .25147 L
.76739 .25144 L
.76741 .25141 L
.76742 .25138 L
.76744 .25135 L
.76746 .25132 L
.76747 .25129 L
.76749 .25126 L
.76751 .25123 L
.76753 .25121 L
.76754 .25118 L
.76756 .25115 L
.76758 .25112 L
.76759 .25109 L
.76761 .25106 L
.76763 .25103 L
.76765 .251 L
.76766 .25097 L
.76768 .25094 L
.7677 .25091 L
.76772 .25088 L
.76773 .25085 L
.76775 .25082 L
.76777 .25079 L
Mistroke
.76779 .25076 L
.7678 .25074 L
.76782 .25071 L
.76784 .25068 L
.76786 .25065 L
.76787 .25062 L
.76789 .25059 L
.76791 .25056 L
.76793 .25053 L
.76794 .2505 L
.76796 .25047 L
.76798 .25044 L
.768 .25042 L
.76801 .25039 L
.76803 .25036 L
.76805 .25033 L
.76807 .2503 L
.76809 .25027 L
.7681 .25024 L
.76812 .25021 L
.76814 .25018 L
.76816 .25016 L
.76818 .25013 L
.76819 .2501 L
.76821 .25007 L
.76823 .25004 L
.76825 .25001 L
.76826 .24998 L
.76828 .24995 L
.7683 .24992 L
.76832 .2499 L
.76834 .24987 L
.76836 .24984 L
.76837 .24981 L
.76839 .24978 L
.76841 .24975 L
.76843 .24972 L
.76845 .2497 L
.76846 .24967 L
.76848 .24964 L
.7685 .24961 L
.76852 .24958 L
.76854 .24955 L
.76856 .24952 L
.76857 .2495 L
.76859 .24947 L
.76861 .24944 L
.76863 .24941 L
.76865 .24938 L
.76867 .24935 L
Mistroke
.76868 .24933 L
.7687 .2493 L
.76872 .24927 L
.76874 .24924 L
.76876 .24921 L
.76878 .24918 L
.76879 .24916 L
.76881 .24913 L
.76883 .2491 L
.76885 .24907 L
.76887 .24904 L
.76889 .24901 L
.76891 .24899 L
.76892 .24896 L
.76894 .24893 L
.76896 .2489 L
.76898 .24887 L
.769 .24885 L
.76902 .24882 L
.76904 .24879 L
.76906 .24876 L
.76907 .24873 L
.76909 .24871 L
.76911 .24868 L
.76913 .24865 L
.76915 .24862 L
.76917 .24859 L
.76919 .24857 L
.76921 .24854 L
.76923 .24851 L
.76924 .24848 L
.76926 .24846 L
.76928 .24843 L
.7693 .2484 L
.76932 .24837 L
.76934 .24834 L
.76936 .24832 L
.76938 .24829 L
.7694 .24826 L
.76942 .24823 L
.76943 .24821 L
.76945 .24818 L
.76947 .24815 L
.76949 .24812 L
.76951 .2481 L
.76953 .24807 L
.76955 .24804 L
.76957 .24801 L
.76959 .24799 L
.76961 .24796 L
Mistroke
.76963 .24793 L
.76965 .2479 L
.76966 .24788 L
.76968 .24785 L
.7697 .24782 L
.76972 .24779 L
.76974 .24777 L
.76976 .24774 L
.76978 .24771 L
.7698 .24769 L
.76982 .24766 L
.76984 .24763 L
.76986 .2476 L
.76988 .24758 L
.7699 .24755 L
.76992 .24752 L
.76994 .24749 L
.76996 .24747 L
.76997 .24744 L
.76999 .24741 L
.77001 .24739 L
.77003 .24736 L
.77005 .24733 L
.77007 .24731 L
.77009 .24728 L
.77011 .24725 L
.77013 .24722 L
.77015 .2472 L
.77017 .24717 L
.77019 .24714 L
.77021 .24712 L
.77023 .24709 L
.77025 .24706 L
.77027 .24704 L
.77029 .24701 L
.77031 .24698 L
.77033 .24696 L
.77035 .24693 L
.77037 .2469 L
.77039 .24688 L
.77041 .24685 L
.77043 .24682 L
.77045 .2468 L
.77047 .24677 L
.77049 .24674 L
.77051 .24672 L
.77053 .24669 L
.77055 .24666 L
.77057 .24664 L
.77059 .24661 L
Mistroke
.77061 .24658 L
.77063 .24656 L
.77065 .24653 L
.77067 .2465 L
.77069 .24648 L
.77071 .24645 L
.77073 .24642 L
.77075 .2464 L
.77077 .24637 L
.77079 .24635 L
.77081 .24632 L
.77083 .24629 L
.77085 .24627 L
.77087 .24624 L
.77089 .24621 L
.77091 .24619 L
.77093 .24616 L
.77095 .24614 L
.77097 .24611 L
.77099 .24608 L
.77101 .24606 L
.77103 .24603 L
.77105 .24601 L
.77107 .24598 L
.77109 .24595 L
.77111 .24593 L
.77113 .2459 L
.77115 .24588 L
.77117 .24585 L
.77119 .24582 L
.77121 .2458 L
.77123 .24577 L
.77125 .24575 L
.77127 .24572 L
.77129 .24569 L
.77131 .24567 L
.77133 .24564 L
.77135 .24562 L
.77137 .24559 L
.7714 .24557 L
.77142 .24554 L
.77144 .24551 L
.77146 .24549 L
.77148 .24546 L
.7715 .24544 L
.77152 .24541 L
.77154 .24539 L
.77156 .24536 L
.77158 .24533 L
.7716 .24531 L
Mistroke
.77162 .24528 L
.77164 .24526 L
.77166 .24523 L
.77168 .24521 L
.7717 .24518 L
.77172 .24516 L
.77175 .24513 L
.77177 .24511 L
.77179 .24508 L
.77181 .24505 L
.77183 .24503 L
.77185 .245 L
.77187 .24498 L
.77189 .24495 L
.77191 .24493 L
.77193 .2449 L
.77195 .24488 L
.77197 .24485 L
.77199 .24483 L
.77201 .2448 L
.77204 .24478 L
.77206 .24475 L
.77208 .24473 L
.7721 .2447 L
.77212 .24468 L
.77214 .24465 L
.77216 .24463 L
.77218 .2446 L
.7722 .24458 L
.77222 .24455 L
.77224 .24453 L
.77227 .2445 L
.77229 .24448 L
.77231 .24445 L
.77233 .24443 L
.77235 .2444 L
.77237 .24438 L
.77239 .24435 L
.77241 .24433 L
.77243 .2443 L
.77245 .24428 L
.77248 .24425 L
.7725 .24423 L
.77252 .24421 L
.77254 .24418 L
.77256 .24416 L
.77258 .24413 L
.7726 .24411 L
.77262 .24408 L
.77264 .24406 L
Mistroke
.77267 .24403 L
.77269 .24401 L
.77271 .24398 L
.77273 .24396 L
.77275 .24394 L
.77277 .24391 L
.77279 .24389 L
.77281 .24386 L
.77284 .24384 L
.77286 .24381 L
.77288 .24379 L
.7729 .24376 L
.77292 .24374 L
.77294 .24372 L
.77296 .24369 L
.77298 .24367 L
.77301 .24364 L
.77303 .24362 L
.77305 .2436 L
.77307 .24357 L
.77309 .24355 L
.77311 .24352 L
.77313 .2435 L
.77315 .24347 L
.77318 .24345 L
.7732 .24343 L
.77322 .2434 L
.77324 .24338 L
.77326 .24335 L
.77328 .24333 L
.7733 .24331 L
.77333 .24328 L
.77335 .24326 L
.77337 .24324 L
.77339 .24321 L
.77341 .24319 L
.77343 .24316 L
.77345 .24314 L
.77348 .24312 L
.7735 .24309 L
.77352 .24307 L
.77354 .24305 L
.77356 .24302 L
.77358 .243 L
.77361 .24297 L
.77363 .24295 L
.77365 .24293 L
.77367 .2429 L
.77369 .24288 L
.77371 .24286 L
Mistroke
.77374 .24283 L
.77376 .24281 L
.77378 .24279 L
.7738 .24276 L
.77382 .24274 L
.77384 .24272 L
.77387 .24269 L
.77389 .24267 L
.77391 .24265 L
.77393 .24262 L
.77395 .2426 L
.77397 .24258 L
.774 .24255 L
.77402 .24253 L
.77404 .24251 L
.77406 .24248 L
.77408 .24246 L
.7741 .24244 L
.77413 .24241 L
.77415 .24239 L
.77417 .24237 L
.77419 .24234 L
.77421 .24232 L
.77423 .2423 L
.77426 .24227 L
.77428 .24225 L
.7743 .24223 L
.77432 .24221 L
.77434 .24218 L
.77437 .24216 L
.77439 .24214 L
.77441 .24211 L
.77443 .24209 L
.77445 .24207 L
.77447 .24205 L
.7745 .24202 L
.77452 .242 L
.77454 .24198 L
.77456 .24196 L
.77458 .24193 L
.77461 .24191 L
.77463 .24189 L
.77465 .24186 L
.77467 .24184 L
.77469 .24182 L
.77472 .2418 L
.77474 .24177 L
.77476 .24175 L
.77478 .24173 L
.7748 .24171 L
Mistroke
.77483 .24168 L
.77485 .24166 L
.77487 .24164 L
.77489 .24162 L
.77491 .24159 L
.77494 .24157 L
.77496 .24155 L
.77498 .24153 L
.775 .24151 L
.77502 .24148 L
.77505 .24146 L
.77507 .24144 L
.77509 .24142 L
.77511 .24139 L
.77513 .24137 L
.77516 .24135 L
.77518 .24133 L
.7752 .24131 L
.77522 .24128 L
.77524 .24126 L
.77527 .24124 L
.77529 .24122 L
.77531 .24119 L
.77533 .24117 L
.77536 .24115 L
.77538 .24113 L
.7754 .24111 L
.77542 .24109 L
.77544 .24106 L
.77547 .24104 L
.77549 .24102 L
.77551 .241 L
.77553 .24098 L
.77556 .24095 L
.77558 .24093 L
.7756 .24091 L
.77562 .24089 L
.77564 .24087 L
.77567 .24085 L
.77569 .24082 L
.77571 .2408 L
.77573 .24078 L
.77576 .24076 L
.77578 .24074 L
.7758 .24072 L
.77582 .24069 L
.77584 .24067 L
.77587 .24065 L
.77589 .24063 L
.77591 .24061 L
Mistroke
.77593 .24059 L
.77596 .24057 L
.77598 .24054 L
.776 .24052 L
.77602 .2405 L
.77604 .24048 L
.77607 .24046 L
.77609 .24044 L
.77611 .24042 L
.77613 .2404 L
.77616 .24037 L
.77618 .24035 L
.7762 .24033 L
.77622 .24031 L
.77625 .24029 L
.77627 .24027 L
.77629 .24025 L
.77631 .24023 L
.77634 .24021 L
.77636 .24018 L
.77638 .24016 L
.7764 .24014 L
.77642 .24012 L
.77645 .2401 L
.77647 .24008 L
.77649 .24006 L
.77651 .24004 L
.77654 .24002 L
.77656 .24 L
.77658 .23997 L
.7766 .23995 L
.77663 .23993 L
.77665 .23991 L
.77667 .23989 L
.77669 .23987 L
.77672 .23985 L
.77674 .23983 L
.77676 .23981 L
.77678 .23979 L
.77681 .23977 L
.77683 .23975 L
.77685 .23973 L
.77687 .23971 L
.7769 .23969 L
.77692 .23967 L
.77694 .23964 L
.77696 .23962 L
.77699 .2396 L
.77701 .23958 L
.77703 .23956 L
Mistroke
.77705 .23954 L
.77708 .23952 L
.7771 .2395 L
.77712 .23948 L
.77714 .23946 L
.77717 .23944 L
.77719 .23942 L
.77721 .2394 L
.77723 .23938 L
.77726 .23936 L
.77728 .23934 L
.7773 .23932 L
.77732 .2393 L
.77735 .23928 L
.77737 .23926 L
.77739 .23924 L
.77741 .23922 L
.77744 .2392 L
.77746 .23918 L
.77748 .23916 L
.7775 .23914 L
.77753 .23912 L
.77755 .2391 L
.77757 .23908 L
.7776 .23906 L
.77762 .23904 L
.77764 .23902 L
.77766 .239 L
.77769 .23898 L
.77771 .23896 L
.77773 .23894 L
.77775 .23892 L
.77778 .2389 L
.7778 .23888 L
.77782 .23886 L
.77784 .23884 L
.77787 .23882 L
.77789 .2388 L
.77791 .23878 L
.77793 .23876 L
.77796 .23875 L
.77798 .23873 L
.778 .23871 L
.77802 .23869 L
.77805 .23867 L
.77807 .23865 L
.77809 .23863 L
.77812 .23861 L
.77814 .23859 L
.77816 .23857 L
Mistroke
.77818 .23855 L
.77821 .23853 L
.77823 .23851 L
.77825 .23849 L
.77827 .23847 L
.7783 .23845 L
.77832 .23844 L
.77834 .23842 L
.77836 .2384 L
.77839 .23838 L
.77841 .23836 L
.77843 .23834 L
.77846 .23832 L
.77848 .2383 L
.7785 .23828 L
.77852 .23826 L
.77855 .23824 L
.77857 .23823 L
.77859 .23821 L
.77861 .23819 L
.77864 .23817 L
.77866 .23815 L
.77868 .23813 L
.77871 .23811 L
.77873 .23809 L
.77875 .23808 L
.77877 .23806 L
.7788 .23804 L
.77882 .23802 L
.77884 .238 L
.77886 .23798 L
.77889 .23796 L
.77891 .23794 L
.77893 .23793 L
.77896 .23791 L
.77898 .23789 L
.779 .23787 L
.77902 .23785 L
.77905 .23783 L
.77907 .23781 L
.77909 .2378 L
.77911 .23778 L
.77914 .23776 L
.77916 .23774 L
.77918 .23772 L
.77921 .2377 L
.77923 .23769 L
.77925 .23767 L
.77927 .23765 L
.7793 .23763 L
Mistroke
.77932 .23761 L
.77934 .23759 L
.77936 .23758 L
.77939 .23756 L
.77941 .23754 L
.77943 .23752 L
.77946 .2375 L
.77948 .23749 L
.7795 .23747 L
.77952 .23745 L
.77955 .23743 L
.77957 .23741 L
.77959 .2374 L
.77961 .23738 L
.77964 .23736 L
.77966 .23734 L
.77968 .23732 L
.77971 .23731 L
.77973 .23729 L
.77975 .23727 L
.77977 .23725 L
.7798 .23723 L
.77982 .23722 L
.77984 .2372 L
.77986 .23718 L
.77989 .23716 L
.77991 .23715 L
.77993 .23713 L
.77996 .23711 L
.77998 .23709 L
.78 .23707 L
.78002 .23706 L
.78005 .23704 L
.78007 .23702 L
.78009 .237 L
.78011 .23699 L
.78014 .23697 L
.78016 .23695 L
.78018 .23693 L
.78021 .23692 L
.78023 .2369 L
.78025 .23688 L
.78027 .23686 L
.7803 .23685 L
.78032 .23683 L
.78034 .23681 L
.78037 .2368 L
.78039 .23678 L
.78041 .23676 L
.78043 .23674 L
Mistroke
.78046 .23673 L
.78048 .23671 L
.7805 .23669 L
.78052 .23668 L
.78055 .23666 L
.78057 .23664 L
.78059 .23662 L
.78062 .23661 L
.78064 .23659 L
.78066 .23657 L
.78068 .23656 L
.78071 .23654 L
.78073 .23652 L
.78075 .23651 L
.78077 .23649 L
.7808 .23647 L
.78082 .23645 L
.78084 .23644 L
.78087 .23642 L
.78089 .2364 L
.78091 .23639 L
.78093 .23637 L
.78096 .23635 L
.78098 .23634 L
.781 .23632 L
.78102 .2363 L
.78105 .23629 L
.78107 .23627 L
.78109 .23625 L
.78112 .23624 L
.78114 .23622 L
.78116 .2362 L
.78118 .23619 L
.78121 .23617 L
.78123 .23615 L
.78125 .23614 L
.78127 .23612 L
.7813 .23611 L
.78132 .23609 L
.78134 .23607 L
.78137 .23606 L
.78139 .23604 L
.78141 .23602 L
.78143 .23601 L
.78146 .23599 L
.78148 .23597 L
.7815 .23596 L
.78152 .23594 L
.78155 .23593 L
.78157 .23591 L
Mistroke
.78159 .23589 L
.78162 .23588 L
.78164 .23586 L
.78166 .23585 L
.78168 .23583 L
.78171 .23581 L
.78173 .2358 L
.78175 .23578 L
.78177 .23577 L
.7818 .23575 L
.78182 .23573 L
.78184 .23572 L
.78186 .2357 L
.78189 .23569 L
.78191 .23567 L
.78193 .23565 L
.78196 .23564 L
.78198 .23562 L
.782 .23561 L
.78202 .23559 L
.78205 .23558 L
.78207 .23556 L
.78209 .23554 L
.78211 .23553 L
.78214 .23551 L
.78216 .2355 L
.78218 .23548 L
.7822 .23547 L
.78223 .23545 L
.78225 .23544 L
.78227 .23542 L
.7823 .2354 L
.78232 .23539 L
.78234 .23537 L
.78236 .23536 L
.78239 .23534 L
.78241 .23533 L
.78243 .23531 L
.78245 .2353 L
.78248 .23528 L
.7825 .23527 L
.78252 .23525 L
.78254 .23524 L
.78257 .23522 L
.78259 .2352 L
.78261 .23519 L
.78263 .23517 L
.78266 .23516 L
.78268 .23514 L
.7827 .23513 L
Mistroke
.78272 .23511 L
.78275 .2351 L
.78277 .23508 L
.78279 .23507 L
.78282 .23505 L
.78284 .23504 L
.78286 .23502 L
.78288 .23501 L
.78291 .23499 L
.78293 .23498 L
.78295 .23496 L
.78297 .23495 L
.783 .23493 L
.78302 .23492 L
.78304 .2349 L
.78306 .23489 L
.78309 .23488 L
.78311 .23486 L
.78313 .23485 L
.78315 .23483 L
.78318 .23482 L
.7832 .2348 L
.78322 .23479 L
.78324 .23477 L
.78327 .23476 L
.78329 .23474 L
.78331 .23473 L
.78333 .23471 L
.78336 .2347 L
.78338 .23469 L
.7834 .23467 L
.78342 .23466 L
.78345 .23464 L
.78347 .23463 L
.78349 .23461 L
.78351 .2346 L
.78354 .23458 L
.78356 .23457 L
.78358 .23456 L
.7836 .23454 L
.78363 .23453 L
.78365 .23451 L
.78367 .2345 L
.78369 .23448 L
.78372 .23447 L
.78374 .23446 L
.78376 .23444 L
.78378 .23443 L
.7838 .23441 L
.78383 .2344 L
Mistroke
.78385 .23439 L
.78387 .23437 L
.78389 .23436 L
.78392 .23434 L
.78394 .23433 L
.78396 .23432 L
.78398 .2343 L
.78401 .23429 L
.78403 .23427 L
.78405 .23426 L
.78407 .23425 L
.7841 .23423 L
.78412 .23422 L
.78414 .2342 L
.78416 .23419 L
.78419 .23418 L
.78421 .23416 L
.78423 .23415 L
.78425 .23414 L
.78427 .23412 L
.7843 .23411 L
.78432 .2341 L
.78434 .23408 L
.78436 .23407 L
.78439 .23405 L
.78441 .23404 L
.78443 .23403 L
.78445 .23401 L
.78448 .234 L
.7845 .23399 L
.78452 .23397 L
.78454 .23396 L
.78456 .23395 L
.78459 .23393 L
.78461 .23392 L
.78463 .23391 L
.78465 .23389 L
.78468 .23388 L
.7847 .23387 L
.78472 .23385 L
.78474 .23384 L
.78476 .23383 L
.78479 .23381 L
.78481 .2338 L
.78483 .23379 L
.78485 .23377 L
.78488 .23376 L
.7849 .23375 L
.78492 .23374 L
.78494 .23372 L
Mistroke
.78496 .23371 L
.78499 .2337 L
.78501 .23368 L
.78503 .23367 L
.78505 .23366 L
.78508 .23364 L
.7851 .23363 L
.78512 .23362 L
.78514 .23361 L
.78516 .23359 L
.78519 .23358 L
.78521 .23357 L
.78523 .23355 L
.78525 .23354 L
.78527 .23353 L
.7853 .23352 L
.78532 .2335 L
.78534 .23349 L
.78536 .23348 L
.78539 .23347 L
.78541 .23345 L
.78543 .23344 L
.78545 .23343 L
.78547 .23342 L
.7855 .2334 L
.78552 .23339 L
.78554 .23338 L
.78556 .23337 L
.78558 .23335 L
.78561 .23334 L
.78563 .23333 L
.78565 .23332 L
.78567 .2333 L
.78569 .23329 L
.78572 .23328 L
.78574 .23327 L
.78576 .23325 L
.78578 .23324 L
.7858 .23323 L
.78583 .23322 L
.78585 .23321 L
.78587 .23319 L
.78589 .23318 L
.78591 .23317 L
.78594 .23316 L
.78596 .23314 L
.78598 .23313 L
.786 .23312 L
.78602 .23311 L
.78604 .2331 L
Mistroke
.78607 .23308 L
.78609 .23307 L
.78611 .23306 L
.78613 .23305 L
.78615 .23304 L
.78618 .23302 L
.7862 .23301 L
.78622 .233 L
.78624 .23299 L
.78626 .23298 L
.78629 .23297 L
.78631 .23295 L
.78633 .23294 L
.78635 .23293 L
.78637 .23292 L
.78639 .23291 L
.78642 .23289 L
.78644 .23288 L
.78646 .23287 L
.78648 .23286 L
.7865 .23285 L
.78653 .23284 L
.78655 .23283 L
.78657 .23281 L
.78659 .2328 L
.78661 .23279 L
.78663 .23278 L
.78666 .23277 L
.78668 .23276 L
.7867 .23274 L
.78672 .23273 L
.78674 .23272 L
.78676 .23271 L
.78679 .2327 L
.78681 .23269 L
.78683 .23268 L
.78685 .23267 L
.78687 .23265 L
.78689 .23264 L
.78692 .23263 L
.78694 .23262 L
.78696 .23261 L
.78698 .2326 L
.787 .23259 L
.78702 .23258 L
.78705 .23256 L
.78707 .23255 L
.78709 .23254 L
.78711 .23253 L
.78713 .23252 L
Mistroke
.78715 .23251 L
.78718 .2325 L
.7872 .23249 L
.78722 .23248 L
.78724 .23247 L
.78726 .23245 L
.78728 .23244 L
.7873 .23243 L
.78733 .23242 L
.78735 .23241 L
.78737 .2324 L
.78739 .23239 L
.78741 .23238 L
.78743 .23237 L
.78746 .23236 L
.78748 .23235 L
.7875 .23234 L
.78752 .23233 L
.78754 .23231 L
.78756 .2323 L
.78758 .23229 L
.78761 .23228 L
.78763 .23227 L
.78765 .23226 L
.78767 .23225 L
.78769 .23224 L
.78771 .23223 L
.78773 .23222 L
.78776 .23221 L
.78778 .2322 L
.7878 .23219 L
.78782 .23218 L
.78784 .23217 L
.78786 .23216 L
.78788 .23215 L
.7879 .23214 L
.78793 .23213 L
.78795 .23212 L
.78797 .23211 L
.78799 .2321 L
.78801 .23209 L
.78803 .23207 L
.78805 .23206 L
.78807 .23205 L
.7881 .23204 L
.78812 .23203 L
.78814 .23202 L
.78816 .23201 L
.78818 .232 L
.7882 .23199 L
Mistroke
.78822 .23198 L
.78824 .23197 L
.78827 .23196 L
.78829 .23195 L
.78831 .23194 L
.78833 .23193 L
.78835 .23192 L
.78837 .23191 L
.78839 .2319 L
.78841 .23189 L
.78843 .23188 L
.78846 .23187 L
.78848 .23187 L
.7885 .23186 L
.78852 .23185 L
.78854 .23184 L
.78856 .23183 L
.78858 .23182 L
.7886 .23181 L
.78862 .2318 L
.78865 .23179 L
.78867 .23178 L
.78869 .23177 L
.78871 .23176 L
.78873 .23175 L
.78875 .23174 L
.78877 .23173 L
.78879 .23172 L
.78881 .23171 L
.78883 .2317 L
.78886 .23169 L
.78888 .23168 L
.7889 .23167 L
.78892 .23166 L
.78894 .23165 L
.78896 .23165 L
.78898 .23164 L
.789 .23163 L
.78902 .23162 L
.78904 .23161 L
.78906 .2316 L
.78909 .23159 L
.78911 .23158 L
.78913 .23157 L
.78915 .23156 L
.78917 .23155 L
.78919 .23154 L
.78921 .23153 L
.78923 .23153 L
.78925 .23152 L
Mistroke
.78927 .23151 L
.78929 .2315 L
.78931 .23149 L
.78934 .23148 L
.78936 .23147 L
.78938 .23146 L
.7894 .23145 L
.78942 .23144 L
.78944 .23144 L
.78946 .23143 L
.78948 .23142 L
.7895 .23141 L
.78952 .2314 L
.78954 .23139 L
.78956 .23138 L
.78958 .23137 L
.7896 .23136 L
.78963 .23136 L
.78965 .23135 L
.78967 .23134 L
.78969 .23133 L
.78971 .23132 L
.78973 .23131 L
.78975 .2313 L
.78977 .2313 L
.78979 .23129 L
.78981 .23128 L
.78983 .23127 L
.78985 .23126 L
.78987 .23125 L
.78989 .23124 L
.78991 .23124 L
.78993 .23123 L
.78995 .23122 L
.78997 .23121 L
.79 .2312 L
.79002 .23119 L
.79004 .23118 L
.79006 .23118 L
.79008 .23117 L
.7901 .23116 L
.79012 .23115 L
.79014 .23114 L
.79016 .23113 L
.79018 .23113 L
.7902 .23112 L
.79022 .23111 L
.79024 .2311 L
.79026 .23109 L
.79028 .23109 L
Mistroke
.7903 .23108 L
.79032 .23107 L
.79034 .23106 L
.79036 .23105 L
.79038 .23105 L
.7904 .23104 L
.79042 .23103 L
.79044 .23102 L
.79046 .23101 L
.79048 .23101 L
.7905 .231 L
.79052 .23099 L
.79054 .23098 L
.79056 .23097 L
.79059 .23097 L
.79061 .23096 L
.79063 .23095 L
.79065 .23094 L
.79067 .23093 L
.79069 .23093 L
.79071 .23092 L
.79073 .23091 L
.79075 .2309 L
.79077 .2309 L
.79079 .23089 L
.79081 .23088 L
.79083 .23087 L
.79085 .23087 L
.79087 .23086 L
.79089 .23085 L
.79091 .23084 L
.79093 .23083 L
.79095 .23083 L
.79097 .23082 L
.79099 .23081 L
.79101 .2308 L
.79103 .2308 L
.79105 .23079 L
.79107 .23078 L
.79109 .23078 L
.79111 .23077 L
.79113 .23076 L
.79115 .23075 L
.79117 .23075 L
.79119 .23074 L
.79121 .23073 L
.79123 .23072 L
.79125 .23072 L
.79127 .23071 L
.79129 .2307 L
Mistroke
.79131 .23069 L
.79133 .23069 L
.79135 .23068 L
.79137 .23067 L
.79139 .23067 L
.79141 .23066 L
.79142 .23065 L
.79144 .23064 L
.79146 .23064 L
.79148 .23063 L
.7915 .23062 L
.79152 .23062 L
.79154 .23061 L
.79156 .2306 L
.79158 .2306 L
.7916 .23059 L
.79162 .23058 L
.79164 .23057 L
.79166 .23057 L
.79168 .23056 L
.7917 .23055 L
.79172 .23055 L
.79174 .23054 L
.79176 .23053 L
.79178 .23053 L
.7918 .23052 L
.79182 .23051 L
.79184 .23051 L
.79186 .2305 L
.79188 .23049 L
.7919 .23049 L
.79192 .23048 L
.79194 .23047 L
.79196 .23047 L
.79197 .23046 L
.79199 .23045 L
.79201 .23045 L
.79203 .23044 L
.79205 .23043 L
.79207 .23043 L
.79209 .23042 L
.79211 .23041 L
.79213 .23041 L
.79215 .2304 L
.79217 .2304 L
.79219 .23039 L
.79221 .23038 L
.79223 .23038 L
.79225 .23037 L
.79227 .23036 L
Mistroke
.79229 .23036 L
.7923 .23035 L
.79232 .23034 L
.79234 .23034 L
.79236 .23033 L
.79238 .23033 L
.7924 .23032 L
.79242 .23031 L
.79244 .23031 L
.79246 .2303 L
.79248 .23029 L
.7925 .23029 L
.79252 .23028 L
.79254 .23028 L
.79255 .23027 L
.79257 .23026 L
.79259 .23026 L
.79261 .23025 L
.79263 .23025 L
.79265 .23024 L
.79267 .23023 L
.79269 .23023 L
.79271 .23022 L
.79273 .23022 L
.79275 .23021 L
.79277 .2302 L
.79278 .2302 L
.7928 .23019 L
.79282 .23019 L
.79284 .23018 L
.79286 .23018 L
.79288 .23017 L
.7929 .23016 L
.79292 .23016 L
.79294 .23015 L
.79296 .23015 L
.79297 .23014 L
.79299 .23014 L
.79301 .23013 L
.79303 .23012 L
.79305 .23012 L
.79307 .23011 L
.79309 .23011 L
.79311 .2301 L
.79313 .2301 L
.79314 .23009 L
.79316 .23009 L
.79318 .23008 L
.7932 .23007 L
.79322 .23007 L
Mistroke
.79324 .23006 L
.79326 .23006 L
.79328 .23005 L
.79329 .23005 L
.79331 .23004 L
.79333 .23004 L
.79335 .23003 L
.79337 .23003 L
.79339 .23002 L
.79341 .23002 L
.79343 .23001 L
.79344 .23 L
.79346 .23 L
.79348 .22999 L
.7935 .22999 L
.79352 .22998 L
.79354 .22998 L
.79356 .22997 L
.79357 .22997 L
.79359 .22996 L
.79361 .22996 L
.79363 .22995 L
.79365 .22995 L
.79367 .22994 L
.79369 .22994 L
.7937 .22993 L
.79372 .22993 L
.79374 .22992 L
.79376 .22992 L
.79378 .22991 L
.7938 .22991 L
.79381 .2299 L
.79383 .2299 L
.79385 .22989 L
.79387 .22989 L
.79389 .22988 L
.79391 .22988 L
.79392 .22987 L
.79394 .22987 L
.79396 .22986 L
.79398 .22986 L
.794 .22985 L
.79402 .22985 L
.79403 .22985 L
.79405 .22984 L
.79407 .22984 L
.79409 .22983 L
.79411 .22983 L
.79413 .22982 L
.79414 .22982 L
Mistroke
.79416 .22981 L
.79418 .22981 L
.7942 .2298 L
.79422 .2298 L
.79423 .22979 L
.79425 .22979 L
.79427 .22979 L
.79429 .22978 L
.79431 .22978 L
.79433 .22977 L
.79434 .22977 L
.79436 .22976 L
.79438 .22976 L
.7944 .22975 L
.79442 .22975 L
.79443 .22975 L
.79445 .22974 L
.79447 .22974 L
.79449 .22973 L
.79451 .22973 L
.79452 .22972 L
.79454 .22972 L
.79456 .22972 L
.79458 .22971 L
.7946 .22971 L
.79461 .2297 L
.79463 .2297 L
.79465 .22969 L
.79467 .22969 L
.79468 .22969 L
.7947 .22968 L
.79472 .22968 L
.79474 .22967 L
.79476 .22967 L
.79477 .22967 L
.79479 .22966 L
.79481 .22966 L
.79483 .22965 L
.79485 .22965 L
.79486 .22965 L
.79488 .22964 L
.7949 .22964 L
.79492 .22963 L
.79493 .22963 L
.79495 .22963 L
.79497 .22962 L
.79499 .22962 L
.795 .22961 L
.79502 .22961 L
.79504 .22961 L
Mistroke
.79506 .2296 L
.79507 .2296 L
.79509 .2296 L
.79511 .22959 L
.79513 .22959 L
.79514 .22958 L
.79516 .22958 L
.79518 .22958 L
.7952 .22957 L
.79521 .22957 L
.79523 .22957 L
.79525 .22956 L
.79527 .22956 L
.79528 .22956 L
.7953 .22955 L
.79532 .22955 L
.79534 .22954 L
.79535 .22954 L
.79537 .22954 L
.79539 .22953 L
.79541 .22953 L
.79542 .22953 L
.79544 .22952 L
.79546 .22952 L
.79548 .22952 L
.79549 .22951 L
.79551 .22951 L
.79553 .22951 L
.79554 .2295 L
.79556 .2295 L
.79558 .2295 L
.7956 .22949 L
.79561 .22949 L
.79563 .22949 L
.79565 .22948 L
.79567 .22948 L
.79568 .22948 L
.7957 .22947 L
.79572 .22947 L
.79573 .22947 L
.79575 .22946 L
.79577 .22946 L
.79578 .22946 L
.7958 .22946 L
.79582 .22945 L
.79584 .22945 L
.79585 .22945 L
.79587 .22944 L
.79589 .22944 L
.7959 .22944 L
Mistroke
.79592 .22943 L
.79594 .22943 L
.79596 .22943 L
.79597 .22942 L
.79599 .22942 L
.79601 .22942 L
.79602 .22942 L
.79604 .22941 L
.79606 .22941 L
.79607 .22941 L
.79609 .2294 L
.79611 .2294 L
.79612 .2294 L
.79614 .2294 L
.79616 .22939 L
.79617 .22939 L
.79619 .22939 L
.79621 .22939 L
.79622 .22938 L
.79624 .22938 L
.79626 .22938 L
.79627 .22937 L
.79629 .22937 L
.79631 .22937 L
.79632 .22937 L
.79634 .22936 L
.79636 .22936 L
.79637 .22936 L
.79639 .22936 L
.79641 .22935 L
.79642 .22935 L
.79644 .22935 L
.79646 .22935 L
.79647 .22934 L
.79649 .22934 L
.79651 .22934 L
.79652 .22934 L
.79654 .22933 L
.79656 .22933 L
.79657 .22933 L
.79659 .22933 L
.79661 .22932 L
.79662 .22932 L
.79664 .22932 L
.79666 .22932 L
.79667 .22931 L
.79669 .22931 L
.7967 .22931 L
.79672 .22931 L
.79674 .22931 L
Mistroke
.79675 .2293 L
.79677 .2293 L
.79679 .2293 L
.7968 .2293 L
.79682 .22929 L
.79684 .22929 L
.79685 .22929 L
.79687 .22929 L
.79688 .22929 L
.7969 .22928 L
.79692 .22928 L
.79693 .22928 L
.79695 .22928 L
.79696 .22928 L
.79698 .22927 L
.797 .22927 L
.79701 .22927 L
.79703 .22927 L
.79705 .22927 L
.79706 .22926 L
.79708 .22926 L
.79709 .22926 L
.79711 .22926 L
.79713 .22926 L
.79714 .22925 L
.79716 .22925 L
.79717 .22925 L
.79719 .22925 L
.79721 .22925 L
.79722 .22924 L
.79724 .22924 L
.79725 .22924 L
.79727 .22924 L
.79729 .22924 L
.7973 .22924 L
.79732 .22923 L
.79733 .22923 L
.79735 .22923 L
.79736 .22923 L
.79738 .22923 L
.7974 .22923 L
.79741 .22922 L
.79743 .22922 L
.79744 .22922 L
.79746 .22922 L
.79747 .22922 L
.79749 .22922 L
.79751 .22921 L
.79752 .22921 L
.79754 .22921 L
Mistroke
.79755 .22921 L
.79757 .22921 L
.79758 .22921 L
.7976 .2292 L
.79762 .2292 L
.79763 .2292 L
.79765 .2292 L
.79766 .2292 L
.79768 .2292 L
.79769 .2292 L
.79771 .22919 L
.79772 .22919 L
.79774 .22919 L
.79776 .22919 L
.79777 .22919 L
.79779 .22919 L
.7978 .22919 L
.79782 .22919 L
.79783 .22918 L
.79785 .22918 L
.79786 .22918 L
.79788 .22918 L
.79789 .22918 L
.79791 .22918 L
.79793 .22918 L
.79794 .22918 L
.79796 .22917 L
.79797 .22917 L
.79799 .22917 L
.798 .22917 L
.79802 .22917 L
.79803 .22917 L
.79805 .22917 L
.79806 .22917 L
.79808 .22917 L
.79809 .22916 L
.79811 .22916 L
.79812 .22916 L
.79814 .22916 L
.79815 .22916 L
.79817 .22916 L
.79818 .22916 L
.7982 .22916 L
.79821 .22916 L
.79823 .22916 L
.79824 .22916 L
.79826 .22915 L
.79828 .22915 L
.79829 .22915 L
.79831 .22915 L
Mistroke
.79832 .22915 L
.79834 .22915 L
.79835 .22915 L
.79836 .22915 L
.79838 .22915 L
.79839 .22915 L
.79841 .22915 L
.79842 .22915 L
.79844 .22914 L
.79845 .22914 L
.79847 .22914 L
.79848 .22914 L
.7985 .22914 L
.79851 .22914 L
.79853 .22914 L
.79854 .22914 L
.79856 .22914 L
.79857 .22914 L
.79859 .22914 L
.7986 .22914 L
.79862 .22914 L
.79863 .22914 L
.79865 .22914 L
.79866 .22914 L
.79868 .22914 L
.79869 .22913 L
.79871 .22913 L
.79872 .22913 L
.79873 .22913 L
.79875 .22913 L
.79876 .22913 L
.79878 .22913 L
.79879 .22913 L
.79881 .22913 L
.79882 .22913 L
.79884 .22913 L
.79885 .22913 L
.79887 .22913 L
.79888 .22913 L
.79889 .22913 L
.79891 .22913 L
.79892 .22913 L
.79894 .22913 L
.79895 .22913 L
.79897 .22913 L
.79898 .22913 L
.799 .22913 L
.79901 .22913 L
.79902 .22913 L
.79904 .22913 L
Mistroke
.79905 .22913 L
.79907 .22913 L
.79908 .22913 L
.7991 .22913 L
.79911 .22913 L
.79912 .22913 L
.79914 .22913 L
.79915 .22913 L
.79917 .22913 L
.79918 .22913 L
.7992 .22913 L
.79921 .22913 L
.79922 .22913 L
.79924 .22913 L
.79925 .22913 L
.79927 .22913 L
.79928 .22913 L
.79929 .22913 L
.79931 .22913 L
.79932 .22913 L
.79934 .22913 L
.79935 .22913 L
.79936 .22913 L
.79938 .22913 L
.79939 .22913 L
.79941 .22913 L
.79942 .22913 L
.79943 .22913 L
.79945 .22913 L
.79946 .22913 L
.79948 .22913 L
.79949 .22913 L
.7995 .22913 L
.79952 .22913 L
.79953 .22913 L
.79955 .22913 L
.79956 .22913 L
.79957 .22913 L
.79959 .22913 L
.7996 .22913 L
.79961 .22913 L
.79963 .22913 L
.79964 .22913 L
.79966 .22913 L
.79967 .22913 L
.79968 .22913 L
.7997 .22913 L
.79971 .22913 L
.79972 .22913 L
.79974 .22913 L
Mistroke
.79975 .22914 L
.79976 .22914 L
.79978 .22914 L
.79979 .22914 L
.79981 .22914 L
.79982 .22914 L
.79983 .22914 L
.79985 .22914 L
.79986 .22914 L
.79987 .22914 L
.79989 .22914 L
.7999 .22914 L
.79991 .22914 L
.79993 .22914 L
.79994 .22914 L
.79995 .22914 L
.79997 .22914 L
.79998 .22915 L
.79999 .22915 L
.80001 .22915 L
.80002 .22915 L
.80003 .22915 L
.80005 .22915 L
.80006 .22915 L
.80007 .22915 L
.80009 .22915 L
.8001 .22915 L
.80011 .22915 L
.80013 .22915 L
.80014 .22915 L
.80015 .22916 L
.80017 .22916 L
.80018 .22916 L
.80019 .22916 L
.80021 .22916 L
.80022 .22916 L
.80023 .22916 L
.80025 .22916 L
.80026 .22916 L
.80027 .22916 L
.80028 .22916 L
.8003 .22917 L
.80031 .22917 L
.80032 .22917 L
.80034 .22917 L
.80035 .22917 L
.80036 .22917 L
.80038 .22917 L
.80039 .22917 L
.8004 .22917 L
Mistroke
.80041 .22917 L
.80043 .22918 L
.80044 .22918 L
.80045 .22918 L
.80047 .22918 L
.80048 .22918 L
.80049 .22918 L
.8005 .22918 L
.80052 .22918 L
.80053 .22918 L
.80054 .22919 L
.80056 .22919 L
.80057 .22919 L
.80058 .22919 L
.80059 .22919 L
.80061 .22919 L
.80062 .22919 L
.80063 .22919 L
.80065 .2292 L
.80066 .2292 L
.80067 .2292 L
.80068 .2292 L
.8007 .2292 L
.80071 .2292 L
.80072 .2292 L
.80073 .22921 L
.80075 .22921 L
.80076 .22921 L
.80077 .22921 L
.80078 .22921 L
.8008 .22921 L
.80081 .22921 L
.80082 .22922 L
.80083 .22922 L
.80085 .22922 L
.80086 .22922 L
.80087 .22922 L
.80088 .22922 L
.8009 .22922 L
.80091 .22923 L
.80092 .22923 L
.80093 .22923 L
.80095 .22923 L
.80096 .22923 L
.80097 .22923 L
.80098 .22924 L
.80099 .22924 L
.80101 .22924 L
.80102 .22924 L
.80103 .22924 L
Mistroke
.80104 .22924 L
.80106 .22924 L
.80107 .22925 L
.80108 .22925 L
.80109 .22925 L
.8011 .22925 L
.80112 .22925 L
.80113 .22926 L
.80114 .22926 L
.80115 .22926 L
.80117 .22926 L
.80118 .22926 L
.80119 .22926 L
.8012 .22927 L
.80121 .22927 L
.80123 .22927 L
.80124 .22927 L
.80125 .22927 L
.80126 .22927 L
.80127 .22928 L
.80129 .22928 L
.8013 .22928 L
.80131 .22928 L
.80132 .22928 L
.80133 .22929 L
.80134 .22929 L
.80136 .22929 L
.80137 .22929 L
.80138 .22929 L
.80139 .2293 L
.8014 .2293 L
.80142 .2293 L
.80143 .2293 L
.80144 .2293 L
.80145 .22931 L
.80146 .22931 L
.80147 .22931 L
.80149 .22931 L
.8015 .22931 L
.80151 .22932 L
.80152 .22932 L
.80153 .22932 L
.80154 .22932 L
.80156 .22932 L
.80157 .22933 L
.80158 .22933 L
.80159 .22933 L
.8016 .22933 L
.80161 .22934 L
.80163 .22934 L
Mistroke
.80164 .22934 L
.80165 .22934 L
.80166 .22934 L
.80167 .22935 L
.80168 .22935 L
.80169 .22935 L
.80171 .22935 L
.80172 .22936 L
.80173 .22936 L
.80174 .22936 L
.80175 .22936 L
.80176 .22936 L
.80177 .22937 L
.80179 .22937 L
.8018 .22937 L
.80181 .22937 L
.80182 .22938 L
.80183 .22938 L
.80184 .22938 L
.80185 .22938 L
.80186 .22939 L
.80188 .22939 L
.80189 .22939 L
.8019 .22939 L
.80191 .2294 L
.80192 .2294 L
.80193 .2294 L
.80194 .2294 L
.80195 .22941 L
.80197 .22941 L
.80198 .22941 L
.80199 .22941 L
.802 .22942 L
.80201 .22942 L
.80202 .22942 L
.80203 .22942 L
.80204 .22943 L
.80205 .22943 L
.80206 .22943 L
.80208 .22943 L
.80209 .22944 L
.8021 .22944 L
.80211 .22944 L
.80212 .22944 L
.80213 .22945 L
.80214 .22945 L
.80215 .22945 L
.80216 .22945 L
.80217 .22946 L
.80218 .22946 L
Mistroke
.8022 .22946 L
.80221 .22947 L
.80222 .22947 L
.80223 .22947 L
.80224 .22947 L
.80225 .22948 L
.80226 .22948 L
.80227 .22948 L
.80228 .22948 L
.80229 .22949 L
.8023 .22949 L
.80231 .22949 L
.80232 .2295 L
.80233 .2295 L
.80235 .2295 L
.80236 .2295 L
.80237 .22951 L
.80238 .22951 L
.80239 .22951 L
.8024 .22952 L
.80241 .22952 L
.80242 .22952 L
.80243 .22952 L
.80244 .22953 L
.80245 .22953 L
.80246 .22953 L
.80247 .22954 L
.80248 .22954 L
.80249 .22954 L
.8025 .22954 L
.80251 .22955 L
.80252 .22955 L
.80253 .22955 L
.80254 .22956 L
.80255 .22956 L
.80257 .22956 L
.80258 .22957 L
.80259 .22957 L
.8026 .22957 L
.80261 .22958 L
.80262 .22958 L
.80263 .22958 L
.80264 .22958 L
.80265 .22959 L
.80266 .22959 L
.80267 .22959 L
.80268 .2296 L
.80269 .2296 L
.8027 .2296 L
.80271 .22961 L
Mistroke
.80272 .22961 L
.80273 .22961 L
.80274 .22962 L
.80275 .22962 L
.80276 .22962 L
.80277 .22963 L
.80278 .22963 L
.80279 .22963 L
.8028 .22964 L
.80281 .22964 L
.80282 .22964 L
.80283 .22965 L
.80284 .22965 L
.80285 .22965 L
.80286 .22966 L
.80287 .22966 L
.80288 .22966 L
.80289 .22966 L
.8029 .22967 L
.80291 .22967 L
.80292 .22968 L
.80293 .22968 L
.80294 .22968 L
.80295 .22969 L
.80296 .22969 L
.80297 .22969 L
.80298 .2297 L
.80299 .2297 L
.803 .2297 L
.80301 .22971 L
.80302 .22971 L
.80303 .22971 L
.80304 .22972 L
.80304 .22972 L
.80305 .22972 L
.80306 .22973 L
.80307 .22973 L
.80308 .22973 L
.80309 .22974 L
.8031 .22974 L
.80311 .22974 L
.80312 .22975 L
.80313 .22975 L
.80314 .22975 L
.80315 .22976 L
.80316 .22976 L
.80317 .22977 L
.80318 .22977 L
.80319 .22977 L
.8032 .22978 L
Mistroke
.80321 .22978 L
.80322 .22978 L
.80323 .22979 L
.80323 .22979 L
.80324 .22979 L
.80325 .2298 L
.80326 .2298 L
.80327 .22981 L
.80328 .22981 L
.80329 .22981 L
.8033 .22982 L
.80331 .22982 L
.80332 .22982 L
.80333 .22983 L
.80334 .22983 L
.80335 .22984 L
.80336 .22984 L
.80336 .22984 L
.80337 .22985 L
.80338 .22985 L
.80339 .22985 L
.8034 .22986 L
.80341 .22986 L
.80342 .22987 L
.80343 .22987 L
.80344 .22987 L
.80345 .22988 L
.80346 .22988 L
.80346 .22988 L
.80347 .22989 L
.80348 .22989 L
.80349 .2299 L
.8035 .2299 L
.80351 .2299 L
.80352 .22991 L
.80353 .22991 L
.80354 .22992 L
.80355 .22992 L
.80355 .22992 L
.80356 .22993 L
.80357 .22993 L
.80358 .22994 L
.80359 .22994 L
.8036 .22994 L
.80361 .22995 L
.80362 .22995 L
.80363 .22996 L
.80363 .22996 L
.80364 .22996 L
.80365 .22997 L
Mistroke
.80366 .22997 L
.80367 .22998 L
.80368 .22998 L
.80369 .22998 L
.8037 .22999 L
.8037 .22999 L
.80371 .23 L
.80372 .23 L
.80373 .23 L
.80374 .23001 L
.80375 .23001 L
.80376 .23002 L
.80376 .23002 L
.80377 .23002 L
.80378 .23003 L
.80379 .23003 L
.8038 .23004 L
.80381 .23004 L
.80382 .23005 L
.80382 .23005 L
.80383 .23005 L
.80384 .23006 L
.80385 .23006 L
.80386 .23007 L
.80387 .23007 L
.80387 .23007 L
.80388 .23008 L
.80389 .23008 L
.8039 .23009 L
.80391 .23009 L
.80392 .2301 L
.80392 .2301 L
.80393 .2301 L
.80394 .23011 L
.80395 .23011 L
.80396 .23012 L
.80397 .23012 L
.80397 .23013 L
.80398 .23013 L
.80399 .23013 L
.804 .23014 L
.80401 .23014 L
.80401 .23015 L
.80402 .23015 L
.80403 .23016 L
.80404 .23016 L
.80405 .23017 L
.80406 .23017 L
.80406 .23017 L
.80407 .23018 L
Mistroke
.80408 .23018 L
.80409 .23019 L
.8041 .23019 L
.8041 .2302 L
.80411 .2302 L
.80412 .23021 L
.80413 .23021 L
.80414 .23021 L
.80414 .23022 L
.80415 .23022 L
.80416 .23023 L
.80417 .23023 L
.80417 .23024 L
.80418 .23024 L
.80419 .23025 L
.8042 .23025 L
.80421 .23025 L
.80421 .23026 L
.80422 .23026 L
.80423 .23027 L
.80424 .23027 L
.80425 .23028 L
.80425 .23028 L
.80426 .23029 L
.80427 .23029 L
.80428 .2303 L
.80428 .2303 L
.80429 .23031 L
.8043 .23031 L
.80431 .23031 L
.80431 .23032 L
.80432 .23032 L
.80433 .23033 L
.80434 .23033 L
.80435 .23034 L
.80435 .23034 L
.80436 .23035 L
.80437 .23035 L
.80438 .23036 L
.80438 .23036 L
.80439 .23037 L
.8044 .23037 L
.80441 .23038 L
.80441 .23038 L
.80442 .23038 L
.80443 .23039 L
.80444 .23039 L
.80444 .2304 L
.80445 .2304 L
.80446 .23041 L
Mistroke
.80446 .23041 L
.80447 .23042 L
.80448 .23042 L
.80449 .23043 L
.80449 .23043 L
.8045 .23044 L
.80451 .23044 L
.80452 .23045 L
.80452 .23045 L
.80453 .23046 L
.80454 .23046 L
.80454 .23047 L
.80455 .23047 L
.80456 .23048 L
.80457 .23048 L
.80457 .23049 L
.80458 .23049 L
.80459 .2305 L
.8046 .2305 L
.8046 .2305 L
.80461 .23051 L
.80462 .23051 L
.80462 .23052 L
.80463 .23052 L
.80464 .23053 L
.80464 .23053 L
.80465 .23054 L
.80466 .23054 L
.80467 .23055 L
.80467 .23055 L
.80468 .23056 L
.80469 .23056 L
.80469 .23057 L
.8047 .23057 L
.80471 .23058 L
.80471 .23058 L
.80472 .23059 L
.80473 .23059 L
.80473 .2306 L
.80474 .2306 L
.80475 .23061 L
.80476 .23061 L
.80476 .23062 L
.80477 .23062 L
.80478 .23063 L
.80478 .23063 L
.80479 .23064 L
.8048 .23064 L
.8048 .23065 L
.80481 .23065 L
Mistroke
.80482 .23066 L
.80482 .23066 L
.80483 .23067 L
.80484 .23068 L
.80484 .23068 L
.80485 .23069 L
.80486 .23069 L
.80486 .2307 L
.80487 .2307 L
.80488 .23071 L
.80488 .23071 L
.80489 .23072 L
.8049 .23072 L
.8049 .23073 L
.80491 .23073 L
.80492 .23074 L
.80492 .23074 L
.80493 .23075 L
.80493 .23075 L
.80494 .23076 L
.80495 .23076 L
.80495 .23077 L
.80496 .23077 L
.80497 .23078 L
.80497 .23078 L
.80498 .23079 L
.80499 .23079 L
.80499 .2308 L
.805 .2308 L
.80501 .23081 L
.80501 .23082 L
.80502 .23082 L
.80502 .23083 L
.80503 .23083 L
.80504 .23084 L
.80504 .23084 L
.80505 .23085 L
.80506 .23085 L
.80506 .23086 L
.80507 .23086 L
.80507 .23087 L
.80508 .23087 L
.80509 .23088 L
.80509 .23088 L
.8051 .23089 L
.8051 .23089 L
.80511 .2309 L
.80512 .23091 L
.80512 .23091 L
.80513 .23092 L
Mistroke
.80514 .23092 L
.80514 .23093 L
.80515 .23093 L
.80515 .23094 L
.80516 .23094 L
.80517 .23095 L
.80517 .23095 L
.80518 .23096 L
.80518 .23097 L
.80519 .23097 L
.80519 .23098 L
.8052 .23098 L
.80521 .23099 L
.80521 .23099 L
.80522 .231 L
.80522 .231 L
.80523 .23101 L
.80524 .23101 L
.80524 .23102 L
.80525 .23103 L
.80525 .23103 L
.80526 .23104 L
.80527 .23104 L
.80527 .23105 L
.80528 .23105 L
.80528 .23106 L
.80529 .23106 L
.80529 .23107 L
.8053 .23107 L
.80531 .23108 L
.80531 .23109 L
.80532 .23109 L
.80532 .2311 L
.80533 .2311 L
.80533 .23111 L
.80534 .23111 L
.80534 .23112 L
.80535 .23112 L
.80536 .23113 L
.80536 .23114 L
.80537 .23114 L
.80537 .23115 L
.80538 .23115 L
.80538 .23116 L
.80539 .23116 L
.80539 .23117 L
.8054 .23118 L
.80541 .23118 L
.80541 .23119 L
.80542 .23119 L
Mistroke
.80542 .2312 L
.80543 .2312 L
.80543 .23121 L
.80544 .23121 L
.80544 .23122 L
.80545 .23123 L
.80545 .23123 L
.80546 .23124 L
.80546 .23124 L
.80547 .23125 L
.80548 .23125 L
.80548 .23126 L
.80549 .23127 L
.80549 .23127 L
.8055 .23128 L
.8055 .23128 L
.80551 .23129 L
.80551 .23129 L
.80552 .2313 L
.80552 .23131 L
.80553 .23131 L
.80553 .23132 L
.80554 .23132 L
.80554 .23133 L
.80555 .23133 L
.80555 .23134 L
.80556 .23135 L
.80556 .23135 L
.80557 .23136 L
.80557 .23136 L
.80558 .23137 L
.80558 .23138 L
.80559 .23138 L
.80559 .23139 L
.8056 .23139 L
.8056 .2314 L
.80561 .2314 L
.80561 .23141 L
.80562 .23142 L
.80562 .23142 L
.80563 .23143 L
.80563 .23143 L
.80564 .23144 L
.80564 .23145 L
.80565 .23145 L
.80565 .23146 L
.80566 .23146 L
.80566 .23147 L
.80567 .23147 L
.80567 .23148 L
Mistroke
.80568 .23149 L
.80568 .23149 L
.80569 .2315 L
.80569 .2315 L
.8057 .23151 L
.8057 .23152 L
.8057 .23152 L
.80571 .23153 L
.80571 .23153 L
.80572 .23154 L
.80572 .23155 L
.80573 .23155 L
.80573 .23156 L
.80574 .23156 L
.80574 .23157 L
.80575 .23157 L
.80575 .23158 L
.80576 .23159 L
.80576 .23159 L
.80577 .2316 L
.80577 .2316 L
.80577 .23161 L
.80578 .23162 L
.80578 .23162 L
.80579 .23163 L
.80579 .23163 L
.8058 .23164 L
.8058 .23165 L
.80581 .23165 L
.80581 .23166 L
.80581 .23166 L
.80582 .23167 L
.80582 .23168 L
.80583 .23168 L
.80583 .23169 L
.80584 .23169 L
.80584 .2317 L
.80585 .23171 L
.80585 .23171 L
.80585 .23172 L
.80586 .23172 L
.80586 .23173 L
.80587 .23174 L
.80587 .23174 L
.80588 .23175 L
.80588 .23176 L
.80588 .23176 L
.80589 .23177 L
.80589 .23177 L
.8059 .23178 L
Mistroke
.8059 .23179 L
.8059 .23179 L
.80591 .2318 L
.80591 .2318 L
.80592 .23181 L
.80592 .23182 L
.80593 .23182 L
.80593 .23183 L
.80593 .23183 L
.80594 .23184 L
.80594 .23185 L
.80595 .23185 L
.80595 .23186 L
.80595 .23186 L
.80596 .23187 L
.80596 .23188 L
.80597 .23188 L
.80597 .23189 L
.80597 .2319 L
.80598 .2319 L
.80598 .23191 L
.80599 .23191 L
.80599 .23192 L
.80599 .23193 L
.806 .23193 L
.806 .23194 L
.80601 .23195 L
.80601 .23195 L
.80601 .23196 L
.80602 .23196 L
.80602 .23197 L
.80602 .23198 L
.80603 .23198 L
.80603 .23199 L
.80604 .23199 L
.80604 .232 L
.80604 .23201 L
.80605 .23201 L
.80605 .23202 L
.80605 .23203 L
.80606 .23203 L
.80606 .23204 L
.80607 .23204 L
.80607 .23205 L
.80607 .23206 L
.80608 .23206 L
.80608 .23207 L
.80608 .23208 L
.80609 .23208 L
.80609 .23209 L
Mistroke
.80609 .23209 L
.8061 .2321 L
.8061 .23211 L
.80611 .23211 L
.80611 .23212 L
.80611 .23213 L
.80612 .23213 L
.80612 .23214 L
.80612 .23214 L
.80613 .23215 L
.80613 .23216 L
.80613 .23216 L
.80614 .23217 L
.80614 .23218 L
.80614 .23218 L
.80615 .23219 L
.80615 .2322 L
.80615 .2322 L
.80616 .23221 L
.80616 .23221 L
.80616 .23222 L
.80617 .23223 L
.80617 .23223 L
.80617 .23224 L
.80618 .23225 L
.80618 .23225 L
.80618 .23226 L
.80619 .23226 L
.80619 .23227 L
.80619 .23228 L
.8062 .23228 L
.8062 .23229 L
.8062 .2323 L
.80621 .2323 L
.80621 .23231 L
.80621 .23232 L
.80622 .23232 L
.80622 .23233 L
.80622 .23233 L
.80623 .23234 L
.80623 .23235 L
.80623 .23235 L
.80624 .23236 L
.80624 .23237 L
.80624 .23237 L
.80624 .23238 L
.80625 .23239 L
.80625 .23239 L
.80625 .2324 L
.80626 .23241 L
Mistroke
.80626 .23241 L
.80626 .23242 L
.80627 .23242 L
.80627 .23243 L
.80627 .23244 L
.80627 .23244 L
.80628 .23245 L
.80628 .23246 L
.80628 .23246 L
.80629 .23247 L
.80629 .23248 L
.80629 .23248 L
.80629 .23249 L
.8063 .2325 L
.8063 .2325 L
.8063 .23251 L
.80631 .23251 L
.80631 .23252 L
.80631 .23253 L
.80631 .23253 L
.80632 .23254 L
.80632 .23255 L
.80632 .23255 L
.80633 .23256 L
.80633 .23257 L
.80633 .23257 L
.80633 .23258 L
.80634 .23259 L
.80634 .23259 L
.80634 .2326 L
.80634 .23261 L
.80635 .23261 L
.80635 .23262 L
.80635 .23263 L
.80636 .23263 L
.80636 .23264 L
.80636 .23264 L
.80636 .23265 L
.80637 .23266 L
.80637 .23266 L
.80637 .23267 L
.80637 .23268 L
.80638 .23268 L
.80638 .23269 L
.80638 .2327 L
.80638 .2327 L
.80639 .23271 L
.80639 .23272 L
.80639 .23272 L
.80639 .23273 L
Mistroke
.8064 .23274 L
.8064 .23274 L
.8064 .23275 L
.8064 .23276 L
.80641 .23276 L
.80641 .23277 L
.80641 .23278 L
.80641 .23278 L
.80642 .23279 L
.80642 .2328 L
.80642 .2328 L
.80642 .23281 L
.80642 .23281 L
.80643 .23282 L
.80643 .23283 L
.80643 .23283 L
.80643 .23284 L
.80644 .23285 L
.80644 .23285 L
.80644 .23286 L
.80644 .23287 L
.80645 .23287 L
.80645 .23288 L
.80645 .23289 L
.80645 .23289 L
.80645 .2329 L
.80646 .23291 L
.80646 .23291 L
.80646 .23292 L
.80646 .23293 L
.80647 .23293 L
.80647 .23294 L
.80647 .23295 L
.80647 .23295 L
.80647 .23296 L
.80648 .23297 L
.80648 .23297 L
.80648 .23298 L
.80648 .23299 L
.80648 .23299 L
.80649 .233 L
.80649 .23301 L
.80649 .23301 L
.80649 .23302 L
.80649 .23303 L
.8065 .23303 L
.8065 .23304 L
.8065 .23305 L
.8065 .23305 L
.8065 .23306 L
Mistroke
.80651 .23307 L
.80651 .23307 L
.80651 .23308 L
.80651 .23309 L
.80651 .23309 L
.80652 .2331 L
.80652 .23311 L
.80652 .23311 L
.80652 .23312 L
.80652 .23313 L
.80652 .23313 L
.80653 .23314 L
.80653 .23315 L
.80653 .23315 L
.80653 .23316 L
.80653 .23317 L
.80653 .23317 L
.80654 .23318 L
.80654 .23319 L
.80654 .23319 L
.80654 .2332 L
.80654 .23321 L
.80655 .23321 L
.80655 .23322 L
.80655 .23323 L
.80655 .23323 L
.80655 .23324 L
.80655 .23325 L
.80656 .23325 L
.80656 .23326 L
.80656 .23327 L
.80656 .23327 L
.80656 .23328 L
.80656 .23329 L
.80656 .23329 L
.80657 .2333 L
.80657 .23331 L
.80657 .23331 L
.80657 .23332 L
.80657 .23333 L
.80657 .23333 L
.80658 .23334 L
.80658 .23335 L
.80658 .23335 L
.80658 .23336 L
.80658 .23337 L
.80658 .23337 L
.80658 .23338 L
.80659 .23339 L
.80659 .23339 L
Mistroke
.80659 .2334 L
.80659 .23341 L
.80659 .23341 L
.80659 .23342 L
.80659 .23343 L
.8066 .23343 L
.8066 .23344 L
.8066 .23345 L
.8066 .23345 L
.8066 .23346 L
.8066 .23347 L
.8066 .23347 L
.8066 .23348 L
.80661 .23349 L
.80661 .23349 L
.80661 .2335 L
.80661 .23351 L
.80661 .23352 L
.80661 .23352 L
.80661 .23353 L
.80661 .23354 L
.80662 .23354 L
.80662 .23355 L
.80662 .23356 L
.80662 .23356 L
.80662 .23357 L
.80662 .23358 L
.80662 .23358 L
.80662 .23359 L
.80663 .2336 L
.80663 .2336 L
.80663 .23361 L
.80663 .23362 L
.80663 .23362 L
.80663 .23363 L
.80663 .23364 L
.80663 .23364 L
.80663 .23365 L
.80663 .23366 L
.80664 .23366 L
.80664 .23367 L
.80664 .23368 L
.80664 .23368 L
.80664 .23369 L
.80664 .2337 L
.80664 .2337 L
.80664 .23371 L
.80664 .23372 L
.80664 .23372 L
.80665 .23373 L
Mistroke
.80665 .23374 L
.80665 .23375 L
.80665 .23375 L
.80665 .23376 L
.80665 .23377 L
.80665 .23377 L
.80665 .23378 L
.80665 .23379 L
.80665 .23379 L
.80665 .2338 L
.80665 .23381 L
.80666 .23381 L
.80666 .23382 L
.80666 .23383 L
.80666 .23383 L
.80666 .23384 L
.80666 .23385 L
.80666 .23385 L
.80666 .23386 L
.80666 .23387 L
.80666 .23387 L
.80666 .23388 L
.80666 .23389 L
.80666 .23389 L
.80667 .2339 L
.80667 .23391 L
.80667 .23391 L
.80667 .23392 L
.80667 .23393 L
.80667 .23394 L
.80667 .23394 L
.80667 .23395 L
.80667 .23396 L
.80667 .23396 L
.80667 .23397 L
.80667 .23398 L
.80667 .23398 L
.80667 .23399 L
.80667 .234 L
.80667 .234 L
.80667 .23401 L
.80668 .23402 L
.80668 .23402 L
.80668 .23403 L
.80668 .23404 L
.80668 .23404 L
.80668 .23405 L
.80668 .23406 L
.80668 .23406 L
.80668 .23407 L
Mistroke
.80668 .23408 L
.80668 .23409 L
.80668 .23409 L
.80668 .2341 L
.80668 .23411 L
.80668 .23411 L
.80668 .23412 L
.80668 .23413 L
.80668 .23413 L
.80668 .23414 L
.80668 .23415 L
.80668 .23415 L
.80668 .23416 L
.80668 .23417 L
.80668 .23417 L
.80668 .23418 L
.80669 .23419 L
.80669 .23419 L
.80669 .2342 L
.80669 .23421 L
.80669 .23421 L
.80669 .23422 L
.80669 .23423 L
.80669 .23424 L
.80669 .23424 L
.80669 .23425 L
.80669 .23426 L
.80669 .23426 L
.80669 .23427 L
.80669 .23428 L
.80669 .23428 L
.80669 .23429 L
.80669 .2343 L
.80669 .2343 L
.80669 .23431 L
.80669 .23432 L
.80669 .23432 L
.80669 .23433 L
.80669 .23434 L
.80669 .23434 L
.80669 .23435 L
.80669 .23436 L
.80669 .23436 L
.80669 .23437 L
.80669 .23438 L
.80669 .23439 L
.80669 .23439 L
.80669 .2344 L
.80669 .23441 L
.80669 .23441 L
Mistroke
.80669 .23442 L
.80669 .23443 L
.80669 .23443 L
.80669 .23444 L
.80669 .23445 L
.80669 .23445 L
.80669 .23446 L
.80669 .23447 L
.80669 .23447 L
.80669 .23448 L
.80669 .23449 L
.80669 .23449 L
.80669 .2345 L
.80669 .23451 L
.80669 .23452 L
.80669 .23452 L
.80669 .23453 L
.80669 .23454 L
.80669 .23454 L
.80669 .23455 L
.80669 .23456 L
.80669 .23456 L
.80669 .23457 L
.80669 .23458 L
.80669 .23458 L
.80669 .23459 L
.80669 .2346 L
.80669 .2346 L
.80669 .23461 L
.80669 .23462 L
.80669 .23462 L
.80668 .23463 L
.80668 .23464 L
.80668 .23464 L
.80668 .23465 L
.80668 .23466 L
.80668 .23467 L
.80668 .23467 L
.80668 .23468 L
.80668 .23469 L
.80668 .23469 L
.80668 .2347 L
.80668 .23471 L
.80668 .23471 L
.80668 .23472 L
.80668 .23473 L
.80668 .23473 L
.80668 .23474 L
.80668 .23475 L
.80668 .23475 L
Mistroke
.80668 .23476 L
.80668 .23477 L
.80668 .23477 L
.80668 .23478 L
.80668 .23479 L
.80668 .23479 L
.80667 .2348 L
.80667 .23481 L
.80667 .23482 L
.80667 .23482 L
.80667 .23483 L
.80667 .23484 L
.80667 .23484 L
.80667 .23485 L
.80667 .23486 L
.80667 .23486 L
.80667 .23487 L
.80667 .23488 L
.80667 .23488 L
.80667 .23489 L
.80667 .2349 L
.80667 .2349 L
.80667 .23491 L
.80666 .23492 L
.80666 .23492 L
.80666 .23493 L
.80666 .23494 L
.80666 .23494 L
.80666 .23495 L
.80666 .23496 L
.80666 .23497 L
.80666 .23497 L
.80666 .23498 L
.80666 .23499 L
.80666 .23499 L
.80666 .235 L
.80666 .23501 L
.80666 .23501 L
.80665 .23502 L
.80665 .23503 L
.80665 .23503 L
.80665 .23504 L
.80665 .23505 L
.80665 .23505 L
.80665 .23506 L
.80665 .23507 L
.80665 .23507 L
.80665 .23508 L
.80665 .23509 L
.80665 .23509 L
Mistroke
.80664 .2351 L
.80664 .23511 L
.80664 .23511 L
.80664 .23512 L
.80664 .23513 L
.80664 .23514 L
.80664 .23514 L
.80664 .23515 L
.80664 .23516 L
.80664 .23516 L
.80664 .23517 L
.80663 .23518 L
.80663 .23518 L
.80663 .23519 L
.80663 .2352 L
.80663 .2352 L
.80663 .23521 L
.80663 .23522 L
.80663 .23522 L
.80663 .23523 L
.80663 .23524 L
.80662 .23524 L
.80662 .23525 L
.80662 .23526 L
.80662 .23526 L
.80662 .23527 L
.80662 .23528 L
.80662 .23528 L
.80662 .23529 L
.80662 .2353 L
.80661 .2353 L
.80661 .23531 L
.80661 .23532 L
.80661 .23532 L
.80661 .23533 L
.80661 .23534 L
.80661 .23535 L
.80661 .23535 L
.80661 .23536 L
.8066 .23537 L
.8066 .23537 L
.8066 .23538 L
.8066 .23539 L
.8066 .23539 L
.8066 .2354 L
.8066 .23541 L
.8066 .23541 L
.8066 .23542 L
.80659 .23543 L
.80659 .23543 L
Mistroke
.80659 .23544 L
.80659 .23545 L
.80659 .23545 L
.80659 .23546 L
.80659 .23547 L
.80658 .23547 L
.80658 .23548 L
.80658 .23549 L
.80658 .23549 L
.80658 .2355 L
.80658 .23551 L
.80658 .23551 L
.80658 .23552 L
.80657 .23553 L
.80657 .23553 L
.80657 .23554 L
.80657 .23555 L
.80657 .23555 L
.80657 .23556 L
.80657 .23557 L
.80656 .23557 L
.80656 .23558 L
.80656 .23559 L
.80656 .23559 L
.80656 .2356 L
.80656 .23561 L
.80656 .23561 L
.80655 .23562 L
.80655 .23563 L
.80655 .23563 L
.80655 .23564 L
.80655 .23565 L
.80655 .23566 L
.80655 .23566 L
.80654 .23567 L
.80654 .23568 L
.80654 .23568 L
.80654 .23569 L
.80654 .2357 L
.80654 .2357 L
.80654 .23571 L
.80653 .23572 L
.80653 .23572 L
.80653 .23573 L
.80653 .23574 L
.80653 .23574 L
.80653 .23575 L
.80652 .23576 L
.80652 .23576 L
.80652 .23577 L
Mistroke
.80652 .23578 L
.80652 .23578 L
.80652 .23579 L
.80651 .2358 L
.80651 .2358 L
.80651 .23581 L
.80651 .23582 L
.80651 .23582 L
.80651 .23583 L
.8065 .23584 L
.8065 .23584 L
.8065 .23585 L
.8065 .23586 L
.8065 .23586 L
.8065 .23587 L
.80649 .23588 L
.80649 .23588 L
.80649 .23589 L
.80649 .2359 L
.80649 .2359 L
.80649 .23591 L
.80648 .23592 L
.80648 .23592 L
.80648 .23593 L
.80648 .23594 L
.80648 .23594 L
.80647 .23595 L
.80647 .23596 L
.80647 .23596 L
.80647 .23597 L
.80647 .23598 L
.80647 .23598 L
.80646 .23599 L
.80646 .236 L
.80646 .236 L
.80646 .23601 L
.80646 .23602 L
.80645 .23602 L
.80645 .23603 L
.80645 .23604 L
.80645 .23604 L
.80645 .23605 L
.80644 .23605 L
.80644 .23606 L
.80644 .23607 L
.80644 .23607 L
.80644 .23608 L
.80644 .23609 L
.80643 .23609 L
.80643 .2361 L
Mistroke
.80643 .23611 L
.80643 .23611 L
.80643 .23612 L
.80642 .23613 L
.80642 .23613 L
.80642 .23614 L
.80642 .23615 L
.80642 .23615 L
.80641 .23616 L
.80641 .23617 L
.80641 .23617 L
.80641 .23618 L
.80641 .23619 L
.8064 .23619 L
.8064 .2362 L
.8064 .23621 L
.8064 .23621 L
.8064 .23622 L
.80639 .23623 L
.80639 .23623 L
.80639 .23624 L
.80639 .23625 L
.80638 .23625 L
.80638 .23626 L
.80638 .23627 L
.80638 .23627 L
.80638 .23628 L
.80637 .23629 L
.80637 .23629 L
.80637 .2363 L
.80637 .23631 L
.80637 .23631 L
.80636 .23632 L
.80636 .23632 L
.80636 .23633 L
.80636 .23634 L
.80635 .23634 L
.80635 .23635 L
.80635 .23636 L
.80635 .23636 L
.80635 .23637 L
.80634 .23638 L
.80634 .23638 L
.80634 .23639 L
.80634 .2364 L
.80633 .2364 L
.80633 .23641 L
.80633 .23642 L
.80633 .23642 L
.80633 .23643 L
Mistroke
.80632 .23644 L
.80632 .23644 L
.80632 .23645 L
.80632 .23646 L
.80631 .23646 L
.80631 .23647 L
.80631 .23647 L
.80631 .23648 L
.8063 .23649 L
.8063 .23649 L
.8063 .2365 L
.8063 .23651 L
.8063 .23651 L
.80629 .23652 L
.80629 .23653 L
.80629 .23653 L
.80629 .23654 L
.80628 .23655 L
.80628 .23655 L
.80628 .23656 L
.80628 .23657 L
.80627 .23657 L
.80627 .23658 L
.80627 .23658 L
.80627 .23659 L
.80626 .2366 L
.80626 .2366 L
.80626 .23661 L
.80626 .23662 L
.80625 .23662 L
.80625 .23663 L
.80625 .23664 L
.80625 .23664 L
.80624 .23665 L
.80624 .23666 L
.80624 .23666 L
.80624 .23667 L
.80623 .23668 L
.80623 .23668 L
.80623 .23669 L
.80623 .23669 L
.80622 .2367 L
.80622 .23671 L
.80622 .23671 L
.80622 .23672 L
.80621 .23673 L
.80621 .23673 L
.80621 .23674 L
.80621 .23675 L
.8062 .23675 L
Mistroke
.8062 .23676 L
.8062 .23676 L
.8062 .23677 L
.80619 .23678 L
.80619 .23678 L
.80619 .23679 L
.80619 .2368 L
.80618 .2368 L
.80618 .23681 L
.80618 .23682 L
.80617 .23682 L
.80617 .23683 L
.80617 .23684 L
.80617 .23684 L
.80616 .23685 L
.80616 .23685 L
.80616 .23686 L
.80616 .23687 L
.80615 .23687 L
.80615 .23688 L
.80615 .23689 L
.80615 .23689 L
.80614 .2369 L
.80614 .2369 L
.80614 .23691 L
.80613 .23692 L
.80613 .23692 L
.80613 .23693 L
.80613 .23694 L
.80612 .23694 L
.80612 .23695 L
.80612 .23696 L
.80612 .23696 L
.80611 .23697 L
.80611 .23697 L
.80611 .23698 L
.8061 .23699 L
.8061 .23699 L
.8061 .237 L
.8061 .23701 L
.80609 .23701 L
.80609 .23702 L
.80609 .23703 L
.80608 .23703 L
.80608 .23704 L
.80608 .23704 L
.80608 .23705 L
.80607 .23706 L
.80607 .23706 L
.80607 .23707 L
Mistroke
.80606 .23708 L
.80606 .23708 L
.80606 .23709 L
.80606 .23709 L
.80605 .2371 L
.80605 .23711 L
.80605 .23711 L
.80604 .23712 L
.80604 .23713 L
.80604 .23713 L
.80604 .23714 L
.80603 .23714 L
.80603 .23715 L
.80603 .23716 L
.80602 .23716 L
.80602 .23717 L
.80602 .23718 L
.80601 .23718 L
.80601 .23719 L
.80601 .23719 L
.80601 .2372 L
.806 .23721 L
.806 .23721 L
.806 .23722 L
.80599 .23723 L
.80599 .23723 L
.80599 .23724 L
.80599 .23724 L
.80598 .23725 L
.80598 .23726 L
.80598 .23726 L
.80597 .23727 L
.80597 .23727 L
.80597 .23728 L
.80596 .23729 L
.80596 .23729 L
.80596 .2373 L
.80595 .23731 L
.80595 .23731 L
.80595 .23732 L
.80595 .23732 L
.80594 .23733 L
.80594 .23734 L
.80594 .23734 L
.80593 .23735 L
.80593 .23736 L
.80593 .23736 L
.80592 .23737 L
.80592 .23737 L
.80592 .23738 L
Mistroke
.80591 .23739 L
.80591 .23739 L
.80591 .2374 L
.80591 .2374 L
.8059 .23741 L
.8059 .23742 L
.8059 .23742 L
.80589 .23743 L
.80589 .23743 L
.80589 .23744 L
.80588 .23745 L
.80588 .23745 L
.80588 .23746 L
.80587 .23747 L
.80587 .23747 L
.80587 .23748 L
.80586 .23748 L
.80586 .23749 L
.80586 .2375 L
.80585 .2375 L
.80585 .23751 L
.80585 .23751 L
.80584 .23752 L
.80584 .23753 L
.80584 .23753 L
.80583 .23754 L
.80583 .23754 L
.80583 .23755 L
.80583 .23756 L
.80582 .23756 L
.80582 .23757 L
.80582 .23757 L
.80581 .23758 L
.80581 .23759 L
.80581 .23759 L
.8058 .2376 L
.8058 .23761 L
.8058 .23761 L
.80579 .23762 L
.80579 .23762 L
.80579 .23763 L
.80578 .23764 L
.80578 .23764 L
.80578 .23765 L
.80577 .23765 L
.80577 .23766 L
.80577 .23767 L
.80576 .23767 L
.80576 .23768 L
.80576 .23768 L
Mistroke
.80575 .23769 L
.80575 .2377 L
.80575 .2377 L
.80574 .23771 L
.80574 .23771 L
.80574 .23772 L
.80573 .23773 L
.80573 .23773 L
.80573 .23774 L
.80572 .23774 L
.80572 .23775 L
.80572 .23776 L
.80571 .23776 L
.80571 .23777 L
.8057 .23777 L
.8057 .23778 L
.8057 .23778 L
.80569 .23779 L
.80569 .2378 L
.80569 .2378 L
.80568 .23781 L
.80568 .23781 L
.80568 .23782 L
.80567 .23783 L
.80567 .23783 L
.80567 .23784 L
.80566 .23784 L
.80566 .23785 L
.80566 .23786 L
.80565 .23786 L
.80565 .23787 L
.80565 .23787 L
.80564 .23788 L
.80564 .23789 L
.80564 .23789 L
.80563 .2379 L
.80563 .2379 L
.80562 .23791 L
.80562 .23791 L
.80562 .23792 L
.80561 .23793 L
.80561 .23793 L
.80561 .23794 L
.8056 .23794 L
.8056 .23795 L
.8056 .23796 L
.80559 .23796 L
.80559 .23797 L
.80559 .23797 L
.80558 .23798 L
Mistroke
.80558 .23799 L
.80558 .23799 L
.80557 .238 L
.80557 .238 L
.80556 .23801 L
.80556 .23801 L
.80556 .23802 L
.80555 .23803 L
.80555 .23803 L
.80555 .23804 L
.80554 .23804 L
.80554 .23805 L
.80554 .23805 L
.80553 .23806 L
.80553 .23807 L
.80552 .23807 L
.80552 .23808 L
.80552 .23808 L
.80551 .23809 L
.80551 .2381 L
.80551 .2381 L
.8055 .23811 L
.8055 .23811 L
.8055 .23812 L
.80549 .23812 L
.80549 .23813 L
.80548 .23814 L
.80548 .23814 L
.80548 .23815 L
.80547 .23815 L
.80547 .23816 L
.80547 .23816 L
.80546 .23817 L
.80546 .23818 L
.80545 .23818 L
.80545 .23819 L
.80545 .23819 L
.80544 .2382 L
.80544 .2382 L
.80544 .23821 L
.80543 .23822 L
.80543 .23822 L
.80543 .23823 L
.80542 .23823 L
.80542 .23824 L
.80541 .23824 L
.80541 .23825 L
.80541 .23826 L
.8054 .23826 L
.8054 .23827 L
Mistroke
.8054 .23827 L
.80539 .23828 L
.80539 .23828 L
.80538 .23829 L
.80538 .2383 L
.80538 .2383 L
.80537 .23831 L
.80537 .23831 L
.80536 .23832 L
.80536 .23832 L
.80536 .23833 L
.80535 .23834 L
.80535 .23834 L
.80535 .23835 L
.80534 .23835 L
.80534 .23836 L
.80533 .23836 L
.80533 .23837 L
.80533 .23837 L
.80532 .23838 L
.80532 .23839 L
.80532 .23839 L
.80531 .2384 L
.80531 .2384 L
.8053 .23841 L
.8053 .23841 L
.8053 .23842 L
.80529 .23842 L
.80529 .23843 L
.80528 .23844 L
.80528 .23844 L
.80528 .23845 L
.80527 .23845 L
.80527 .23846 L
.80526 .23846 L
.80526 .23847 L
.80526 .23847 L
.80525 .23848 L
.80525 .23849 L
.80525 .23849 L
.80524 .2385 L
.80524 .2385 L
.80523 .23851 L
.80523 .23851 L
.80523 .23852 L
.80522 .23852 L
.80522 .23853 L
.80521 .23854 L
.80521 .23854 L
.80521 .23855 L
Mistroke
.8052 .23855 L
.8052 .23856 L
.80519 .23856 L
.80519 .23857 L
.80519 .23857 L
.80518 .23858 L
.80518 .23859 L
.80517 .23859 L
.80517 .2386 L
.80517 .2386 L
.80516 .23861 L
.80516 .23861 L
.80515 .23862 L
.80515 .23862 L
.80515 .23863 L
.80514 .23863 L
.80514 .23864 L
.80513 .23865 L
.80513 .23865 L
.80513 .23866 L
.80512 .23866 L
.80512 .23867 L
.80511 .23867 L
.80511 .23868 L
.80511 .23868 L
.8051 .23869 L
.8051 .23869 L
.80509 .2387 L
.80509 .2387 L
.80509 .23871 L
.80508 .23872 L
.80508 .23872 L
.80507 .23873 L
.80507 .23873 L
.80507 .23874 L
.80506 .23874 L
.80506 .23875 L
.80505 .23875 L
.80505 .23876 L
.80505 .23876 L
.80504 .23877 L
.80504 .23877 L
.80503 .23878 L
.80503 .23879 L
.80503 .23879 L
.80502 .2388 L
.80502 .2388 L
.80501 .23881 L
.80501 .23881 L
.80501 .23882 L
Mistroke
.805 .23882 L
.805 .23883 L
.80499 .23883 L
.80499 .23884 L
.80498 .23884 L
.80498 .23885 L
.80498 .23885 L
.80497 .23886 L
.80497 .23886 L
.80496 .23887 L
.80496 .23888 L
.80496 .23888 L
.80495 .23889 L
.80495 .23889 L
.80494 .2389 L
.80494 .2389 L
.80494 .23891 L
.80493 .23891 L
.80493 .23892 L
.80492 .23892 L
.80492 .23893 L
.80491 .23893 L
.80491 .23894 L
.80491 .23894 L
.8049 .23895 L
.8049 .23895 L
.80489 .23896 L
.80489 .23896 L
.80489 .23897 L
.80488 .23897 L
.80488 .23898 L
.80487 .23899 L
.80487 .23899 L
.80486 .239 L
.80486 .239 L
.80486 .23901 L
.80485 .23901 L
.80485 .23902 L
.80484 .23902 L
.80484 .23903 L
.80484 .23903 L
.80483 .23904 L
.80483 .23904 L
.80482 .23905 L
.80482 .23905 L
.80481 .23906 L
.80481 .23906 L
.80481 .23907 L
.8048 .23907 L
.8048 .23908 L
Mistroke
.80479 .23908 L
.80479 .23909 L
.80478 .23909 L
.80478 .2391 L
.80478 .2391 L
.80477 .23911 L
.80477 .23911 L
.80476 .23912 L
.80476 .23912 L
.80475 .23913 L
.80475 .23913 L
.80475 .23914 L
.80474 .23914 L
.80474 .23915 L
.80473 .23915 L
.80473 .23916 L
.80473 .23916 L
.80472 .23917 L
.80472 .23917 L
.80471 .23918 L
.80471 .23919 L
.8047 .23919 L
.8047 .2392 L
.8047 .2392 L
.80469 .23921 L
.80469 .23921 L
.80468 .23922 L
.80468 .23922 L
.80467 .23923 L
.80467 .23923 L
.80467 .23924 L
.80466 .23924 L
.80466 .23925 L
.80465 .23925 L
.80465 .23926 L
.80464 .23926 L
.80464 .23927 L
.80463 .23927 L
.80463 .23928 L
.80463 .23928 L
.80462 .23929 L
.80462 .23929 L
.80461 .2393 L
.80461 .2393 L
.8046 .23931 L
.8046 .23931 L
.8046 .23931 L
.80459 .23932 L
.80459 .23932 L
.80458 .23933 L
Mistroke
.80458 .23933 L
.80457 .23934 L
.80457 .23934 L
.80457 .23935 L
.80456 .23935 L
.80456 .23936 L
.80455 .23936 L
.80455 .23937 L
.80454 .23937 L
.80454 .23938 L
.80454 .23938 L
.80453 .23939 L
.80453 .23939 L
.80452 .2394 L
.80452 .2394 L
.80451 .23941 L
.80451 .23941 L
.8045 .23942 L
.8045 .23942 L
.8045 .23943 L
.80449 .23943 L
.80449 .23944 L
.80448 .23944 L
.80448 .23945 L
.80447 .23945 L
.80447 .23946 L
.80446 .23946 L
.80446 .23947 L
.80446 .23947 L
.80445 .23948 L
.80445 .23948 L
.80444 .23949 L
.80444 .23949 L
.80443 .2395 L
.80443 .2395 L
.80443 .2395 L
.80442 .23951 L
.80442 .23951 L
.80441 .23952 L
.80441 .23952 L
.8044 .23953 L
.8044 .23953 L
.80439 .23954 L
.80439 .23954 L
.80439 .23955 L
.80438 .23955 L
.80438 .23956 L
.80437 .23956 L
.80437 .23957 L
.80436 .23957 L
Mistroke
.80436 .23958 L
.80435 .23958 L
.80435 .23959 L
.80435 .23959 L
.80434 .23959 L
.80434 .2396 L
.80433 .2396 L
.80433 .23961 L
.80432 .23961 L
.80432 .23962 L
.80431 .23962 L
.80431 .23963 L
.80431 .23963 L
.8043 .23964 L
.8043 .23964 L
.80429 .23965 L
.80429 .23965 L
.80428 .23966 L
.80428 .23966 L
.80427 .23967 L
.80427 .23967 L
.80427 .23967 L
.80426 .23968 L
.80426 .23968 L
.80425 .23969 L
.80425 .23969 L
.80424 .2397 L
.80424 .2397 L
.80423 .23971 L
.80423 .23971 L
.80422 .23972 L
.80422 .23972 L
.80422 .23973 L
.80421 .23973 L
.80421 .23973 L
.8042 .23974 L
.8042 .23974 L
.80419 .23975 L
.80419 .23975 L
.80418 .23976 L
.80418 .23976 L
.80418 .23977 L
.80417 .23977 L
.80417 .23978 L
.80416 .23978 L
.80416 .23978 L
.80415 .23979 L
.80415 .23979 L
.80414 .2398 L
.80414 .2398 L
Mistroke
.80413 .23981 L
.80413 .23981 L
.80413 .23982 L
.80412 .23982 L
.80412 .23983 L
.80411 .23983 L
.80411 .23983 L
.8041 .23984 L
.8041 .23984 L
.80409 .23985 L
.80409 .23985 L
.80408 .23986 L
.80408 .23986 L
.80408 .23987 L
.80407 .23987 L
.80407 .23987 L
.80406 .23988 L
.80406 .23988 L
.80405 .23989 L
.80405 .23989 L
.80404 .2399 L
.80404 .2399 L
.80403 .23991 L
.80403 .23991 L
.80403 .23991 L
.80402 .23992 L
.80402 .23992 L
.80401 .23993 L
.80401 .23993 L
.804 .23994 L
.804 .23994 L
.80399 .23995 L
.80399 .23995 L
.80398 .23995 L
.80398 .23996 L
.80398 .23996 L
.80397 .23997 L
.80397 .23997 L
.80396 .23998 L
.80396 .23998 L
.80395 .23998 L
.80395 .23999 L
.80394 .23999 L
.80394 .24 L
.80393 .24 L
.80393 .24001 L
.80393 .24001 L
.80392 .24002 L
.80392 .24002 L
.80391 .24002 L
Mistroke
.80391 .24003 L
.8039 .24003 L
.8039 .24004 L
.80389 .24004 L
.80389 .24005 L
.80388 .24005 L
.80388 .24005 L
.80387 .24006 L
.80387 .24006 L
.80387 .24007 L
.80386 .24007 L
.80386 .24008 L
.80385 .24008 L
.80385 .24008 L
.80384 .24009 L
.80384 .24009 L
.80383 .2401 L
.80383 .2401 L
.80382 .24011 L
.80382 .24011 L
.80382 .24011 L
.80381 .24012 L
.80381 .24012 L
.8038 .24013 L
.8038 .24013 L
.80379 .24013 L
.80379 .24014 L
.80378 .24014 L
.80378 .24015 L
.80377 .24015 L
.80377 .24016 L
.80376 .24016 L
.80376 .24016 L
.80376 .24017 L
.80375 .24017 L
.80375 .24018 L
.80374 .24018 L
.80374 .24019 L
.80373 .24019 L
.80373 .24019 L
.80372 .2402 L
.80372 .2402 L
.80371 .24021 L
.80371 .24021 L
.8037 .24021 L
.8037 .24022 L
.8037 .24022 L
.80369 .24023 L
.80369 .24023 L
.80368 .24023 L
Mistroke
.80368 .24024 L
.80367 .24024 L
.80367 .24025 L
.80366 .24025 L
.80366 .24026 L
.80365 .24026 L
.80365 .24026 L
.80364 .24027 L
.80364 .24027 L
.80363 .24028 L
.80363 .24028 L
.80363 .24028 L
.80362 .24029 L
.80362 .24029 L
.80361 .2403 L
.80361 .2403 L
.8036 .2403 L
.8036 .24031 L
.80359 .24031 L
.80359 .24032 L
.80358 .24032 L
.80358 .24032 L
.80357 .24033 L
.80357 .24033 L
.80357 .24034 L
.80356 .24034 L
.80356 .24034 L
.80355 .24035 L
.80355 .24035 L
.80354 .24036 L
.80354 .24036 L
.80353 .24036 L
.80353 .24037 L
.80352 .24037 L
.80352 .24038 L
.80351 .24038 L
.80351 .24038 L
.8035 .24039 L
.8035 .24039 L
.8035 .2404 L
.80349 .2404 L
.80349 .2404 L
.80348 .24041 L
.80348 .24041 L
.80347 .24042 L
.80347 .24042 L
.80346 .24042 L
.80346 .24043 L
.80345 .24043 L
.80345 .24043 L
Mistroke
.80344 .24044 L
.80344 .24044 L
.80343 .24045 L
.80343 .24045 L
.80343 .24045 L
.80342 .24046 L
.80342 .24046 L
.80341 .24047 L
.80341 .24047 L
.8034 .24047 L
.8034 .24048 L
.80339 .24048 L
.80339 .24049 L
.80338 .24049 L
.80338 .24049 L
.80337 .2405 L
.80337 .2405 L
.80336 .2405 L
.80336 .24051 L
.80336 .24051 L
.80335 .24052 L
.80335 .24052 L
.80334 .24052 L
.80334 .24053 L
.80333 .24053 L
.80333 .24053 L
.80332 .24054 L
.80332 .24054 L
.80331 .24055 L
.80331 .24055 L
.8033 .24055 L
.8033 .24056 L
.80329 .24056 L
.80329 .24056 L
.80329 .24057 L
.80328 .24057 L
.80328 .24058 L
.80327 .24058 L
.80327 .24058 L
.80326 .24059 L
.80326 .24059 L
.80325 .24059 L
.80325 .2406 L
.80324 .2406 L
.80324 .24061 L
.80323 .24061 L
.80323 .24061 L
.80322 .24062 L
.80322 .24062 L
.80322 .24062 L
Mistroke
.80321 .24063 L
.80321 .24063 L
.8032 .24064 L
.8032 .24064 L
.80319 .24064 L
.80319 .24065 L
.80318 .24065 L
.80318 .24065 L
.80317 .24066 L
.80317 .24066 L
.80316 .24066 L
.80316 .24067 L
.80315 .24067 L
.80315 .24068 L
.80315 .24068 L
.80314 .24068 L
.80314 .24069 L
.80313 .24069 L
.80313 .24069 L
.80312 .2407 L
.80312 .2407 L
.80311 .2407 L
.80311 .24071 L
.8031 .24071 L
.8031 .24071 L
.80309 .24072 L
.80309 .24072 L
.80308 .24073 L
.80308 .24073 L
.80307 .24073 L
.80307 .24074 L
.80307 .24074 L
.80306 .24074 L
.80306 .24075 L
.80305 .24075 L
.80305 .24075 L
.80304 .24076 L
.80304 .24076 L
.80303 .24076 L
.80303 .24077 L
.80302 .24077 L
.80302 .24078 L
.80301 .24078 L
.80301 .24078 L
.803 .24079 L
.803 .24079 L
.803 .24079 L
.80299 .2408 L
.80299 .2408 L
.80298 .2408 L
Mistroke
.80298 .24081 L
.80297 .24081 L
.80297 .24081 L
.80296 .24082 L
.80296 .24082 L
.80295 .24082 L
.80295 .24083 L
.80294 .24083 L
.80294 .24083 L
.80293 .24084 L
.80293 .24084 L
.80293 .24084 L
.80292 .24085 L
.80292 .24085 L
.80291 .24085 L
.80291 .24086 L
.8029 .24086 L
.8029 .24086 L
.80289 .24087 L
.80289 .24087 L
.80288 .24087 L
.80288 .24088 L
.80287 .24088 L
.80287 .24088 L
.80286 .24089 L
.80286 .24089 L
.80286 .2409 L
.80285 .2409 L
.80285 .2409 L
.80284 .24091 L
.80284 .24091 L
.80283 .24091 L
.80283 .24092 L
.80282 .24092 L
.80282 .24092 L
.80281 .24093 L
.80281 .24093 L
.8028 .24093 L
.8028 .24093 L
.80279 .24094 L
.80279 .24094 L
.80279 .24094 L
.80278 .24095 L
.80278 .24095 L
.80277 .24095 L
.80277 .24096 L
.80276 .24096 L
.80276 .24096 L
.80275 .24097 L
.80275 .24097 L
Mistroke
.80274 .24097 L
.80274 .24098 L
.80273 .24098 L
.80273 .24098 L
.80272 .24099 L
.80272 .24099 L
.80272 .24099 L
.80271 .241 L
.80271 .241 L
.8027 .241 L
.8027 .24101 L
.80269 .24101 L
.80269 .24101 L
.80268 .24102 L
.80268 .24102 L
.80267 .24102 L
.80267 .24103 L
.80266 .24103 L
.80266 .24103 L
.80265 .24104 L
.80265 .24104 L
.80265 .24104 L
.80264 .24104 L
.80264 .24105 L
.80263 .24105 L
.80263 .24105 L
.80262 .24106 L
.80262 .24106 L
.80261 .24106 L
.80261 .24107 L
.8026 .24107 L
.8026 .24107 L
.80259 .24108 L
.80259 .24108 L
.80258 .24108 L
.80258 .24109 L
.80258 .24109 L
.80257 .24109 L
.80257 .24109 L
.80256 .2411 L
.80256 .2411 L
.80255 .2411 L
.80255 .24111 L
.80254 .24111 L
.80254 .24111 L
.80253 .24112 L
.80253 .24112 L
.80252 .24112 L
.80252 .24113 L
.80252 .24113 L
Mistroke
.80251 .24113 L
.80251 .24113 L
.8025 .24114 L
.8025 .24114 L
.80249 .24114 L
.80249 .24115 L
.80248 .24115 L
.80248 .24115 L
.80247 .24116 L
.80247 .24116 L
.80246 .24116 L
.80246 .24116 L
.80245 .24117 L
.80245 .24117 L
.80245 .24117 L
.80244 .24118 L
.80244 .24118 L
.80243 .24118 L
.80243 .24119 L
.80242 .24119 L
.80242 .24119 L
.80241 .24119 L
.80241 .2412 L
.8024 .2412 L
.8024 .2412 L
.80239 .24121 L
.80239 .24121 L
.80239 .24121 L
.80238 .24121 L
.80238 .24122 L
.80237 .24122 L
.80237 .24122 L
.80236 .24123 L
.80236 .24123 L
.80235 .24123 L
.80235 .24123 L
.80234 .24124 L
.80234 .24124 L
.80233 .24124 L
.80233 .24125 L
.80233 .24125 L
.80232 .24125 L
.80232 .24126 L
.80231 .24126 L
.80231 .24126 L
.8023 .24126 L
.8023 .24127 L
.80229 .24127 L
.80229 .24127 L
.80228 .24127 L
Mistroke
.80228 .24128 L
.80227 .24128 L
.80227 .24128 L
.80227 .24129 L
.80226 .24129 L
.80226 .24129 L
.80225 .24129 L
.80225 .2413 L
.80224 .2413 L
.80224 .2413 L
.80223 .24131 L
.80223 .24131 L
.80222 .24131 L
.80222 .24131 L
.80222 .24132 L
.80221 .24132 L
.80221 .24132 L
.8022 .24133 L
.8022 .24133 L
.80219 .24133 L
.80219 .24133 L
.80218 .24134 L
.80218 .24134 L
.80217 .24134 L
.80217 .24134 L
.80216 .24135 L
.80216 .24135 L
.80216 .24135 L
.80215 .24136 L
.80215 .24136 L
.80214 .24136 L
.80214 .24136 L
.80213 .24137 L
.80213 .24137 L
.80212 .24137 L
.80212 .24137 L
.80211 .24138 L
.80211 .24138 L
.80211 .24138 L
.8021 .24138 L
.8021 .24139 L
.80209 .24139 L
.80209 .24139 L
.80208 .2414 L
.80208 .2414 L
.80207 .2414 L
.80207 .2414 L
.80206 .24141 L
.80206 .24141 L
.80206 .24141 L
Mistroke
.80205 .24141 L
.80205 .24142 L
.80204 .24142 L
.80204 .24142 L
.80203 .24142 L
.80203 .24143 L
.80202 .24143 L
.80202 .24143 L
.80201 .24143 L
.80201 .24144 L
.80201 .24144 L
.802 .24144 L
.802 .24144 L
.80199 .24145 L
.80199 .24145 L
.80198 .24145 L
.80198 .24145 L
.80197 .24146 L
.80197 .24146 L
.80196 .24146 L
.80196 .24147 L
.80196 .24147 L
.80195 .24147 L
.80195 .24147 L
.80194 .24148 L
.80194 .24148 L
.80193 .24148 L
.80193 .24148 L
.80192 .24149 L
.80192 .24149 L
.80191 .24149 L
.80191 .24149 L
.80191 .2415 L
.8019 .2415 L
.8019 .2415 L
.80189 .2415 L
.80189 .24151 L
.80188 .24151 L
.80188 .24151 L
.80187 .24151 L
.80187 .24151 L
.80186 .24152 L
.80186 .24152 L
.80186 .24152 L
.80185 .24152 L
.80185 .24153 L
.80184 .24153 L
.80184 .24153 L
.80183 .24153 L
.80183 .24154 L
Mistroke
.80182 .24154 L
.80182 .24154 L
.80182 .24154 L
.80181 .24155 L
.80181 .24155 L
.8018 .24155 L
.8018 .24155 L
.80179 .24156 L
.80179 .24156 L
.80178 .24156 L
.80178 .24156 L
.80178 .24157 L
.80177 .24157 L
.80177 .24157 L
.80176 .24157 L
.80176 .24157 L
.80175 .24158 L
.80175 .24158 L
.80174 .24158 L
.80174 .24158 L
.80173 .24159 L
.80173 .24159 L
.80173 .24159 L
.80172 .24159 L
.80172 .2416 L
.80171 .2416 L
.80171 .2416 L
.8017 .2416 L
.8017 .2416 L
.80169 .24161 L
.80169 .24161 L
.80169 .24161 L
.80168 .24161 L
.80168 .24162 L
.80167 .24162 L
.80167 .24162 L
.80166 .24162 L
.80166 .24163 L
.80165 .24163 L
.80165 .24163 L
.80165 .24163 L
.80164 .24163 L
.80164 .24164 L
.80163 .24164 L
.80163 .24164 L
.80162 .24164 L
.80162 .24165 L
.80161 .24165 L
.80161 .24165 L
.80161 .24165 L
Mistroke
.8016 .24165 L
.8016 .24166 L
.80159 .24166 L
.80159 .24166 L
.80158 .24166 L
.80158 .24167 L
.80158 .24167 L
.80157 .24167 L
.80157 .24167 L
.80156 .24167 L
.80156 .24168 L
.80155 .24168 L
.80155 .24168 L
.80154 .24168 L
.80154 .24168 L
.80154 .24169 L
.80153 .24169 L
.80153 .24169 L
.80152 .24169 L
.80152 .2417 L
.80151 .2417 L
.80151 .2417 L
.8015 .2417 L
.8015 .2417 L
.8015 .24171 L
.80149 .24171 L
.80149 .24171 L
.80148 .24171 L
.80148 .24171 L
.80147 .24172 L
.80147 .24172 L
.80147 .24172 L
.80146 .24172 L
.80146 .24172 L
.80145 .24173 L
.80145 .24173 L
.80144 .24173 L
.80144 .24173 L
.80143 .24173 L
.80143 .24174 L
.80143 .24174 L
.80142 .24174 L
.80142 .24174 L
.80141 .24175 L
.80141 .24175 L
.8014 .24175 L
.8014 .24175 L
.8014 .24175 L
.80139 .24176 L
.80139 .24176 L
Mistroke
.80138 .24176 L
.80138 .24176 L
.80137 .24176 L
.80137 .24177 L
.80137 .24177 L
.80136 .24177 L
.80136 .24177 L
.80135 .24177 L
.80135 .24178 L
.80134 .24178 L
.80134 .24178 L
.80133 .24178 L
.80133 .24178 L
.80133 .24178 L
.80132 .24179 L
.80132 .24179 L
.80131 .24179 L
.80131 .24179 L
.8013 .24179 L
.8013 .2418 L
.8013 .2418 L
.80129 .2418 L
.80129 .2418 L
.80128 .2418 L
.80128 .24181 L
.80127 .24181 L
.80127 .24181 L
.80127 .24181 L
.80126 .24181 L
.80126 .24182 L
.80125 .24182 L
.80125 .24182 L
.80124 .24182 L
.80124 .24182 L
.80124 .24182 L
.80123 .24183 L
.80123 .24183 L
.80122 .24183 L
.80122 .24183 L
.80121 .24183 L
.80121 .24184 L
.80121 .24184 L
.8012 .24184 L
.8012 .24184 L
.80119 .24184 L
.80119 .24185 L
.80118 .24185 L
.80118 .24185 L
.80118 .24185 L
.80117 .24185 L
Mistroke
.80117 .24185 L
.80116 .24186 L
.80116 .24186 L
.80115 .24186 L
.80115 .24186 L
.80115 .24186 L
.80114 .24186 L
.80114 .24187 L
.80113 .24187 L
.80113 .24187 L
.80113 .24187 L
.80112 .24187 L
.80112 .24188 L
.80111 .24188 L
.80111 .24188 L
.8011 .24188 L
.8011 .24188 L
.8011 .24188 L
.80109 .24189 L
.80109 .24189 L
.80108 .24189 L
.80108 .24189 L
.80107 .24189 L
.80107 .24189 L
.80107 .2419 L
.80106 .2419 L
.80106 .2419 L
.80105 .2419 L
.80105 .2419 L
.80105 .2419 L
.80104 .24191 L
.80104 .24191 L
.80103 .24191 L
.80103 .24191 L
.80102 .24191 L
.80102 .24191 L
.80102 .24192 L
.80101 .24192 L
.80101 .24192 L
.801 .24192 L
.801 .24192 L
.801 .24192 L
.80099 .24193 L
.80099 .24193 L
.80098 .24193 L
.80098 .24193 L
.80097 .24193 L
.80097 .24193 L
.80097 .24194 L
.80096 .24194 L
Mistroke
.80096 .24194 L
.80095 .24194 L
.80095 .24194 L
.80095 .24194 L
.80094 .24195 L
.80094 .24195 L
.80093 .24195 L
.80093 .24195 L
.80092 .24195 L
.80092 .24195 L
.80092 .24196 L
.80091 .24196 L
.80091 .24196 L
.8009 .24196 L
.8009 .24196 L
.8009 .24196 L
.80089 .24196 L
.80089 .24197 L
.80088 .24197 L
.80088 .24197 L
.80087 .24197 L
.80087 .24197 L
.80087 .24197 L
.80086 .24198 L
.80086 .24198 L
.80085 .24198 L
.80085 .24198 L
.80085 .24198 L
.80084 .24198 L
.80084 .24198 L
.80083 .24199 L
.80083 .24199 L
.80083 .24199 L
.80082 .24199 L
.80082 .24199 L
.80081 .24199 L
.80081 .24199 L
.80081 .242 L
.8008 .242 L
.8008 .242 L
.80079 .242 L
.80079 .242 L
.80078 .242 L
.80078 .24201 L
.80078 .24201 L
.80077 .24201 L
.80077 .24201 L
.80076 .24201 L
.80076 .24201 L
.80076 .24201 L
Mistroke
.80075 .24202 L
.80075 .24202 L
.80074 .24202 L
.80074 .24202 L
.80074 .24202 L
.80073 .24202 L
.80073 .24202 L
.80072 .24202 L
.80072 .24203 L
.80072 .24203 L
.80071 .24203 L
.80071 .24203 L
.8007 .24203 L
.8007 .24203 L
.8007 .24203 L
.80069 .24204 L
.80069 .24204 L
.80068 .24204 L
.80068 .24204 L
.80068 .24204 L
.80067 .24204 L
.80067 .24204 L
.80066 .24205 L
.80066 .24205 L
.80066 .24205 L
.80065 .24205 L
.80065 .24205 L
.80064 .24205 L
.80064 .24205 L
.80064 .24205 L
.80063 .24206 L
.80063 .24206 L
.80062 .24206 L
.80062 .24206 L
.80062 .24206 L
.80061 .24206 L
.80061 .24206 L
.8006 .24207 L
.8006 .24207 L
.8006 .24207 L
.80059 .24207 L
.80059 .24207 L
.80058 .24207 L
.80058 .24207 L
.80058 .24207 L
.80057 .24208 L
.80057 .24208 L
.80056 .24208 L
.80056 .24208 L
.80056 .24208 L
Mistroke
.80055 .24208 L
.80055 .24208 L
.80054 .24208 L
.80054 .24209 L
.80054 .24209 L
.80053 .24209 L
.80053 .24209 L
.80053 .24209 L
.80052 .24209 L
.80052 .24209 L
.80051 .24209 L
.80051 .24209 L
.80051 .2421 L
.8005 .2421 L
.8005 .2421 L
.80049 .2421 L
.80049 .2421 L
.80049 .2421 L
.80048 .2421 L
.80048 .2421 L
.80047 .24211 L
.80047 .24211 L
.80047 .24211 L
.80046 .24211 L
.80046 .24211 L
.80046 .24211 L
.80045 .24211 L
.80045 .24211 L
.80044 .24211 L
.80044 .24212 L
.80044 .24212 L
.80043 .24212 L
.80043 .24212 L
.80042 .24212 L
.80042 .24212 L
.80042 .24212 L
.80041 .24212 L
.80041 .24212 L
.8004 .24213 L
.8004 .24213 L
.8004 .24213 L
.80039 .24213 L
.80039 .24213 L
.80039 .24213 L
.80038 .24213 L
.80038 .24213 L
.80037 .24213 L
.80037 .24214 L
.80037 .24214 L
.80036 .24214 L
Mistroke
.80036 .24214 L
.80035 .24214 L
.80035 .24214 L
.80035 .24214 L
.80034 .24214 L
.80034 .24214 L
.80034 .24215 L
.80033 .24215 L
.80033 .24215 L
.80032 .24215 L
.80032 .24215 L
.80032 .24215 L
.80031 .24215 L
.80031 .24215 L
.80031 .24215 L
.8003 .24215 L
.8003 .24216 L
.80029 .24216 L
.80029 .24216 L
.80029 .24216 L
.80028 .24216 L
.80028 .24216 L
.80028 .24216 L
.80027 .24216 L
.80027 .24216 L
.80026 .24216 L
.80026 .24217 L
.80026 .24217 L
.80025 .24217 L
.80025 .24217 L
.80025 .24217 L
.80024 .24217 L
.80024 .24217 L
.80023 .24217 L
.80023 .24217 L
.80023 .24217 L
.80022 .24217 L
.80022 .24218 L
.80022 .24218 L
.80021 .24218 L
.80021 .24218 L
.8002 .24218 L
.8002 .24218 L
.8002 .24218 L
.80019 .24218 L
.80019 .24218 L
.80019 .24218 L
.80018 .24218 L
.80018 .24219 L
.80017 .24219 L
Mistroke
.80017 .24219 L
.80017 .24219 L
.80016 .24219 L
.80016 .24219 L
.80016 .24219 L
.80015 .24219 L
.80015 .24219 L
.80014 .24219 L
.80014 .24219 L
.80014 .2422 L
.80013 .2422 L
.80013 .2422 L
.80013 .2422 L
.80012 .2422 L
.80012 .2422 L
.80012 .2422 L
.80011 .2422 L
.80011 .2422 L
.8001 .2422 L
.8001 .2422 L
.8001 .2422 L
.80009 .24221 L
.80009 .24221 L
.80009 .24221 L
.80008 .24221 L
.80008 .24221 L
.80008 .24221 L
.80007 .24221 L
.80007 .24221 L
.80006 .24221 L
.80006 .24221 L
.80006 .24221 L
.80005 .24221 L
.80005 .24221 L
.80005 .24222 L
.80004 .24222 L
.80004 .24222 L
.80004 .24222 L
.80003 .24222 L
.80003 .24222 L
.80002 .24222 L
.80002 .24222 L
.80002 .24222 L
.80001 .24222 L
.80001 .24222 L
.80001 .24222 L
.8 .24222 L
.8 .24223 L
.8 .24223 L
.79999 .24223 L
Mistroke
.79999 .24223 L
.79999 .24223 L
.79998 .24223 L
.79998 .24223 L
.79997 .24223 L
.79997 .24223 L
.79997 .24223 L
.79996 .24223 L
.79996 .24223 L
.79996 .24223 L
.79995 .24223 L
.79995 .24223 L
.79995 .24224 L
.79994 .24224 L
.79994 .24224 L
.79994 .24224 L
.79993 .24224 L
.79993 .24224 L
.79993 .24224 L
.79992 .24224 L
.79992 .24224 L
.79991 .24224 L
.79991 .24224 L
.79991 .24224 L
.7999 .24224 L
.7999 .24224 L
.7999 .24224 L
.79989 .24225 L
.79989 .24225 L
.79989 .24225 L
.79988 .24225 L
.79988 .24225 L
.79988 .24225 L
.79987 .24225 L
.79987 .24225 L
.79987 .24225 L
.79986 .24225 L
.79986 .24225 L
.79986 .24225 L
.79985 .24225 L
.79985 .24225 L
.79984 .24225 L
.79984 .24225 L
.79984 .24225 L
.79983 .24226 L
.79983 .24226 L
.79983 .24226 L
.79982 .24226 L
.79982 .24226 L
.79982 .24226 L
Mistroke
.79981 .24226 L
.79981 .24226 L
.79981 .24226 L
.7998 .24226 L
.7998 .24226 L
.7998 .24226 L
.79979 .24226 L
.79979 .24226 L
.79979 .24226 L
.79978 .24226 L
.79978 .24226 L
.79978 .24226 L
.79977 .24227 L
.79977 .24227 L
.79977 .24227 L
.79976 .24227 L
.79976 .24227 L
.79976 .24227 L
.79975 .24227 L
.79975 .24227 L
.79975 .24227 L
.79974 .24227 L
.79974 .24227 L
.79974 .24227 L
.79973 .24227 L
.79973 .24227 L
.79973 .24227 L
.79972 .24227 L
.79972 .24227 L
.79972 .24227 L
.79971 .24227 L
.79971 .24227 L
.79971 .24228 L
.7997 .24228 L
.7997 .24228 L
.7997 .24228 L
.79969 .24228 L
.79969 .24228 L
.79969 .24228 L
.79968 .24228 L
.79968 .24228 L
.79968 .24228 L
.79967 .24228 L
.79967 .24228 L
.79967 .24228 L
.79966 .24228 L
.79966 .24228 L
.79966 .24228 L
.79965 .24228 L
.79965 .24228 L
Mistroke
.79965 .24228 L
.79964 .24228 L
.79964 .24228 L
.79964 .24228 L
.79963 .24228 L
.79963 .24228 L
.79963 .24229 L
.79962 .24229 L
.79962 .24229 L
.79962 .24229 L
.79961 .24229 L
.79961 .24229 L
.79961 .24229 L
.7996 .24229 L
.7996 .24229 L
.7996 .24229 L
.79959 .24229 L
.79959 .24229 L
.79959 .24229 L
.79958 .24229 L
.79958 .24229 L
.79958 .24229 L
.79957 .24229 L
.79957 .24229 L
.79957 .24229 L
.79956 .24229 L
.79956 .24229 L
.79956 .24229 L
.79955 .24229 L
.79955 .24229 L
.79955 .24229 L
.79954 .24229 L
.79954 .24229 L
.79954 .24229 L
.79953 .24229 L
.79953 .24229 L
.79953 .2423 L
.79953 .2423 L
.79952 .2423 L
.79952 .2423 L
.79952 .2423 L
.79951 .2423 L
.79951 .2423 L
.79951 .2423 L
.7995 .2423 L
.7995 .2423 L
.7995 .2423 L
.79949 .2423 L
.79949 .2423 L
.79949 .2423 L
Mistroke
.79948 .2423 L
.79948 .2423 L
.79948 .2423 L
.79947 .2423 L
.79947 .2423 L
.79947 .2423 L
.79946 .2423 L
.79946 .2423 L
.79946 .2423 L
.79946 .2423 L
.79945 .2423 L
.79945 .2423 L
.79945 .2423 L
.79944 .2423 L
.79944 .2423 L
.79944 .2423 L
.79943 .2423 L
.79943 .2423 L
.79943 .2423 L
.79942 .2423 L
.79942 .2423 L
.79942 .2423 L
.79941 .2423 L
.79941 .2423 L
.79941 .2423 L
.79941 .2423 L
.7994 .2423 L
.7994 .2423 L
.7994 .2423 L
.79939 .24231 L
.79939 .24231 L
.79939 .24231 L
.79938 .24231 L
.79938 .24231 L
.79938 .24231 L
.79937 .24231 L
.79937 .24231 L
.79937 .24231 L
.79937 .24231 L
.79936 .24231 L
.79936 .24231 L
.79936 .24231 L
.79935 .24231 L
.79935 .24231 L
.79935 .24231 L
.79934 .24231 L
.79934 .24231 L
.79934 .24231 L
.79934 .24231 L
.79933 .24231 L
Mistroke
.79933 .24231 L
.79933 .24231 L
.79932 .24231 L
.79932 .24231 L
.79932 .24231 L
.79931 .24231 L
.79931 .24231 L
.79931 .24231 L
.79931 .24231 L
.7993 .24231 L
.7993 .24231 L
.7993 .24231 L
.79929 .24231 L
.79929 .24231 L
.79929 .24231 L
.79928 .24231 L
.79928 .24231 L
.79928 .24231 L
.79928 .24231 L
.79927 .24231 L
.79927 .24231 L
.79927 .24231 L
.79926 .24231 L
.79926 .24231 L
.79926 .24231 L
.79925 .24231 L
.79925 .24231 L
.79925 .24231 L
.79925 .24231 L
.79924 .24231 L
.79924 .24231 L
.79924 .24231 L
.79923 .24231 L
.79923 .24231 L
.79923 .24231 L
.79923 .24231 L
.79922 .24231 L
.79922 .24231 L
.79922 .24231 L
.79921 .24231 L
.79921 .24231 L
.79921 .24231 L
.7992 .24231 L
.7992 .24231 L
.7992 .24231 L
.7992 .24231 L
.79919 .24231 L
.79919 .24231 L
.79919 .24231 L
.79918 .24231 L
Mistroke
.79918 .24231 L
.79918 .24231 L
.79918 .24231 L
.79917 .24231 L
.79917 .24231 L
.79917 .24231 L
.79916 .24231 L
.79916 .24231 L
.79916 .24231 L
.79916 .24231 L
.79915 .24231 L
.79915 .24231 L
.79915 .24231 L
.79914 .24231 L
.79914 .24231 L
.79914 .24231 L
.79914 .24231 L
.79913 .24231 L
.79913 .24231 L
.79913 .24231 L
.79912 .24231 L
.79912 .24231 L
.79912 .24231 L
.79912 .24231 L
.79911 .24231 L
.79911 .24231 L
.79911 .24231 L
.79911 .24231 L
.7991 .24231 L
.7991 .24231 L
.7991 .24231 L
.79909 .24231 L
.79909 .24231 L
.79909 .24231 L
.79909 .24231 L
.79908 .24231 L
.79908 .24231 L
.79908 .24231 L
.79907 .24231 L
.79907 .24231 L
.79907 .24231 L
.79907 .24231 L
.79906 .24231 L
.79906 .24231 L
.79906 .24231 L
.79906 .24231 L
.79905 .24231 L
.79905 .24231 L
.79905 .24231 L
.79904 .24231 L
Mistroke
.79904 .24231 L
.79904 .24231 L
.79904 .2423 L
.79903 .2423 L
.79903 .2423 L
.79903 .2423 L
.79903 .2423 L
.79902 .2423 L
.79902 .2423 L
.79902 .2423 L
.79901 .2423 L
.79901 .2423 L
.79901 .2423 L
.79901 .2423 L
.799 .2423 L
.799 .2423 L
.799 .2423 L
.799 .2423 L
.79899 .2423 L
.79899 .2423 L
.79899 .2423 L
.79898 .2423 L
.79898 .2423 L
.79898 .2423 L
.79898 .2423 L
.79897 .2423 L
.79897 .2423 L
.79897 .2423 L
.79897 .2423 L
.79896 .2423 L
.79896 .2423 L
.79896 .2423 L
.79896 .2423 L
.79895 .2423 L
.79895 .2423 L
.79895 .2423 L
.79894 .2423 L
.79894 .2423 L
.79894 .2423 L
.79894 .2423 L
.79893 .2423 L
.79893 .2423 L
.79893 .2423 L
.79893 .2423 L
.79892 .2423 L
.79892 .2423 L
.79892 .2423 L
.79892 .2423 L
.79891 .24229 L
.79891 .24229 L
Mistroke
.79891 .24229 L
.79891 .24229 L
.7989 .24229 L
.7989 .24229 L
.7989 .24229 L
.7989 .24229 L
.79889 .24229 L
.79889 .24229 L
.79889 .24229 L
.79889 .24229 L
.79888 .24229 L
.79888 .24229 L
.79888 .24229 L
.79887 .24229 L
.79887 .24229 L
.79887 .24229 L
.79887 .24229 L
.79886 .24229 L
.79886 .24229 L
.79886 .24229 L
.79886 .24229 L
.79885 .24229 L
.79885 .24229 L
.79885 .24229 L
.79885 .24229 L
.79884 .24229 L
.79884 .24229 L
.79884 .24229 L
.79884 .24229 L
.79883 .24229 L
.79883 .24228 L
.79883 .24228 L
.79883 .24228 L
.79882 .24228 L
.79882 .24228 L
.79882 .24228 L
.79882 .24228 L
.79881 .24228 L
.79881 .24228 L
.79881 .24228 L
.79881 .24228 L
.7988 .24228 L
.7988 .24228 L
.7988 .24228 L
.7988 .24228 L
.79879 .24228 L
.79879 .24228 L
.79879 .24228 L
.79879 .24228 L
.79879 .24228 L
Mistroke
.79878 .24228 L
.79878 .24228 L
.79878 .24228 L
.79878 .24228 L
.79877 .24228 L
.79877 .24228 L
.79877 .24228 L
.79877 .24227 L
.79876 .24227 L
.79876 .24227 L
.79876 .24227 L
.79876 .24227 L
.79875 .24227 L
.79875 .24227 L
.79875 .24227 L
.79875 .24227 L
.79874 .24227 L
.79874 .24227 L
.79874 .24227 L
.79874 .24227 L
.79873 .24227 L
.79873 .24227 L
.79873 .24227 L
.79873 .24227 L
.79872 .24227 L
.79872 .24227 L
.79872 .24227 L
.79872 .24227 L
.79872 .24227 L
.79871 .24227 L
.79871 .24226 L
.79871 .24226 L
.79871 .24226 L
.7987 .24226 L
.7987 .24226 L
.7987 .24226 L
.7987 .24226 L
.79869 .24226 L
.79869 .24226 L
.79869 .24226 L
.79869 .24226 L
.79868 .24226 L
.79868 .24226 L
.79868 .24226 L
.79868 .24226 L
.79868 .24226 L
.79867 .24226 L
.79867 .24226 L
.79867 .24226 L
.79867 .24226 L
Mistroke
.79866 .24225 L
.79866 .24225 L
.79866 .24225 L
.79866 .24225 L
.79865 .24225 L
.79865 .24225 L
.79865 .24225 L
.79865 .24225 L
.79865 .24225 L
.79864 .24225 L
.79864 .24225 L
.79864 .24225 L
.79864 .24225 L
.79863 .24225 L
.79863 .24225 L
.79863 .24225 L
.79863 .24225 L
.79863 .24225 L
.79862 .24225 L
.79862 .24224 L
.79862 .24224 L
.79862 .24224 L
.79861 .24224 L
.79861 .24224 L
.79861 .24224 L
.79861 .24224 L
.79861 .24224 L
.7986 .24224 L
.7986 .24224 L
.7986 .24224 L
.7986 .24224 L
.79859 .24224 L
.79859 .24224 L
.79859 .24224 L
.79859 .24224 L
.79859 .24224 L
.79858 .24224 L
.79858 .24223 L
.79858 .24223 L
.79858 .24223 L
.79857 .24223 L
.79857 .24223 L
.79857 .24223 L
.79857 .24223 L
.79857 .24223 L
.79856 .24223 L
.79856 .24223 L
.79856 .24223 L
.79856 .24223 L
.79856 .24223 L
Mistroke
.79855 .24223 L
.79855 .24223 L
.79855 .24223 L
.79855 .24223 L
.79854 .24222 L
.79854 .24222 L
.79854 .24222 L
.79854 .24222 L
.79854 .24222 L
.79853 .24222 L
.79853 .24222 L
.79853 .24222 L
.79853 .24222 L
.79853 .24222 L
.79852 .24222 L
.79852 .24222 L
.79852 .24222 L
.79852 .24222 L
.79851 .24222 L
.79851 .24222 L
.79851 .24221 L
.79851 .24221 L
.79851 .24221 L
.7985 .24221 L
.7985 .24221 L
.7985 .24221 L
.7985 .24221 L
.7985 .24221 L
.79849 .24221 L
.79849 .24221 L
.79849 .24221 L
.79849 .24221 L
.79849 .24221 L
.79848 .24221 L
.79848 .24221 L
.79848 .2422 L
.79848 .2422 L
.79848 .2422 L
.79847 .2422 L
.79847 .2422 L
.79847 .2422 L
.79847 .2422 L
.79847 .2422 L
.79846 .2422 L
.79846 .2422 L
.79846 .2422 L
.79846 .2422 L
.79846 .2422 L
.79845 .2422 L
.79845 .24219 L
Mistroke
.79845 .24219 L
.79845 .24219 L
.79845 .24219 L
.79844 .24219 L
.79844 .24219 L
.79844 .24219 L
.79844 .24219 L
.79844 .24219 L
.79843 .24219 L
.79843 .24219 L
.79843 .24219 L
.79843 .24219 L
.79843 .24219 L
.79842 .24218 L
.79842 .24218 L
.79842 .24218 L
.79842 .24218 L
.79842 .24218 L
.79841 .24218 L
.79841 .24218 L
.79841 .24218 L
.79841 .24218 L
.79841 .24218 L
.7984 .24218 L
.7984 .24218 L
.7984 .24218 L
.7984 .24218 L
.7984 .24217 L
.79839 .24217 L
.79839 .24217 L
.79839 .24217 L
.79839 .24217 L
.79839 .24217 L
.79838 .24217 L
.79838 .24217 L
.79838 .24217 L
.79838 .24217 L
.79838 .24217 L
.79838 .24217 L
.79837 .24217 L
.79837 .24216 L
.79837 .24216 L
.79837 .24216 L
.79837 .24216 L
.79836 .24216 L
.79836 .24216 L
.79836 .24216 L
.79836 .24216 L
.79836 .24216 L
.79835 .24216 L
Mistroke
.79835 .24216 L
.79835 .24216 L
.79835 .24216 L
.79835 .24215 L
.79835 .24215 L
.79834 .24215 L
.79834 .24215 L
.79834 .24215 L
.79834 .24215 L
.79834 .24215 L
.79833 .24215 L
.79833 .24215 L
.79833 .24215 L
.79833 .24215 L
.79833 .24215 L
.79832 .24214 L
.79832 .24214 L
.79832 .24214 L
.79832 .24214 L
.79832 .24214 L
.79832 .24214 L
.79831 .24214 L
.79831 .24214 L
.79831 .24214 L
.79831 .24214 L
.79831 .24214 L
.79831 .24214 L
.7983 .24213 L
.7983 .24213 L
.7983 .24213 L
.7983 .24213 L
.7983 .24213 L
.79829 .24213 L
.79829 .24213 L
.79829 .24213 L
.79829 .24213 L
.79829 .24213 L
.79829 .24213 L
.79828 .24213 L
.79828 .24212 L
.79828 .24212 L
.79828 .24212 L
.79828 .24212 L
.79828 .24212 L
.79827 .24212 L
.79827 .24212 L
.79827 .24212 L
.79827 .24212 L
.79827 .24212 L
.79826 .24212 L
Mistroke
.79826 .24212 L
.79826 .24211 L
.79826 .24211 L
.79826 .24211 L
.79826 .24211 L
.79825 .24211 L
.79825 .24211 L
.79825 .24211 L
.79825 .24211 L
.79825 .24211 L
.79825 .24211 L
.79824 .24211 L
.79824 .2421 L
.79824 .2421 L
.79824 .2421 L
.79824 .2421 L
.79824 .2421 L
.79823 .2421 L
.79823 .2421 L
.79823 .2421 L
.79823 .2421 L
.79823 .2421 L
.79823 .2421 L
.79822 .24209 L
.79822 .24209 L
.79822 .24209 L
.79822 .24209 L
.79822 .24209 L
.79822 .24209 L
.79821 .24209 L
.79821 .24209 L
.79821 .24209 L
.79821 .24209 L
.79821 .24209 L
.79821 .24208 L
.7982 .24208 L
.7982 .24208 L
.7982 .24208 L
.7982 .24208 L
.7982 .24208 L
.7982 .24208 L
.79819 .24208 L
.79819 .24208 L
.79819 .24208 L
.79819 .24208 L
.79819 .24207 L
.79819 .24207 L
.79819 .24207 L
.79818 .24207 L
.79818 .24207 L
Mistroke
.79818 .24207 L
.79818 .24207 L
.79818 .24207 L
.79818 .24207 L
.79817 .24207 L
.79817 .24206 L
.79817 .24206 L
.79817 .24206 L
.79817 .24206 L
.79817 .24206 L
.79817 .24206 L
.79816 .24206 L
.79816 .24206 L
.79816 .24206 L
.79816 .24206 L
.79816 .24206 L
.79816 .24205 L
.79815 .24205 L
.79815 .24205 L
.79815 .24205 L
.79815 .24205 L
.79815 .24205 L
.79815 .24205 L
.79815 .24205 L
.79814 .24205 L
.79814 .24205 L
.79814 .24204 L
.79814 .24204 L
.79814 .24204 L
.79814 .24204 L
.79813 .24204 L
.79813 .24204 L
.79813 .24204 L
.79813 .24204 L
.79813 .24204 L
.79813 .24204 L
.79813 .24203 L
.79812 .24203 L
.79812 .24203 L
.79812 .24203 L
.79812 .24203 L
.79812 .24203 L
.79812 .24203 L
.79812 .24203 L
.79811 .24203 L
.79811 .24203 L
.79811 .24202 L
.79811 .24202 L
.79811 .24202 L
.79811 .24202 L
Mistroke
.79811 .24202 L
.7981 .24202 L
.7981 .24202 L
.7981 .24202 L
.7981 .24202 L
.7981 .24202 L
.7981 .24201 L
.7981 .24201 L
.79809 .24201 L
.79809 .24201 L
.79809 .24201 L
.79809 .24201 L
.79809 .24201 L
.79809 .24201 L
.79809 .24201 L
.79808 .242 L
.79808 .242 L
.79808 .242 L
.79808 .242 L
.79808 .242 L
.79808 .242 L
.79808 .242 L
.79807 .242 L
.79807 .242 L
.79807 .242 L
.79807 .24199 L
.79807 .24199 L
.79807 .24199 L
.79807 .24199 L
.79806 .24199 L
.79806 .24199 L
.79806 .24199 L
.79806 .24199 L
.79806 .24199 L
.79806 .24198 L
.79806 .24198 L
.79806 .24198 L
.79805 .24198 L
.79805 .24198 L
.79805 .24198 L
.79805 .24198 L
.79805 .24198 L
.79805 .24198 L
.79805 .24198 L
.79804 .24197 L
.79804 .24197 L
.79804 .24197 L
.79804 .24197 L
.79804 .24197 L
.79804 .24197 L
Mistroke
.79804 .24197 L
.79804 .24197 L
.79803 .24197 L
.79803 .24196 L
.79803 .24196 L
.79803 .24196 L
.79803 .24196 L
.79803 .24196 L
.79803 .24196 L
.79803 .24196 L
.79802 .24196 L
.79802 .24196 L
.79802 .24195 L
.79802 .24195 L
.79802 .24195 L
.79802 .24195 L
.79802 .24195 L
.79801 .24195 L
.79801 .24195 L
.79801 .24195 L
.79801 .24195 L
.79801 .24194 L
.79801 .24194 L
.79801 .24194 L
.79801 .24194 L
.798 .24194 L
.798 .24194 L
.798 .24194 L
.798 .24194 L
.798 .24194 L
.798 .24193 L
.798 .24193 L
.798 .24193 L
.798 .24193 L
.79799 .24193 L
.79799 .24193 L
.79799 .24193 L
.79799 .24193 L
.79799 .24193 L
.79799 .24192 L
.79799 .24192 L
.79799 .24192 L
.79798 .24192 L
.79798 .24192 L
.79798 .24192 L
.79798 .24192 L
.79798 .24192 L
.79798 .24192 L
.79798 .24191 L
.79798 .24191 L
Mistroke
.79797 .24191 L
.79797 .24191 L
.79797 .24191 L
.79797 .24191 L
.79797 .24191 L
.79797 .24191 L
.79797 .24191 L
.79797 .2419 L
.79797 .2419 L
.79796 .2419 L
.79796 .2419 L
.79796 .2419 L
.79796 .2419 L
.79796 .2419 L
.79796 .2419 L
.79796 .24189 L
.79796 .24189 L
.79796 .24189 L
.79795 .24189 L
.79795 .24189 L
.79795 .24189 L
.79795 .24189 L
.79795 .24189 L
.79795 .24189 L
.79795 .24188 L
.79795 .24188 L
.79795 .24188 L
.79794 .24188 L
.79794 .24188 L
.79794 .24188 L
.79794 .24188 L
.79794 .24188 L
.79794 .24188 L
.79794 .24187 L
.79794 .24187 L
.79794 .24187 L
.79793 .24187 L
.79793 .24187 L
.79793 .24187 L
.79793 .24187 L
.79793 .24187 L
.79793 .24186 L
.79793 .24186 L
.79793 .24186 L
.79793 .24186 L
.79792 .24186 L
.79792 .24186 L
.79792 .24186 L
.79792 .24186 L
.79792 .24186 L
Mistroke
.79792 .24185 L
.79792 .24185 L
.79792 .24185 L
.79792 .24185 L
.79792 .24185 L
.79791 .24185 L
.79791 .24185 L
.79791 .24185 L
.79791 .24184 L
.79791 .24184 L
.79791 .24184 L
.79791 .24184 L
.79791 .24184 L
.79791 .24184 L
.79791 .24184 L
.7979 .24184 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24183 L
.7979 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24182 L
.79789 .24181 L
.79789 .24181 L
.79788 .24181 L
.79788 .24181 L
.79788 .24181 L
.79788 .24181 L
.79788 .24181 L
.79788 .24181 L
.79788 .2418 L
.79788 .2418 L
.79788 .2418 L
.79788 .2418 L
.79788 .2418 L
.79787 .2418 L
.79787 .2418 L
.79787 .2418 L
.79787 .24179 L
Mistroke
.79787 .24179 L
.79787 .24179 L
.79787 .24179 L
.79787 .24179 L
.79787 .24179 L
.79787 .24179 L
.79787 .24179 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24178 L
.79786 .24177 L
.79786 .24177 L
.79786 .24177 L
.79785 .24177 L
.79785 .24177 L
.79785 .24177 L
.79785 .24177 L
.79785 .24177 L
.79785 .24176 L
.79785 .24176 L
.79785 .24176 L
.79785 .24176 L
.79785 .24176 L
.79785 .24176 L
.79785 .24176 L
.79784 .24176 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24175 L
.79784 .24174 L
.79784 .24174 L
.79784 .24174 L
.79783 .24174 L
.79783 .24174 L
.79783 .24174 L
.79783 .24174 L
.79783 .24174 L
.79783 .24173 L
.79783 .24173 L
.79783 .24173 L
Mistroke
.79783 .24173 L
.79783 .24173 L
.79783 .24173 L
.79783 .24173 L
.79782 .24173 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24172 L
.79782 .24171 L
.79782 .24171 L
.79782 .24171 L
.79782 .24171 L
.79781 .24171 L
.79781 .24171 L
.79781 .24171 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .2417 L
.79781 .24169 L
.79781 .24169 L
.79781 .24169 L
.7978 .24169 L
.7978 .24169 L
.7978 .24169 L
.7978 .24169 L
.7978 .24169 L
.7978 .24168 L
.7978 .24168 L
.7978 .24168 L
.7978 .24168 L
.7978 .24168 L
.7978 .24168 L
.7978 .24168 L
.7978 .24167 L
.7978 .24167 L
.79779 .24167 L
.79779 .24167 L
.79779 .24167 L
.79779 .24167 L
.79779 .24167 L
Mistroke
.79779 .24167 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24166 L
.79779 .24165 L
.79778 .24165 L
.79778 .24165 L
.79778 .24165 L
.79778 .24165 L
.79778 .24165 L
.79778 .24165 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24164 L
.79778 .24163 L
.79778 .24163 L
.79777 .24163 L
.79777 .24163 L
.79777 .24163 L
.79777 .24163 L
.79777 .24163 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24162 L
.79777 .24161 L
.79777 .24161 L
.79777 .24161 L
.79777 .24161 L
.79776 .24161 L
.79776 .24161 L
.79776 .24161 L
.79776 .2416 L
.79776 .2416 L
.79776 .2416 L
.79776 .2416 L
Mistroke
.79776 .2416 L
.79776 .2416 L
.79776 .2416 L
.79776 .2416 L
.79776 .24159 L
.79776 .24159 L
.79776 .24159 L
.79776 .24159 L
.79776 .24159 L
.79776 .24159 L
.79776 .24159 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24158 L
.79775 .24157 L
.79775 .24157 L
.79775 .24157 L
.79775 .24157 L
.79775 .24157 L
.79775 .24157 L
.79775 .24157 L
.79775 .24156 L
.79775 .24156 L
.79775 .24156 L
.79775 .24156 L
.79775 .24156 L
.79774 .24156 L
.79774 .24156 L
.79774 .24156 L
.79774 .24155 L
.79774 .24155 L
.79774 .24155 L
.79774 .24155 L
.79774 .24155 L
.79774 .24155 L
.79774 .24155 L
.79774 .24154 L
.79774 .24154 L
.79774 .24154 L
.79774 .24154 L
.79774 .24154 L
.79774 .24154 L
.79774 .24154 L
.79774 .24153 L
.79774 .24153 L
Mistroke
.79774 .24153 L
.79774 .24153 L
.79774 .24153 L
.79773 .24153 L
.79773 .24153 L
.79773 .24153 L
.79773 .24152 L
.79773 .24152 L
.79773 .24152 L
.79773 .24152 L
.79773 .24152 L
.79773 .24152 L
.79773 .24152 L
.79773 .24151 L
.79773 .24151 L
.79773 .24151 L
.79773 .24151 L
.79773 .24151 L
.79773 .24151 L
.79773 .24151 L
.79773 .2415 L
.79773 .2415 L
.79773 .2415 L
.79773 .2415 L
.79773 .2415 L
.79773 .2415 L
.79773 .2415 L
.79772 .2415 L
.79772 .24149 L
.79772 .24149 L
.79772 .24149 L
.79772 .24149 L
.79772 .24149 L
.79772 .24149 L
.79772 .24149 L
.79772 .24148 L
.79772 .24148 L
.79772 .24148 L
.79772 .24148 L
.79772 .24148 L
.79772 .24148 L
.79772 .24148 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
.79772 .24147 L
Mistroke
.79772 .24146 L
.79772 .24146 L
.79772 .24146 L
.79772 .24146 L
.79772 .24146 L
.79771 .24146 L
.79771 .24146 L
.79771 .24145 L
.79771 .24145 L
.79771 .24145 L
.79771 .24145 L
.79771 .24145 L
.79771 .24145 L
.79771 .24145 L
.79771 .24144 L
.79771 .24144 L
.79771 .24144 L
.79771 .24144 L
.79771 .24144 L
.79771 .24144 L
.79771 .24144 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24143 L
.79771 .24142 L
.79771 .24142 L
.79771 .24142 L
.79771 .24142 L
.79771 .24142 L
.79771 .24142 L
.79771 .24142 L
.79771 .24141 L
.79771 .24141 L
.79771 .24141 L
.7977 .24141 L
.7977 .24141 L
.7977 .24141 L
.7977 .24141 L
.7977 .2414 L
.7977 .2414 L
.7977 .2414 L
.7977 .2414 L
.7977 .2414 L
.7977 .2414 L
.7977 .2414 L
Mistroke
.7977 .24139 L
.7977 .24139 L
.7977 .24139 L
.7977 .24139 L
.7977 .24139 L
.7977 .24139 L
.7977 .24139 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24138 L
.7977 .24137 L
.7977 .24137 L
.7977 .24137 L
.7977 .24137 L
.7977 .24137 L
.7977 .24137 L
.7977 .24137 L
.7977 .24136 L
.7977 .24136 L
.7977 .24136 L
.7977 .24136 L
.7977 .24136 L
.7977 .24136 L
.7977 .24136 L
.7977 .24135 L
.7977 .24135 L
.7977 .24135 L
.7977 .24135 L
.7977 .24135 L
.7977 .24135 L
.7977 .24135 L
.7977 .24134 L
.7977 .24134 L
.79769 .24134 L
.79769 .24134 L
.79769 .24134 L
.79769 .24134 L
.79769 .24134 L
.79769 .24133 L
.79769 .24133 L
.79769 .24133 L
.79769 .24133 L
.79769 .24133 L
.79769 .24133 L
.79769 .24133 L
Mistroke
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24132 L
.79769 .24131 L
.79769 .24131 L
.79769 .24131 L
.79769 .24131 L
.79769 .24131 L
.79769 .24131 L
.79769 .24131 L
.79769 .2413 L
.79769 .2413 L
.79769 .2413 L
.79769 .2413 L
.79769 .2413 L
.79769 .2413 L
.79769 .2413 L
.79769 .24129 L
.79769 .24129 L
.79769 .24129 L
.79769 .24129 L
.79769 .24129 L
.79769 .24129 L
.79769 .24129 L
.79769 .24128 L
.79769 .24128 L
.79769 .24128 L
.79769 .24128 L
.79769 .24128 L
.79769 .24128 L
.79769 .24128 L
.79769 .24127 L
.79769 .24127 L
.79769 .24127 L
.79769 .24127 L
.79769 .24127 L
.79769 .24127 L
.79769 .24127 L
.79769 .24126 L
.79769 .24126 L
.79769 .24126 L
.79769 .24126 L
.79769 .24126 L
.79769 .24126 L
.79769 .24126 L
Mistroke
.79769 .24125 L
.79769 .24125 L
.79769 .24125 L
.79769 .24125 L
.79769 .24125 L
.79769 .24125 L
.79769 .24125 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24124 L
.79769 .24123 L
.79769 .24123 L
.79769 .24123 L
.79769 .24123 L
.79769 .24123 L
.79769 .24123 L
.79769 .24123 L
.79769 .24122 L
.79769 .24122 L
.79769 .24122 L
.79769 .24122 L
.79769 .24122 L
.79769 .24122 L
.79769 .24122 L
.79769 .24121 L
.79769 .24121 L
.79769 .24121 L
.79769 .24121 L
.79769 .24121 L
.79769 .24121 L
.79769 .24121 L
.79769 .2412 L
.79769 .2412 L
.79769 .2412 L
.79769 .2412 L
.79769 .2412 L
.79769 .2412 L
.79769 .2412 L
.79769 .24119 L
.79769 .24119 L
.79769 .24119 L
.79769 .24119 L
.79769 .24119 L
.79769 .24119 L
.79769 .24119 L
Mistroke
.79769 .24118 L
.79769 .24118 L
.79769 .24118 L
.79769 .24118 L
.79769 .24118 L
.79769 .24118 L
.79769 .24118 L
.79769 .24117 L
.79769 .24117 L
.79769 .24117 L
.79769 .24117 L
.79769 .24117 L
.79769 .24117 L
.79769 .24117 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24116 L
.79769 .24115 L
.79769 .24115 L
.79769 .24115 L
.79769 .24115 L
.79769 .24115 L
.79769 .24115 L
.79769 .24115 L
.79769 .24114 L
.79769 .24114 L
.79769 .24114 L
.79769 .24114 L
.79769 .24114 L
.79769 .24114 L
.79769 .24114 L
.79769 .24113 L
.79769 .24113 L
.79769 .24113 L
.79769 .24113 L
.79769 .24113 L
.79769 .24113 L
.79769 .24113 L
.79769 .24112 L
.79769 .24112 L
.79769 .24112 L
.79769 .24112 L
.79769 .24112 L
.79769 .24112 L
.79769 .24112 L
Mistroke
.79769 .24111 L
.79769 .24111 L
.79769 .24111 L
.79769 .24111 L
.79769 .24111 L
.79769 .24111 L
.79769 .24111 L
.79769 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .2411 L
.7977 .24109 L
.7977 .24109 L
.7977 .24109 L
.7977 .24109 L
.7977 .24109 L
.7977 .24109 L
.7977 .24109 L
.7977 .24108 L
.7977 .24108 L
.7977 .24108 L
.7977 .24108 L
.7977 .24108 L
.7977 .24108 L
.7977 .24108 L
.7977 .24107 L
.7977 .24107 L
.7977 .24107 L
.7977 .24107 L
.7977 .24107 L
.7977 .24107 L
.7977 .24107 L
.7977 .24106 L
.7977 .24106 L
.7977 .24106 L
.7977 .24106 L
.7977 .24106 L
.7977 .24106 L
.7977 .24106 L
.7977 .24105 L
.7977 .24105 L
.7977 .24105 L
.7977 .24105 L
.7977 .24105 L
.7977 .24105 L
.7977 .24105 L
Mistroke
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24104 L
.7977 .24103 L
.7977 .24103 L
.79771 .24103 L
.79771 .24103 L
.79771 .24103 L
.79771 .24103 L
.79771 .24103 L
.79771 .24102 L
.79771 .24102 L
.79771 .24102 L
.79771 .24102 L
.79771 .24102 L
.79771 .24102 L
.79771 .24102 L
.79771 .24101 L
.79771 .24101 L
.79771 .24101 L
.79771 .24101 L
.79771 .24101 L
.79771 .24101 L
.79771 .24101 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .241 L
.79771 .24099 L
.79771 .24099 L
.79771 .24099 L
.79771 .24099 L
.79771 .24099 L
.79771 .24099 L
.79771 .24099 L
.79771 .24098 L
.79771 .24098 L
.79771 .24098 L
.79771 .24098 L
.79772 .24098 L
.79772 .24098 L
Mistroke
.79772 .24098 L
.79772 .24097 L
.79772 .24097 L
.79772 .24097 L
.79772 .24097 L
.79772 .24097 L
.79772 .24097 L
.79772 .24097 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24096 L
.79772 .24095 L
.79772 .24095 L
.79772 .24095 L
.79772 .24095 L
.79772 .24095 L
.79772 .24095 L
.79772 .24095 L
.79772 .24094 L
.79772 .24094 L
.79772 .24094 L
.79772 .24094 L
.79772 .24094 L
.79772 .24094 L
.79773 .24094 L
.79773 .24093 L
.79773 .24093 L
.79773 .24093 L
.79773 .24093 L
.79773 .24093 L
.79773 .24093 L
.79773 .24093 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24092 L
.79773 .24091 L
.79773 .24091 L
.79773 .24091 L
.79773 .24091 L
.79773 .24091 L
Mistroke
.79773 .24091 L
.79773 .24091 L
.79773 .2409 L
.79773 .2409 L
.79773 .2409 L
.79773 .2409 L
.79773 .2409 L
.79774 .2409 L
.79774 .2409 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24089 L
.79774 .24088 L
.79774 .24088 L
.79774 .24088 L
.79774 .24088 L
.79774 .24088 L
.79774 .24088 L
.79774 .24088 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24087 L
.79774 .24086 L
.79775 .24086 L
.79775 .24086 L
.79775 .24086 L
.79775 .24086 L
.79775 .24086 L
.79775 .24086 L
.79775 .24085 L
.79775 .24085 L
.79775 .24085 L
.79775 .24085 L
.79775 .24085 L
.79775 .24085 L
.79775 .24085 L
.79775 .24084 L
.79775 .24084 L
.79775 .24084 L
.79775 .24084 L
Mistroke
.79775 .24084 L
.79775 .24084 L
.79775 .24084 L
.79775 .24084 L
.79775 .24083 L
.79775 .24083 L
.79776 .24083 L
.79776 .24083 L
.79776 .24083 L
.79776 .24083 L
.79776 .24083 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24082 L
.79776 .24081 L
.79776 .24081 L
.79776 .24081 L
.79776 .24081 L
.79776 .24081 L
.79776 .24081 L
.79776 .24081 L
.79776 .2408 L
.79776 .2408 L
.79777 .2408 L
.79777 .2408 L
.79777 .2408 L
.79777 .2408 L
.79777 .2408 L
.79777 .2408 L
.79777 .24079 L
.79777 .24079 L
.79777 .24079 L
.79777 .24079 L
.79777 .24079 L
.79777 .24079 L
.79777 .24079 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79777 .24078 L
.79778 .24077 L
Mistroke
.79778 .24077 L
.79778 .24077 L
.79778 .24077 L
.79778 .24077 L
.79778 .24077 L
.79778 .24077 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24076 L
.79778 .24075 L
.79778 .24075 L
.79778 .24075 L
.79778 .24075 L
.79779 .24075 L
.79779 .24075 L
.79779 .24075 L
.79779 .24075 L
.79779 .24074 L
.79779 .24074 L
.79779 .24074 L
.79779 .24074 L
.79779 .24074 L
.79779 .24074 L
.79779 .24074 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.79779 .24073 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24072 L
.7978 .24071 L
.7978 .24071 L
.7978 .24071 L
.7978 .24071 L
.7978 .24071 L
Mistroke
.7978 .24071 L
.7978 .24071 L
.7978 .2407 L
.7978 .2407 L
.7978 .2407 L
.79781 .2407 L
.79781 .2407 L
.79781 .2407 L
.79781 .2407 L
.79781 .2407 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24069 L
.79781 .24068 L
.79781 .24068 L
.79781 .24068 L
.79781 .24068 L
.79781 .24068 L
.79782 .24068 L
.79782 .24068 L
.79782 .24068 L
.79782 .24067 L
.79782 .24067 L
.79782 .24067 L
.79782 .24067 L
.79782 .24067 L
.79782 .24067 L
.79782 .24067 L
.79782 .24066 L
.79782 .24066 L
.79782 .24066 L
.79782 .24066 L
.79782 .24066 L
.79782 .24066 L
.79782 .24066 L
.79783 .24066 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24065 L
.79783 .24064 L
Mistroke
.79783 .24064 L
.79783 .24064 L
.79783 .24064 L
.79783 .24064 L
.79783 .24064 L
.79783 .24064 L
.79784 .24064 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24063 L
.79784 .24062 L
.79784 .24062 L
.79784 .24062 L
.79784 .24062 L
.79784 .24062 L
.79784 .24062 L
.79784 .24062 L
.79785 .24062 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .24061 L
.79785 .2406 L
.79785 .2406 L
.79785 .2406 L
.79785 .2406 L
.79785 .2406 L
.79785 .2406 L
.79785 .2406 L
.79786 .2406 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24059 L
.79786 .24058 L
.79786 .24058 L
.79786 .24058 L
Mistroke
.79786 .24058 L
.79786 .24058 L
.79786 .24058 L
.79787 .24058 L
.79787 .24058 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24057 L
.79787 .24056 L
.79787 .24056 L
.79787 .24056 L
.79787 .24056 L
.79787 .24056 L
.79788 .24056 L
.79788 .24056 L
.79788 .24056 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24055 L
.79788 .24054 L
.79788 .24054 L
.79788 .24054 L
.79789 .24054 L
.79789 .24054 L
.79789 .24054 L
.79789 .24054 L
.79789 .24054 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24053 L
.79789 .24052 L
.7979 .24052 L
.7979 .24052 L
.7979 .24052 L
Mistroke
.7979 .24052 L
.7979 .24052 L
.7979 .24052 L
.7979 .24052 L
.7979 .24051 L
.7979 .24051 L
.7979 .24051 L
.7979 .24051 L
.7979 .24051 L
.7979 .24051 L
.7979 .24051 L
.79791 .24051 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .2405 L
.79791 .24049 L
.79791 .24049 L
.79791 .24049 L
.79791 .24049 L
.79792 .24049 L
.79792 .24049 L
.79792 .24049 L
.79792 .24049 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24048 L
.79792 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24047 L
.79793 .24046 L
.79793 .24046 L
.79793 .24046 L
.79793 .24046 L
Mistroke
.79793 .24046 L
.79793 .24046 L
.79794 .24046 L
.79794 .24046 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24045 L
.79794 .24044 L
.79794 .24044 L
.79795 .24044 L
.79795 .24044 L
.79795 .24044 L
.79795 .24044 L
.79795 .24044 L
.79795 .24044 L
.79795 .24043 L
.79795 .24043 L
.79795 .24043 L
.79795 .24043 L
.79795 .24043 L
.79795 .24043 L
.79795 .24043 L
.79796 .24043 L
.79796 .24043 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24042 L
.79796 .24041 L
.79796 .24041 L
.79797 .24041 L
.79797 .24041 L
.79797 .24041 L
.79797 .24041 L
.79797 .24041 L
.79797 .24041 L
.79797 .2404 L
.79797 .2404 L
.79797 .2404 L
Mistroke
.79797 .2404 L
.79797 .2404 L
.79797 .2404 L
.79797 .2404 L
.79798 .2404 L
.79798 .2404 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24039 L
.79798 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24038 L
.79799 .24037 L
.79799 .24037 L
.79799 .24037 L
.79799 .24037 L
.79799 .24037 L
.798 .24037 L
.798 .24037 L
.798 .24037 L
.798 .24037 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.798 .24036 L
.79801 .24036 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
.79801 .24035 L
Mistroke
.79801 .24035 L
.79801 .24034 L
.79801 .24034 L
.79801 .24034 L
.79802 .24034 L
.79802 .24034 L
.79802 .24034 L
.79802 .24034 L
.79802 .24034 L
.79802 .24034 L
.79802 .24033 L
.79802 .24033 L
.79802 .24033 L
.79802 .24033 L
.79802 .24033 L
.79802 .24033 L
.79803 .24033 L
.79803 .24033 L
.79803 .24033 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79803 .24032 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .24031 L
.79804 .2403 L
.79804 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .2403 L
.79805 .24029 L
.79805 .24029 L
.79805 .24029 L
Mistroke
.79805 .24029 L
.79805 .24029 L
.79806 .24029 L
.79806 .24029 L
.79806 .24029 L
.79806 .24029 L
.79806 .24028 L
.79806 .24028 L
.79806 .24028 L
.79806 .24028 L
.79806 .24028 L
.79806 .24028 L
.79806 .24028 L
.79807 .24028 L
.79807 .24028 L
.79807 .24028 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79807 .24027 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24026 L
.79808 .24025 L
.79808 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24025 L
.79809 .24024 L
.79809 .24024 L
.79809 .24024 L
.79809 .24024 L
.7981 .24024 L
.7981 .24024 L
Mistroke
.7981 .24024 L
.7981 .24024 L
.7981 .24024 L
.7981 .24024 L
.7981 .24023 L
.7981 .24023 L
.7981 .24023 L
.7981 .24023 L
.7981 .24023 L
.79811 .24023 L
.79811 .24023 L
.79811 .24023 L
.79811 .24023 L
.79811 .24023 L
.79811 .24022 L
.79811 .24022 L
.79811 .24022 L
.79811 .24022 L
.79811 .24022 L
.79811 .24022 L
.79811 .24022 L
.79812 .24022 L
.79812 .24022 L
.79812 .24022 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79812 .24021 L
.79813 .24021 L
.79813 .24021 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79813 .2402 L
.79814 .2402 L
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
Mistroke
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
.79814 .24019 L
.79814 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24018 L
.79815 .24017 L
.79815 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24017 L
.79816 .24016 L
.79816 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24016 L
.79817 .24015 L
.79817 .24015 L
.79817 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24015 L
.79818 .24014 L
.79818 .24014 L
.79818 .24014 L
.79818 .24014 L
.79819 .24014 L
Mistroke
.79819 .24014 L
.79819 .24014 L
.79819 .24014 L
.79819 .24014 L
.79819 .24014 L
.79819 .24014 L
.79819 .24013 L
.79819 .24013 L
.79819 .24013 L
.79819 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24013 L
.7982 .24012 L
.7982 .24012 L
.7982 .24012 L
.7982 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24012 L
.79821 .24011 L
.79821 .24011 L
.79821 .24011 L
.79821 .24011 L
.79822 .24011 L
.79822 .24011 L
.79822 .24011 L
.79822 .24011 L
.79822 .24011 L
.79822 .24011 L
.79822 .2401 L
.79822 .2401 L
.79822 .2401 L
.79822 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .2401 L
.79823 .24009 L
Mistroke
.79823 .24009 L
.79823 .24009 L
.79823 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24009 L
.79824 .24008 L
.79824 .24008 L
.79824 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24008 L
.79825 .24007 L
.79825 .24007 L
.79825 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24007 L
.79826 .24006 L
.79826 .24006 L
.79826 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24006 L
.79827 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
Mistroke
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24005 L
.79828 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.79829 .24004 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.7983 .24003 L
.79831 .24003 L
.79831 .24003 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79831 .24002 L
.79832 .24002 L
.79832 .24002 L
.79832 .24002 L
.79832 .24001 L
.79832 .24001 L
.79832 .24001 L
.79832 .24001 L
.79832 .24001 L
.79832 .24001 L
.79832 .24001 L
.79833 .24001 L
Mistroke
.79833 .24001 L
.79833 .24001 L
.79833 .24001 L
.79833 .24001 L
.79833 .24 L
.79833 .24 L
.79833 .24 L
.79833 .24 L
.79833 .24 L
.79833 .24 L
.79834 .24 L
.79834 .24 L
.79834 .24 L
.79834 .24 L
.79834 .24 L
.79834 .24 L
.79834 .24 L
.79834 .23999 L
.79834 .23999 L
.79834 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23999 L
.79835 .23998 L
.79835 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79836 .23998 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
.79837 .23997 L
Mistroke
.79837 .23997 L
.79837 .23997 L
.79838 .23997 L
.79838 .23997 L
.79838 .23997 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79838 .23996 L
.79839 .23996 L
.79839 .23996 L
.79839 .23996 L
.79839 .23996 L
.79839 .23996 L
.79839 .23995 L
.79839 .23995 L
.79839 .23995 L
.79839 .23995 L
.79839 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23995 L
.7984 .23994 L
.7984 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79841 .23994 L
.79842 .23994 L
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
Mistroke
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
.79842 .23993 L
.79843 .23993 L
.79843 .23993 L
.79843 .23993 L
.79843 .23993 L
.79843 .23992 L
.79843 .23992 L
.79843 .23992 L
.79843 .23992 L
.79843 .23992 L
.79843 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23992 L
.79844 .23991 L
.79844 .23991 L
.79844 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79845 .23991 L
.79846 .23991 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79846 .2399 L
.79847 .2399 L
.79847 .2399 L
.79847 .2399 L
Mistroke
.79847 .2399 L
.79847 .2399 L
.79847 .23989 L
.79847 .23989 L
.79847 .23989 L
.79847 .23989 L
.79847 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23989 L
.79848 .23988 L
.79848 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.79849 .23988 L
.7985 .23988 L
.7985 .23988 L
.7985 .23988 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.7985 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23987 L
.79851 .23986 L
.79851 .23986 L
.79852 .23986 L
Mistroke
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79852 .23986 L
.79853 .23986 L
.79853 .23986 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79853 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23985 L
.79854 .23984 L
.79854 .23984 L
.79854 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79855 .23984 L
.79856 .23984 L
.79856 .23984 L
.79856 .23984 L
.79856 .23983 L
.79856 .23983 L
.79856 .23983 L
.79856 .23983 L
.79856 .23983 L
Mistroke
.79856 .23983 L
.79856 .23983 L
.79856 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23983 L
.79857 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79858 .23982 L
.79859 .23982 L
.79859 .23982 L
.79859 .23982 L
.79859 .23982 L
.79859 .23982 L
.79859 .23981 L
.79859 .23981 L
.79859 .23981 L
.79859 .23981 L
.79859 .23981 L
.79859 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.7986 .23981 L
.79861 .23981 L
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
Mistroke
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
.79861 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .2398 L
.79862 .23979 L
.79862 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79863 .23979 L
.79864 .23979 L
.79864 .23979 L
.79864 .23979 L
.79864 .23979 L
.79864 .23979 L
.79864 .23978 L
.79864 .23978 L
.79864 .23978 L
.79864 .23978 L
.79864 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79865 .23978 L
.79866 .23978 L
Mistroke
.79866 .23978 L
.79866 .23978 L
.79866 .23978 L
.79866 .23977 L
.79866 .23977 L
.79866 .23977 L
.79866 .23977 L
.79866 .23977 L
.79866 .23977 L
.79866 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79867 .23977 L
.79868 .23977 L
.79868 .23977 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79868 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.79869 .23976 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
Mistroke
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.7987 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79871 .23975 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79872 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79873 .23974 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79874 .23973 L
.79875 .23973 L
Mistroke
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79875 .23973 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79876 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79877 .23972 L
.79878 .23972 L
.79878 .23972 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79878 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
Mistroke
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.79879 .23971 L
.7988 .23971 L
.7988 .23971 L
.7988 .23971 L
.7988 .23971 L
.7988 .23971 L
.7988 .2397 L
.7988 .2397 L
.7988 .2397 L
.7988 .2397 L
.7988 .2397 L
.7988 .2397 L
.7988 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79881 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .2397 L
.79882 .23969 L
.79882 .23969 L
.79882 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
.79883 .23969 L
Mistroke
.79883 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79884 .23969 L
.79885 .23969 L
.79885 .23969 L
.79885 .23969 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79885 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79886 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23968 L
.79887 .23967 L
.79887 .23967 L
.79888 .23967 L
Mistroke
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79888 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.79889 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23967 L
.7989 .23966 L
.7989 .23966 L
.7989 .23966 L
.7989 .23966 L
.7989 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79891 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
Mistroke
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79892 .23966 L
.79893 .23966 L
.79893 .23966 L
.79893 .23966 L
.79893 .23966 L
.79893 .23966 L
.79893 .23966 L
.79893 .23965 L
.79893 .23965 L
.79893 .23965 L
.79893 .23965 L
.79893 .23965 L
.79893 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79894 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79895 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
Mistroke
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23965 L
.79896 .23964 L
.79896 .23964 L
.79896 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79897 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79898 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.79899 .23964 L
.799 .23964 L
.799 .23964 L
Mistroke
.799 .23964 L
.799 .23964 L
.799 .23964 L
.799 .23964 L
.799 .23963 L
.799 .23963 L
.799 .23963 L
.799 .23963 L
.799 .23963 L
.799 .23963 L
.799 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79901 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79902 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
.79903 .23963 L
Mistroke
.79903 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23963 L
.79904 .23962 L
.79904 .23962 L
.79904 .23962 L
.79904 .23962 L
.79904 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79905 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79906 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
Mistroke
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79907 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79908 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.79909 .23962 L
.7991 .23962 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.7991 .23961 L
.79911 .23961 L
Mistroke
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79911 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79912 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79913 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
Mistroke
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79914 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79915 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79916 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
Mistroke
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79917 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79918 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.79919 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
Mistroke
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.7992 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79921 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79922 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
Mistroke
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79923 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79924 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79925 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
Mistroke
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79926 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79927 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79928 .23961 L
.79929 .23961 L
.79929 .23961 L
Mistroke
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.79929 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.7993 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
Mistroke
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79931 .23961 L
.79932 .23961 L
.79932 .23961 L
.79932 .23961 L
.79932 .23961 L
.79932 .23961 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79932 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
.79933 .23962 L
Mistroke
.79933 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79934 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79935 .23962 L
.79936 .23962 L
.79936 .23962 L
.79936 .23962 L
Mistroke
.79936 .23962 L
.79936 .23962 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79936 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79937 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
Mistroke
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79938 .23963 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.79939 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
Mistroke
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.7994 .23964 L
.79941 .23964 L
.79941 .23964 L
.79941 .23964 L
.79941 .23964 L
.79941 .23964 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
Mistroke
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79941 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23965 L
.79942 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
Mistroke
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79943 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23966 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
.79944 .23967 L
Mistroke
.79944 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23967 L
.79945 .23968 L
.79945 .23968 L
.79945 .23968 L
.79945 .23968 L
.79945 .23968 L
.79945 .23968 L
.79945 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
Mistroke
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23968 L
.79946 .23969 L
.79946 .23969 L
.79946 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
Mistroke
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .23969 L
.79947 .2397 L
.79947 .2397 L
.79947 .2397 L
.79947 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
Mistroke
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .2397 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79948 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23971 L
.79949 .23972 L
.79949 .23972 L
Mistroke
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.79949 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23972 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
Mistroke
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23973 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.7995 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
Mistroke
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23974 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
.79951 .23975 L
Mistroke
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23976 L
.79951 .23977 L
.79951 .23977 L
.79951 .23977 L
.79951 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
Mistroke
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23977 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
Mistroke
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23978 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .23979 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
Mistroke
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .2398 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
Mistroke
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23981 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23982 L
.79952 .23983 L
.79952 .23983 L
Mistroke
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23983 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
Mistroke
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23984 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
Mistroke
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23985 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23986 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
Mistroke
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23987 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
Mistroke
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23988 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79952 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .23989 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
Mistroke
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .2399 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
Mistroke
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23991 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.79951 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
Mistroke
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23992 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23993 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
Mistroke
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.7995 .23994 L
.79949 .23994 L
.79949 .23994 L
.79949 .23994 L
.79949 .23994 L
.79949 .23994 L
.79949 .23994 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
Mistroke
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23995 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
Mistroke
.79949 .23996 L
.79949 .23996 L
.79949 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23996 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
Mistroke
.79948 .23997 L
.79948 .23997 L
.79948 .23997 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79948 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23998 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
Mistroke
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79947 .23999 L
.79946 .23999 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
Mistroke
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79946 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
Mistroke
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24001 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
Mistroke
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79945 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24002 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
Mistroke
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79944 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24003 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
Mistroke
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79943 .24004 L
.79942 .24004 L
.79942 .24004 L
.79942 .24004 L
.79942 .24004 L
.79942 .24004 L
.79942 .24004 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
Mistroke
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79942 .24005 L
.79941 .24005 L
.79941 .24005 L
.79941 .24005 L
.79941 .24005 L
.79941 .24005 L
.79941 .24005 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
Mistroke
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.79941 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24006 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
Mistroke
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.7994 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24007 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
Mistroke
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79939 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
Mistroke
.79938 .24008 L
.79938 .24008 L
.79938 .24008 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79938 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
Mistroke
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .24009 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79937 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
Mistroke
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79936 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .2401 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
Mistroke
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79935 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
Mistroke
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24011 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79934 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
Mistroke
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79933 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
Mistroke
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24012 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79932 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
Mistroke
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.79931 .24013 L
.7993 .24013 L
.7993 .24013 L
Mistroke
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24013 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
Mistroke
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.7993 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
Mistroke
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79929 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
Mistroke
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79928 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24014 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
Mistroke
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79927 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
Mistroke
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79926 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
Mistroke
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
Mistroke
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79925 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
Mistroke
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79924 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
Mistroke
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
Mistroke
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79923 .24015 L
.79922 .24015 L
.79922 .24015 L
.79922 .24015 L
.79922 .24015 L
.79922 .24015 L
.79922 .24015 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
Mistroke
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79922 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
Mistroke
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
Mistroke
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.79921 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24016 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
Mistroke
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
Mistroke
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.7992 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
Mistroke
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
Mistroke
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79919 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
Mistroke
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
Mistroke
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79918 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
Mistroke
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
Mistroke
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24015 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
Mistroke
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79917 .24014 L
.79916 .24014 L
Mistroke
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
Mistroke
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
Mistroke
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24014 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
Mistroke
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
Mistroke
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79916 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
Mistroke
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
Mistroke
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24013 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
Mistroke
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
Mistroke
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
Mistroke
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
.79915 .24012 L
Mistroke
.79915 .24012 L
.79915 .24012 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
Mistroke
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
Mistroke
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
Mistroke
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .24011 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
Mistroke
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
Mistroke
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
Mistroke
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
.79915 .2401 L
Mistroke
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
Mistroke
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
Mistroke
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79915 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
Mistroke
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24009 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
Mistroke
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
Mistroke
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
Mistroke
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
Mistroke
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24008 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
Mistroke
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
Mistroke
.79916 .24007 L
.79916 .24007 L
.79916 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
Mistroke
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
Mistroke
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
Mistroke
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24007 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
Mistroke
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
.79917 .24006 L
Mistroke
.79917 .24006 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00A?oonfX5o`000?oooo]Z
n?oonfX004Cooo]Z1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoookJP00A?oonfX5o`00
0?oooo]Zn?oonfX004Cooo]Z1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoookJP00A?oo
nfX5o`000?oooo]Zn?oonfX004Cooo]Z1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoook
JP00A?oonfX5o`000?oooo]Zn?oonfX004Cooo]Z1Ol0003ooookJS[ooo]Z:ola0?nCoookJP00A?oo
nfX5o`000?oooo]Z<OoonfXloc40oh_ooo]Z0014oookJPGo0000oooonfXYoookJQ?o<@3o9ooonfX?
oc40ohKooo]Z0014oookJPGo0000oooonfXSoookJPoo<@3o>OoonfX<oc40oh7ooo]Z0014oookJPGo
0000oooonfXNoookJPgo<@3oAOoonfX;oc40oggooo]Z0014oookJPGo0000oooonfXIoookJPco<@3o
D?oonfX9oc40og[ooo]Z0014oookJPGo0000oooonfXDoookJPco<@3oFOoonfX9oc40ogKooo]Z0014
oookJPGo0000oooonfX@oookJP_o<@3oH_oonfX7oc40ogCooo]Z0014oookJPGo0000oooonfX<oook
JP[o<@3oJ_oonfX7oc40og7ooo]Z0014oookJPGo0000oooonfX8oookJP[o<@3oL?oonfX7oc40ofoo
oo]Z0014oookJPGo0000oooonfX5oookJPWo<@3oMooonfX6oc40ofgooo]Z0014oookJPGo0000oooo
nfX1oookJPWo<@3oOOoonfX7oc40of[ooo]Z0014oookJPGo0000oOoonfX8oc40ohCooo]Z1Ola0?mY
oookJP00A?oonfX5o`000?Wooo]Z2Ola0?n9oookJPGo<@3oIooonfX004Cooo]Z1Ol0003foookJPWo
<@3oS_oonfX5oc40ofGooo]Z0014oookJPGo0000looonfX8oc40oi?ooo]Z1Ola0?mToookJP00A?oo
nfX5o`000?3ooo]Z2?la0?nHoookJPGo<@3oH_oonfX004Cooo]Z1Ol0003]oookJPSo<@3oWOoonfX4
oc40of7ooo]Z0014oookJPGo0000jooonfX7oc40oj7ooo]Z1Ola0?mOoookJP00A?oonfX5o`000>So
oo]Z1ola0?nUoookJPGo<@3oG_oonfX004Cooo]Z1Ol0003UoookJPOo<@3oZ_oonfX4oc40oegooo]Z
0014oookJPGo0000hooonfX7oc40ojgooo]Z1?la0?mLoookJP00A?oonfX5o`000>3ooo]Z1ola0?na
oookJPCo<@3oFooonfX004Cooo]Z1Ol0003MoookJPOo<@3o]OoonfX4oc40oe[ooo]Z0014oookJPGo
0000fooonfX7oc40okSooo]Z1?la0?mIoookJP00A?oonfX5o`000=Wooo]Z1_la0?nloookJPCo<@3o
F?oonfX004Cooo]Z1Ol0003FoookJPOo<@3o_ooonfX4oc40oeOooo]Z0014oookJPGo0000e?oonfX6
oc40ol?ooo]Z1?la0?mFoookJP007?oonfX5o`00O`Cooo]Z0ol007l6oookJP?o001o1?oonfX5o`00
O`[ooo]Z1Ol0003BoookJPKo<@3oa_oonfX3oc40oeKooo]Z000KoookJPOo001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJPOo001o2OoonfX5o`000<oooo]Z1ola0?o9oookJP?o<@3oEOoonfX001_ooo]Z
0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX3o`00O`;ooo]Z1?l007l01?oonf[o
001oo`00Ool007l9oookJPGo0000cOoonfX7oc40olcooo]Z0ola0?mDoookJP006_oonfX3o`00O`?o
oo]Z0ol007l6oookJPWo001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol0003;oook
JPKo<@3ocooonfX3oc40oeCooo]Z000JoookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l7oookJP?o
001o2?oonfX6o`000<Sooo]Z1_la0?oBoookJP?o<@3oDooonfX001[ooo]Z0ol007l3oookJP?o001o
1_oonfX2o`00O`?ooo]Z0ol007l8oookJP?o001o2?oonfX5o`000<Oooo]Z1_la0?oEoookJP?o<@3o
D_oonfX001[ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007l3oookJP;o001o0_oo
nfX4o`00O`Sooo]Z1Ol00035oookJPKo<@3oeooonfX3oc40oe;ooo]Z000JoookJP?o001o0ooonfX3
o`00O`Oooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJPOo001o2OoonfX5o`000<?ooo]Z1_la
0?oJoookJP?o<@3oDOoonfX001[ooo]Z0ol007l3oookJP?o001o2?oonfX2o`00O`04oookJ_l007oo
001oo`00O`?ooo]Z1_l007l:oookJPGo0000`OoonfX6oc40omcooo]Z0ola0?mAoookJP006_oonfX3
o`00O`?ooo]Z0ol007l9oookJPGo001o0ooonfX2o`00O`kooo]Z1Ol0002ooookJPKo<@3ogooonfX3
oc40oe3ooo]Z000KoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00O`?ooo]Z0_l007l>
oookJPGo0000_OoonfX6oc40on7ooo]Z0ola0?m@oookJP006ooonfX7o`00O`_ooo]Z1?l007l4oook
JPOo001o2?oonfX5o`000;_ooo]Z1_la0?oToookJP;o<@3oD?oonfX001cooo]Z1Ol007l=oookJP?o
001o1?oonfX7o`00O`Sooo]Z1Ol0002ioookJPKo<@3oi_oonfX3oc40odoooo]Z0014oookJPGo0000
]ooonfX6oc40onSooo]Z0ola0?m?oookJP00A?oonfX5o`000;Gooo]Z1_la0?o[oookJP;o<@3oCooo
nfX004Cooo]Z1Ol0002coookJPKo<@3okOoonfX3oc40odkooo]Z0014oookJPGo0000/_oonfX5oc40
onoooo]Z0ola0?m>oookJP00A?oonfX5o`000;3ooo]Z1Ola0?oboookJP;o<@3oC_oonfX004Cooo]Z
1Ol0002^oookJPGo<@3om?oonfX2oc40odkooo]Z0014oookJPGo0000[?oonfX6oc40ooGooo]Z0_la
0?m>oookJP00A?oonfX5o`000:[ooo]Z1_la0?ogoookJP;o<@3oC_oonfX004Cooo]Z1Ol0002Yoook
JPGo<@3onOoonfX3oc40odgooo]Z0014oookJPGo0000YooonfX5oc40oo_ooo]Z0ola0?m=oookJP00
A?oonfX5o`000:Kooo]Z1Ola0?omoookJP;o<@3oCOoonfX004Cooo]Z1Ol0002ToookJPGo<@3ooooo
nfX2oc40odgooo]Z0014oookJPGo0000X_oonfX5oc40oooooo]Z0_oonfX2oc40odgooo]Z0014oook
JPGo0000XOoonfX5oc40oooooo]Z0ooonfX2oc40odgooo]Z0014oookJPGo0000C_oonfX5o`00O`Co
oo]Z0ol007l6oookJP?o001o??oonfX5oc40o`Oooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OdSo
oo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OdSooo]Z1Ol007l4oookJP?o001o0ooonfX3o`00Oc?o
oo]Z0_la0?m=oookJP00A?oonfX5o`0004gooo]Z1ol007l3oookJP?o001o1_oonfX3o`00Oc[ooo]Z
1Ola0?l8oookJPOo001o0ooonfX3o`00O`;ooo]Z1ol007m6oookJPOo001o0ooonfX3o`00O`;ooo]Z
1ol007m6oookJPOo001o0ooonfX3o`00O`?ooo]Z0ol007lcoookJP;o<@3oCOoonfX004Cooo]Z1Ol0
001=oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007lioookJPGo<@3o
2OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00O`04
oookJ_l007oo001oo`00OdKooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oonfX3
o`00O`;ooo]Z0ol007m5oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`?ooo]Z0ol0
07lcoookJP;o<@3oCOoonfX004Cooo]Z1Ol0001<oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007lf
oookJPGo<@3o2_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00OdCooo]Z0ol007l3
oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007m4oookJP?o001o0ooonfX3o`00O`Wooo]Z0_l007lc
oookJP;o<@3oCOoonfX004Cooo]Z1Ol0001<oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007leoook
JPGo<@3o2ooonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oA?oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00OdCooo]Z0ol007l3oookJP?o001o2OoonfX3o`00Oc7ooo]Z0ola0?m=oook
JP00A?oonfX5o`0004cooo]Z0ol007l3oookJP?o001o1_oonfX2o`00O`?ooo]Z0ol007ldoookJPGo
<@3o3OoonfX3o`00O`?ooo]Z0ol007l<oookJP?o001oA?oonfX3o`00O`?ooo]Z0ol007l6oookJPCo
001o0_oonfX3o`00OdCooo]Z0ol007l3oookJP?o001o2OoonfX3o`00Oc7ooo]Z0ola0?m=oookJP00
A?oonfX5o`0004cooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`;ooo]Z0ol007lcoookJPCo<@3o
3ooonfX3o`00O`?ooo]Z0ol007l7oookJP;o001o0_oonfX4o`00OdCooo]Z0ol007l3oookJP?o001o
1_oonfX8o`00OdGooo]Z0ol007l3oookJP?o001o2_oonfX2o`00Oc7ooo]Z0_la0?m>oookJP00A?oo
nfX5o`0004cooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001oo`00Oc7ooo]Z
1Ola0?l@oookJP?o001o0ooonfX3o`00O`Oooo]Z1ol007m5oookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l01?oonf[o001oo`00Ool007m6oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l`oookJP;o
<@3oC_oonfX004Cooo]Z1Ol0001<oookJP?o001o0ooonfX3o`00O`Sooo]Z0_l007l01?oonf[o001o
o`00Ool007l_oookJPGo<@3o4_oonfX3o`00O`?ooo]Z0ol007l7oookJPKo001oA_oonfX3o`00O`?o
oo]Z0ol007l6oookJP?o001oB_oonfX3o`00O`?ooo]Z0ol007l;oookJP;o001o<?oonfX2oc40odko
oo]Z0014oookJPGo0000C?oonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o;_oonfX5oc40oa?ooo]Z
0ol007l3oookJP?o001o1ooonfX2o`00Od[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00Od[ooo]Z
0ol007l3oookJP?o001o3?oonfX2o`00Oboooo]Z0_la0?m>oookJP00A?oonfX5o`0004gooo]Z0ol0
07l01?oonf[o001oo`00Ool007l:oookJPGo001o;OoonfX4oc40oaKooo]Z0ol007l01?oonf[o001o
o`00Ool007l8oookJP;o001oBooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l2oook
JP?o001oAOoonfX3o`00O`04oookJ_l007oo001oo`00O`gooo]Z0_l007l_oookJP;o<@3oC_oonfX0
04Cooo]Z1Ol0001=oookJPOo001o2ooonfX4o`00Ob_ooo]Z1Ola0?lGoookJPOo001o2OoonfX7o`00
OdGooo]Z1ol007l8oookJPOo001oA_oonfX7o`00O`Oooo]Z2Ol007l]oookJP?o<@3oC_oonfX004Co
oo]Z1Ol0001>oookJPGo001o3OoonfX3o`00Ob[ooo]Z1?la0?lJoookJPGo001o2_oonfX7o`00OdKo
oo]Z1Ol007l;oookJPCo001oB?oonfX5o`00O`Sooo]Z2Ol007l]oookJP?o<@3oC_oonfX004Cooo]Z
1Ol0002;oookJPGo<@3ooooonfXGoookJP;o<@3oCooonfX004Cooo]Z1Ol0002:oookJPCo<@3ooooo
nfXIoookJP;o<@3oCooonfX004Cooo]Z1Ol00028oookJPGo<@3ooooonfXIoookJP?o<@3oCooonfX0
04Cooo]Z1Ol00027oookJPGo<@3ooooonfXJoookJP?o<@3o7OoonfX3o`00O`Cooo]Z0ol007l3oook
JPCo001o00Gooo]Zo`00Ool007oo001ooookJP03o`00O`Cooo]Z1Ol007l5oookJPGo001o1_oonfX0
04Cooo]Z1Ol00025oookJPGo<@3ooooonfXLoookJP;o<@3o7_oonfX3o`00O`?ooo]Z1?l007l2oook
JPSo001o0_oonfX3o`00O`Cooo]Z1Ol007l4oookJPOo001o1OoonfX00<go00001Ola0?ooo`0001co
00000ola0?lAo`0000gooo]Z0ol007l3oookJPCo001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o0ooonfX7o`00O`;ooo]Z1?l007l2oookJP?o001o1?oonfX00<co00001?la0?ooo`0001ko0000
0ola0?lAo`0000gooo]Z0ol007l2oookJPGo001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o
0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l:oookJP00b_l00005oc40oooo0000
7ol00002oc40oa;o00003OoonfX3o`00O`;ooo]Z1Ol007l2oookJPCo001o00Cooo]Zo`00Ool007oo
001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2oookJPWo001o1?oonfX00<Wo
00001Ola0?ooo`0001oo00000ola0?lBo`0000gooo]Z0ol007l00ooonf[o001oo`00O`04o`00O`?o
oo]Z1ol007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z2Ol007l4oook
JP00b?l00004oc40oooo00008Ol00003oc40oa;o00003OoonfX3o`00O`04oookJ_l007oo001ooook
JP?o001o1ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001o
o`00O`?ooo]Z0ol007l4oookJP00A?oonfX5o`0005Wooo]Z00?o0000oookJ_oonfX08OoonfX5oc40
oc?ooo]Z00?o0000oookJ_oonfX0FOoonfX00ol0003ooo]ZoookJP1JoookJP03o`000?oonf[ooo]Z
037ooo]Z0ola0?lPoookJPKo001o00Cooo]Zo`00Ool007oo001o0_oonfX3o`00O`;ooo]Z0ol007l2
oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o1?oo
nfX004Cooo]Z1Ol0001loookJPCo<@3ooooonfXSoookJP?o<@3o8?oonfX5o`00O`;ooo]Z0ol007l2
oookJPSo001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX7o`00O`Gooo]Z0014oook
JPGo0000NooonfX4oc40oooooo]Z8ooonfX3oc40ob7ooo]Z1Ol007l2oookJP?o001o1?oonfX4o`00
O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l5oookJP?o001o0_oonfX5o`00O`Kooo]Z0014oook
JPGo0000NOoonfX5oc40oooooo]Z9?oonfX3oc40ob7ooo]Z1?l007l3oookJP?o001o:?oonfX004Co
oo]Z1Ol0001hoookJPGo<@3ooooonfXToookJP?o<@3o8_oonfX4o`00O`?ooo]Z0ol007l<oookJP?o
001o6OoonfX004Cooo]Z1Ol0001goookJPCo<@3ooooonfXVoookJP?o<@3o8_oonfX3o`00O`Cooo]Z
0ol007l<oookJP?o001o6OoonfX004Cooo]Z1Ol0001foookJPCo<@3ooooonfXVoookJP?o<@3oEOoo
nfX004Cooo]Z1Ol0001doookJPGo<@3ooooonfXWoookJP?o<@3oEOoonfX004Cooo]Z1Ol0001coook
JPCo<@3ooooonfXXoookJP?o<@3oE_oonfX004Cooo]Z1Ol0001boookJPCo<@3ooooonfXYoookJP?o
<@3oE_oonfX004Cooo]Z1Ol0001aoookJPCo<@3ooooonfXYoookJP?o<@3oEooonfX004Cooo]Z1Ol0
001_oookJPGo<@3ooooonfXZoookJP?o<@3oEooonfX004Cooo]Z1Ol0001^oookJPCo<@3ooooonfX[
oookJP?o<@3oF?oonfX004Cooo]Z1Ol0001]oookJPCo<@3ooooonfX[oookJPCo<@3oF?oonfX004Co
oo]Z1Ol0001/oookJPCo<@3ooooonfX/oookJP?o<@3oFOoonfX004Cooo]Z1Ol0001ZoookJPCo<@3o
oooonfX]oookJP?o<@3oF_oonfX004Cooo]Z1Ol0001YoookJPCo<@3ooooonfX]oookJPCo<@3oF_oo
nfX004Cooo]Z1Ol0001XoookJPCo<@3ooooonfX^oookJP?o<@3oFooonfX004Cooo]Z1Ol0001Woook
JPCo<@3ooooonfX^oookJP?o<@3oG?oonfX004Cooo]Z1Ol0001VoookJPCo<@3ooooonfX^oookJPCo
<@3oG?oonfX004Cooo]Z1Ol0001UoookJP?o<@3ooooonfX_oookJPCo<@3oGOoonfX004Cooo]Z1Ol0
001SoookJPCo<@3ooooonfX`oookJP?o<@3oG_oonfX004Cooo]Z1Ol0001RoookJPCo<@3ooooonfX`
oookJP?o<@3oGooonfX004Cooo]Z1Ol0001QoookJPCo<@3ooooonfX`oookJPCo<@3oGooonfX004Co
oo]Z1Ol0001PoookJPCo<@3ooooonfX`oookJPCo<@3oH?oonfX004Cooo]Z1Ol0001OoookJPCo<@3o
oooonfX`oookJPCo<@3oHOoonfX004Cooo]Z1Ol0001MoookJPGo<@3ooooonfX`oookJPCo<@3oH_oo
nfX004Cooo]Z1Ol0001LoookJPCo<@3ooooonfXboookJP?o<@3oHooonfX004Cooo]Z1Ol0001Koook
JPCo<@3ooooonfXboookJP?o<@3oI?oonfX004Cooo]Z1Ol0001JoookJPCo<@3ooooonfXboookJPCo
<@3oI?oonfX004Cooo]Z1Ol0001IoookJPCo<@3okooonfX6oc40occooo]Z1?la0?mUoookJP00A?oo
nfX5o`0005Sooo]Z1?la0?o]oookJP_o<@3o>OoonfX4oc40ofKooo]Z0014oookJPGo0000EooonfX4
oc40oncooo]Z1ola0?l00ooonf[o<@3ooc40o`03oc40ocSooo]Z1?la0?mWoookJP00A?oonfX5o`00
05Kooo]Z1?la0?o[oookJPKo<@3o1_oonfX3oc40ocOooo]Z1?la0?mXoookJP00A?oonfX5o`0005Go
oo]Z1?la0?o[oookJPGo<@3o2?oonfX3oc40ocKooo]Z1?la0?mYoookJP00A?oonfX5o`0005Cooo]Z
1?la0?o[oookJPCo<@3o1ooonfX2oc40o`04oookJ_la0?oo<@3ooc40ocGooo]Z1?la0?mZoookJP00
7?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5o`00O`[ooo]Z1Ol0001CoookJP?o<@3o
k?oonfX4oc40o`Oooo]Z1_la0?leoookJPCo<@3oJooonfX001_ooo]Z1ol007l3oookJP?o001o0_oo
nfX7o`00O`?ooo]Z1ol007l9oookJPGo0000DOoonfX4oc40oncooo]Z1?la0?l8oookJPKo<@3o=?oo
nfX4oc40ofcooo]Z000KoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`03oookJ_l0
07oo001o00;o001o00Cooo]Zo`00Ool007oo001o0_oonfX4o`00O`04oookJ_l007oo001oo`00O`Wo
oo]Z1Ol0001@oookJPCo<@3ok?oonfX4oc40o`Wooo]Z1Ola0?ldoookJPCo<@3oKOoonfX001[ooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o
001o2?oonfX5o`0004oooo]Z1?la0?o/oookJPCo<@3o@OoonfX5oc40ofkooo]Z000JoookJP?o001o
0ooonfX3o`00O`cooo]Z0ol007l7oookJP?o001o2?oonfX6o`0004gooo]Z1?la0?o/oookJPCo<@3o
@OoonfX4oc40og3ooo]Z000JoookJP?o001o0ooonfX3o`00O`cooo]Z0ol007l7oookJP?o001o2?oo
nfX5o`0004gooo]Z1?la0?o]oookJP?o<@3o@OoonfX4oc40og7ooo]Z000JoookJP?o001o0ooonfX3
o`00O`Oooo]Z0_l007l2oookJPCo001o0_oonfX2o`00O`;ooo]Z1?l007l8oookJPGo0000C?oonfX4
oc40ongooo]Z1?la0?m0oookJPCo<@3oL_oonfX001[ooo]Z0ol007l3oookJP?o001o1ooonfX7o`00
O`?ooo]Z1ol007l9oookJPGo0000BooonfX4oc40onkooo]Z0ola0?m0oookJPCo<@3oLooonfX001[o
oo]Z0ol007l3oookJP?o001o1ooonfX6o`00O`Cooo]Z1_l007l:oookJPGo0000B_oonfX4oc40onko
oo]Z0ola0?looookJPGo<@3oM?oonfX001[ooo]Z0ol007l3oookJP?o001o1ooonfX2o`00O`Sooo]Z
0_l007l>oookJPGo0000BOoonfX4oc40onoooo]Z0ola0?lnoookJPCo<@3oM_oonfX001_ooo]Z0ol0
07l01?oonf[o001oo`00Ool007l8oookJP;o001o2?oonfX2o`00O`kooo]Z1Ol00018oookJPCo<@3o
l?oonfX3oc40occooo]Z1Ola0?mgoookJP006ooonfX7o`00O`Wooo]Z1ol007l3oookJPOo001o2?oo
nfX5o`0004Oooo]Z1?la0?o`oookJP?o<@3o??oonfX5oc40ogSooo]Z000LoookJPGo001o2_oonfX7
o`00O`?ooo]Z1ol007l8oookJPGo0000A_oonfX4oc40oo7ooo]Z0ola0?lkoookJPCo<@3oN_oonfX0
04Cooo]Z1Ol00015oookJPCo<@3ol_oonfX3oc40ocWooo]Z1Ola0?mkoookJP00A?oonfX5o`0004Co
oo]Z1?la0?ocoookJP?o<@3o>?oonfX5oc40ogcooo]Z0014oookJPGo0000@ooonfX4oc40ooCooo]Z
0_la0?lgoookJPGo<@3oO_oonfX004Cooo]Z1Ol00012oookJPCo<@3omOoonfX3oc40ocCooo]Z1_la
0?mooookJP00A?oonfX5o`00047ooo]Z1?la0?ofoookJP?o<@3o<ooonfX5oc40oh7ooo]Z0014oook
JPGo0000@?oonfX4oc40ooOooo]Z0ola0?laoookJPGo<@3oPooonfX004Cooo]Z1Ol0000ooookJPCo
<@3on?oonfX3oc40oboooo]Z1_la0?n4oookJP00A?oonfX5o`0003kooo]Z1?la0?ojoookJP?o<@3o
;?oonfX6oc40ohKooo]Z0014oookJPGo0000?OoonfX4oc40oo_ooo]Z1?la0?lYoookJPKo<@3oR?oo
nfX004Cooo]Z1Ol0000loookJPCo<@3ooOoonfX3oc40obOooo]Z1_la0?n:oookJP00A?oonfX5o`00
03_ooo]Z1?la0?onoookJPCo<@3o8ooonfX7oc40ohcooo]Z0014oookJPGo0000>_oonfX4oc40oooo
oo]Z0OoonfX4oc40ob3ooo]Z1ola0?n>oookJP00A?oonfX5o`0003[ooo]Z0ola0?oooookJP?ooo]Z
1Ola0?lJoookJPSo<@3oTOoonfX004Cooo]Z1Ol0000ioookJP?o<@3ooooonfX5oookJPKo<@3o5Ooo
nfX9oc40oi?ooo]Z0014oookJPGo0000=ooonfX4oc40oooooo]Z1ooonfX8oc40o`gooo]Z2ola0?nF
oookJP00A?oonfX5o`0003Kooo]Z1?la0?oooookJP[ooo]Z6_la0?nJoookJP00A?oonfX5o`0003Ko
oo]Z0ola0?oooookJPkooo]Z4ola0?nNoookJP00A?oonfX5o`0003Gooo]Z0ola0?oooookJ/3ooo]Z
0014oookJPGo0000=?oonfX3oc40oooooo]Z`OoonfX004Cooo]Z1Ol0000coookJP?o<@3ooooonf[2
oookJP00A?oonfX5o`0003;ooo]Z1?la0?oooookJ/;ooo]Z0014oookJPGo0000<OoonfX4oc40oooo
oo]Z`ooonfX004Cooo]Z1Ol0000`oookJPCo<@3ooooonf[4oookJP00A?oonfX5o`0002oooo]Z1?la
0?oooookJ/Gooo]Z0014oookJPGo0000;_oonfX4oc40oooooo]Za_oonfX004Cooo]Z1Ol0000]oook
JPCo<@3ooooonf[7oookJP00A?oonfX5o`0002cooo]Z1?la0?oooookJ/Sooo]Z0014oookJPGo0000
;?oonfX3oc40oooooo]ZbOoonfX004Cooo]Z1Ol0000[oookJP?o<@3ooooonf[:oookJP00A?oonfX5
o`0002[ooo]Z0ola0?oooookJ/_ooo]Z000VoookJPGo001o1?oonfX3o`00O`?ooo]Z1Ol007l:oook
JPGo0000:OoonfX3oc40oooooo]Zc?oonfX002Gooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Wo
oo]Z1Ol0000XoookJPCo<@3ooooonf[<oookJP009OoonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`Sooo]Z1Ol0000WoookJPCo<@3ooooonf[=oookJP00
9?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1Ol0000VoookJPCo<@3o
oooonf[>oookJP009?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Sooo]Z1_l0
000ToookJPCo<@3ooooonf[?oookJP009?oonfX3o`00O`?ooo]Z0ol007l6oookJPCo001o0_oonfX3
o`00O`Sooo]Z1Ol0000UoookJP?o<@3ooooonf[@oookJP009?oonfX3o`00O`?ooo]Z0ol007l6oook
JPSo001o2OoonfX5o`0002Cooo]Z0ola0?oooookJ]7ooo]Z000ToookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l01?oonf[o001oo`00Ool007l:oookJPGo00008ooonfX3oc40oooooo]Zd_oonfX002Co
oo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`kooo]Z1Ol0000RoookJP?o<@3ooooonf[CoookJP00
9?oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o3_oonfX5o`00027ooo]Z1?la0?oooookJ]?ooo]Z
000UoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3o`00O`;ooo]Z0ol007l8oookJPGo0000
8?oonfX4oc40oooooo]Ze?oonfX002Gooo]Z1ol007l8oookJPOo001o2OoonfX5o`0001oooo]Z1?la
0?oooookJ]Gooo]Z000VoookJPGo001o2ooonfX4o`00O`[ooo]Z1Ol0000OoookJP?o<@3ooooonf[F
oookJP00A?oonfX5o`0001kooo]Z0ola0?oooookJ]Oooo]Z0014oookJPGo00007OoonfX3oc40oooo
oo]Zf?oonfX004Cooo]Z1Ol0000LoookJPCo<@3ooooonf[HoookJP00A?oonfX5o`0001_ooo]Z1?la
0?oooookJ]Wooo]Z0014oookJPGo00006_oonfX4oc40oooooo]Zf_oonfX004Cooo]Z1Ol0000Joook
JP?o<@3ooooonf[KoookJP00A?oonfX5o`0001Wooo]Z0ola0?oooookJ]cooo]Z0014oookJPGo0000
6?oonfX3oc40oooooo]ZgOoonfX004Cooo]Z1Ol0000GoookJPCo<@3ooooonf[MoookJP00A?oonfX5
o`0001Kooo]Z1?la0?oooookJ]kooo]Z0014oookJPGo00005_oonfX3oc40oooooo]ZgooonfX004Co
oo]Z1Ol0000EoookJP?o<@3ooooonf[PoookJP00A?oonfX5o`0001Cooo]Z0ola0?oooookJ^7ooo]Z
0014oookJPGo00004ooonfX4oc40oooooo]ZhOoonfX004Cooo]Z1Ol0000BoookJPCo<@3ooooonf[R
oookJP00A?oonfX5o`0001;ooo]Z0ola0?oooookJ^?ooo]Z0014oookJPGo00004OoonfX3oc40oooo
oo]Zi?oonfX004Cooo]Z1Ol0000@oookJP?o<@3ooooonf[UoookJP00A?oonfX5o`0000oooo]Z1?la
0?oooookJ^Gooo]Z0014oookJPGo00003_oonfX4oc40oooooo]Zi_oonfX004Cooo]Z1Ol0000>oook
JP?o<@3ooooonf[WoookJP00A?oonfX5o`0000gooo]Z0ola0?oooookJ^Sooo]Z0014oookJPGo0000
3?oonfX3oc40oooooo]ZjOoonfX004Cooo]Z1Ol0000;oookJPCo<@3ooooonf[YoookJP00A?oonfX5
o`0000[ooo]Z1?la0?oooookJ^[ooo]Z0014oookJPGo00002_oonfX3oc40oooooo]ZjooonfX004Co
oo]Z1Ol00009oookJP?o<@3ooooonf[/oookJP00A?oonfX5o`0000Sooo]Z0ola0?oooookJ^gooo]Z
0014oookJPGo00001ooonfX4oc40oooooo]ZkOoonfX004Cooo]Z1Ol00007oookJP?o<@3ooooonf[^
oookJP007?oonfX5o`00O`Cooo]Z0ol007l3oookJPGo001o1OoonfX5o`00O`[ooo]Z1Ol00006oook
JP?o<@3ooooonf[_oookJP006ooonfX7o`00O`?ooo]Z0ol007l2oookJPOo001o0ooonfX7o`00O`Wo
oo]Z1Ol00005oookJP?o<@3ooooonf[`oookJP006ooonfX3o`00O`04oookJ_l007oo001oo`00O`?o
oo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`03oookJ_l007oo001o00;o001o00Cooo]Zo`00Ool0
07oo001o2OoonfX5o`0000Cooo]Z1?la0?oooookJ_3ooo]Z000JoookJP?o001o0ooonfX3o`00O`Ko
oo]Z0ol007l3oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Sooo]Z1Ol00004oook
JP?o<@3ooooonf[aoookJP006_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Oo
oo]Z0ol007l8oookJPKo00000_oonfX3oc40oooooo]Zl_oonfX001[ooo]Z0ol007l3oookJP?o001o
1_oonfX4o`00O`;ooo]Z0ol007l7oookJP?o001o2?oonfX5o`0000;ooo]Z0ola0?oooookJ_?ooo]Z
000JoookJP?o001o0ooonfX3o`00O`Kooo]Z2?l007l3oookJP;o001o0_oonfX4o`00O`Sooo]Z1Ol0
00000ooonf[o<@3ooc40o`02oc40oooooo]ZlooonfX001[ooo]Z0ol007l3oookJP?o001o1_oonfX3
o`00O`04oookJ_l007oo001oo`00O`Cooo]Z1ol007l9oookJPGo000000Cooo]Zoc40oola0?oo<@3o
oooonf[doookJP006_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o2?oonfX6o`00O`[ooo]Z1Ol0
0003oc40oooooo]ZmOoonfX001[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`Sooo]Z0_l007l>
oookJPCo00000ola0?oooookJ_Kooo]Z000KoookJP?o001o00Cooo]Zo`00Ool007oo001o2?oonfX3
o`00O`;ooo]Z0ol007l2oookJP;o001o3_oonfX3o`0000Co<@3ooooonf[foookJP006ooonfX7o`00
O`Sooo]Z1ol007l4oookJPOo001o2?oonfX3o`0000?o<@3ooooonf[goookJP007?oonfX5o`00O`_o
oo]Z1?l007l5oookJPOo001o2?oonfX2o`0000?o<@3ooooonf[hoookJP00A?oonfX01Ol0003o<@3o
oc40oola0?oo00000?oooo]Zn?oonfX004Cooo]Z1?la0?l00ol0003ooo]ZoookJP3ooookJ_Kooo]Z
0014oookJP?o<@3o0_l0003ooookJ_Sooo]Z0013oookJP?o<@3o0ol0003ooookJ_Sooo]Z0012oook
JP?o<@3o1?l0003ooookJ_Sooo]Z0012oookJP?o<@3o1?l0003ooookJ_Sooo]Z0011oookJP?o<@3o
1Ol0003ooookJ_Sooo]Z0010oookJP?o<@3o00?ooo]Zo`000?l000000ol0003ooookJ_Sooo]Z000o
oookJPCo<@3o00?ooo]Zo`000?l000000ol0003ooookJ_Sooo]Z000ooookJP?o<@3o0_oonfX5o`00
0?oooo]Zn?oonfX003kooo]Z0ola0?l3oookJPGo0000oooonf[hoookJP00?OoonfX3oc40o`Cooo]Z
1Ol0003ooookJ_Sooo]Z000moookJP?o<@3o1?oonfX5o`000?oooo]Zn?oonfX003cooo]Z0ola0?l5
oookJPGo0000oooonf[hoookJP00>ooonfX3oc40o`Kooo]Z1Ol0003ooookJ_Sooo]Z000joookJPCo
<@3o1_oonfX5o`000?oooo]Zn?oonfX003[ooo]Z0ola0?l7oookJPGo0000oooonf[hoookJP00>Ooo
nfX3oc40o`Sooo]Z1Ol0003ooookJ_Sooo]Z000hoookJPCo<@3o2?oonfX5o`000?oooo]Zn?oonfX0
03Sooo]Z0ola0?l9oookJPGo0000oooonf[hoookJP00=ooonfX3oc40o`[ooo]Z1Ol0003ooookJ_So
oo]Z000foookJP?o<@3o2ooonfX5o`000?oooo]Zn?oonfX003Kooo]Z0ola0?l;oookJPGo0000oooo
nf[hoookJP00=OoonfX3oc40o`cooo]Z1Ol0003ooookJ_Sooo]Z000doookJP?o<@3o3OoonfX5o`00
0?oooo]Zn?oonfX003?ooo]Z1?la0?l=oookJPGo0000oooonf[hoookJP00<ooonfX3oc40o`kooo]Z
1Ol0003ooookJ_Sooo]Z000boookJP?o<@3o3ooonfX5o`000?oooo]Zn?oonfX0037ooo]Z1?la0?l?
oookJPGo0000oooonf[hoookJP00<OoonfX3oc40oa3ooo]Z1Ol0003ooookJ_Sooo]Z000VoookJPGo
001o1?oonfX01?l007oo<@3ooc40oola0?l2oookJP?o001o3?oonfX5o`000?oooo]Zn?oonfX002Go
oo]Z1ol007l3oookJPCo<@3o0_oonfX3o`00O`cooo]Z1Ol0003ooookJ_Sooo]Z000UoookJP?o001o
00Cooo]Zo`00Ool007oo001o0ooonfX3oc40o`?ooo]Z0ol007l<oookJPGo0000oooonf[hoookJP00
9?oonfX3o`00O`?ooo]Z0ol007l01?oonf[o<@3ooc40oola0?l5oookJP;o001o3?oonfX5o`000?oo
oo]Zn?oonfX002Cooo]Z0ol007l3oookJP?o001o1?la0?l5oookJP?o001o2ooonfX6o`000?oooo]Z
mooonfX002Cooo]Z0ol007l3oookJP?o001o0ola0?l6oookJP?o001o2ooonfX5o`000?oooo]Zn?oo
nfX002Cooo]Z0ol007l3oookJP;o001o0ola0?l8oookJP;o001o2ooonfX5o`000?oooo]Zn?oonfX0
02Cooo]Z0ol007l3oookJP03o`00Oola0?oo<@3o00;o<@3o2?oonfX3o`00O`[ooo]Z1Ol0003ooook
J_Sooo]Z000ToookJP?o001o0ooonfX01?l007oo<@3ooc40oola0?l:oookJP;o001o2_oonfX5o`00
0?oooo]Zn?oonfX002Cooo]Z0ol007l3oookJP?o<@3o3?oonfX2o`00O`Wooo]Z1Ol0003ooookJ_So
oo]Z000UoookJP?o001o00?ooo]Zoc40oola0?l00_la0?l<oookJP;o001o2OoonfX5o`000?oooo]Z
n?oonfX002Gooo]Z1?l007l3oc40o`Oooo]Z2Ol007l8oookJPGo0000oooonf[hoookJP009_oonfX2
o`00O`?o<@3o2?oonfX9o`00O`Sooo]Z1Ol0003ooookJ_Sooo]Z000WoookJPCo<@3o6OoonfX5o`00
0?oooo]Zn?oonfX002Oooo]Z0ola0?lJoookJPGo0000oooonf[hoookJP009_oonfX3oc40oa_ooo]Z
1Ol0003ooookJ_Sooo]Z000VoookJP?o<@3o6ooonfX5o`000?oooo]Zn?oonfX002Gooo]Z0ola0?lL
oookJPGo0000oooonf[hoookJP009?oonfX3oc40oagooo]Z1Ol0003ooookJ_Sooo]Z000ToookJP?o
<@3o7OoonfX5o`000?oooo]Zn?oonfX002?ooo]Z0ola0?lNoookJPGo0000oooonf[hoookJP008_oo
nfX3oc40oaoooo]Z1Ol0003ooookJ_Sooo]Z000RoookJP?o<@3o7ooonfX5o`000?oooo]Zn?oonfX0
027ooo]Z0ola0?lPoookJPGo0000oooonf[hoookJP008?oonfX3oc40ob7ooo]Z1Ol0003ooookJ_So
oo]Z000PoookJP?o<@3o8OoonfX5o`000?oooo]Zn?oonfX001oooo]Z0ola0?lRoookJPGo0000oooo
nf[hoookJP007_oonfX4oc40ob;ooo]Z1Ol0003ooookJ_Sooo]Z000NoookJP?o<@3o8ooonfX5o`00
0?oooo]Zn?oonfX001gooo]Z0ola0?lToookJPGo0000oooonf[hoookJP007OoonfX3oc40obCooo]Z
1Ol0003ooookJ_Sooo]Z000LoookJP?o<@3o9OoonfX5o`000?oooo]Zn?oonfX001_ooo]Z0ola0?lV
oookJPGo0000oooonf[hoookJP006ooonfX3oc40obKooo]Z1Ol0003ooookJ_Sooo]Z000JoookJP?o
<@3o9ooonfX5o`000?oooo]Zn?oonfX001Wooo]Z0ola0?lXoookJPGo0000oooonf[hoookJP006Ooo
nfX3oc40obSooo]Z1Ol0003ooookJ_Sooo]Z000HoookJP?o<@3o:OoonfX5o`000?oooo]Zn?oonfX0
01Sooo]Z0ola0?lYoookJPGo0000oooonf[hoookJP005ooonfX3oc40ob[ooo]Z1Ol0003ooookJ_So
oo]Z000FoookJP?o<@3o:ooonfX5o`000?oooo]Zn?oonfX001Kooo]Z0ola0?l[oookJPGo0000oooo
nf[hoookJP005OoonfX3oc40obcooo]Z1Ol0003ooookJ_Sooo]Z000EoookJP?o<@3o1?oonfX5o`00
O`Cooo]Z0ol007l3oookJP?o001o1ooonfX5o`00O`[ooo]Z1Ol0003ooookJ_Sooo]Z000DoookJP?o
<@3o1?oonfX7o`00O`?ooo]Z0ol007l3oookJP?o001o1_oonfX7o`00O`Wooo]Z1Ol0003ooookJ_So
oo]Z000CoookJP?o<@3o1OoonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l3oookJP?o
001o1OoonfX4o`00O`04oookJ_l007oo001oo`00O`Wooo]Z1Ol0003ooookJ_Sooo]Z000CoookJP;o
<@3o1OoonfX3o`00O`?ooo]Z0ol007l9oookJP;o001o1OoonfX3o`00O`?ooo]Z0ol007l8oookJPGo
0000oooonf[hoookJP004_oonfX3oc40o`Gooo]Z0ol007l3oookJP?o001o2OoonfX3o`00O`[ooo]Z
0ol007l8oookJPKo0000oooonf[goookJP004OoonfX3oc40o`Kooo]Z0ol007l3oookJP?o001o2Ooo
nfX3o`00O`[ooo]Z0ol007l8oookJPGo0000oooonf[hoookJP004OoonfX3oc40o`Kooo]Z0ol007l3
oookJP?o001o2_oonfX2o`00O`Gooo]Z0_l007l2oookJPCo001o2?oonfX5o`000?oooo]Zn?oonfX0
013ooo]Z0ola0?l7oookJP?o001o0ooonfX3o`00O`[ooo]Z0ol007l4oookJPOo001o2OoonfX5o`00
0?oooo]Zn?oonfX0013ooo]Z0_la0?l8oookJP?o001o0ooonfX3o`00O`_ooo]Z0_l007l4oookJPKo
001o2_oonfX5o`000?oooo]Zn?oonfX000oooo]Z0ola0?l8oookJP?o001o0ooonfX3o`00O`cooo]Z
0_l007l3oookJP;o001o3_oonfX5o`000?oooo]Zn?oonfX000kooo]Z0ola0?l:oookJP?o001o00Co
oo]Zo`00Ool007oo001o3OoonfX2o`00O`?ooo]Z0_l007l>oookJPGo0000oooonf[hoookJP003_oo
nfX3oc40o`[ooo]Z1ol007l7oookJPWo001o0ooonfX7o`00O`Sooo]Z1Ol0003ooookJ_Sooo]Z000=
oookJP?o<@3o3?oonfX5o`00O`Sooo]Z2Ol007l3oookJPOo001o2?oonfX5o`000?oooo]Zn?oonfX0
00gooo]Z0_la0?leoookJPGo0000oooonf[hoookJP00A?oonfX5o`000?oooo]Zn?oonfX004Cooo]Z
1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoookJP00A?oonfX5o`000?oooo]Zn?oonfX0
04Cooo]Z1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoookJP00A?oonfX5o`000?oooo]Z
n?oonfX004Cooo]Z1Ol0003ooookJ_Sooo]Z0014oookJPGo0000oooonf[hoookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003o
oookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z
@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oo
oo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2
oookJP00oooonf[ooookJT;ooo]Z000^oookJPCo001o1OoonfX4o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l4oookJPGo001o1_oonfX3o`00O`04oookJ_l007oo
001oo`00Oooooo]Zh_oonfX002gooo]Z1_l007l3oookJPSo001o0ooonfX8o`00O`?ooo]Z1ol007l4
oookJPSo001ooooonf[RoookJP00;?oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00
O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z1?l007l2oookJP?o001o0_oonfX4o`00
O`03oookJ_l007oo001o00;o001ooooonf[RoookJP00;?oonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`Sooo]Z0ol007l3oookJP?o
001ooooonf[RoookJP00;?oonfX3o`00O`;ooo]Z0ol007l2oookJPCo001o00Cooo]Zo`00Ool007oo
001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJPWo001o0_oonfX3o`00O`?ooo]Z0ol007oooookJ^;o
oo]Z000aoookJP?o001o0ooonfX7o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX9o`00O`;ooo]Z
0ol007l3oookJP?o001ooooonf[RoookJP00<OoonfX3o`00O`Oooo]Z0ol007l2oookJP?o001o0ooo
nfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007oooookJ^;ooo]Z000a
oookJP?o001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJPCo001o00?ooo]Zo`00Ool007l00_l007l2
oookJP?o001o0ooonfX3o`00O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00Oooooo]Zh_oonfX0
037ooo]Z0ol007l2oookJPSo001o0ooonfX8o`00O`?ooo]Z1ol007l4oookJPSo001ooooonf[Roook
JP00<OoonfX3o`00O`Cooo]Z1?l007l6oookJP?o001o00Cooo]Zo`00Ool007oo001o1?oonfX5o`00
O`Kooo]Z0ol007l01?oonf[o001oo`00Ool007oooookJ^;ooo]Z000aoookJP?o001o4_oonfX3o`00
Oa?ooo]Z0ol007oooookJ^;ooo]Z000aoookJP?o001o4_oonfX3o`00Oa?ooo]Z0ol007oooookJ^;o
oo]Z000aoookJP?o001o4_oonfX3o`00Oa?ooo]Z0ol007oooookJ^;ooo]Z003ooookJ_oooo]Z@_oo
nfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00001\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {0.224145, 0.397311, \
0.00108355, 0.00116303}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell["\<\
Now calculate trajectories for a variety of initial conditions for \
the jaded and naive populations, selected randomly, then plot them on the \
naive\[Dash]jaded plane:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(graphicslist\  = 
      Table[ListPlot[
          NestList[TomorrowsPopulation, {Random[], Random[]}, 20000], 
          PlotRange \[Rule] All, PlotJoined \[Rule] True, 
          PlotStyle \[Rule] {Hue[Random[]], Thickness[0.005]}, 
          DisplayFunction \[Rule] Identity], {i, 1, 10}]\)], "Input",
  CellTags->"mmtag:24:graphics_list__example"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False], ",", 
        TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
          False,
          Editable->False]}], "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Show[graphicslist, DisplayFunction \[Rule] $DisplayFunction, 
      AxesLabel \[Rule] {"\<Naive\>", "\<Jaded\>"}]\)], "Input",
  CellTags->"mmtag:24:the_MIT_joke_model__visualized"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.006532 0.688099 -0.0235471 0.681835 [
[.13109 .10032 -14.5 -20 ]
[.13109 .10032 14.5 0 ]
[.26871 .10032 -14.5 -20 ]
[.26871 .10032 14.5 0 ]
[.40633 .10032 -14.5 -20 ]
[.40633 .10032 14.5 0 ]
[.54395 .10032 -14.5 -20 ]
[.54395 .10032 14.5 0 ]
[.68157 .10032 -7 -20 ]
[.68157 .10032 7 0 ]
[.81919 .10032 -14.5 -20 ]
[.81919 .10032 14.5 0 ]
[.95681 .10032 -14.5 -20 ]
[.95681 .10032 14.5 0 ]
[1.025 .11282 0 -10 ]
[1.025 .11282 51.9375 10 ]
[-0.01903 .24919 -29 -10 ]
[-0.01903 .24919 0 10 ]
[-0.01903 .38555 -29 -10 ]
[-0.01903 .38555 0 10 ]
[-0.01903 .52192 -29 -10 ]
[-0.01903 .52192 0 10 ]
[-0.00653 .64303 -27.9375 0 ]
[-0.00653 .64303 27.9375 20 ]
[ -0.01153 -0.005 0 0 ]
[ 1.005 .62303 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.13109 .11282 m
.13109 .11907 L
s
gsave
.13109 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.2) show
1.000 setlinewidth
grestore
.26871 .11282 m
.26871 .11907 L
s
gsave
.26871 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
.40633 .11282 m
.40633 .11907 L
s
gsave
.40633 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
.54395 .11282 m
.54395 .11907 L
s
gsave
.54395 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.68157 .11282 m
.68157 .11907 L
s
gsave
.68157 .10032 -68 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.81919 .11282 m
.81919 .11907 L
s
gsave
.81919 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.2) show
1.000 setlinewidth
grestore
.95681 .11282 m
.95681 .11907 L
s
gsave
.95681 .10032 -75.5 -24 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(1.4) show
1.000 setlinewidth
grestore
.125 Mabswid
.02787 .11282 m
.02787 .11657 L
s
.06228 .11282 m
.06228 .11657 L
s
.09668 .11282 m
.09668 .11657 L
s
.16549 .11282 m
.16549 .11657 L
s
.1999 .11282 m
.1999 .11657 L
s
.2343 .11282 m
.2343 .11657 L
s
.30311 .11282 m
.30311 .11657 L
s
.33752 .11282 m
.33752 .11657 L
s
.37192 .11282 m
.37192 .11657 L
s
.44073 .11282 m
.44073 .11657 L
s
.47514 .11282 m
.47514 .11657 L
s
.50954 .11282 m
.50954 .11657 L
s
.57835 .11282 m
.57835 .11657 L
s
.61276 .11282 m
.61276 .11657 L
s
.64716 .11282 m
.64716 .11657 L
s
.71597 .11282 m
.71597 .11657 L
s
.75038 .11282 m
.75038 .11657 L
s
.78478 .11282 m
.78478 .11657 L
s
.85359 .11282 m
.85359 .11657 L
s
.888 .11282 m
.888 .11657 L
s
.9224 .11282 m
.9224 .11657 L
s
.99121 .11282 m
.99121 .11657 L
s
.01 w
0 .11282 m
1 .11282 L
s
gsave
1.025 .11282 -61 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Naive) show
110.938 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
-0.00653 .24919 m
-0.00028 .24919 L
s
gsave
-0.01903 .24919 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.4) show
1.000 setlinewidth
grestore
-0.00653 .38555 m
-0.00028 .38555 L
s
gsave
-0.01903 .38555 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.6) show
1.000 setlinewidth
grestore
-0.00653 .52192 m
-0.00028 .52192 L
s
gsave
-0.01903 .52192 -90 -14 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(0.8) show
1.000 setlinewidth
grestore
.125 Mabswid
-0.00653 .14691 m
-0.00278 .14691 L
s
-0.00653 .181 m
-0.00278 .181 L
s
-0.00653 .2151 m
-0.00278 .2151 L
s
-0.00653 .28328 m
-0.00278 .28328 L
s
-0.00653 .31737 m
-0.00278 .31737 L
s
-0.00653 .35146 m
-0.00278 .35146 L
s
-0.00653 .41965 m
-0.00278 .41965 L
s
-0.00653 .45374 m
-0.00278 .45374 L
s
-0.00653 .48783 m
-0.00278 .48783 L
s
-0.00653 .07873 m
-0.00278 .07873 L
s
-0.00653 .04464 m
-0.00278 .04464 L
s
-0.00653 .01054 m
-0.00278 .01054 L
s
-0.00653 .55601 m
-0.00278 .55601 L
s
-0.00653 .5901 m
-0.00278 .5901 L
s
.01 w
-0.00653 0 m
-0.00653 .61803 L
s
gsave
-0.00653 .64303 -88.9375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 28 translate 1 -1 scale
/g { setgray} bind def
/k { setcmykcolor} bind def
/p { gsave} bind def
/r { setrgbcolor} bind def
/w { setlinewidth} bind def
/C { curveto} bind def
/F { fill} bind def
/L { lineto} bind def
/rL { rlineto} bind def
/P { grestore} bind def
/s { stroke} bind def
/S { show} bind def
/N {currentpoint 3 -1 roll show moveto} bind def
/Msf { findfont exch scalefont [1 0 0 -1 0 0 ] makefont setfont} bind def
/m { moveto} bind def
/Mr { rmoveto} bind def
/Mx {currentpoint exch pop moveto} bind def
/My {currentpoint pop exch moveto} bind def
/X {0 rmoveto} bind def
/Y {0 exch rmoveto} bind def
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
63.000 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
(Jaded) show
114.875 19.000 moveto
%%IncludeResource: font Helvetica-Bold
%%IncludeFont: Helvetica-Bold
/Helvetica-Bold findfont 18.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.500 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
1 .713 0 r
.005 w
.65196 .12907 m
.65215 .12915 L
.65233 .12923 L
.65252 .12931 L
.6527 .12939 L
.65289 .12947 L
.65307 .12955 L
.65326 .12963 L
.65344 .12971 L
.65363 .12979 L
.65381 .12987 L
.65399 .12996 L
.65418 .13004 L
.65436 .13012 L
.65454 .1302 L
.65473 .13028 L
.65491 .13036 L
.65509 .13045 L
.65527 .13053 L
.65546 .13061 L
.65564 .13069 L
.65582 .13077 L
.656 .13086 L
.65618 .13094 L
.65636 .13102 L
.65654 .13111 L
.65672 .13119 L
.6569 .13127 L
.65708 .13136 L
.65726 .13144 L
.65744 .13152 L
.65762 .13161 L
.6578 .13169 L
.65798 .13177 L
.65816 .13186 L
.65834 .13194 L
.65852 .13203 L
.6587 .13211 L
.65887 .13219 L
.65905 .13228 L
.65923 .13236 L
.65941 .13245 L
.65958 .13253 L
.65976 .13262 L
.65994 .1327 L
.66011 .13279 L
.66029 .13287 L
.66046 .13296 L
.66064 .13305 L
.66081 .13313 L
Mistroke
.66099 .13322 L
.66116 .1333 L
.66134 .13339 L
.66151 .13348 L
.66169 .13356 L
.66186 .13365 L
.66204 .13374 L
.66221 .13382 L
.66238 .13391 L
.66256 .134 L
.66273 .13408 L
.6629 .13417 L
.66307 .13426 L
.66325 .13434 L
.66342 .13443 L
.66359 .13452 L
.66376 .13461 L
.66393 .1347 L
.6641 .13478 L
.66427 .13487 L
.66445 .13496 L
.66462 .13505 L
.66479 .13514 L
.66496 .13523 L
.66513 .13531 L
.6653 .1354 L
.66546 .13549 L
.66563 .13558 L
.6658 .13567 L
.66597 .13576 L
.66614 .13585 L
.66631 .13594 L
.66647 .13603 L
.66664 .13612 L
.66681 .13621 L
.66698 .1363 L
.66714 .13639 L
.66731 .13648 L
.66748 .13657 L
.66764 .13666 L
.66781 .13675 L
.66798 .13684 L
.66814 .13693 L
.66831 .13702 L
.66847 .13712 L
.66864 .13721 L
.6688 .1373 L
.66897 .13739 L
.66913 .13748 L
.66929 .13757 L
Mistroke
.66946 .13767 L
.66962 .13776 L
.66978 .13785 L
.66995 .13794 L
.67011 .13803 L
.67027 .13813 L
.67043 .13822 L
.6706 .13831 L
.67076 .1384 L
.67092 .1385 L
.67108 .13859 L
.67124 .13868 L
.6714 .13878 L
.67156 .13887 L
.67172 .13896 L
.67188 .13906 L
.67204 .13915 L
.6722 .13925 L
.67236 .13934 L
.67252 .13943 L
.67268 .13953 L
.67284 .13962 L
.673 .13972 L
.67316 .13981 L
.67331 .13991 L
.67347 .14 L
.67363 .1401 L
.67379 .14019 L
.67394 .14029 L
.6741 .14038 L
.67426 .14048 L
.67441 .14058 L
.67457 .14067 L
.67473 .14077 L
.67488 .14086 L
.67504 .14096 L
.67519 .14106 L
.67535 .14115 L
.6755 .14125 L
.67566 .14135 L
.67581 .14144 L
.67596 .14154 L
.67612 .14164 L
.67627 .14173 L
.67642 .14183 L
.67658 .14193 L
.67673 .14203 L
.67688 .14212 L
.67703 .14222 L
.67719 .14232 L
Mistroke
.67734 .14242 L
.67749 .14252 L
.67764 .14261 L
.67779 .14271 L
.67794 .14281 L
.67809 .14291 L
.67824 .14301 L
.67839 .14311 L
.67854 .14321 L
.67869 .14331 L
.67884 .1434 L
.67899 .1435 L
.67914 .1436 L
.67929 .1437 L
.67944 .1438 L
.67958 .1439 L
.67973 .144 L
.67988 .1441 L
.68003 .1442 L
.68017 .1443 L
.68032 .1444 L
.68047 .14451 L
.68061 .14461 L
.68076 .14471 L
.6809 .14481 L
.68105 .14491 L
.6812 .14501 L
.68134 .14511 L
.68148 .14521 L
.68163 .14532 L
.68177 .14542 L
.68192 .14552 L
.68206 .14562 L
.6822 .14572 L
.68235 .14583 L
.68249 .14593 L
.68263 .14603 L
.68278 .14613 L
.68292 .14624 L
.68306 .14634 L
.6832 .14644 L
.68334 .14655 L
.68349 .14665 L
.68363 .14675 L
.68377 .14686 L
.68391 .14696 L
.68405 .14706 L
.68419 .14717 L
.68433 .14727 L
.68447 .14738 L
Mistroke
.68461 .14748 L
.68475 .14758 L
.68488 .14769 L
.68502 .14779 L
.68516 .1479 L
.6853 .148 L
.68544 .14811 L
.68557 .14821 L
.68571 .14832 L
.68585 .14842 L
.68598 .14853 L
.68612 .14864 L
.68626 .14874 L
.68639 .14885 L
.68653 .14895 L
.68666 .14906 L
.6868 .14917 L
.68693 .14927 L
.68707 .14938 L
.6872 .14949 L
.68734 .14959 L
.68747 .1497 L
.6876 .14981 L
.68774 .14991 L
.68787 .15002 L
.688 .15013 L
.68814 .15024 L
.68827 .15034 L
.6884 .15045 L
.68853 .15056 L
.68866 .15067 L
.6888 .15078 L
.68893 .15088 L
.68906 .15099 L
.68919 .1511 L
.68932 .15121 L
.68945 .15132 L
.68958 .15143 L
.68971 .15154 L
.68984 .15165 L
.68996 .15176 L
.69009 .15187 L
.69022 .15198 L
.69035 .15209 L
.69048 .1522 L
.69061 .15231 L
.69073 .15242 L
.69086 .15253 L
.69099 .15264 L
.69111 .15275 L
Mistroke
.69124 .15286 L
.69137 .15297 L
.69149 .15308 L
.69162 .15319 L
.69174 .1533 L
.69187 .15341 L
.69199 .15352 L
.69212 .15364 L
.69224 .15375 L
.69236 .15386 L
.69249 .15397 L
.69261 .15408 L
.69273 .1542 L
.69286 .15431 L
.69298 .15442 L
.6931 .15453 L
.69322 .15465 L
.69335 .15476 L
.69347 .15487 L
.69359 .15498 L
.69371 .1551 L
.69383 .15521 L
.69395 .15532 L
.69407 .15544 L
.69419 .15555 L
.69431 .15567 L
.69443 .15578 L
.69455 .15589 L
.69467 .15601 L
.69479 .15612 L
.6949 .15624 L
.69502 .15635 L
.69514 .15647 L
.69526 .15658 L
.69537 .1567 L
.69549 .15681 L
.69561 .15693 L
.69572 .15704 L
.69584 .15716 L
.69596 .15727 L
.69607 .15739 L
.69619 .15751 L
.6963 .15762 L
.69642 .15774 L
.69653 .15785 L
.69665 .15797 L
.69676 .15809 L
.69687 .1582 L
.69699 .15832 L
.6971 .15844 L
Mistroke
.69721 .15856 L
.69733 .15867 L
.69744 .15879 L
.69755 .15891 L
.69766 .15903 L
.69777 .15914 L
.69788 .15926 L
.698 .15938 L
.69811 .1595 L
.69822 .15962 L
.69833 .15973 L
.69844 .15985 L
.69855 .15997 L
.69866 .16009 L
.69876 .16021 L
.69887 .16033 L
.69898 .16045 L
.69909 .16057 L
.6992 .16069 L
.69931 .16081 L
.69941 .16092 L
.69952 .16104 L
.69963 .16116 L
.69973 .16128 L
.69984 .16141 L
.69995 .16153 L
.70005 .16165 L
.70016 .16177 L
.70026 .16189 L
.70037 .16201 L
.70047 .16213 L
.70058 .16225 L
.70068 .16237 L
.70078 .16249 L
.70089 .16261 L
.70099 .16274 L
.70109 .16286 L
.7012 .16298 L
.7013 .1631 L
.7014 .16322 L
.7015 .16335 L
.7016 .16347 L
.7017 .16359 L
.70181 .16371 L
.70191 .16384 L
.70201 .16396 L
.70211 .16408 L
.70221 .16421 L
.70231 .16433 L
.70241 .16445 L
Mistroke
.7025 .16458 L
.7026 .1647 L
.7027 .16482 L
.7028 .16495 L
.7029 .16507 L
.703 .1652 L
.70309 .16532 L
.70319 .16545 L
.70329 .16557 L
.70338 .1657 L
.70348 .16582 L
.70357 .16595 L
.70367 .16607 L
.70377 .1662 L
.70386 .16632 L
.70396 .16645 L
.70405 .16657 L
.70414 .1667 L
.70424 .16682 L
.70433 .16695 L
.70442 .16708 L
.70452 .1672 L
.70461 .16733 L
.7047 .16746 L
.7048 .16758 L
.70489 .16771 L
.70498 .16784 L
.70507 .16796 L
.70516 .16809 L
.70525 .16822 L
.70534 .16835 L
.70543 .16847 L
.70552 .1686 L
.70561 .16873 L
.7057 .16886 L
.70579 .16899 L
.70588 .16911 L
.70597 .16924 L
.70606 .16937 L
.70614 .1695 L
.70623 .16963 L
.70632 .16976 L
.70641 .16989 L
.70649 .17002 L
.70658 .17014 L
.70666 .17027 L
.70675 .1704 L
.70684 .17053 L
.70692 .17066 L
.70701 .17079 L
Mistroke
.70709 .17092 L
.70718 .17105 L
.70726 .17118 L
.70734 .17131 L
.70743 .17145 L
.70751 .17158 L
.70759 .17171 L
.70768 .17184 L
.70776 .17197 L
.70784 .1721 L
.70792 .17223 L
.708 .17236 L
.70808 .1725 L
.70817 .17263 L
.70825 .17276 L
.70833 .17289 L
.70841 .17302 L
.70849 .17316 L
.70857 .17329 L
.70865 .17342 L
.70872 .17355 L
.7088 .17369 L
.70888 .17382 L
.70896 .17395 L
.70904 .17409 L
.70911 .17422 L
.70919 .17435 L
.70927 .17449 L
.70934 .17462 L
.70942 .17475 L
.7095 .17489 L
.70957 .17502 L
.70965 .17516 L
.70972 .17529 L
.7098 .17543 L
.70987 .17556 L
.70995 .17569 L
.71002 .17583 L
.71009 .17596 L
.71017 .1761 L
.71024 .17624 L
.71031 .17637 L
.71038 .17651 L
.71046 .17664 L
.71053 .17678 L
.7106 .17691 L
.71067 .17705 L
.71074 .17719 L
.71081 .17732 L
.71088 .17746 L
Mistroke
.71095 .1776 L
.71102 .17773 L
.71109 .17787 L
.71116 .17801 L
.71123 .17814 L
.7113 .17828 L
.71137 .17842 L
.71144 .17856 L
.7115 .17869 L
.71157 .17883 L
.71164 .17897 L
.7117 .17911 L
.71177 .17925 L
.71184 .17938 L
.7119 .17952 L
.71197 .17966 L
.71203 .1798 L
.7121 .17994 L
.71216 .18008 L
.71223 .18022 L
.71229 .18036 L
.71235 .1805 L
.71242 .18063 L
.71248 .18077 L
.71254 .18091 L
.71261 .18105 L
.71267 .18119 L
.71273 .18133 L
.71279 .18147 L
.71285 .18161 L
.71291 .18176 L
.71298 .1819 L
.71304 .18204 L
.7131 .18218 L
.71316 .18232 L
.71322 .18246 L
.71327 .1826 L
.71333 .18274 L
.71339 .18288 L
.71345 .18303 L
.71351 .18317 L
.71357 .18331 L
.71362 .18345 L
.71368 .18359 L
.71374 .18374 L
.71379 .18388 L
.71385 .18402 L
.71391 .18416 L
.71396 .18431 L
.71402 .18445 L
Mistroke
.71407 .18459 L
.71413 .18474 L
.71418 .18488 L
.71424 .18502 L
.71429 .18517 L
.71434 .18531 L
.7144 .18545 L
.71445 .1856 L
.7145 .18574 L
.71455 .18589 L
.71461 .18603 L
.71466 .18618 L
.71471 .18632 L
.71476 .18647 L
.71481 .18661 L
.71486 .18676 L
.71491 .1869 L
.71496 .18705 L
.71501 .18719 L
.71506 .18734 L
.71511 .18748 L
.71516 .18763 L
.7152 .18777 L
.71525 .18792 L
.7153 .18807 L
.71535 .18821 L
.7154 .18836 L
.71544 .18851 L
.71549 .18865 L
.71553 .1888 L
.71558 .18895 L
.71563 .18909 L
.71567 .18924 L
.71572 .18939 L
.71576 .18953 L
.7158 .18968 L
.71585 .18983 L
.71589 .18998 L
.71594 .19013 L
.71598 .19027 L
.71602 .19042 L
.71606 .19057 L
.71611 .19072 L
.71615 .19087 L
.71619 .19102 L
.71623 .19117 L
.71627 .19131 L
.71631 .19146 L
.71635 .19161 L
.71639 .19176 L
Mistroke
.71643 .19191 L
.71647 .19206 L
.71651 .19221 L
.71655 .19236 L
.71659 .19251 L
.71663 .19266 L
.71666 .19281 L
.7167 .19296 L
.71674 .19311 L
.71678 .19326 L
.71681 .19341 L
.71685 .19356 L
.71688 .19371 L
.71692 .19387 L
.71695 .19402 L
.71699 .19417 L
.71702 .19432 L
.71706 .19447 L
.71709 .19462 L
.71713 .19478 L
.71716 .19493 L
.71719 .19508 L
.71723 .19523 L
.71726 .19538 L
.71729 .19554 L
.71732 .19569 L
.71735 .19584 L
.71739 .19599 L
.71742 .19615 L
.71745 .1963 L
.71748 .19645 L
.71751 .19661 L
.71754 .19676 L
.71757 .19691 L
.7176 .19707 L
.71762 .19722 L
.71765 .19738 L
.71768 .19753 L
.71771 .19768 L
.71774 .19784 L
.71776 .19799 L
.71779 .19815 L
.71782 .1983 L
.71784 .19846 L
.71787 .19861 L
.7179 .19877 L
.71792 .19892 L
.71795 .19908 L
.71797 .19923 L
.71799 .19939 L
Mistroke
.71802 .19954 L
.71804 .1997 L
.71807 .19986 L
.71809 .20001 L
.71811 .20017 L
.71813 .20033 L
.71816 .20048 L
.71818 .20064 L
.7182 .2008 L
.71822 .20095 L
.71824 .20111 L
.71826 .20127 L
.71828 .20142 L
.7183 .20158 L
.71832 .20174 L
.71834 .2019 L
.71836 .20205 L
.71838 .20221 L
.7184 .20237 L
.71842 .20253 L
.71843 .20268 L
.71845 .20284 L
.71847 .203 L
.71849 .20316 L
.7185 .20332 L
.71852 .20348 L
.71853 .20364 L
.71855 .2038 L
.71857 .20395 L
.71858 .20411 L
.7186 .20427 L
.71861 .20443 L
.71862 .20459 L
.71864 .20475 L
.71865 .20491 L
.71866 .20507 L
.71868 .20523 L
.71869 .20539 L
.7187 .20555 L
.71871 .20571 L
.71872 .20587 L
.71874 .20603 L
.71875 .20619 L
.71876 .20636 L
.71877 .20652 L
.71878 .20668 L
.71879 .20684 L
.7188 .207 L
.71881 .20716 L
.71881 .20732 L
Mistroke
.71882 .20749 L
.71883 .20765 L
.71884 .20781 L
.71885 .20797 L
.71885 .20813 L
.71886 .2083 L
.71887 .20846 L
.71887 .20862 L
.71888 .20878 L
.71888 .20895 L
.71889 .20911 L
.71889 .20927 L
.7189 .20944 L
.7189 .2096 L
.71891 .20976 L
.71891 .20993 L
.71891 .21009 L
.71892 .21025 L
.71892 .21042 L
.71892 .21058 L
.71892 .21075 L
.71892 .21091 L
.71893 .21107 L
.71893 .21124 L
.71893 .2114 L
.71893 .21157 L
.71893 .21173 L
.71893 .2119 L
.71893 .21206 L
.71893 .21223 L
.71893 .21239 L
.71892 .21256 L
.71892 .21272 L
.71892 .21289 L
.71892 .21305 L
.71891 .21322 L
.71891 .21339 L
.71891 .21355 L
.7189 .21372 L
.7189 .21389 L
.7189 .21405 L
.71889 .21422 L
.71889 .21438 L
.71888 .21455 L
.71888 .21472 L
.71887 .21489 L
.71886 .21505 L
.71886 .21522 L
.71885 .21539 L
.71884 .21555 L
Mistroke
.71884 .21572 L
.71883 .21589 L
.71882 .21606 L
.71881 .21623 L
.7188 .21639 L
.71879 .21656 L
.71878 .21673 L
.71877 .2169 L
.71876 .21707 L
.71875 .21723 L
.71874 .2174 L
.71873 .21757 L
.71872 .21774 L
.71871 .21791 L
.7187 .21808 L
.71868 .21825 L
.71867 .21842 L
.71866 .21859 L
.71865 .21876 L
.71863 .21893 L
.71862 .2191 L
.7186 .21927 L
.71859 .21944 L
.71858 .21961 L
.71856 .21978 L
.71854 .21995 L
.71853 .22012 L
.71851 .22029 L
.7185 .22046 L
.71848 .22063 L
.71846 .2208 L
.71845 .22097 L
.71843 .22114 L
.71841 .22131 L
.71839 .22148 L
.71837 .22166 L
.71835 .22183 L
.71833 .222 L
.71832 .22217 L
.7183 .22234 L
.71827 .22251 L
.71825 .22269 L
.71823 .22286 L
.71821 .22303 L
.71819 .2232 L
.71817 .22338 L
.71815 .22355 L
.71812 .22372 L
.7181 .22389 L
.71808 .22407 L
Mistroke
.71806 .22424 L
.71803 .22441 L
.71801 .22459 L
.71798 .22476 L
.71796 .22493 L
.71793 .22511 L
.71791 .22528 L
.71788 .22545 L
.71786 .22563 L
.71783 .2258 L
.7178 .22598 L
.71778 .22615 L
.71775 .22632 L
.71772 .2265 L
.71769 .22667 L
.71767 .22685 L
.71764 .22702 L
.71761 .2272 L
.71758 .22737 L
.71755 .22755 L
.71752 .22772 L
.71749 .2279 L
.71746 .22807 L
.71743 .22825 L
.7174 .22842 L
.71737 .2286 L
.71734 .22877 L
.7173 .22895 L
.71727 .22913 L
.71724 .2293 L
.71721 .22948 L
.71717 .22965 L
.71714 .22983 L
.71711 .23001 L
.71707 .23018 L
.71704 .23036 L
.717 .23054 L
.71697 .23071 L
.71693 .23089 L
.7169 .23107 L
.71686 .23124 L
.71682 .23142 L
.71679 .2316 L
.71675 .23178 L
.71671 .23195 L
.71668 .23213 L
.71664 .23231 L
.7166 .23249 L
.71656 .23267 L
.71652 .23284 L
Mistroke
.71648 .23302 L
.71644 .2332 L
.7164 .23338 L
.71636 .23356 L
.71632 .23373 L
.71628 .23391 L
.71624 .23409 L
.7162 .23427 L
.71616 .23445 L
.71612 .23463 L
.71607 .23481 L
.71603 .23499 L
.71599 .23517 L
.71594 .23535 L
.7159 .23552 L
.71586 .2357 L
.71581 .23588 L
.71577 .23606 L
.71572 .23624 L
.71568 .23642 L
.71563 .2366 L
.71559 .23678 L
.71554 .23696 L
.71549 .23714 L
.71545 .23732 L
.7154 .2375 L
.71535 .23769 L
.71531 .23787 L
.71526 .23805 L
.71521 .23823 L
.71516 .23841 L
.71511 .23859 L
.71506 .23877 L
.71501 .23895 L
.71496 .23913 L
.71491 .23931 L
.71486 .2395 L
.71481 .23968 L
.71476 .23986 L
.71471 .24004 L
.71466 .24022 L
.71461 .2404 L
.71455 .24059 L
.7145 .24077 L
.71445 .24095 L
.71439 .24113 L
.71434 .24132 L
.71429 .2415 L
.71423 .24168 L
.71418 .24186 L
Mistroke
.71412 .24205 L
.71407 .24223 L
.71401 .24241 L
.71396 .24259 L
.7139 .24278 L
.71384 .24296 L
.71379 .24314 L
.71373 .24333 L
.71367 .24351 L
.71362 .24369 L
.71356 .24388 L
.7135 .24406 L
.71344 .24425 L
.71338 .24443 L
.71332 .24461 L
.71326 .2448 L
.7132 .24498 L
.71314 .24517 L
.71308 .24535 L
.71302 .24553 L
.71296 .24572 L
.7129 .2459 L
.71284 .24609 L
.71278 .24627 L
.71271 .24646 L
.71265 .24664 L
.71259 .24683 L
.71253 .24701 L
.71246 .2472 L
.7124 .24738 L
.71233 .24757 L
.71227 .24775 L
.71221 .24794 L
.71214 .24812 L
.71208 .24831 L
.71201 .24849 L
.71194 .24868 L
.71188 .24887 L
.71181 .24905 L
.71174 .24924 L
.71168 .24942 L
.71161 .24961 L
.71154 .2498 L
.71147 .24998 L
.7114 .25017 L
.71134 .25036 L
.71127 .25054 L
.7112 .25073 L
.71113 .25092 L
.71106 .2511 L
Mistroke
.71099 .25129 L
.71092 .25148 L
.71085 .25166 L
.71078 .25185 L
.7107 .25204 L
.71063 .25222 L
.71056 .25241 L
.71049 .2526 L
.71042 .25279 L
.71034 .25297 L
.71027 .25316 L
.7102 .25335 L
.71012 .25354 L
.71005 .25372 L
.70997 .25391 L
.7099 .2541 L
.70982 .25429 L
.70975 .25448 L
.70967 .25466 L
.7096 .25485 L
.70952 .25504 L
.70944 .25523 L
.70937 .25542 L
.70929 .25561 L
.70921 .25579 L
.70913 .25598 L
.70906 .25617 L
.70898 .25636 L
.7089 .25655 L
.70882 .25674 L
.70874 .25693 L
.70866 .25712 L
.70858 .25731 L
.7085 .2575 L
.70842 .25768 L
.70834 .25787 L
.70826 .25806 L
.70818 .25825 L
.7081 .25844 L
.70801 .25863 L
.70793 .25882 L
.70785 .25901 L
.70777 .2592 L
.70768 .25939 L
.7076 .25958 L
.70752 .25977 L
.70743 .25996 L
.70735 .26015 L
.70726 .26034 L
.70718 .26053 L
Mistroke
.70709 .26072 L
.70701 .26091 L
.70692 .2611 L
.70683 .26129 L
.70675 .26148 L
.70666 .26168 L
.70657 .26187 L
.70649 .26206 L
.7064 .26225 L
.70631 .26244 L
.70622 .26263 L
.70614 .26282 L
.70605 .26301 L
.70596 .2632 L
.70587 .26339 L
.70578 .26359 L
.70569 .26378 L
.7056 .26397 L
.70551 .26416 L
.70542 .26435 L
.70533 .26454 L
.70523 .26473 L
.70514 .26493 L
.70505 .26512 L
.70496 .26531 L
.70487 .2655 L
.70477 .26569 L
.70468 .26588 L
.70459 .26608 L
.70449 .26627 L
.7044 .26646 L
.7043 .26665 L
.70421 .26685 L
.70411 .26704 L
.70402 .26723 L
.70392 .26742 L
.70383 .26762 L
.70373 .26781 L
.70364 .268 L
.70354 .26819 L
.70344 .26839 L
.70334 .26858 L
.70325 .26877 L
.70315 .26896 L
.70305 .26916 L
.70295 .26935 L
.70285 .26954 L
.70276 .26974 L
.70266 .26993 L
.70256 .27012 L
Mistroke
.70246 .27032 L
.70236 .27051 L
.70226 .2707 L
.70216 .2709 L
.70206 .27109 L
.70195 .27128 L
.70185 .27148 L
.70175 .27167 L
.70165 .27186 L
.70155 .27206 L
.70144 .27225 L
.70134 .27244 L
.70124 .27264 L
.70113 .27283 L
.70103 .27303 L
.70093 .27322 L
.70082 .27341 L
.70072 .27361 L
.70061 .2738 L
.70051 .274 L
.7004 .27419 L
.7003 .27438 L
.70019 .27458 L
.70008 .27477 L
.69998 .27497 L
.69987 .27516 L
.69976 .27536 L
.69966 .27555 L
.69955 .27574 L
.69944 .27594 L
.69933 .27613 L
.69922 .27633 L
.69911 .27652 L
.69901 .27672 L
.6989 .27691 L
.69879 .27711 L
.69868 .2773 L
.69857 .2775 L
.69846 .27769 L
.69834 .27789 L
.69823 .27808 L
.69812 .27828 L
.69801 .27847 L
.6979 .27867 L
.69779 .27886 L
.69767 .27906 L
.69756 .27925 L
.69745 .27945 L
.69734 .27964 L
.69722 .27984 L
Mistroke
.69711 .28003 L
.69699 .28023 L
.69688 .28042 L
.69677 .28062 L
.69665 .28081 L
.69654 .28101 L
.69642 .28121 L
.6963 .2814 L
.69619 .2816 L
.69607 .28179 L
.69596 .28199 L
.69584 .28218 L
.69572 .28238 L
.6956 .28258 L
.69549 .28277 L
.69537 .28297 L
.69525 .28316 L
.69513 .28336 L
.69501 .28356 L
.69489 .28375 L
.69478 .28395 L
.69466 .28414 L
.69454 .28434 L
.69442 .28454 L
.6943 .28473 L
.69418 .28493 L
.69406 .28512 L
.69393 .28532 L
.69381 .28552 L
.69369 .28571 L
.69357 .28591 L
.69345 .2861 L
.69332 .2863 L
.6932 .2865 L
.69308 .28669 L
.69296 .28689 L
.69283 .28709 L
.69271 .28728 L
.69259 .28748 L
.69246 .28768 L
.69234 .28787 L
.69221 .28807 L
.69209 .28827 L
.69196 .28846 L
.69184 .28866 L
.69171 .28886 L
.69158 .28905 L
.69146 .28925 L
.69133 .28945 L
.6912 .28964 L
Mistroke
.69108 .28984 L
.69095 .29004 L
.69082 .29023 L
.69069 .29043 L
.69057 .29063 L
.69044 .29082 L
.69031 .29102 L
.69018 .29122 L
.69005 .29141 L
.68992 .29161 L
.68979 .29181 L
.68966 .292 L
.68953 .2922 L
.6894 .2924 L
.68927 .29259 L
.68914 .29279 L
.68901 .29299 L
.68888 .29318 L
.68875 .29338 L
.68861 .29358 L
.68848 .29378 L
.68835 .29397 L
.68822 .29417 L
.68808 .29437 L
.68795 .29456 L
.68782 .29476 L
.68768 .29496 L
.68755 .29516 L
.68742 .29535 L
.68728 .29555 L
.68715 .29575 L
.68701 .29594 L
.68688 .29614 L
.68674 .29634 L
.68661 .29654 L
.68647 .29673 L
.68633 .29693 L
.6862 .29713 L
.68606 .29732 L
.68592 .29752 L
.68579 .29772 L
.68565 .29792 L
.68551 .29811 L
.68537 .29831 L
.68523 .29851 L
.6851 .2987 L
.68496 .2989 L
.68482 .2991 L
.68468 .2993 L
.68454 .29949 L
Mistroke
.6844 .29969 L
.68426 .29989 L
.68412 .30009 L
.68398 .30028 L
.68384 .30048 L
.6837 .30068 L
.68356 .30087 L
.68342 .30107 L
.68328 .30127 L
.68313 .30147 L
.68299 .30166 L
.68285 .30186 L
.68271 .30206 L
.68256 .30225 L
.68242 .30245 L
.68228 .30265 L
.68213 .30285 L
.68199 .30304 L
.68185 .30324 L
.6817 .30344 L
.68156 .30364 L
.68141 .30383 L
.68127 .30403 L
.68112 .30423 L
.68098 .30442 L
.68083 .30462 L
.68069 .30482 L
.68054 .30502 L
.6804 .30521 L
.68025 .30541 L
.6801 .30561 L
.67996 .3058 L
.67981 .306 L
.67966 .3062 L
.67951 .3064 L
.67937 .30659 L
.67922 .30679 L
.67907 .30699 L
.67892 .30718 L
.67877 .30738 L
.67862 .30758 L
.67847 .30777 L
.67832 .30797 L
.67817 .30817 L
.67802 .30837 L
.67787 .30856 L
.67772 .30876 L
.67757 .30896 L
.67742 .30915 L
.67727 .30935 L
Mistroke
.67712 .30955 L
.67697 .30974 L
.67682 .30994 L
.67667 .31014 L
.67651 .31033 L
.67636 .31053 L
.67621 .31073 L
.67606 .31093 L
.6759 .31112 L
.67575 .31132 L
.6756 .31152 L
.67544 .31171 L
.67529 .31191 L
.67513 .31211 L
.67498 .3123 L
.67483 .3125 L
.67467 .3127 L
.67452 .31289 L
.67436 .31309 L
.6742 .31328 L
.67405 .31348 L
.67389 .31368 L
.67374 .31387 L
.67358 .31407 L
.67342 .31427 L
.67327 .31446 L
.67311 .31466 L
.67295 .31486 L
.6728 .31505 L
.67264 .31525 L
.67248 .31545 L
.67232 .31564 L
.67216 .31584 L
.67201 .31603 L
.67185 .31623 L
.67169 .31643 L
.67153 .31662 L
.67137 .31682 L
.67121 .31701 L
.67105 .31721 L
.67089 .31741 L
.67073 .3176 L
.67057 .3178 L
.67041 .31799 L
.67025 .31819 L
.67009 .31839 L
.66993 .31858 L
.66977 .31878 L
.66961 .31897 L
.66944 .31917 L
Mistroke
.66928 .31936 L
.66912 .31956 L
.66896 .31976 L
.66879 .31995 L
.66863 .32015 L
.66847 .32034 L
.66831 .32054 L
.66814 .32073 L
.66798 .32093 L
.66782 .32112 L
.66765 .32132 L
.66749 .32151 L
.66732 .32171 L
.66716 .3219 L
.66699 .3221 L
.66683 .32229 L
.66666 .32249 L
.6665 .32268 L
.66633 .32288 L
.66617 .32307 L
.666 .32327 L
.66583 .32346 L
.66567 .32366 L
.6655 .32385 L
.66534 .32405 L
.66517 .32424 L
.665 .32444 L
.66483 .32463 L
.66467 .32483 L
.6645 .32502 L
.66433 .32522 L
.66416 .32541 L
.66399 .3256 L
.66383 .3258 L
.66366 .32599 L
.66349 .32619 L
.66332 .32638 L
.66315 .32658 L
.66298 .32677 L
.66281 .32696 L
.66264 .32716 L
.66247 .32735 L
.6623 .32755 L
.66213 .32774 L
.66196 .32793 L
.66179 .32813 L
.66162 .32832 L
.66145 .32851 L
.66128 .32871 L
.66111 .3289 L
Mistroke
.66093 .3291 L
.66076 .32929 L
.66059 .32948 L
.66042 .32968 L
.66025 .32987 L
.66007 .33006 L
.6599 .33026 L
.65973 .33045 L
.65956 .33064 L
.65938 .33083 L
.65921 .33103 L
.65904 .33122 L
.65886 .33141 L
.65869 .33161 L
.65851 .3318 L
.65834 .33199 L
.65816 .33218 L
.65799 .33238 L
.65782 .33257 L
.65764 .33276 L
.65747 .33295 L
.65729 .33315 L
.65711 .33334 L
.65694 .33353 L
.65676 .33372 L
.65659 .33391 L
.65641 .33411 L
.65623 .3343 L
.65606 .33449 L
.65588 .33468 L
.6557 .33487 L
.65553 .33507 L
.65535 .33526 L
.65517 .33545 L
.655 .33564 L
.65482 .33583 L
.65464 .33602 L
.65446 .33621 L
.65428 .33641 L
.6541 .3366 L
.65393 .33679 L
.65375 .33698 L
.65357 .33717 L
.65339 .33736 L
.65321 .33755 L
.65303 .33774 L
.65285 .33793 L
.65267 .33812 L
.65249 .33831 L
.65231 .3385 L
Mistroke
.65213 .33869 L
.65195 .33888 L
.65177 .33907 L
.65159 .33927 L
.65141 .33946 L
.65123 .33965 L
.65105 .33984 L
.65087 .34003 L
.65069 .34021 L
.6505 .3404 L
.65032 .34059 L
.65014 .34078 L
.64996 .34097 L
.64978 .34116 L
.64959 .34135 L
.64941 .34154 L
.64923 .34173 L
.64905 .34192 L
.64886 .34211 L
.64868 .3423 L
.6485 .34249 L
.64831 .34268 L
.64813 .34286 L
.64795 .34305 L
.64776 .34324 L
.64758 .34343 L
.64739 .34362 L
.64721 .34381 L
.64703 .34399 L
.64684 .34418 L
.64666 .34437 L
.64647 .34456 L
.64629 .34475 L
.6461 .34493 L
.64592 .34512 L
.64573 .34531 L
.64554 .3455 L
.64536 .34569 L
.64517 .34587 L
.64499 .34606 L
.6448 .34625 L
.64461 .34643 L
.64443 .34662 L
.64424 .34681 L
.64405 .347 L
.64387 .34718 L
.64368 .34737 L
.64349 .34756 L
.64331 .34774 L
.64312 .34793 L
Mistroke
.64293 .34812 L
.64274 .3483 L
.64256 .34849 L
.64237 .34867 L
.64218 .34886 L
.64199 .34905 L
.6418 .34923 L
.64161 .34942 L
.64143 .3496 L
.64124 .34979 L
.64105 .34997 L
.64086 .35016 L
.64067 .35034 L
.64048 .35053 L
.64029 .35071 L
.6401 .3509 L
.63991 .35108 L
.63972 .35127 L
.63953 .35145 L
.63934 .35164 L
.63915 .35182 L
.63896 .35201 L
.63877 .35219 L
.63858 .35238 L
.63839 .35256 L
.6382 .35274 L
.63801 .35293 L
.63782 .35311 L
.63763 .3533 L
.63743 .35348 L
.63724 .35366 L
.63705 .35385 L
.63686 .35403 L
.63667 .35421 L
.63648 .3544 L
.63628 .35458 L
.63609 .35476 L
.6359 .35494 L
.63571 .35513 L
.63551 .35531 L
.63532 .35549 L
.63513 .35568 L
.63494 .35586 L
.63474 .35604 L
.63455 .35622 L
.63436 .3564 L
.63416 .35659 L
.63397 .35677 L
.63378 .35695 L
.63358 .35713 L
Mistroke
.63339 .35731 L
.6332 .35749 L
.633 .35767 L
.63281 .35786 L
.63261 .35804 L
.63242 .35822 L
.63222 .3584 L
.63203 .35858 L
.63184 .35876 L
.63164 .35894 L
.63145 .35912 L
.63125 .3593 L
.63106 .35948 L
.63086 .35966 L
.63067 .35984 L
.63047 .36002 L
.63027 .3602 L
.63008 .36038 L
.62988 .36056 L
.62969 .36074 L
.62949 .36092 L
.6293 .3611 L
.6291 .36128 L
.6289 .36145 L
.62871 .36163 L
.62851 .36181 L
.62831 .36199 L
.62812 .36217 L
.62792 .36235 L
.62772 .36253 L
.62753 .3627 L
.62733 .36288 L
.62713 .36306 L
.62693 .36324 L
.62674 .36341 L
.62654 .36359 L
.62634 .36377 L
.62614 .36395 L
.62595 .36412 L
.62575 .3643 L
.62555 .36448 L
.62535 .36465 L
.62516 .36483 L
.62496 .36501 L
.62476 .36518 L
.62456 .36536 L
.62436 .36554 L
.62416 .36571 L
.62396 .36589 L
.62377 .36606 L
Mistroke
.62357 .36624 L
.62337 .36642 L
.62317 .36659 L
.62297 .36677 L
.62277 .36694 L
.62257 .36712 L
.62237 .36729 L
.62217 .36747 L
.62197 .36764 L
.62177 .36782 L
.62157 .36799 L
.62137 .36816 L
.62118 .36834 L
.62098 .36851 L
.62078 .36869 L
.62058 .36886 L
.62037 .36903 L
.62017 .36921 L
.61997 .36938 L
.61977 .36955 L
.61957 .36973 L
.61937 .3699 L
.61917 .37007 L
.61897 .37025 L
.61877 .37042 L
.61857 .37059 L
.61837 .37076 L
.61817 .37093 L
.61797 .37111 L
.61777 .37128 L
.61756 .37145 L
.61736 .37162 L
.61716 .37179 L
.61696 .37197 L
.61676 .37214 L
.61656 .37231 L
.61636 .37248 L
.61615 .37265 L
.61595 .37282 L
.61575 .37299 L
.61555 .37316 L
.61535 .37333 L
.61514 .3735 L
.61494 .37367 L
.61474 .37384 L
.61454 .37401 L
.61434 .37418 L
.61413 .37435 L
.61393 .37452 L
.61373 .37469 L
Mistroke
.61352 .37486 L
.61332 .37503 L
.61312 .3752 L
.61292 .37536 L
.61271 .37553 L
.61251 .3757 L
.61231 .37587 L
.6121 .37604 L
.6119 .3762 L
.6117 .37637 L
.6115 .37654 L
.61129 .37671 L
.61109 .37687 L
.61089 .37704 L
.61068 .37721 L
.61048 .37738 L
.61027 .37754 L
.61007 .37771 L
.60987 .37788 L
.60966 .37804 L
.60946 .37821 L
.60926 .37837 L
.60905 .37854 L
.60885 .37871 L
.60864 .37887 L
.60844 .37904 L
.60824 .3792 L
.60803 .37937 L
.60783 .37953 L
.60762 .3797 L
.60742 .37986 L
.60721 .38003 L
.60701 .38019 L
.60681 .38036 L
.6066 .38052 L
.6064 .38068 L
.60619 .38085 L
.60599 .38101 L
.60578 .38117 L
.60558 .38134 L
.60537 .3815 L
.60517 .38166 L
.60496 .38183 L
.60476 .38199 L
.60455 .38215 L
.60435 .38231 L
.60414 .38248 L
.60394 .38264 L
.60373 .3828 L
.60353 .38296 L
Mistroke
.60332 .38312 L
.60312 .38329 L
.60291 .38345 L
.60271 .38361 L
.6025 .38377 L
.6023 .38393 L
.60209 .38409 L
.60188 .38425 L
.60168 .38441 L
.60147 .38457 L
.60127 .38473 L
.60106 .38489 L
.60086 .38505 L
.60065 .38521 L
.60045 .38537 L
.60024 .38553 L
.60003 .38569 L
.59983 .38585 L
.59962 .38601 L
.59942 .38617 L
.59921 .38632 L
.599 .38648 L
.5988 .38664 L
.59859 .3868 L
.59839 .38696 L
.59818 .38711 L
.59797 .38727 L
.59777 .38743 L
.59756 .38759 L
.59736 .38774 L
.59715 .3879 L
.59694 .38806 L
.59674 .38821 L
.59653 .38837 L
.59632 .38853 L
.59612 .38868 L
.59591 .38884 L
.5957 .38899 L
.5955 .38915 L
.59529 .38931 L
.59509 .38946 L
.59488 .38962 L
.59467 .38977 L
.59447 .38993 L
.59426 .39008 L
.59405 .39023 L
.59385 .39039 L
.59364 .39054 L
.59343 .3907 L
.59323 .39085 L
Mistroke
.59302 .391 L
.59281 .39116 L
.59261 .39131 L
.5924 .39146 L
.59219 .39162 L
.59199 .39177 L
.59178 .39192 L
.59157 .39207 L
.59137 .39223 L
.59116 .39238 L
.59095 .39253 L
.59074 .39268 L
.59054 .39283 L
.59033 .39298 L
.59012 .39314 L
.58992 .39329 L
.58971 .39344 L
.5895 .39359 L
.5893 .39374 L
.58909 .39389 L
.58888 .39404 L
.58868 .39419 L
.58847 .39434 L
.58826 .39449 L
.58806 .39464 L
.58785 .39479 L
.58764 .39494 L
.58743 .39509 L
.58723 .39523 L
.58702 .39538 L
.58681 .39553 L
.58661 .39568 L
.5864 .39583 L
.58619 .39598 L
.58599 .39612 L
.58578 .39627 L
.58557 .39642 L
.58536 .39657 L
.58516 .39671 L
.58495 .39686 L
.58474 .39701 L
.58454 .39715 L
.58433 .3973 L
.58412 .39744 L
.58392 .39759 L
.58371 .39774 L
.5835 .39788 L
.58329 .39803 L
.58309 .39817 L
.58288 .39832 L
Mistroke
.58267 .39846 L
.58247 .39861 L
.58226 .39875 L
.58205 .3989 L
.58185 .39904 L
.58164 .39918 L
.58143 .39933 L
.58122 .39947 L
.58102 .39962 L
.58081 .39976 L
.5806 .3999 L
.5804 .40004 L
.58019 .40019 L
.57998 .40033 L
.57978 .40047 L
.57957 .40061 L
.57936 .40076 L
.57916 .4009 L
.57895 .40104 L
.57874 .40118 L
.57854 .40132 L
.57833 .40146 L
.57812 .4016 L
.57792 .40174 L
.57771 .40189 L
.5775 .40203 L
.5773 .40217 L
.57709 .40231 L
.57688 .40245 L
.57668 .40258 L
.57647 .40272 L
.57626 .40286 L
.57606 .403 L
.57585 .40314 L
.57564 .40328 L
.57544 .40342 L
.57523 .40356 L
.57502 .40369 L
.57482 .40383 L
.57461 .40397 L
.5744 .40411 L
.5742 .40425 L
.57399 .40438 L
.57378 .40452 L
.57358 .40466 L
.57337 .40479 L
.57317 .40493 L
.57296 .40507 L
.57275 .4052 L
.57255 .40534 L
Mistroke
.57234 .40547 L
.57213 .40561 L
.57193 .40574 L
.57172 .40588 L
.57152 .40601 L
.57131 .40615 L
.5711 .40628 L
.5709 .40642 L
.57069 .40655 L
.57049 .40668 L
.57028 .40682 L
.57007 .40695 L
.56987 .40709 L
.56966 .40722 L
.56946 .40735 L
.56925 .40748 L
.56904 .40762 L
.56884 .40775 L
.56863 .40788 L
.56843 .40801 L
.56822 .40815 L
.56802 .40828 L
.56781 .40841 L
.56761 .40854 L
.5674 .40867 L
.56719 .4088 L
.56699 .40893 L
.56678 .40906 L
.56658 .40919 L
.56637 .40932 L
.56617 .40945 L
.56596 .40958 L
.56576 .40971 L
.56555 .40984 L
.56535 .40997 L
.56514 .4101 L
.56494 .41023 L
.56473 .41036 L
.56453 .41048 L
.56432 .41061 L
.56412 .41074 L
.56391 .41087 L
.56371 .411 L
.5635 .41112 L
.5633 .41125 L
.56309 .41138 L
.56289 .4115 L
.56269 .41163 L
.56248 .41176 L
.56228 .41188 L
Mistroke
.56207 .41201 L
.56187 .41214 L
.56166 .41226 L
.56146 .41239 L
.56126 .41251 L
.56105 .41264 L
.56085 .41276 L
.56064 .41289 L
.56044 .41301 L
.56024 .41313 L
.56003 .41326 L
.55983 .41338 L
.55962 .41351 L
.55942 .41363 L
.55922 .41375 L
.55901 .41387 L
.55881 .414 L
.55861 .41412 L
.5584 .41424 L
.5582 .41436 L
.55799 .41449 L
.55779 .41461 L
.55759 .41473 L
.55739 .41485 L
.55718 .41497 L
.55698 .41509 L
.55678 .41521 L
.55657 .41533 L
.55637 .41546 L
.55617 .41558 L
.55596 .4157 L
.55576 .41582 L
.55556 .41593 L
.55536 .41605 L
.55515 .41617 L
.55495 .41629 L
.55475 .41641 L
.55455 .41653 L
.55434 .41665 L
.55414 .41677 L
.55394 .41688 L
.55374 .417 L
.55353 .41712 L
.55333 .41724 L
.55313 .41735 L
.55293 .41747 L
.55273 .41759 L
.55252 .4177 L
.55232 .41782 L
.55212 .41794 L
Mistroke
.55192 .41805 L
.55172 .41817 L
.55152 .41828 L
.55132 .4184 L
.55111 .41851 L
.55091 .41863 L
.55071 .41874 L
.55051 .41886 L
.55031 .41897 L
.55011 .41909 L
.54991 .4192 L
.54971 .41931 L
.54951 .41943 L
.5493 .41954 L
.5491 .41965 L
.5489 .41977 L
.5487 .41988 L
.5485 .41999 L
.5483 .4201 L
.5481 .42022 L
.5479 .42033 L
.5477 .42044 L
.5475 .42055 L
.5473 .42066 L
.5471 .42077 L
.5469 .42088 L
.5467 .42099 L
.5465 .42111 L
.5463 .42122 L
.5461 .42133 L
.5459 .42144 L
.5457 .42154 L
.5455 .42165 L
.5453 .42176 L
.5451 .42187 L
.54491 .42198 L
.54471 .42209 L
.54451 .4222 L
.54431 .42231 L
.54411 .42241 L
.54391 .42252 L
.54371 .42263 L
.54351 .42274 L
.54332 .42284 L
.54312 .42295 L
.54292 .42306 L
.54272 .42316 L
.54252 .42327 L
.54232 .42338 L
.54213 .42348 L
Mistroke
.54193 .42359 L
.54173 .42369 L
.54153 .4238 L
.54133 .4239 L
.54114 .42401 L
.54094 .42411 L
.54074 .42422 L
.54054 .42432 L
.54035 .42442 L
.54015 .42453 L
.53995 .42463 L
.53975 .42474 L
.53956 .42484 L
.53936 .42494 L
.53916 .42504 L
.53897 .42515 L
.53877 .42525 L
.53857 .42535 L
.53838 .42545 L
.53818 .42555 L
.53799 .42566 L
.53779 .42576 L
.53759 .42586 L
.5374 .42596 L
.5372 .42606 L
.537 .42616 L
.53681 .42626 L
.53661 .42636 L
.53642 .42646 L
.53622 .42656 L
.53603 .42666 L
.53583 .42676 L
.53564 .42686 L
.53544 .42696 L
.53525 .42705 L
.53505 .42715 L
.53486 .42725 L
.53466 .42735 L
.53447 .42745 L
.53427 .42754 L
.53408 .42764 L
.53388 .42774 L
.53369 .42784 L
.53349 .42793 L
.5333 .42803 L
.53311 .42813 L
.53291 .42822 L
.53272 .42832 L
.53252 .42841 L
.53233 .42851 L
Mistroke
.53214 .4286 L
.53194 .4287 L
.53175 .42879 L
.53156 .42889 L
.53136 .42898 L
.53117 .42908 L
.53098 .42917 L
.53079 .42926 L
.53059 .42936 L
.5304 .42945 L
.53021 .42954 L
.53001 .42964 L
.52982 .42973 L
.52963 .42982 L
.52944 .42991 L
.52925 .43001 L
.52905 .4301 L
.52886 .43019 L
.52867 .43028 L
.52848 .43037 L
.52829 .43046 L
.5281 .43055 L
.5279 .43064 L
.52771 .43073 L
.52752 .43082 L
.52733 .43091 L
.52714 .431 L
.52695 .43109 L
.52676 .43118 L
.52657 .43127 L
.52638 .43136 L
.52619 .43145 L
.526 .43154 L
.52581 .43163 L
.52562 .43171 L
.52543 .4318 L
.52524 .43189 L
.52505 .43198 L
.52486 .43206 L
.52467 .43215 L
.52448 .43224 L
.52429 .43232 L
.5241 .43241 L
.52391 .4325 L
.52372 .43258 L
.52353 .43267 L
.52334 .43275 L
.52315 .43284 L
.52296 .43292 L
.52278 .43301 L
Mistroke
.52259 .43309 L
.5224 .43318 L
.52221 .43326 L
.52202 .43335 L
.52183 .43343 L
.52165 .43351 L
.52146 .4336 L
.52127 .43368 L
.52108 .43376 L
.5209 .43385 L
.52071 .43393 L
.52052 .43401 L
.52033 .43409 L
.52015 .43418 L
.51996 .43426 L
.51977 .43434 L
.51959 .43442 L
.5194 .4345 L
.51921 .43458 L
.51903 .43466 L
.51884 .43474 L
.51866 .43482 L
.51847 .4349 L
.51828 .43498 L
.5181 .43506 L
.51791 .43514 L
.51773 .43522 L
.51754 .4353 L
.51736 .43538 L
.51717 .43546 L
.51699 .43554 L
.5168 .43562 L
.51662 .43569 L
.51643 .43577 L
.51625 .43585 L
.51606 .43593 L
.51588 .436 L
.51569 .43608 L
.51551 .43616 L
.51533 .43623 L
.51514 .43631 L
.51496 .43639 L
.51478 .43646 L
.51459 .43654 L
.51441 .43661 L
.51423 .43669 L
.51404 .43676 L
.51386 .43684 L
.51368 .43691 L
.51349 .43699 L
Mistroke
.51331 .43706 L
.51313 .43713 L
.51295 .43721 L
.51276 .43728 L
.51258 .43735 L
.5124 .43743 L
.51222 .4375 L
.51204 .43757 L
.51185 .43765 L
.51167 .43772 L
.51149 .43779 L
.51131 .43786 L
.51113 .43793 L
.51095 .43801 L
.51077 .43808 L
.51058 .43815 L
.5104 .43822 L
.51022 .43829 L
.51004 .43836 L
.50986 .43843 L
.50968 .4385 L
.5095 .43857 L
.50932 .43864 L
.50914 .43871 L
.50896 .43878 L
.50878 .43885 L
.5086 .43892 L
.50842 .43898 L
.50825 .43905 L
.50807 .43912 L
.50789 .43919 L
.50771 .43926 L
.50753 .43932 L
.50735 .43939 L
.50717 .43946 L
.50699 .43952 L
.50682 .43959 L
.50664 .43966 L
.50646 .43972 L
.50628 .43979 L
.5061 .43986 L
.50593 .43992 L
.50575 .43999 L
.50557 .44005 L
.5054 .44012 L
.50522 .44018 L
.50504 .44025 L
.50486 .44031 L
.50469 .44038 L
.50451 .44044 L
Mistroke
.50434 .4405 L
.50416 .44057 L
.50398 .44063 L
.50381 .44069 L
.50363 .44076 L
.50346 .44082 L
.50328 .44088 L
.5031 .44094 L
.50293 .44101 L
.50275 .44107 L
.50258 .44113 L
.5024 .44119 L
.50223 .44125 L
.50205 .44131 L
.50188 .44137 L
.50171 .44144 L
.50153 .4415 L
.50136 .44156 L
.50118 .44162 L
.50101 .44168 L
.50084 .44174 L
.50066 .4418 L
.50049 .44185 L
.50031 .44191 L
.50014 .44197 L
.49997 .44203 L
.4998 .44209 L
.49962 .44215 L
.49945 .44221 L
.49928 .44226 L
.49911 .44232 L
.49893 .44238 L
.49876 .44244 L
.49859 .44249 L
.49842 .44255 L
.49825 .44261 L
.49807 .44266 L
.4979 .44272 L
.49773 .44277 L
.49756 .44283 L
.49739 .44289 L
.49722 .44294 L
.49705 .443 L
.49688 .44305 L
.49671 .44311 L
.49654 .44316 L
.49637 .44322 L
.4962 .44327 L
.49603 .44332 L
.49586 .44338 L
Mistroke
.49569 .44343 L
.49552 .44348 L
.49535 .44354 L
.49518 .44359 L
.49501 .44364 L
.49484 .4437 L
.49467 .44375 L
.4945 .4438 L
.49433 .44385 L
.49417 .4439 L
.494 .44396 L
.49383 .44401 L
.49366 .44406 L
.49349 .44411 L
.49333 .44416 L
.49316 .44421 L
.49299 .44426 L
.49282 .44431 L
.49266 .44436 L
.49249 .44441 L
.49232 .44446 L
.49216 .44451 L
.49199 .44456 L
.49182 .44461 L
.49166 .44466 L
.49149 .4447 L
.49132 .44475 L
.49116 .4448 L
.49099 .44485 L
.49083 .4449 L
.49066 .44494 L
.4905 .44499 L
.49033 .44504 L
.49017 .44509 L
.49 .44513 L
.48984 .44518 L
.48967 .44523 L
.48951 .44527 L
.48934 .44532 L
.48918 .44536 L
.48902 .44541 L
.48885 .44545 L
.48869 .4455 L
.48852 .44554 L
.48836 .44559 L
.4882 .44563 L
.48803 .44568 L
.48787 .44572 L
.48771 .44577 L
.48755 .44581 L
Mistroke
.48738 .44585 L
.48722 .4459 L
.48706 .44594 L
.4869 .44598 L
.48673 .44603 L
.48657 .44607 L
.48641 .44611 L
.48625 .44615 L
.48609 .4462 L
.48593 .44624 L
.48577 .44628 L
.4856 .44632 L
.48544 .44636 L
.48528 .4464 L
.48512 .44644 L
.48496 .44648 L
.4848 .44652 L
.48464 .44657 L
.48448 .44661 L
.48432 .44665 L
.48416 .44668 L
.484 .44672 L
.48384 .44676 L
.48369 .4468 L
.48353 .44684 L
.48337 .44688 L
.48321 .44692 L
.48305 .44696 L
.48289 .447 L
.48273 .44703 L
.48258 .44707 L
.48242 .44711 L
.48226 .44715 L
.4821 .44718 L
.48194 .44722 L
.48179 .44726 L
.48163 .44729 L
.48147 .44733 L
.48132 .44737 L
.48116 .4474 L
.481 .44744 L
.48085 .44747 L
.48069 .44751 L
.48053 .44754 L
.48038 .44758 L
.48022 .44761 L
.48007 .44765 L
.47991 .44768 L
.47975 .44772 L
.4796 .44775 L
Mistroke
.47944 .44779 L
.47929 .44782 L
.47913 .44785 L
.47898 .44789 L
.47882 .44792 L
.47867 .44795 L
.47852 .44799 L
.47836 .44802 L
.47821 .44805 L
.47805 .44808 L
.4779 .44811 L
.47775 .44815 L
.47759 .44818 L
.47744 .44821 L
.47729 .44824 L
.47713 .44827 L
.47698 .4483 L
.47683 .44833 L
.47668 .44836 L
.47652 .44839 L
.47637 .44842 L
.47622 .44845 L
.47607 .44848 L
.47592 .44851 L
.47576 .44854 L
.47561 .44857 L
.47546 .4486 L
.47531 .44863 L
.47516 .44866 L
.47501 .44869 L
.47486 .44872 L
.47471 .44874 L
.47456 .44877 L
.47441 .4488 L
.47426 .44883 L
.47411 .44886 L
.47396 .44888 L
.47381 .44891 L
.47366 .44894 L
.47351 .44896 L
.47336 .44899 L
.47321 .44902 L
.47306 .44904 L
.47291 .44907 L
.47277 .44909 L
.47262 .44912 L
.47247 .44914 L
.47232 .44917 L
.47217 .44919 L
.47203 .44922 L
Mistroke
.47188 .44924 L
.47173 .44927 L
.47158 .44929 L
.47144 .44932 L
.47129 .44934 L
.47114 .44936 L
.471 .44939 L
.47085 .44941 L
.4707 .44943 L
.47056 .44946 L
.47041 .44948 L
.47027 .4495 L
.47012 .44953 L
.46997 .44955 L
.46983 .44957 L
.46968 .44959 L
.46954 .44961 L
.46939 .44963 L
.46925 .44966 L
.4691 .44968 L
.46896 .4497 L
.46882 .44972 L
.46867 .44974 L
.46853 .44976 L
.46838 .44978 L
.46824 .4498 L
.4681 .44982 L
.46795 .44984 L
.46781 .44986 L
.46767 .44988 L
.46752 .4499 L
.46738 .44992 L
.46724 .44994 L
.4671 .44996 L
.46695 .44997 L
.46681 .44999 L
.46667 .45001 L
.46653 .45003 L
.46639 .45005 L
.46624 .45006 L
.4661 .45008 L
.46596 .4501 L
.46582 .45012 L
.46568 .45013 L
.46554 .45015 L
.4654 .45017 L
.46526 .45018 L
.46512 .4502 L
.46498 .45021 L
.46484 .45023 L
Mistroke
.4647 .45025 L
.46456 .45026 L
.46442 .45028 L
.46428 .45029 L
.46414 .45031 L
.464 .45032 L
.46386 .45034 L
.46372 .45035 L
.46359 .45037 L
.46345 .45038 L
.46331 .45039 L
.46317 .45041 L
.46303 .45042 L
.46289 .45044 L
.46276 .45045 L
.46262 .45046 L
.46248 .45047 L
.46235 .45049 L
.46221 .4505 L
.46207 .45051 L
.46193 .45053 L
.4618 .45054 L
.46166 .45055 L
.46153 .45056 L
.46139 .45057 L
.46125 .45058 L
.46112 .4506 L
.46098 .45061 L
.46085 .45062 L
.46071 .45063 L
.46058 .45064 L
.46044 .45065 L
.46031 .45066 L
.46017 .45067 L
.46004 .45068 L
.4599 .45069 L
.45977 .4507 L
.45964 .45071 L
.4595 .45072 L
.45937 .45073 L
.45923 .45074 L
.4591 .45074 L
.45897 .45075 L
.45883 .45076 L
.4587 .45077 L
.45857 .45078 L
.45844 .45079 L
.4583 .45079 L
.45817 .4508 L
.45804 .45081 L
Mistroke
.45791 .45082 L
.45778 .45082 L
.45764 .45083 L
.45751 .45084 L
.45738 .45084 L
.45725 .45085 L
.45712 .45086 L
.45699 .45086 L
.45686 .45087 L
.45673 .45087 L
.4566 .45088 L
.45647 .45088 L
.45634 .45089 L
.45621 .4509 L
.45608 .4509 L
.45595 .45091 L
.45582 .45091 L
.45569 .45091 L
.45556 .45092 L
.45543 .45092 L
.4553 .45093 L
.45517 .45093 L
.45504 .45093 L
.45492 .45094 L
.45479 .45094 L
.45466 .45094 L
.45453 .45095 L
.4544 .45095 L
.45428 .45095 L
.45415 .45096 L
.45402 .45096 L
.45389 .45096 L
.45377 .45096 L
.45364 .45096 L
.45351 .45097 L
.45339 .45097 L
.45326 .45097 L
.45313 .45097 L
.45301 .45097 L
.45288 .45097 L
.45276 .45097 L
.45263 .45097 L
.45251 .45098 L
.45238 .45098 L
.45226 .45098 L
.45213 .45098 L
.45201 .45098 L
.45188 .45098 L
.45176 .45098 L
.45163 .45097 L
Mistroke
.45151 .45097 L
.45138 .45097 L
.45126 .45097 L
.45114 .45097 L
.45101 .45097 L
.45089 .45097 L
.45077 .45097 L
.45064 .45096 L
.45052 .45096 L
.4504 .45096 L
.45028 .45096 L
.45015 .45096 L
.45003 .45095 L
.44991 .45095 L
.44979 .45095 L
.44967 .45094 L
.44954 .45094 L
.44942 .45094 L
.4493 .45093 L
.44918 .45093 L
.44906 .45093 L
.44894 .45092 L
.44882 .45092 L
.4487 .45092 L
.44858 .45091 L
.44846 .45091 L
.44834 .4509 L
.44822 .4509 L
.4481 .45089 L
.44798 .45089 L
.44786 .45088 L
.44774 .45088 L
.44762 .45087 L
.4475 .45086 L
.44738 .45086 L
.44726 .45085 L
.44715 .45085 L
.44703 .45084 L
.44691 .45083 L
.44679 .45083 L
.44667 .45082 L
.44656 .45081 L
.44644 .45081 L
.44632 .4508 L
.4462 .45079 L
.44609 .45078 L
.44597 .45078 L
.44585 .45077 L
.44574 .45076 L
.44562 .45075 L
Mistroke
.4455 .45075 L
.44539 .45074 L
.44527 .45073 L
.44516 .45072 L
.44504 .45071 L
.44492 .4507 L
.44481 .45069 L
.44469 .45068 L
.44458 .45067 L
.44446 .45067 L
.44435 .45066 L
.44423 .45065 L
.44412 .45064 L
.44401 .45063 L
.44389 .45062 L
.44378 .45061 L
.44366 .45059 L
.44355 .45058 L
.44344 .45057 L
.44332 .45056 L
.44321 .45055 L
.4431 .45054 L
.44298 .45053 L
.44287 .45052 L
.44276 .45051 L
.44265 .45049 L
.44253 .45048 L
.44242 .45047 L
.44231 .45046 L
.4422 .45045 L
.44209 .45043 L
.44198 .45042 L
.44186 .45041 L
.44175 .45039 L
.44164 .45038 L
.44153 .45037 L
.44142 .45036 L
.44131 .45034 L
.4412 .45033 L
.44109 .45031 L
.44098 .4503 L
.44087 .45029 L
.44076 .45027 L
.44065 .45026 L
.44054 .45024 L
.44043 .45023 L
.44032 .45021 L
.44021 .4502 L
.4401 .45019 L
.44 .45017 L
Mistroke
.43989 .45015 L
.43978 .45014 L
.43967 .45012 L
.43956 .45011 L
.43945 .45009 L
.43935 .45008 L
.43924 .45006 L
.43913 .45004 L
.43902 .45003 L
.43892 .45001 L
.43881 .45 L
.4387 .44998 L
.4386 .44996 L
.43849 .44995 L
.43838 .44993 L
.43828 .44991 L
.43817 .44989 L
.43807 .44988 L
.43796 .44986 L
.43785 .44984 L
.43775 .44982 L
.43764 .4498 L
.43754 .44979 L
.43743 .44977 L
.43733 .44975 L
.43722 .44973 L
.43712 .44971 L
.43702 .44969 L
.43691 .44968 L
.43681 .44966 L
.4367 .44964 L
.4366 .44962 L
.4365 .4496 L
.43639 .44958 L
.43629 .44956 L
.43619 .44954 L
.43608 .44952 L
.43598 .4495 L
.43588 .44948 L
.43577 .44946 L
.43567 .44944 L
.43557 .44942 L
.43547 .4494 L
.43537 .44938 L
.43526 .44936 L
.43516 .44933 L
.43506 .44931 L
.43496 .44929 L
.43486 .44927 L
.43476 .44925 L
Mistroke
.43466 .44923 L
.43456 .44921 L
.43446 .44918 L
.43436 .44916 L
.43425 .44914 L
.43415 .44912 L
.43405 .4491 L
.43395 .44907 L
.43386 .44905 L
.43376 .44903 L
.43366 .449 L
.43356 .44898 L
.43346 .44896 L
.43336 .44893 L
.43326 .44891 L
.43316 .44889 L
.43306 .44886 L
.43297 .44884 L
.43287 .44882 L
.43277 .44879 L
.43267 .44877 L
.43257 .44874 L
.43248 .44872 L
.43238 .4487 L
.43228 .44867 L
.43218 .44865 L
.43209 .44862 L
.43199 .4486 L
.43189 .44857 L
.4318 .44855 L
.4317 .44852 L
.43161 .4485 L
.43151 .44847 L
.43141 .44844 L
.43132 .44842 L
.43122 .44839 L
.43113 .44837 L
.43103 .44834 L
.43094 .44831 L
.43084 .44829 L
.43075 .44826 L
.43065 .44823 L
.43056 .44821 L
.43046 .44818 L
.43037 .44815 L
.43027 .44813 L
.43018 .4481 L
.43009 .44807 L
.42999 .44805 L
.4299 .44802 L
Mistroke
.42981 .44799 L
.42971 .44796 L
.42962 .44793 L
.42953 .44791 L
.42943 .44788 L
.42934 .44785 L
.42925 .44782 L
.42916 .44779 L
.42906 .44776 L
.42897 .44774 L
.42888 .44771 L
.42879 .44768 L
.4287 .44765 L
.42861 .44762 L
.42851 .44759 L
.42842 .44756 L
.42833 .44753 L
.42824 .4475 L
.42815 .44747 L
.42806 .44744 L
.42797 .44741 L
.42788 .44738 L
.42779 .44735 L
.4277 .44732 L
.42761 .44729 L
.42752 .44726 L
.42743 .44723 L
.42734 .4472 L
.42725 .44717 L
.42716 .44714 L
.42707 .44711 L
.42699 .44708 L
.4269 .44705 L
.42681 .44702 L
.42672 .44698 L
.42663 .44695 L
.42654 .44692 L
.42646 .44689 L
.42637 .44686 L
.42628 .44683 L
.42619 .44679 L
.42611 .44676 L
.42602 .44673 L
.42593 .4467 L
.42584 .44666 L
.42576 .44663 L
.42567 .4466 L
.42559 .44657 L
.4255 .44653 L
.42541 .4465 L
Mistroke
.42533 .44647 L
.42524 .44643 L
.42516 .4464 L
.42507 .44637 L
.42498 .44633 L
.4249 .4463 L
.42481 .44627 L
.42473 .44623 L
.42464 .4462 L
.42456 .44616 L
.42447 .44613 L
.42439 .4461 L
.42431 .44606 L
.42422 .44603 L
.42414 .44599 L
.42405 .44596 L
.42397 .44592 L
.42389 .44589 L
.4238 .44585 L
.42372 .44582 L
.42364 .44578 L
.42355 .44575 L
.42347 .44571 L
.42339 .44568 L
.42331 .44564 L
.42322 .44561 L
.42314 .44557 L
.42306 .44553 L
.42298 .4455 L
.4229 .44546 L
.42281 .44543 L
.42273 .44539 L
.42265 .44535 L
.42257 .44532 L
.42249 .44528 L
.42241 .44524 L
.42233 .44521 L
.42225 .44517 L
.42217 .44513 L
.42209 .4451 L
.42201 .44506 L
.42192 .44502 L
.42185 .44499 L
.42177 .44495 L
.42169 .44491 L
.42161 .44487 L
.42153 .44484 L
.42145 .4448 L
.42137 .44476 L
.42129 .44472 L
Mistroke
.42121 .44468 L
.42113 .44465 L
.42105 .44461 L
.42097 .44457 L
.4209 .44453 L
.42082 .44449 L
.42074 .44445 L
.42066 .44442 L
.42058 .44438 L
.42051 .44434 L
.42043 .4443 L
.42035 .44426 L
.42028 .44422 L
.4202 .44418 L
.42012 .44414 L
.42004 .4441 L
.41997 .44406 L
.41989 .44402 L
.41982 .44398 L
.41974 .44394 L
.41966 .4439 L
.41959 .44386 L
.41951 .44382 L
.41944 .44378 L
.41936 .44374 L
.41928 .4437 L
.41921 .44366 L
.41913 .44362 L
.41906 .44358 L
.41899 .44354 L
.41891 .4435 L
.41884 .44346 L
.41876 .44342 L
.41869 .44338 L
.41861 .44334 L
.41854 .4433 L
.41847 .44325 L
.41839 .44321 L
.41832 .44317 L
.41824 .44313 L
.41817 .44309 L
.4181 .44305 L
.41803 .443 L
.41795 .44296 L
.41788 .44292 L
.41781 .44288 L
.41773 .44284 L
.41766 .44279 L
.41759 .44275 L
.41752 .44271 L
Mistroke
.41745 .44267 L
.41737 .44262 L
.4173 .44258 L
.41723 .44254 L
.41716 .4425 L
.41709 .44245 L
.41702 .44241 L
.41695 .44237 L
.41688 .44232 L
.41681 .44228 L
.41674 .44224 L
.41666 .44219 L
.41659 .44215 L
.41652 .44211 L
.41645 .44206 L
.41638 .44202 L
.41631 .44198 L
.41625 .44193 L
.41618 .44189 L
.41611 .44184 L
.41604 .4418 L
.41597 .44176 L
.4159 .44171 L
.41583 .44167 L
.41576 .44162 L
.41569 .44158 L
.41562 .44153 L
.41556 .44149 L
.41549 .44144 L
.41542 .4414 L
.41535 .44135 L
.41529 .44131 L
.41522 .44126 L
.41515 .44122 L
.41508 .44117 L
.41502 .44113 L
.41495 .44108 L
.41488 .44104 L
.41481 .44099 L
.41475 .44095 L
.41468 .4409 L
.41462 .44085 L
.41455 .44081 L
.41448 .44076 L
.41442 .44072 L
.41435 .44067 L
.41429 .44062 L
.41422 .44058 L
.41415 .44053 L
.41409 .44049 L
Mistroke
.41402 .44044 L
.41396 .44039 L
.41389 .44035 L
.41383 .4403 L
.41376 .44025 L
.4137 .44021 L
.41364 .44016 L
.41357 .44011 L
.41351 .44006 L
.41344 .44002 L
.41338 .43997 L
.41332 .43992 L
.41325 .43988 L
.41319 .43983 L
.41313 .43978 L
.41306 .43973 L
.413 .43968 L
.41294 .43964 L
.41287 .43959 L
.41281 .43954 L
.41275 .43949 L
.41269 .43945 L
.41262 .4394 L
.41256 .43935 L
.4125 .4393 L
.41244 .43925 L
.41238 .4392 L
.41231 .43916 L
.41225 .43911 L
.41219 .43906 L
.41213 .43901 L
.41207 .43896 L
.41201 .43891 L
.41195 .43886 L
.41189 .43882 L
.41183 .43877 L
.41177 .43872 L
.4117 .43867 L
.41164 .43862 L
.41158 .43857 L
.41152 .43852 L
.41146 .43847 L
.41141 .43842 L
.41135 .43837 L
.41129 .43832 L
.41123 .43827 L
.41117 .43822 L
.41111 .43817 L
.41105 .43812 L
.41099 .43807 L
Mistroke
.41093 .43802 L
.41087 .43797 L
.41081 .43792 L
.41076 .43787 L
.4107 .43782 L
.41064 .43777 L
.41058 .43772 L
.41052 .43767 L
.41047 .43762 L
.41041 .43757 L
.41035 .43752 L
.41029 .43747 L
.41024 .43742 L
.41018 .43737 L
.41012 .43732 L
.41007 .43727 L
.41001 .43721 L
.40995 .43716 L
.4099 .43711 L
.40984 .43706 L
.40978 .43701 L
.40973 .43696 L
.40967 .43691 L
.40962 .43686 L
.40956 .4368 L
.40951 .43675 L
.40945 .4367 L
.4094 .43665 L
.40934 .4366 L
.40928 .43655 L
.40923 .43649 L
.40918 .43644 L
.40912 .43639 L
.40907 .43634 L
.40901 .43629 L
.40896 .43623 L
.4089 .43618 L
.40885 .43613 L
.4088 .43608 L
.40874 .43602 L
.40869 .43597 L
.40863 .43592 L
.40858 .43587 L
.40853 .43581 L
.40847 .43576 L
.40842 .43571 L
.40837 .43566 L
.40832 .4356 L
.40826 .43555 L
.40821 .4355 L
Mistroke
.40816 .43544 L
.40811 .43539 L
.40805 .43534 L
.408 .43528 L
.40795 .43523 L
.4079 .43518 L
.40785 .43512 L
.40779 .43507 L
.40774 .43502 L
.40769 .43496 L
.40764 .43491 L
.40759 .43486 L
.40754 .4348 L
.40749 .43475 L
.40744 .43469 L
.40739 .43464 L
.40734 .43459 L
.40728 .43453 L
.40723 .43448 L
.40718 .43442 L
.40713 .43437 L
.40708 .43432 L
.40703 .43426 L
.40698 .43421 L
.40694 .43415 L
.40689 .4341 L
.40684 .43404 L
.40679 .43399 L
.40674 .43394 L
.40669 .43388 L
.40664 .43383 L
.40659 .43377 L
.40654 .43372 L
.40649 .43366 L
.40645 .43361 L
.4064 .43355 L
.40635 .4335 L
.4063 .43344 L
.40625 .43339 L
.40621 .43333 L
.40616 .43328 L
.40611 .43322 L
.40606 .43317 L
.40602 .43311 L
.40597 .43305 L
.40592 .433 L
.40588 .43294 L
.40583 .43289 L
.40578 .43283 L
.40574 .43278 L
Mistroke
.40569 .43272 L
.40564 .43267 L
.4056 .43261 L
.40555 .43255 L
.4055 .4325 L
.40546 .43244 L
.40541 .43239 L
.40537 .43233 L
.40532 .43227 L
.40528 .43222 L
.40523 .43216 L
.40519 .4321 L
.40514 .43205 L
.4051 .43199 L
.40505 .43194 L
.40501 .43188 L
.40496 .43182 L
.40492 .43177 L
.40487 .43171 L
.40483 .43165 L
.40478 .4316 L
.40474 .43154 L
.4047 .43148 L
.40465 .43143 L
.40461 .43137 L
.40457 .43131 L
.40452 .43126 L
.40448 .4312 L
.40444 .43114 L
.40439 .43108 L
.40435 .43103 L
.40431 .43097 L
.40426 .43091 L
.40422 .43086 L
.40418 .4308 L
.40414 .43074 L
.40409 .43068 L
.40405 .43063 L
.40401 .43057 L
.40397 .43051 L
.40393 .43045 L
.40388 .4304 L
.40384 .43034 L
.4038 .43028 L
.40376 .43022 L
.40372 .43017 L
.40368 .43011 L
.40364 .43005 L
.40359 .42999 L
.40355 .42993 L
Mistroke
.40351 .42988 L
.40347 .42982 L
.40343 .42976 L
.40339 .4297 L
.40335 .42964 L
.40331 .42959 L
.40327 .42953 L
.40323 .42947 L
.40319 .42941 L
.40315 .42935 L
.40311 .42929 L
.40307 .42924 L
.40303 .42918 L
.40299 .42912 L
.40295 .42906 L
.40292 .429 L
.40288 .42894 L
.40284 .42888 L
.4028 .42883 L
.40276 .42877 L
.40272 .42871 L
.40268 .42865 L
.40265 .42859 L
.40261 .42853 L
.40257 .42847 L
.40253 .42841 L
.40249 .42835 L
.40246 .4283 L
.40242 .42824 L
.40238 .42818 L
.40234 .42812 L
.40231 .42806 L
.40227 .428 L
.40223 .42794 L
.40219 .42788 L
.40216 .42782 L
.40212 .42776 L
.40208 .4277 L
.40205 .42764 L
.40201 .42758 L
.40197 .42752 L
.40194 .42747 L
.4019 .42741 L
.40187 .42735 L
.40183 .42729 L
.40179 .42723 L
.40176 .42717 L
.40172 .42711 L
.40169 .42705 L
.40165 .42699 L
Mistroke
.40162 .42693 L
.40158 .42687 L
.40155 .42681 L
.40151 .42675 L
.40148 .42669 L
.40144 .42663 L
.40141 .42657 L
.40137 .42651 L
.40134 .42645 L
.4013 .42639 L
.40127 .42633 L
.40124 .42627 L
.4012 .42621 L
.40117 .42615 L
.40113 .42609 L
.4011 .42603 L
.40107 .42597 L
.40103 .42591 L
.401 .42585 L
.40097 .42578 L
.40093 .42572 L
.4009 .42566 L
.40087 .4256 L
.40084 .42554 L
.4008 .42548 L
.40077 .42542 L
.40074 .42536 L
.40071 .4253 L
.40067 .42524 L
.40064 .42518 L
.40061 .42512 L
.40058 .42506 L
.40054 .425 L
.40051 .42493 L
.40048 .42487 L
.40045 .42481 L
.40042 .42475 L
.40039 .42469 L
.40036 .42463 L
.40032 .42457 L
.40029 .42451 L
.40026 .42445 L
.40023 .42439 L
.4002 .42432 L
.40017 .42426 L
.40014 .4242 L
.40011 .42414 L
.40008 .42408 L
.40005 .42402 L
.40002 .42396 L
Mistroke
.39999 .4239 L
.39996 .42383 L
.39993 .42377 L
.3999 .42371 L
.39987 .42365 L
.39984 .42359 L
.39981 .42353 L
.39978 .42347 L
.39975 .4234 L
.39972 .42334 L
.39969 .42328 L
.39966 .42322 L
.39964 .42316 L
.39961 .4231 L
.39958 .42303 L
.39955 .42297 L
.39952 .42291 L
.39949 .42285 L
.39947 .42279 L
.39944 .42272 L
.39941 .42266 L
.39938 .4226 L
.39935 .42254 L
.39933 .42248 L
.3993 .42241 L
.39927 .42235 L
.39924 .42229 L
.39922 .42223 L
.39919 .42217 L
.39916 .4221 L
.39913 .42204 L
.39911 .42198 L
.39908 .42192 L
.39905 .42186 L
.39903 .42179 L
.399 .42173 L
.39897 .42167 L
.39895 .42161 L
.39892 .42154 L
.3989 .42148 L
.39887 .42142 L
.39884 .42136 L
.39882 .4213 L
.39879 .42123 L
.39877 .42117 L
.39874 .42111 L
.39872 .42105 L
.39869 .42098 L
.39866 .42092 L
.39864 .42086 L
Mistroke
.39861 .4208 L
.39859 .42073 L
.39856 .42067 L
.39854 .42061 L
.39852 .42055 L
.39849 .42048 L
.39847 .42042 L
.39844 .42036 L
.39842 .42029 L
.39839 .42023 L
.39837 .42017 L
.39834 .42011 L
.39832 .42004 L
.3983 .41998 L
.39827 .41992 L
.39825 .41986 L
.39823 .41979 L
.3982 .41973 L
.39818 .41967 L
.39816 .4196 L
.39813 .41954 L
.39811 .41948 L
.39809 .41941 L
.39806 .41935 L
.39804 .41929 L
.39802 .41923 L
.398 .41916 L
.39797 .4191 L
.39795 .41904 L
.39793 .41897 L
.39791 .41891 L
.39788 .41885 L
.39786 .41878 L
.39784 .41872 L
.39782 .41866 L
.3978 .41859 L
.39778 .41853 L
.39775 .41847 L
.39773 .4184 L
.39771 .41834 L
.39769 .41828 L
.39767 .41821 L
.39765 .41815 L
.39763 .41809 L
.39761 .41802 L
.39758 .41796 L
.39756 .4179 L
.39754 .41783 L
.39752 .41777 L
.3975 .41771 L
Mistroke
.39748 .41764 L
.39746 .41758 L
.39744 .41752 L
.39742 .41745 L
.3974 .41739 L
.39738 .41733 L
.39736 .41726 L
.39734 .4172 L
.39732 .41714 L
.3973 .41707 L
.39728 .41701 L
.39726 .41695 L
.39725 .41688 L
.39723 .41682 L
.39721 .41676 L
.39719 .41669 L
.39717 .41663 L
.39715 .41656 L
.39713 .4165 L
.39711 .41644 L
.39709 .41637 L
.39708 .41631 L
.39706 .41625 L
.39704 .41618 L
.39702 .41612 L
.397 .41605 L
.39698 .41599 L
.39697 .41593 L
.39695 .41586 L
.39693 .4158 L
.39691 .41574 L
.3969 .41567 L
.39688 .41561 L
.39686 .41554 L
.39684 .41548 L
.39683 .41542 L
.39681 .41535 L
.39679 .41529 L
.39678 .41522 L
.39676 .41516 L
.39674 .4151 L
.39673 .41503 L
.39671 .41497 L
.39669 .41491 L
.39668 .41484 L
.39666 .41478 L
.39664 .41471 L
.39663 .41465 L
.39661 .41459 L
.3966 .41452 L
Mistroke
.39658 .41446 L
.39656 .41439 L
.39655 .41433 L
.39653 .41427 L
.39652 .4142 L
.3965 .41414 L
.39649 .41407 L
.39647 .41401 L
.39646 .41394 L
.39644 .41388 L
.39643 .41382 L
.39641 .41375 L
.3964 .41369 L
.39638 .41362 L
.39637 .41356 L
.39635 .4135 L
.39634 .41343 L
.39632 .41337 L
.39631 .4133 L
.39629 .41324 L
.39628 .41318 L
.39627 .41311 L
.39625 .41305 L
.39624 .41298 L
.39622 .41292 L
.39621 .41285 L
.3962 .41279 L
.39618 .41273 L
.39617 .41266 L
.39616 .4126 L
.39614 .41253 L
.39613 .41247 L
.39612 .4124 L
.3961 .41234 L
.39609 .41228 L
.39608 .41221 L
.39606 .41215 L
.39605 .41208 L
.39604 .41202 L
.39603 .41195 L
.39601 .41189 L
.396 .41183 L
.39599 .41176 L
.39598 .4117 L
.39597 .41163 L
.39595 .41157 L
.39594 .4115 L
.39593 .41144 L
.39592 .41138 L
.39591 .41131 L
Mistroke
.39589 .41125 L
.39588 .41118 L
.39587 .41112 L
.39586 .41105 L
.39585 .41099 L
.39584 .41093 L
.39583 .41086 L
.39581 .4108 L
.3958 .41073 L
.39579 .41067 L
.39578 .4106 L
.39577 .41054 L
.39576 .41048 L
.39575 .41041 L
.39574 .41035 L
.39573 .41028 L
.39572 .41022 L
.39571 .41015 L
.3957 .41009 L
.39569 .41002 L
.39568 .40996 L
.39567 .4099 L
.39566 .40983 L
.39565 .40977 L
.39564 .4097 L
.39563 .40964 L
.39562 .40957 L
.39561 .40951 L
.3956 .40944 L
.39559 .40938 L
.39558 .40932 L
.39557 .40925 L
.39556 .40919 L
.39555 .40912 L
.39555 .40906 L
.39554 .40899 L
.39553 .40893 L
.39552 .40887 L
.39551 .4088 L
.3955 .40874 L
.39549 .40867 L
.39549 .40861 L
.39548 .40854 L
.39547 .40848 L
.39546 .40841 L
.39545 .40835 L
.39544 .40829 L
.39544 .40822 L
.39543 .40816 L
.39542 .40809 L
Mistroke
.39541 .40803 L
.39541 .40796 L
.3954 .4079 L
.39539 .40783 L
.39538 .40777 L
.39538 .40771 L
.39537 .40764 L
.39536 .40758 L
.39536 .40751 L
.39535 .40745 L
.39534 .40738 L
.39533 .40732 L
.39533 .40726 L
.39532 .40719 L
.39531 .40713 L
.39531 .40706 L
.3953 .407 L
.3953 .40693 L
.39529 .40687 L
.39528 .4068 L
.39528 .40674 L
.39527 .40668 L
.39526 .40661 L
.39526 .40655 L
.39525 .40648 L
.39525 .40642 L
.39524 .40635 L
.39524 .40629 L
.39523 .40623 L
.39522 .40616 L
.39522 .4061 L
.39521 .40603 L
.39521 .40597 L
.3952 .4059 L
.3952 .40584 L
.39519 .40578 L
.39519 .40571 L
.39518 .40565 L
.39518 .40558 L
.39517 .40552 L
.39517 .40545 L
.39516 .40539 L
.39516 .40533 L
.39516 .40526 L
.39515 .4052 L
.39515 .40513 L
.39514 .40507 L
.39514 .405 L
.39513 .40494 L
.39513 .40488 L
Mistroke
.39513 .40481 L
.39512 .40475 L
.39512 .40468 L
.39512 .40462 L
.39511 .40455 L
.39511 .40449 L
.39511 .40443 L
.3951 .40436 L
.3951 .4043 L
.3951 .40423 L
.39509 .40417 L
.39509 .4041 L
.39509 .40404 L
.39508 .40398 L
.39508 .40391 L
.39508 .40385 L
.39507 .40378 L
.39507 .40372 L
.39507 .40366 L
.39507 .40359 L
.39506 .40353 L
.39506 .40346 L
.39506 .4034 L
.39506 .40333 L
.39505 .40327 L
.39505 .40321 L
.39505 .40314 L
.39505 .40308 L
.39505 .40301 L
.39505 .40295 L
.39504 .40289 L
.39504 .40282 L
.39504 .40276 L
.39504 .40269 L
.39504 .40263 L
.39504 .40257 L
.39503 .4025 L
.39503 .40244 L
.39503 .40237 L
.39503 .40231 L
.39503 .40225 L
.39503 .40218 L
.39503 .40212 L
.39503 .40205 L
.39503 .40199 L
.39503 .40193 L
.39502 .40186 L
.39502 .4018 L
.39502 .40173 L
.39502 .40167 L
Mistroke
.39502 .40161 L
.39502 .40154 L
.39502 .40148 L
.39502 .40142 L
.39502 .40135 L
.39502 .40129 L
.39502 .40122 L
.39502 .40116 L
.39502 .4011 L
.39502 .40103 L
.39502 .40097 L
.39502 .4009 L
.39502 .40084 L
.39502 .40078 L
.39502 .40071 L
.39503 .40065 L
.39503 .40059 L
.39503 .40052 L
.39503 .40046 L
.39503 .40039 L
.39503 .40033 L
.39503 .40027 L
.39503 .4002 L
.39503 .40014 L
.39503 .40008 L
.39504 .40001 L
.39504 .39995 L
.39504 .39989 L
.39504 .39982 L
.39504 .39976 L
.39504 .39969 L
.39504 .39963 L
.39505 .39957 L
.39505 .3995 L
.39505 .39944 L
.39505 .39938 L
.39505 .39931 L
.39506 .39925 L
.39506 .39919 L
.39506 .39912 L
.39506 .39906 L
.39507 .399 L
.39507 .39893 L
.39507 .39887 L
.39507 .39881 L
.39508 .39874 L
.39508 .39868 L
.39508 .39862 L
.39508 .39855 L
.39509 .39849 L
Mistroke
.39509 .39843 L
.39509 .39836 L
.3951 .3983 L
.3951 .39824 L
.3951 .39817 L
.39511 .39811 L
.39511 .39805 L
.39511 .39798 L
.39512 .39792 L
.39512 .39786 L
.39512 .39779 L
.39513 .39773 L
.39513 .39767 L
.39513 .3976 L
.39514 .39754 L
.39514 .39748 L
.39515 .39741 L
.39515 .39735 L
.39515 .39729 L
.39516 .39722 L
.39516 .39716 L
.39517 .3971 L
.39517 .39704 L
.39517 .39697 L
.39518 .39691 L
.39518 .39685 L
.39519 .39678 L
.39519 .39672 L
.3952 .39666 L
.3952 .39659 L
.39521 .39653 L
.39521 .39647 L
.39522 .39641 L
.39522 .39634 L
.39523 .39628 L
.39523 .39622 L
.39524 .39615 L
.39524 .39609 L
.39525 .39603 L
.39525 .39597 L
.39526 .3959 L
.39526 .39584 L
.39527 .39578 L
.39528 .39571 L
.39528 .39565 L
.39529 .39559 L
.39529 .39553 L
.3953 .39546 L
.3953 .3954 L
.39531 .39534 L
Mistroke
.39532 .39528 L
.39532 .39521 L
.39533 .39515 L
.39534 .39509 L
.39534 .39503 L
.39535 .39496 L
.39535 .3949 L
.39536 .39484 L
.39537 .39478 L
.39537 .39471 L
.39538 .39465 L
.39539 .39459 L
.39539 .39453 L
.3954 .39446 L
.39541 .3944 L
.39541 .39434 L
.39542 .39428 L
.39543 .39421 L
.39544 .39415 L
.39544 .39409 L
.39545 .39403 L
.39546 .39396 L
.39546 .3939 L
.39547 .39384 L
.39548 .39378 L
.39549 .39372 L
.39549 .39365 L
.3955 .39359 L
.39551 .39353 L
.39552 .39347 L
.39553 .3934 L
.39553 .39334 L
.39554 .39328 L
.39555 .39322 L
.39556 .39316 L
.39557 .39309 L
.39557 .39303 L
.39558 .39297 L
.39559 .39291 L
.3956 .39285 L
.39561 .39278 L
.39562 .39272 L
.39562 .39266 L
.39563 .3926 L
.39564 .39254 L
.39565 .39248 L
.39566 .39241 L
.39567 .39235 L
.39568 .39229 L
.39569 .39223 L
Mistroke
.39569 .39217 L
.3957 .3921 L
.39571 .39204 L
.39572 .39198 L
.39573 .39192 L
.39574 .39186 L
.39575 .3918 L
.39576 .39173 L
.39577 .39167 L
.39578 .39161 L
.39579 .39155 L
.3958 .39149 L
.39581 .39143 L
.39582 .39137 L
.39583 .3913 L
.39583 .39124 L
.39584 .39118 L
.39585 .39112 L
.39586 .39106 L
.39587 .391 L
.39588 .39094 L
.39589 .39087 L
.3959 .39081 L
.39592 .39075 L
.39593 .39069 L
.39594 .39063 L
.39595 .39057 L
.39596 .39051 L
.39597 .39045 L
.39598 .39038 L
.39599 .39032 L
.396 .39026 L
.39601 .3902 L
.39602 .39014 L
.39603 .39008 L
.39604 .39002 L
.39605 .38996 L
.39606 .3899 L
.39607 .38983 L
.39609 .38977 L
.3961 .38971 L
.39611 .38965 L
.39612 .38959 L
.39613 .38953 L
.39614 .38947 L
.39615 .38941 L
.39617 .38935 L
.39618 .38929 L
.39619 .38923 L
.3962 .38917 L
Mistroke
.39621 .3891 L
.39622 .38904 L
.39623 .38898 L
.39625 .38892 L
.39626 .38886 L
.39627 .3888 L
.39628 .38874 L
.39629 .38868 L
.39631 .38862 L
.39632 .38856 L
.39633 .3885 L
.39634 .38844 L
.39636 .38838 L
.39637 .38832 L
.39638 .38826 L
.39639 .3882 L
.3964 .38814 L
.39642 .38808 L
.39643 .38801 L
.39644 .38795 L
.39646 .38789 L
.39647 .38783 L
.39648 .38777 L
.39649 .38771 L
.39651 .38765 L
.39652 .38759 L
.39653 .38753 L
.39655 .38747 L
.39656 .38741 L
.39657 .38735 L
.39658 .38729 L
.3966 .38723 L
.39661 .38717 L
.39662 .38711 L
.39664 .38705 L
.39665 .38699 L
.39667 .38693 L
.39668 .38687 L
.39669 .38681 L
.39671 .38675 L
.39672 .38669 L
.39673 .38663 L
.39675 .38657 L
.39676 .38651 L
.39677 .38645 L
.39679 .38639 L
.3968 .38633 L
.39682 .38627 L
.39683 .38622 L
.39684 .38616 L
Mistroke
.39686 .3861 L
.39687 .38604 L
.39689 .38598 L
.3969 .38592 L
.39692 .38586 L
.39693 .3858 L
.39695 .38574 L
.39696 .38568 L
.39697 .38562 L
.39699 .38556 L
.397 .3855 L
.39702 .38544 L
.39703 .38538 L
.39705 .38532 L
.39706 .38526 L
.39708 .3852 L
.39709 .38515 L
.39711 .38509 L
.39712 .38503 L
.39714 .38497 L
.39715 .38491 L
.39717 .38485 L
.39718 .38479 L
.3972 .38473 L
.39721 .38467 L
.39723 .38461 L
.39724 .38456 L
.39726 .3845 L
.39728 .38444 L
.39729 .38438 L
.39731 .38432 L
.39732 .38426 L
.39734 .3842 L
.39735 .38414 L
.39737 .38408 L
.39738 .38403 L
.3974 .38397 L
.39742 .38391 L
.39743 .38385 L
.39745 .38379 L
.39746 .38373 L
.39748 .38367 L
.3975 .38362 L
.39751 .38356 L
.39753 .3835 L
.39755 .38344 L
.39756 .38338 L
.39758 .38332 L
.39759 .38326 L
.39761 .38321 L
Mistroke
.39763 .38315 L
.39764 .38309 L
.39766 .38303 L
.39768 .38297 L
.39769 .38291 L
.39771 .38286 L
.39773 .3828 L
.39774 .38274 L
.39776 .38268 L
.39778 .38262 L
.39779 .38257 L
.39781 .38251 L
.39783 .38245 L
.39785 .38239 L
.39786 .38233 L
.39788 .38228 L
.3979 .38222 L
.39791 .38216 L
.39793 .3821 L
.39795 .38204 L
.39797 .38199 L
.39798 .38193 L
.398 .38187 L
.39802 .38181 L
.39804 .38176 L
.39805 .3817 L
.39807 .38164 L
.39809 .38158 L
.39811 .38152 L
.39813 .38147 L
.39814 .38141 L
.39816 .38135 L
.39818 .38129 L
.3982 .38124 L
.39821 .38118 L
.39823 .38112 L
.39825 .38106 L
.39827 .38101 L
.39829 .38095 L
.39831 .38089 L
.39832 .38084 L
.39834 .38078 L
.39836 .38072 L
.39838 .38066 L
.3984 .38061 L
.39842 .38055 L
.39843 .38049 L
.39845 .38044 L
.39847 .38038 L
.39849 .38032 L
Mistroke
.39851 .38026 L
.39853 .38021 L
.39855 .38015 L
.39856 .38009 L
.39858 .38004 L
.3986 .37998 L
.39862 .37992 L
.39864 .37987 L
.39866 .37981 L
.39868 .37975 L
.3987 .3797 L
.39872 .37964 L
.39874 .37958 L
.39875 .37953 L
.39877 .37947 L
.39879 .37941 L
.39881 .37936 L
.39883 .3793 L
.39885 .37924 L
.39887 .37919 L
.39889 .37913 L
.39891 .37907 L
.39893 .37902 L
.39895 .37896 L
.39897 .3789 L
.39899 .37885 L
.39901 .37879 L
.39903 .37874 L
.39905 .37868 L
.39907 .37862 L
.39909 .37857 L
.39911 .37851 L
.39913 .37845 L
.39915 .3784 L
.39917 .37834 L
.39919 .37829 L
.39921 .37823 L
.39923 .37817 L
.39925 .37812 L
.39927 .37806 L
.39929 .37801 L
.39931 .37795 L
.39933 .3779 L
.39935 .37784 L
.39937 .37778 L
.39939 .37773 L
.39941 .37767 L
.39943 .37762 L
.39945 .37756 L
.39947 .37751 L
Mistroke
.39949 .37745 L
.39951 .37739 L
.39953 .37734 L
.39955 .37728 L
.39957 .37723 L
.3996 .37717 L
.39962 .37712 L
.39964 .37706 L
.39966 .37701 L
.39968 .37695 L
.3997 .3769 L
.39972 .37684 L
.39974 .37679 L
.39976 .37673 L
.39978 .37668 L
.39981 .37662 L
.39983 .37656 L
.39985 .37651 L
.39987 .37645 L
.39989 .3764 L
.39991 .37634 L
.39993 .37629 L
.39995 .37623 L
.39998 .37618 L
.4 .37613 L
.40002 .37607 L
.40004 .37602 L
.40006 .37596 L
.40008 .37591 L
.40011 .37585 L
.40013 .3758 L
.40015 .37574 L
.40017 .37569 L
.40019 .37563 L
.40022 .37558 L
.40024 .37552 L
.40026 .37547 L
.40028 .37541 L
.4003 .37536 L
.40033 .37531 L
.40035 .37525 L
.40037 .3752 L
.40039 .37514 L
.40041 .37509 L
.40044 .37503 L
.40046 .37498 L
.40048 .37493 L
.4005 .37487 L
.40053 .37482 L
.40055 .37476 L
Mistroke
.40057 .37471 L
.40059 .37466 L
.40062 .3746 L
.40064 .37455 L
.40066 .37449 L
.40068 .37444 L
.40071 .37439 L
.40073 .37433 L
.40075 .37428 L
.40077 .37422 L
.4008 .37417 L
.40082 .37412 L
.40084 .37406 L
.40086 .37401 L
.40089 .37396 L
.40091 .3739 L
.40093 .37385 L
.40096 .3738 L
.40098 .37374 L
.401 .37369 L
.40103 .37363 L
.40105 .37358 L
.40107 .37353 L
.4011 .37347 L
.40112 .37342 L
.40114 .37337 L
.40117 .37331 L
.40119 .37326 L
.40121 .37321 L
.40124 .37316 L
.40126 .3731 L
.40128 .37305 L
.40131 .373 L
.40133 .37294 L
.40135 .37289 L
.40138 .37284 L
.4014 .37278 L
.40142 .37273 L
.40145 .37268 L
.40147 .37263 L
.4015 .37257 L
.40152 .37252 L
.40154 .37247 L
.40157 .37241 L
.40159 .37236 L
.40161 .37231 L
.40164 .37226 L
.40166 .3722 L
.40169 .37215 L
.40171 .3721 L
Mistroke
.40174 .37205 L
.40176 .37199 L
.40178 .37194 L
.40181 .37189 L
.40183 .37184 L
.40186 .37178 L
.40188 .37173 L
.4019 .37168 L
.40193 .37163 L
.40195 .37158 L
.40198 .37152 L
.402 .37147 L
.40203 .37142 L
.40205 .37137 L
.40208 .37131 L
.4021 .37126 L
.40213 .37121 L
.40215 .37116 L
.40217 .37111 L
.4022 .37105 L
.40222 .371 L
.40225 .37095 L
.40227 .3709 L
.4023 .37085 L
.40232 .3708 L
.40235 .37074 L
.40237 .37069 L
.4024 .37064 L
.40242 .37059 L
.40245 .37054 L
.40247 .37049 L
.4025 .37043 L
.40252 .37038 L
.40255 .37033 L
.40257 .37028 L
.4026 .37023 L
.40262 .37018 L
.40265 .37013 L
.40267 .37008 L
.4027 .37002 L
.40272 .36997 L
.40275 .36992 L
.40278 .36987 L
.4028 .36982 L
.40283 .36977 L
.40285 .36972 L
.40288 .36967 L
.4029 .36962 L
.40293 .36956 L
.40295 .36951 L
Mistroke
.40298 .36946 L
.403 .36941 L
.40303 .36936 L
.40306 .36931 L
.40308 .36926 L
.40311 .36921 L
.40313 .36916 L
.40316 .36911 L
.40318 .36906 L
.40321 .36901 L
.40324 .36896 L
.40326 .36891 L
.40329 .36885 L
.40331 .3688 L
.40334 .36875 L
.40337 .3687 L
.40339 .36865 L
.40342 .3686 L
.40344 .36855 L
.40347 .3685 L
.4035 .36845 L
.40352 .3684 L
.40355 .36835 L
.40358 .3683 L
.4036 .36825 L
.40363 .3682 L
.40365 .36815 L
.40368 .3681 L
.40371 .36805 L
.40373 .368 L
.40376 .36795 L
.40379 .3679 L
.40381 .36785 L
.40384 .3678 L
.40387 .36775 L
.40389 .3677 L
.40392 .36765 L
.40395 .3676 L
.40397 .36755 L
.404 .3675 L
.40403 .36746 L
.40405 .36741 L
.40408 .36736 L
.40411 .36731 L
.40413 .36726 L
.40416 .36721 L
.40419 .36716 L
.40421 .36711 L
.40424 .36706 L
.40427 .36701 L
Mistroke
.40429 .36696 L
.40432 .36691 L
.40435 .36686 L
.40438 .36681 L
.4044 .36677 L
.40443 .36672 L
.40446 .36667 L
.40448 .36662 L
.40451 .36657 L
.40454 .36652 L
.40457 .36647 L
.40459 .36642 L
.40462 .36637 L
.40465 .36633 L
.40467 .36628 L
.4047 .36623 L
.40473 .36618 L
.40476 .36613 L
.40478 .36608 L
.40481 .36603 L
.40484 .36598 L
.40487 .36594 L
.40489 .36589 L
.40492 .36584 L
.40495 .36579 L
.40498 .36574 L
.405 .36569 L
.40503 .36565 L
.40506 .3656 L
.40509 .36555 L
.40512 .3655 L
.40514 .36545 L
.40517 .36541 L
.4052 .36536 L
.40523 .36531 L
.40525 .36526 L
.40528 .36521 L
.40531 .36517 L
.40534 .36512 L
.40537 .36507 L
.40539 .36502 L
.40542 .36497 L
.40545 .36493 L
.40548 .36488 L
.40551 .36483 L
.40553 .36478 L
.40556 .36474 L
.40559 .36469 L
.40562 .36464 L
.40565 .36459 L
Mistroke
.40567 .36455 L
.4057 .3645 L
.40573 .36445 L
.40576 .3644 L
.40579 .36436 L
.40582 .36431 L
.40584 .36426 L
.40587 .36421 L
.4059 .36417 L
.40593 .36412 L
.40596 .36407 L
.40599 .36403 L
.40601 .36398 L
.40604 .36393 L
.40607 .36388 L
.4061 .36384 L
.40613 .36379 L
.40616 .36374 L
.40619 .3637 L
.40621 .36365 L
.40624 .3636 L
.40627 .36356 L
.4063 .36351 L
.40633 .36346 L
.40636 .36342 L
.40639 .36337 L
.40641 .36332 L
.40644 .36328 L
.40647 .36323 L
.4065 .36318 L
.40653 .36314 L
.40656 .36309 L
.40659 .36304 L
.40662 .363 L
.40665 .36295 L
.40667 .36291 L
.4067 .36286 L
.40673 .36281 L
.40676 .36277 L
.40679 .36272 L
.40682 .36267 L
.40685 .36263 L
.40688 .36258 L
.40691 .36254 L
.40694 .36249 L
.40696 .36244 L
.40699 .3624 L
.40702 .36235 L
.40705 .36231 L
.40708 .36226 L
Mistroke
.40711 .36222 L
.40714 .36217 L
.40717 .36212 L
.4072 .36208 L
.40723 .36203 L
.40726 .36199 L
.40729 .36194 L
.40732 .3619 L
.40735 .36185 L
.40738 .36181 L
.4074 .36176 L
.40743 .36171 L
.40746 .36167 L
.40749 .36162 L
.40752 .36158 L
.40755 .36153 L
.40758 .36149 L
.40761 .36144 L
.40764 .3614 L
.40767 .36135 L
.4077 .36131 L
.40773 .36126 L
.40776 .36122 L
.40779 .36117 L
.40782 .36113 L
.40785 .36108 L
.40788 .36104 L
.40791 .36099 L
.40794 .36095 L
.40797 .3609 L
.408 .36086 L
.40803 .36081 L
.40806 .36077 L
.40809 .36073 L
.40812 .36068 L
.40815 .36064 L
.40818 .36059 L
.40821 .36055 L
.40824 .3605 L
.40827 .36046 L
.4083 .36041 L
.40833 .36037 L
.40836 .36033 L
.40839 .36028 L
.40842 .36024 L
.40845 .36019 L
.40848 .36015 L
.40851 .36011 L
.40854 .36006 L
.40857 .36002 L
Mistroke
.4086 .35997 L
.40863 .35993 L
.40866 .35989 L
.40869 .35984 L
.40872 .3598 L
.40875 .35975 L
.40878 .35971 L
.40881 .35967 L
.40884 .35962 L
.40887 .35958 L
.4089 .35954 L
.40893 .35949 L
.40896 .35945 L
.40899 .3594 L
.40902 .35936 L
.40905 .35932 L
.40908 .35927 L
.40911 .35923 L
.40915 .35919 L
.40918 .35914 L
.40921 .3591 L
.40924 .35906 L
.40927 .35901 L
.4093 .35897 L
.40933 .35893 L
.40936 .35889 L
.40939 .35884 L
.40942 .3588 L
.40945 .35876 L
.40948 .35871 L
.40951 .35867 L
.40954 .35863 L
.40957 .35858 L
.4096 .35854 L
.40964 .3585 L
.40967 .35846 L
.4097 .35841 L
.40973 .35837 L
.40976 .35833 L
.40979 .35829 L
.40982 .35824 L
.40985 .3582 L
.40988 .35816 L
.40991 .35812 L
.40994 .35807 L
.40998 .35803 L
.41001 .35799 L
.41004 .35795 L
.41007 .3579 L
.4101 .35786 L
Mistroke
.41013 .35782 L
.41016 .35778 L
.41019 .35774 L
.41022 .35769 L
.41025 .35765 L
.41029 .35761 L
.41032 .35757 L
.41035 .35753 L
.41038 .35748 L
.41041 .35744 L
.41044 .3574 L
.41047 .35736 L
.4105 .35732 L
.41054 .35727 L
.41057 .35723 L
.4106 .35719 L
.41063 .35715 L
.41066 .35711 L
.41069 .35707 L
.41072 .35702 L
.41075 .35698 L
.41079 .35694 L
.41082 .3569 L
.41085 .35686 L
.41088 .35682 L
.41091 .35678 L
.41094 .35674 L
.41097 .35669 L
.41101 .35665 L
.41104 .35661 L
.41107 .35657 L
.4111 .35653 L
.41113 .35649 L
.41116 .35645 L
.41119 .35641 L
.41123 .35637 L
.41126 .35632 L
.41129 .35628 L
.41132 .35624 L
.41135 .3562 L
.41138 .35616 L
.41142 .35612 L
.41145 .35608 L
.41148 .35604 L
.41151 .356 L
.41154 .35596 L
.41157 .35592 L
.41161 .35588 L
.41164 .35584 L
.41167 .3558 L
Mistroke
.4117 .35576 L
.41173 .35572 L
.41176 .35567 L
.4118 .35563 L
.41183 .35559 L
.41186 .35555 L
.41189 .35551 L
.41192 .35547 L
.41195 .35543 L
.41199 .35539 L
.41202 .35535 L
.41205 .35531 L
.41208 .35527 L
.41211 .35523 L
.41215 .35519 L
.41218 .35515 L
.41221 .35511 L
.41224 .35507 L
.41227 .35503 L
.41231 .35499 L
.41234 .35495 L
.41237 .35492 L
.4124 .35488 L
.41243 .35484 L
.41247 .3548 L
.4125 .35476 L
.41253 .35472 L
.41256 .35468 L
.41259 .35464 L
.41263 .3546 L
.41266 .35456 L
.41269 .35452 L
.41272 .35448 L
.41275 .35444 L
.41279 .3544 L
.41282 .35436 L
.41285 .35432 L
.41288 .35429 L
.41292 .35425 L
.41295 .35421 L
.41298 .35417 L
.41301 .35413 L
.41304 .35409 L
.41308 .35405 L
.41311 .35401 L
.41314 .35397 L
.41317 .35394 L
.41321 .3539 L
.41324 .35386 L
.41327 .35382 L
Mistroke
.4133 .35378 L
.41333 .35374 L
.41337 .3537 L
.4134 .35367 L
.41343 .35363 L
.41346 .35359 L
.4135 .35355 L
.41353 .35351 L
.41356 .35347 L
.41359 .35344 L
.41363 .3534 L
.41366 .35336 L
.41369 .35332 L
.41372 .35328 L
.41376 .35324 L
.41379 .35321 L
.41382 .35317 L
.41385 .35313 L
.41389 .35309 L
.41392 .35305 L
.41395 .35302 L
.41398 .35298 L
.41402 .35294 L
.41405 .3529 L
.41408 .35287 L
.41411 .35283 L
.41415 .35279 L
.41418 .35275 L
.41421 .35271 L
.41424 .35268 L
.41428 .35264 L
.41431 .3526 L
.41434 .35256 L
.41437 .35253 L
.41441 .35249 L
.41444 .35245 L
.41447 .35242 L
.41451 .35238 L
.41454 .35234 L
.41457 .3523 L
.4146 .35227 L
.41464 .35223 L
.41467 .35219 L
.4147 .35216 L
.41473 .35212 L
.41477 .35208 L
.4148 .35204 L
.41483 .35201 L
.41487 .35197 L
.4149 .35193 L
Mistroke
.41493 .3519 L
.41496 .35186 L
.415 .35182 L
.41503 .35179 L
.41506 .35175 L
.4151 .35171 L
.41513 .35168 L
.41516 .35164 L
.41519 .3516 L
.41523 .35157 L
.41526 .35153 L
.41529 .35149 L
.41533 .35146 L
.41536 .35142 L
.41539 .35139 L
.41542 .35135 L
.41546 .35131 L
.41549 .35128 L
.41552 .35124 L
.41556 .3512 L
.41559 .35117 L
.41562 .35113 L
.41565 .3511 L
.41569 .35106 L
.41572 .35102 L
.41575 .35099 L
.41579 .35095 L
.41582 .35092 L
.41585 .35088 L
.41589 .35084 L
.41592 .35081 L
.41595 .35077 L
.41599 .35074 L
.41602 .3507 L
.41605 .35067 L
.41608 .35063 L
.41612 .3506 L
.41615 .35056 L
.41618 .35052 L
.41622 .35049 L
.41625 .35045 L
.41628 .35042 L
.41632 .35038 L
.41635 .35035 L
.41638 .35031 L
.41642 .35028 L
.41645 .35024 L
.41648 .35021 L
.41651 .35017 L
.41655 .35014 L
Mistroke
.41658 .3501 L
.41661 .35007 L
.41665 .35003 L
.41668 .35 L
.41671 .34996 L
.41675 .34993 L
.41678 .34989 L
.41681 .34986 L
.41685 .34982 L
.41688 .34979 L
.41691 .34975 L
.41695 .34972 L
.41698 .34968 L
.41701 .34965 L
.41705 .34962 L
.41708 .34958 L
.41711 .34955 L
.41715 .34951 L
.41718 .34948 L
.41721 .34944 L
.41725 .34941 L
.41728 .34938 L
.41731 .34934 L
.41735 .34931 L
.41738 .34927 L
.41741 .34924 L
.41745 .3492 L
.41748 .34917 L
.41751 .34914 L
.41755 .3491 L
.41758 .34907 L
.41761 .34903 L
.41765 .349 L
.41768 .34897 L
.41771 .34893 L
.41775 .3489 L
.41778 .34887 L
.41781 .34883 L
.41785 .3488 L
.41788 .34876 L
.41791 .34873 L
.41795 .3487 L
.41798 .34866 L
.41801 .34863 L
.41805 .3486 L
.41808 .34856 L
.41811 .34853 L
.41815 .3485 L
.41818 .34846 L
.41821 .34843 L
Mistroke
.41825 .3484 L
.41828 .34836 L
.41831 .34833 L
.41835 .3483 L
.41838 .34826 L
.41841 .34823 L
.41845 .3482 L
.41848 .34817 L
.41851 .34813 L
.41855 .3481 L
.41858 .34807 L
.41862 .34803 L
.41865 .348 L
.41868 .34797 L
.41872 .34794 L
.41875 .3479 L
.41878 .34787 L
.41882 .34784 L
.41885 .34781 L
.41888 .34777 L
.41892 .34774 L
.41895 .34771 L
.41898 .34768 L
.41902 .34764 L
.41905 .34761 L
.41908 .34758 L
.41912 .34755 L
.41915 .34751 L
.41919 .34748 L
.41922 .34745 L
.41925 .34742 L
.41929 .34738 L
.41932 .34735 L
.41935 .34732 L
.41939 .34729 L
.41942 .34726 L
.41945 .34722 L
.41949 .34719 L
.41952 .34716 L
.41955 .34713 L
.41959 .3471 L
.41962 .34707 L
.41966 .34703 L
.41969 .347 L
.41972 .34697 L
.41976 .34694 L
.41979 .34691 L
.41982 .34688 L
.41986 .34684 L
.41989 .34681 L
Mistroke
.41992 .34678 L
.41996 .34675 L
.41999 .34672 L
.42003 .34669 L
.42006 .34666 L
.42009 .34662 L
.42013 .34659 L
.42016 .34656 L
.42019 .34653 L
.42023 .3465 L
.42026 .34647 L
.42029 .34644 L
.42033 .34641 L
.42036 .34638 L
.4204 .34634 L
.42043 .34631 L
.42046 .34628 L
.4205 .34625 L
.42053 .34622 L
.42056 .34619 L
.4206 .34616 L
.42063 .34613 L
.42066 .3461 L
.4207 .34607 L
.42073 .34604 L
.42077 .34601 L
.4208 .34598 L
.42083 .34595 L
.42087 .34592 L
.4209 .34588 L
.42093 .34585 L
.42097 .34582 L
.421 .34579 L
.42103 .34576 L
.42107 .34573 L
.4211 .3457 L
.42114 .34567 L
.42117 .34564 L
.4212 .34561 L
.42124 .34558 L
.42127 .34555 L
.4213 .34552 L
.42134 .34549 L
.42137 .34546 L
.42141 .34543 L
.42144 .3454 L
.42147 .34537 L
.42151 .34534 L
.42154 .34531 L
.42157 .34528 L
Mistroke
.42161 .34525 L
.42164 .34522 L
.42168 .34519 L
.42171 .34517 L
.42174 .34514 L
.42178 .34511 L
.42181 .34508 L
.42184 .34505 L
.42188 .34502 L
.42191 .34499 L
.42194 .34496 L
.42198 .34493 L
.42201 .3449 L
.42205 .34487 L
.42208 .34484 L
.42211 .34481 L
.42215 .34478 L
.42218 .34475 L
.42221 .34473 L
.42225 .3447 L
.42228 .34467 L
.42232 .34464 L
.42235 .34461 L
.42238 .34458 L
.42242 .34455 L
.42245 .34452 L
.42248 .34449 L
.42252 .34447 L
.42255 .34444 L
.42259 .34441 L
.42262 .34438 L
.42265 .34435 L
.42269 .34432 L
.42272 .34429 L
.42275 .34427 L
.42279 .34424 L
.42282 .34421 L
.42285 .34418 L
.42289 .34415 L
.42292 .34412 L
.42296 .3441 L
.42299 .34407 L
.42302 .34404 L
.42306 .34401 L
.42309 .34398 L
.42312 .34395 L
.42316 .34393 L
.42319 .3439 L
.42323 .34387 L
.42326 .34384 L
Mistroke
.42329 .34381 L
.42333 .34379 L
.42336 .34376 L
.42339 .34373 L
.42343 .3437 L
.42346 .34368 L
.4235 .34365 L
.42353 .34362 L
.42356 .34359 L
.4236 .34356 L
.42363 .34354 L
.42366 .34351 L
.4237 .34348 L
.42373 .34345 L
.42376 .34343 L
.4238 .3434 L
.42383 .34337 L
.42387 .34334 L
.4239 .34332 L
.42393 .34329 L
.42397 .34326 L
.424 .34324 L
.42403 .34321 L
.42407 .34318 L
.4241 .34315 L
.42414 .34313 L
.42417 .3431 L
.4242 .34307 L
.42424 .34305 L
.42427 .34302 L
.4243 .34299 L
.42434 .34297 L
.42437 .34294 L
.4244 .34291 L
.42444 .34289 L
.42447 .34286 L
.42451 .34283 L
.42454 .3428 L
.42457 .34278 L
.42461 .34275 L
.42464 .34273 L
.42467 .3427 L
.42471 .34267 L
.42474 .34265 L
.42477 .34262 L
.42481 .34259 L
.42484 .34257 L
.42488 .34254 L
.42491 .34251 L
.42494 .34249 L
Mistroke
.42498 .34246 L
.42501 .34244 L
.42504 .34241 L
.42508 .34238 L
.42511 .34236 L
.42514 .34233 L
.42518 .3423 L
.42521 .34228 L
.42524 .34225 L
.42528 .34223 L
.42531 .3422 L
.42535 .34218 L
.42538 .34215 L
.42541 .34212 L
.42545 .3421 L
.42548 .34207 L
.42551 .34205 L
.42555 .34202 L
.42558 .342 L
.42561 .34197 L
.42565 .34194 L
.42568 .34192 L
.42571 .34189 L
.42575 .34187 L
.42578 .34184 L
.42582 .34182 L
.42585 .34179 L
.42588 .34177 L
.42592 .34174 L
.42595 .34172 L
.42598 .34169 L
.42602 .34167 L
.42605 .34164 L
.42608 .34162 L
.42612 .34159 L
.42615 .34157 L
.42618 .34154 L
.42622 .34152 L
.42625 .34149 L
.42628 .34147 L
.42632 .34144 L
.42635 .34142 L
.42638 .34139 L
.42642 .34137 L
.42645 .34134 L
.42649 .34132 L
.42652 .34129 L
.42655 .34127 L
.42659 .34124 L
.42662 .34122 L
Mistroke
.42665 .34119 L
.42669 .34117 L
.42672 .34114 L
.42675 .34112 L
.42679 .3411 L
.42682 .34107 L
.42685 .34105 L
.42689 .34102 L
.42692 .341 L
.42695 .34097 L
.42699 .34095 L
.42702 .34093 L
.42705 .3409 L
.42709 .34088 L
.42712 .34085 L
.42715 .34083 L
.42719 .34081 L
.42722 .34078 L
.42725 .34076 L
.42729 .34073 L
.42732 .34071 L
.42735 .34069 L
.42739 .34066 L
.42742 .34064 L
.42745 .34062 L
.42749 .34059 L
.42752 .34057 L
.42755 .34054 L
.42759 .34052 L
.42762 .3405 L
.42765 .34047 L
.42769 .34045 L
.42772 .34043 L
.42775 .3404 L
.42779 .34038 L
.42782 .34036 L
.42785 .34033 L
.42789 .34031 L
.42792 .34029 L
.42795 .34026 L
.42799 .34024 L
.42802 .34022 L
.42805 .34019 L
.42809 .34017 L
.42812 .34015 L
.42815 .34013 L
.42819 .3401 L
.42822 .34008 L
.42825 .34006 L
.42829 .34003 L
Mistroke
.42832 .34001 L
.42835 .33999 L
.42838 .33996 L
.42842 .33994 L
.42845 .33992 L
.42848 .3399 L
.42852 .33987 L
.42855 .33985 L
.42858 .33983 L
.42862 .33981 L
.42865 .33978 L
.42868 .33976 L
.42872 .33974 L
.42875 .33972 L
.42878 .33969 L
.42882 .33967 L
.42885 .33965 L
.42888 .33963 L
.42891 .3396 L
.42895 .33958 L
.42898 .33956 L
.42901 .33954 L
.42905 .33952 L
.42908 .33949 L
.42911 .33947 L
.42915 .33945 L
.42918 .33943 L
.42921 .33941 L
.42925 .33938 L
.42928 .33936 L
.42931 .33934 L
.42934 .33932 L
.42938 .3393 L
.42941 .33928 L
.42944 .33925 L
.42948 .33923 L
.42951 .33921 L
.42954 .33919 L
.42958 .33917 L
.42961 .33915 L
.42964 .33912 L
.42967 .3391 L
.42971 .33908 L
.42974 .33906 L
.42977 .33904 L
.42981 .33902 L
.42984 .339 L
.42987 .33897 L
.4299 .33895 L
.42994 .33893 L
Mistroke
.42997 .33891 L
.43 .33889 L
.43004 .33887 L
.43007 .33885 L
.4301 .33883 L
.43013 .3388 L
.43017 .33878 L
.4302 .33876 L
.43023 .33874 L
.43027 .33872 L
.4303 .3387 L
.43033 .33868 L
.43036 .33866 L
.4304 .33864 L
.43043 .33862 L
.43046 .3386 L
.4305 .33858 L
.43053 .33855 L
.43056 .33853 L
.43059 .33851 L
.43063 .33849 L
.43066 .33847 L
.43069 .33845 L
.43072 .33843 L
.43076 .33841 L
.43079 .33839 L
.43082 .33837 L
.43086 .33835 L
.43089 .33833 L
.43092 .33831 L
.43095 .33829 L
.43099 .33827 L
.43102 .33825 L
.43105 .33823 L
.43108 .33821 L
.43112 .33819 L
.43115 .33817 L
.43118 .33815 L
.43121 .33813 L
.43125 .33811 L
.43128 .33809 L
.43131 .33807 L
.43134 .33805 L
.43138 .33803 L
.43141 .33801 L
.43144 .33799 L
.43147 .33797 L
.43151 .33795 L
.43154 .33793 L
.43157 .33791 L
Mistroke
.4316 .33789 L
.43164 .33787 L
.43167 .33785 L
.4317 .33783 L
.43173 .33781 L
.43177 .33779 L
.4318 .33777 L
.43183 .33775 L
.43186 .33774 L
.4319 .33772 L
.43193 .3377 L
.43196 .33768 L
.43199 .33766 L
.43203 .33764 L
.43206 .33762 L
.43209 .3376 L
.43212 .33758 L
.43216 .33756 L
.43219 .33754 L
.43222 .33752 L
.43225 .33751 L
.43228 .33749 L
.43232 .33747 L
.43235 .33745 L
.43238 .33743 L
.43241 .33741 L
.43245 .33739 L
.43248 .33737 L
.43251 .33736 L
.43254 .33734 L
.43258 .33732 L
.43261 .3373 L
.43264 .33728 L
.43267 .33726 L
.4327 .33724 L
.43274 .33723 L
.43277 .33721 L
.4328 .33719 L
.43283 .33717 L
.43286 .33715 L
.4329 .33713 L
.43293 .33711 L
.43296 .3371 L
.43299 .33708 L
.43303 .33706 L
.43306 .33704 L
.43309 .33702 L
.43312 .33701 L
.43315 .33699 L
.43319 .33697 L
Mistroke
.43322 .33695 L
.43325 .33693 L
.43328 .33692 L
.43331 .3369 L
.43335 .33688 L
.43338 .33686 L
.43341 .33684 L
.43344 .33683 L
.43347 .33681 L
.43351 .33679 L
.43354 .33677 L
.43357 .33676 L
.4336 .33674 L
.43363 .33672 L
.43367 .3367 L
.4337 .33669 L
.43373 .33667 L
.43376 .33665 L
.43379 .33663 L
.43382 .33662 L
.43386 .3366 L
.43389 .33658 L
.43392 .33656 L
.43395 .33655 L
.43398 .33653 L
.43402 .33651 L
.43405 .33649 L
.43408 .33648 L
.43411 .33646 L
.43414 .33644 L
.43417 .33643 L
.43421 .33641 L
.43424 .33639 L
.43427 .33637 L
.4343 .33636 L
.43433 .33634 L
.43436 .33632 L
.4344 .33631 L
.43443 .33629 L
.43446 .33627 L
.43449 .33626 L
.43452 .33624 L
.43455 .33622 L
.43459 .33621 L
.43462 .33619 L
.43465 .33617 L
.43468 .33616 L
.43471 .33614 L
.43474 .33612 L
.43478 .33611 L
Mistroke
.43481 .33609 L
.43484 .33607 L
.43487 .33606 L
.4349 .33604 L
.43493 .33602 L
.43496 .33601 L
.435 .33599 L
.43503 .33598 L
.43506 .33596 L
.43509 .33594 L
.43512 .33593 L
.43515 .33591 L
.43518 .3359 L
.43522 .33588 L
.43525 .33586 L
.43528 .33585 L
.43531 .33583 L
.43534 .33582 L
.43537 .3358 L
.4354 .33578 L
.43544 .33577 L
.43547 .33575 L
.4355 .33574 L
.43553 .33572 L
.43556 .3357 L
.43559 .33569 L
.43562 .33567 L
.43565 .33566 L
.43569 .33564 L
.43572 .33563 L
.43575 .33561 L
.43578 .3356 L
.43581 .33558 L
.43584 .33556 L
.43587 .33555 L
.4359 .33553 L
.43593 .33552 L
.43597 .3355 L
.436 .33549 L
.43603 .33547 L
.43606 .33546 L
.43609 .33544 L
.43612 .33543 L
.43615 .33541 L
.43618 .3354 L
.43621 .33538 L
.43625 .33537 L
.43628 .33535 L
.43631 .33534 L
.43634 .33532 L
Mistroke
.43637 .33531 L
.4364 .33529 L
.43643 .33528 L
.43646 .33526 L
.43649 .33525 L
.43652 .33523 L
.43655 .33522 L
.43659 .3352 L
.43662 .33519 L
.43665 .33517 L
.43668 .33516 L
.43671 .33514 L
.43674 .33513 L
.43677 .33511 L
.4368 .3351 L
.43683 .33508 L
.43686 .33507 L
.43689 .33506 L
.43692 .33504 L
.43696 .33503 L
.43699 .33501 L
.43702 .335 L
.43705 .33498 L
.43708 .33497 L
.43711 .33496 L
.43714 .33494 L
.43717 .33493 L
.4372 .33491 L
.43723 .3349 L
.43726 .33488 L
.43729 .33487 L
.43732 .33486 L
.43735 .33484 L
.43738 .33483 L
.43741 .33481 L
.43745 .3348 L
.43748 .33479 L
.43751 .33477 L
.43754 .33476 L
.43757 .33475 L
.4376 .33473 L
.43763 .33472 L
.43766 .3347 L
.43769 .33469 L
.43772 .33468 L
.43775 .33466 L
.43778 .33465 L
.43781 .33464 L
.43784 .33462 L
.43787 .33461 L
Mistroke
.4379 .3346 L
.43793 .33458 L
.43796 .33457 L
.43799 .33456 L
.43802 .33454 L
.43805 .33453 L
.43808 .33452 L
.43811 .3345 L
.43814 .33449 L
.43817 .33448 L
.4382 .33446 L
.43823 .33445 L
.43826 .33444 L
.4383 .33442 L
.43833 .33441 L
.43836 .3344 L
.43839 .33438 L
.43842 .33437 L
.43845 .33436 L
.43848 .33434 L
.43851 .33433 L
.43854 .33432 L
.43857 .33431 L
.4386 .33429 L
.43863 .33428 L
.43866 .33427 L
.43869 .33425 L
.43872 .33424 L
.43875 .33423 L
.43878 .33422 L
.43881 .3342 L
.43884 .33419 L
.43887 .33418 L
.4389 .33417 L
.43893 .33415 L
.43896 .33414 L
.43899 .33413 L
.43902 .33412 L
.43905 .3341 L
.43907 .33409 L
.4391 .33408 L
.43913 .33407 L
.43916 .33406 L
.43919 .33404 L
.43922 .33403 L
.43925 .33402 L
.43928 .33401 L
.43931 .33399 L
.43934 .33398 L
.43937 .33397 L
Mistroke
.4394 .33396 L
.43943 .33395 L
.43946 .33393 L
.43949 .33392 L
.43952 .33391 L
.43955 .3339 L
.43958 .33389 L
.43961 .33387 L
.43964 .33386 L
.43967 .33385 L
.4397 .33384 L
.43973 .33383 L
.43976 .33382 L
.43979 .3338 L
.43982 .33379 L
.43985 .33378 L
.43987 .33377 L
.4399 .33376 L
.43993 .33375 L
.43996 .33373 L
.43999 .33372 L
.44002 .33371 L
.44005 .3337 L
.44008 .33369 L
.44011 .33368 L
.44014 .33367 L
.44017 .33365 L
.4402 .33364 L
.44023 .33363 L
.44026 .33362 L
.44029 .33361 L
.44031 .3336 L
.44034 .33359 L
.44037 .33358 L
.4404 .33356 L
.44043 .33355 L
.44046 .33354 L
.44049 .33353 L
.44052 .33352 L
.44055 .33351 L
.44058 .3335 L
.44061 .33349 L
.44064 .33348 L
.44066 .33347 L
.44069 .33346 L
.44072 .33344 L
.44075 .33343 L
.44078 .33342 L
.44081 .33341 L
.44084 .3334 L
Mistroke
.44087 .33339 L
.4409 .33338 L
.44093 .33337 L
.44095 .33336 L
.44098 .33335 L
.44101 .33334 L
.44104 .33333 L
.44107 .33332 L
.4411 .33331 L
.44113 .3333 L
.44116 .33329 L
.44119 .33328 L
.44121 .33327 L
.44124 .33325 L
.44127 .33324 L
.4413 .33323 L
.44133 .33322 L
.44136 .33321 L
.44139 .3332 L
.44141 .33319 L
.44144 .33318 L
.44147 .33317 L
.4415 .33316 L
.44153 .33315 L
.44156 .33314 L
.44159 .33313 L
.44162 .33312 L
.44164 .33311 L
.44167 .3331 L
.4417 .33309 L
.44173 .33308 L
.44176 .33307 L
.44179 .33306 L
.44181 .33305 L
.44184 .33304 L
.44187 .33304 L
.4419 .33303 L
.44193 .33302 L
.44196 .33301 L
.44199 .333 L
.44201 .33299 L
.44204 .33298 L
.44207 .33297 L
.4421 .33296 L
.44213 .33295 L
.44216 .33294 L
.44218 .33293 L
.44221 .33292 L
.44224 .33291 L
.44227 .3329 L
Mistroke
.4423 .33289 L
.44232 .33288 L
.44235 .33287 L
.44238 .33287 L
.44241 .33286 L
.44244 .33285 L
.44247 .33284 L
.44249 .33283 L
.44252 .33282 L
.44255 .33281 L
.44258 .3328 L
.44261 .33279 L
.44263 .33278 L
.44266 .33277 L
.44269 .33277 L
.44272 .33276 L
.44275 .33275 L
.44277 .33274 L
.4428 .33273 L
.44283 .33272 L
.44286 .33271 L
.44288 .3327 L
.44291 .33269 L
.44294 .33269 L
.44297 .33268 L
.443 .33267 L
.44302 .33266 L
.44305 .33265 L
.44308 .33264 L
.44311 .33263 L
.44313 .33263 L
.44316 .33262 L
.44319 .33261 L
.44322 .3326 L
.44325 .33259 L
.44327 .33258 L
.4433 .33258 L
.44333 .33257 L
.44336 .33256 L
.44338 .33255 L
.44341 .33254 L
.44344 .33253 L
.44347 .33253 L
.44349 .33252 L
.44352 .33251 L
.44355 .3325 L
.44358 .33249 L
.4436 .33249 L
.44363 .33248 L
.44366 .33247 L
Mistroke
.44369 .33246 L
.44371 .33245 L
.44374 .33245 L
.44377 .33244 L
.4438 .33243 L
.44382 .33242 L
.44385 .33241 L
.44388 .33241 L
.4439 .3324 L
.44393 .33239 L
.44396 .33238 L
.44399 .33238 L
.44401 .33237 L
.44404 .33236 L
.44407 .33235 L
.4441 .33234 L
.44412 .33234 L
.44415 .33233 L
.44418 .33232 L
.4442 .33231 L
.44423 .33231 L
.44426 .3323 L
.44428 .33229 L
.44431 .33228 L
.44434 .33228 L
.44437 .33227 L
.44439 .33226 L
.44442 .33226 L
.44445 .33225 L
.44447 .33224 L
.4445 .33223 L
.44453 .33223 L
.44455 .33222 L
.44458 .33221 L
.44461 .3322 L
.44463 .3322 L
.44466 .33219 L
.44469 .33218 L
.44472 .33218 L
.44474 .33217 L
.44477 .33216 L
.4448 .33216 L
.44482 .33215 L
.44485 .33214 L
.44488 .33213 L
.4449 .33213 L
.44493 .33212 L
.44496 .33211 L
.44498 .33211 L
.44501 .3321 L
Mistroke
.44503 .33209 L
.44506 .33209 L
.44509 .33208 L
.44511 .33207 L
.44514 .33207 L
.44517 .33206 L
.44519 .33205 L
.44522 .33205 L
.44525 .33204 L
.44527 .33203 L
.4453 .33203 L
.44533 .33202 L
.44535 .33202 L
.44538 .33201 L
.44541 .332 L
.44543 .332 L
.44546 .33199 L
.44548 .33198 L
.44551 .33198 L
.44554 .33197 L
.44556 .33196 L
.44559 .33196 L
.44562 .33195 L
.44564 .33195 L
.44567 .33194 L
.44569 .33193 L
.44572 .33193 L
.44575 .33192 L
.44577 .33192 L
.4458 .33191 L
.44582 .3319 L
.44585 .3319 L
.44588 .33189 L
.4459 .33189 L
.44593 .33188 L
.44595 .33187 L
.44598 .33187 L
.44601 .33186 L
.44603 .33186 L
.44606 .33185 L
.44608 .33185 L
.44611 .33184 L
.44614 .33183 L
.44616 .33183 L
.44619 .33182 L
.44621 .33182 L
.44624 .33181 L
.44626 .33181 L
.44629 .3318 L
.44632 .3318 L
Mistroke
.44634 .33179 L
.44637 .33178 L
.44639 .33178 L
.44642 .33177 L
.44644 .33177 L
.44647 .33176 L
.4465 .33176 L
.44652 .33175 L
.44655 .33175 L
.44657 .33174 L
.4466 .33174 L
.44662 .33173 L
.44665 .33173 L
.44667 .33172 L
.4467 .33172 L
.44672 .33171 L
.44675 .3317 L
.44678 .3317 L
.4468 .33169 L
.44683 .33169 L
.44685 .33168 L
.44688 .33168 L
.4469 .33167 L
.44693 .33167 L
.44695 .33166 L
.44698 .33166 L
.447 .33166 L
.44703 .33165 L
.44705 .33165 L
.44708 .33164 L
.4471 .33164 L
.44713 .33163 L
.44715 .33163 L
.44718 .33162 L
.4472 .33162 L
.44723 .33161 L
.44725 .33161 L
.44728 .3316 L
.4473 .3316 L
.44733 .33159 L
.44735 .33159 L
.44738 .33158 L
.4474 .33158 L
.44743 .33158 L
.44745 .33157 L
.44748 .33157 L
.4475 .33156 L
.44753 .33156 L
.44755 .33155 L
.44758 .33155 L
Mistroke
.4476 .33155 L
.44763 .33154 L
.44765 .33154 L
.44768 .33153 L
.4477 .33153 L
.44773 .33152 L
.44775 .33152 L
.44778 .33152 L
.4478 .33151 L
.44783 .33151 L
.44785 .3315 L
.44788 .3315 L
.4479 .3315 L
.44792 .33149 L
.44795 .33149 L
.44797 .33148 L
.448 .33148 L
.44802 .33148 L
.44805 .33147 L
.44807 .33147 L
.4481 .33146 L
.44812 .33146 L
.44814 .33146 L
.44817 .33145 L
.44819 .33145 L
.44822 .33144 L
.44824 .33144 L
.44827 .33144 L
.44829 .33143 L
.44832 .33143 L
.44834 .33143 L
.44836 .33142 L
.44839 .33142 L
.44841 .33142 L
.44844 .33141 L
.44846 .33141 L
.44848 .33141 L
.44851 .3314 L
.44853 .3314 L
.44856 .33139 L
.44858 .33139 L
.44861 .33139 L
.44863 .33138 L
.44865 .33138 L
.44868 .33138 L
.4487 .33137 L
.44873 .33137 L
.44875 .33137 L
.44877 .33137 L
.4488 .33136 L
Mistroke
.44882 .33136 L
.44884 .33136 L
.44887 .33135 L
.44889 .33135 L
.44892 .33135 L
.44894 .33134 L
.44896 .33134 L
.44899 .33134 L
.44901 .33133 L
.44903 .33133 L
.44906 .33133 L
.44908 .33133 L
.44911 .33132 L
.44913 .33132 L
.44915 .33132 L
.44918 .33131 L
.4492 .33131 L
.44922 .33131 L
.44925 .33131 L
.44927 .3313 L
.44929 .3313 L
.44932 .3313 L
.44934 .33129 L
.44936 .33129 L
.44939 .33129 L
.44941 .33129 L
.44944 .33128 L
.44946 .33128 L
.44948 .33128 L
.44951 .33128 L
.44953 .33127 L
.44955 .33127 L
.44958 .33127 L
.4496 .33127 L
.44962 .33126 L
.44964 .33126 L
.44967 .33126 L
.44969 .33126 L
.44971 .33125 L
.44974 .33125 L
.44976 .33125 L
.44978 .33125 L
.44981 .33125 L
.44983 .33124 L
.44985 .33124 L
.44988 .33124 L
.4499 .33124 L
.44992 .33123 L
.44995 .33123 L
.44997 .33123 L
Mistroke
.44999 .33123 L
.45001 .33123 L
.45004 .33122 L
.45006 .33122 L
.45008 .33122 L
.45011 .33122 L
.45013 .33122 L
.45015 .33121 L
.45017 .33121 L
.4502 .33121 L
.45022 .33121 L
.45024 .33121 L
.45026 .3312 L
.45029 .3312 L
.45031 .3312 L
.45033 .3312 L
.45036 .3312 L
.45038 .3312 L
.4504 .33119 L
.45042 .33119 L
.45045 .33119 L
.45047 .33119 L
.45049 .33119 L
.45051 .33119 L
.45054 .33118 L
.45056 .33118 L
.45058 .33118 L
.4506 .33118 L
.45063 .33118 L
.45065 .33118 L
.45067 .33118 L
.45069 .33117 L
.45072 .33117 L
.45074 .33117 L
.45076 .33117 L
.45078 .33117 L
.4508 .33117 L
.45083 .33117 L
.45085 .33116 L
.45087 .33116 L
.45089 .33116 L
.45092 .33116 L
.45094 .33116 L
.45096 .33116 L
.45098 .33116 L
.451 .33116 L
.45103 .33116 L
.45105 .33115 L
.45107 .33115 L
.45109 .33115 L
Mistroke
.45111 .33115 L
.45114 .33115 L
.45116 .33115 L
.45118 .33115 L
.4512 .33115 L
.45122 .33115 L
.45125 .33115 L
.45127 .33114 L
.45129 .33114 L
.45131 .33114 L
.45133 .33114 L
.45135 .33114 L
.45138 .33114 L
.4514 .33114 L
.45142 .33114 L
.45144 .33114 L
.45146 .33114 L
.45148 .33114 L
.45151 .33114 L
.45153 .33114 L
.45155 .33113 L
.45157 .33113 L
.45159 .33113 L
.45161 .33113 L
.45164 .33113 L
.45166 .33113 L
.45168 .33113 L
.4517 .33113 L
.45172 .33113 L
.45174 .33113 L
.45176 .33113 L
.45179 .33113 L
.45181 .33113 L
.45183 .33113 L
.45185 .33113 L
.45187 .33113 L
.45189 .33113 L
.45191 .33113 L
.45193 .33113 L
.45196 .33113 L
.45198 .33113 L
.452 .33113 L
.45202 .33113 L
.45204 .33113 L
.45206 .33113 L
.45208 .33113 L
.4521 .33113 L
.45212 .33113 L
.45215 .33113 L
.45217 .33112 L
Mistroke
.45219 .33112 L
.45221 .33112 L
.45223 .33112 L
.45225 .33112 L
.45227 .33113 L
.45229 .33113 L
.45231 .33113 L
.45233 .33113 L
.45236 .33113 L
.45238 .33113 L
.4524 .33113 L
.45242 .33113 L
.45244 .33113 L
.45246 .33113 L
.45248 .33113 L
.4525 .33113 L
.45252 .33113 L
.45254 .33113 L
.45256 .33113 L
.45258 .33113 L
.4526 .33113 L
.45262 .33113 L
.45264 .33113 L
.45267 .33113 L
.45269 .33113 L
.45271 .33113 L
.45273 .33113 L
.45275 .33113 L
.45277 .33113 L
.45279 .33113 L
.45281 .33113 L
.45283 .33113 L
.45285 .33113 L
.45287 .33113 L
.45289 .33114 L
.45291 .33114 L
.45293 .33114 L
.45295 .33114 L
.45297 .33114 L
.45299 .33114 L
.45301 .33114 L
.45303 .33114 L
.45305 .33114 L
.45307 .33114 L
.45309 .33114 L
.45311 .33114 L
.45313 .33114 L
.45315 .33115 L
.45317 .33115 L
.45319 .33115 L
Mistroke
.45321 .33115 L
.45323 .33115 L
.45325 .33115 L
.45327 .33115 L
.45329 .33115 L
.45331 .33115 L
.45333 .33115 L
.45335 .33115 L
.45337 .33116 L
.45339 .33116 L
.45341 .33116 L
.45343 .33116 L
.45345 .33116 L
.45347 .33116 L
.45349 .33116 L
.45351 .33116 L
.45353 .33117 L
.45355 .33117 L
.45357 .33117 L
.45359 .33117 L
.45361 .33117 L
.45363 .33117 L
.45365 .33117 L
.45367 .33117 L
.45369 .33118 L
.45371 .33118 L
.45373 .33118 L
.45375 .33118 L
.45376 .33118 L
.45378 .33118 L
.4538 .33118 L
.45382 .33119 L
.45384 .33119 L
.45386 .33119 L
.45388 .33119 L
.4539 .33119 L
.45392 .33119 L
.45394 .3312 L
.45396 .3312 L
.45398 .3312 L
.454 .3312 L
.45402 .3312 L
.45404 .3312 L
.45405 .33121 L
.45407 .33121 L
.45409 .33121 L
.45411 .33121 L
.45413 .33121 L
.45415 .33121 L
.45417 .33122 L
Mistroke
.45419 .33122 L
.45421 .33122 L
.45423 .33122 L
.45424 .33122 L
.45426 .33123 L
.45428 .33123 L
.4543 .33123 L
.45432 .33123 L
.45434 .33123 L
.45436 .33123 L
.45438 .33124 L
.4544 .33124 L
.45441 .33124 L
.45443 .33124 L
.45445 .33125 L
.45447 .33125 L
.45449 .33125 L
.45451 .33125 L
.45453 .33125 L
.45455 .33126 L
.45456 .33126 L
.45458 .33126 L
.4546 .33126 L
.45462 .33126 L
.45464 .33127 L
.45466 .33127 L
.45467 .33127 L
.45469 .33127 L
.45471 .33128 L
.45473 .33128 L
.45475 .33128 L
.45477 .33128 L
.45479 .33129 L
.4548 .33129 L
.45482 .33129 L
.45484 .33129 L
.45486 .3313 L
.45488 .3313 L
.4549 .3313 L
.45491 .3313 L
.45493 .33131 L
.45495 .33131 L
.45497 .33131 L
.45499 .33131 L
.455 .33132 L
.45502 .33132 L
.45504 .33132 L
.45506 .33132 L
.45508 .33133 L
.45509 .33133 L
Mistroke
.45511 .33133 L
.45513 .33133 L
.45515 .33134 L
.45517 .33134 L
.45518 .33134 L
.4552 .33135 L
.45522 .33135 L
.45524 .33135 L
.45526 .33135 L
.45527 .33136 L
.45529 .33136 L
.45531 .33136 L
.45533 .33137 L
.45534 .33137 L
.45536 .33137 L
.45538 .33137 L
.4554 .33138 L
.45542 .33138 L
.45543 .33138 L
.45545 .33139 L
.45547 .33139 L
.45549 .33139 L
.4555 .3314 L
.45552 .3314 L
.45554 .3314 L
.45556 .3314 L
.45557 .33141 L
.45559 .33141 L
.45561 .33141 L
.45563 .33142 L
.45564 .33142 L
.45566 .33142 L
.45568 .33143 L
.4557 .33143 L
.45571 .33143 L
.45573 .33144 L
.45575 .33144 L
.45576 .33144 L
.45578 .33145 L
.4558 .33145 L
.45582 .33145 L
.45583 .33146 L
.45585 .33146 L
.45587 .33146 L
.45588 .33147 L
.4559 .33147 L
.45592 .33147 L
.45594 .33148 L
.45595 .33148 L
.45597 .33148 L
Mistroke
.45599 .33149 L
.456 .33149 L
.45602 .33149 L
.45604 .3315 L
.45605 .3315 L
.45607 .33151 L
.45609 .33151 L
.45611 .33151 L
.45612 .33152 L
.45614 .33152 L
.45616 .33152 L
.45617 .33153 L
.45619 .33153 L
.45621 .33153 L
.45622 .33154 L
.45624 .33154 L
.45626 .33155 L
.45627 .33155 L
.45629 .33155 L
.45631 .33156 L
.45632 .33156 L
.45634 .33156 L
.45636 .33157 L
.45637 .33157 L
.45639 .33158 L
.4564 .33158 L
.45642 .33158 L
.45644 .33159 L
.45645 .33159 L
.45647 .3316 L
.45649 .3316 L
.4565 .3316 L
.45652 .33161 L
.45654 .33161 L
.45655 .33162 L
.45657 .33162 L
.45658 .33162 L
.4566 .33163 L
.45662 .33163 L
.45663 .33164 L
.45665 .33164 L
.45667 .33165 L
.45668 .33165 L
.4567 .33165 L
.45671 .33166 L
.45673 .33166 L
.45675 .33167 L
.45676 .33167 L
.45678 .33167 L
.45679 .33168 L
Mistroke
.45681 .33168 L
.45683 .33169 L
.45684 .33169 L
.45686 .3317 L
.45687 .3317 L
.45689 .3317 L
.45691 .33171 L
.45692 .33171 L
.45694 .33172 L
.45695 .33172 L
.45697 .33173 L
.45698 .33173 L
.457 .33174 L
.45702 .33174 L
.45703 .33174 L
.45705 .33175 L
.45706 .33175 L
.45708 .33176 L
.45709 .33176 L
.45711 .33177 L
.45713 .33177 L
.45714 .33178 L
.45716 .33178 L
.45717 .33179 L
.45719 .33179 L
.4572 .3318 L
.45722 .3318 L
.45723 .3318 L
.45725 .33181 L
.45726 .33181 L
.45728 .33182 L
.4573 .33182 L
.45731 .33183 L
.45733 .33183 L
.45734 .33184 L
.45736 .33184 L
.45737 .33185 L
.45739 .33185 L
.4574 .33186 L
.45742 .33186 L
.45743 .33187 L
.45745 .33187 L
.45746 .33188 L
.45748 .33188 L
.45749 .33189 L
.45751 .33189 L
.45752 .3319 L
.45754 .3319 L
.45755 .33191 L
.45757 .33191 L
Mistroke
.45758 .33192 L
.4576 .33192 L
.45761 .33193 L
.45763 .33193 L
.45764 .33194 L
.45766 .33194 L
.45767 .33195 L
.45769 .33195 L
.4577 .33196 L
.45772 .33196 L
.45773 .33197 L
.45775 .33197 L
.45776 .33198 L
.45778 .33198 L
.45779 .33199 L
.4578 .33199 L
.45782 .332 L
.45783 .332 L
.45785 .33201 L
.45786 .33201 L
.45788 .33202 L
.45789 .33202 L
.45791 .33203 L
.45792 .33204 L
.45794 .33204 L
.45795 .33205 L
.45796 .33205 L
.45798 .33206 L
.45799 .33206 L
.45801 .33207 L
.45802 .33207 L
.45804 .33208 L
.45805 .33208 L
.45806 .33209 L
.45808 .33209 L
.45809 .3321 L
.45811 .33211 L
.45812 .33211 L
.45814 .33212 L
.45815 .33212 L
.45816 .33213 L
.45818 .33213 L
.45819 .33214 L
.45821 .33214 L
.45822 .33215 L
.45823 .33216 L
.45825 .33216 L
.45826 .33217 L
.45828 .33217 L
.45829 .33218 L
Mistroke
.4583 .33218 L
.45832 .33219 L
.45833 .3322 L
.45835 .3322 L
.45836 .33221 L
.45837 .33221 L
.45839 .33222 L
.4584 .33222 L
.45842 .33223 L
.45843 .33224 L
.45844 .33224 L
.45846 .33225 L
.45847 .33225 L
.45848 .33226 L
.4585 .33227 L
.45851 .33227 L
.45852 .33228 L
.45854 .33228 L
.45855 .33229 L
.45857 .3323 L
.45858 .3323 L
.45859 .33231 L
.45861 .33231 L
.45862 .33232 L
.45863 .33232 L
.45865 .33233 L
.45866 .33234 L
.45867 .33234 L
.45869 .33235 L
.4587 .33236 L
.45871 .33236 L
.45873 .33237 L
.45874 .33237 L
.45875 .33238 L
.45877 .33239 L
.45878 .33239 L
.45879 .3324 L
.45881 .3324 L
.45882 .33241 L
.45883 .33242 L
.45885 .33242 L
.45886 .33243 L
.45887 .33244 L
.45889 .33244 L
.4589 .33245 L
.45891 .33245 L
.45892 .33246 L
.45894 .33247 L
.45895 .33247 L
.45896 .33248 L
Mistroke
.45898 .33249 L
.45899 .33249 L
.459 .3325 L
.45901 .3325 L
.45903 .33251 L
.45904 .33252 L
.45905 .33252 L
.45907 .33253 L
.45908 .33254 L
.45909 .33254 L
.4591 .33255 L
.45912 .33256 L
.45913 .33256 L
.45914 .33257 L
.45916 .33258 L
.45917 .33258 L
.45918 .33259 L
.45919 .33259 L
.45921 .3326 L
.45922 .33261 L
.45923 .33261 L
.45924 .33262 L
.45926 .33263 L
.45927 .33263 L
.45928 .33264 L
.45929 .33265 L
.45931 .33265 L
.45932 .33266 L
.45933 .33267 L
.45934 .33267 L
.45935 .33268 L
.45937 .33269 L
.45938 .33269 L
.45939 .3327 L
.4594 .33271 L
.45942 .33271 L
.45943 .33272 L
.45944 .33273 L
.45945 .33273 L
.45947 .33274 L
.45948 .33275 L
.45949 .33276 L
.4595 .33276 L
.45951 .33277 L
.45953 .33278 L
.45954 .33278 L
.45955 .33279 L
.45956 .3328 L
.45957 .3328 L
.45959 .33281 L
Mistroke
.4596 .33282 L
.45961 .33282 L
.45962 .33283 L
.45963 .33284 L
.45965 .33284 L
.45966 .33285 L
.45967 .33286 L
.45968 .33287 L
.45969 .33287 L
.4597 .33288 L
.45972 .33289 L
.45973 .33289 L
.45974 .3329 L
.45975 .33291 L
.45976 .33291 L
.45977 .33292 L
.45979 .33293 L
.4598 .33294 L
.45981 .33294 L
.45982 .33295 L
.45983 .33296 L
.45984 .33296 L
.45986 .33297 L
.45987 .33298 L
.45988 .33299 L
.45989 .33299 L
.4599 .333 L
.45991 .33301 L
.45992 .33302 L
.45994 .33302 L
.45995 .33303 L
.45996 .33304 L
.45997 .33304 L
.45998 .33305 L
.45999 .33306 L
.46 .33307 L
.46001 .33307 L
.46003 .33308 L
.46004 .33309 L
.46005 .3331 L
.46006 .3331 L
.46007 .33311 L
.46008 .33312 L
.46009 .33312 L
.4601 .33313 L
.46011 .33314 L
.46013 .33315 L
.46014 .33315 L
.46015 .33316 L
.46016 .33317 L
Mistroke
.46017 .33318 L
.46018 .33318 L
.46019 .33319 L
.4602 .3332 L
.46021 .33321 L
.46022 .33321 L
.46023 .33322 L
.46025 .33323 L
.46026 .33324 L
.46027 .33324 L
.46028 .33325 L
.46029 .33326 L
.4603 .33327 L
.46031 .33327 L
.46032 .33328 L
.46033 .33329 L
.46034 .3333 L
.46035 .33331 L
.46036 .33331 L
.46037 .33332 L
.46038 .33333 L
.4604 .33334 L
.46041 .33334 L
.46042 .33335 L
.46043 .33336 L
.46044 .33337 L
.46045 .33337 L
.46046 .33338 L
.46047 .33339 L
.46048 .3334 L
.46049 .33341 L
.4605 .33341 L
.46051 .33342 L
.46052 .33343 L
.46053 .33344 L
.46054 .33344 L
.46055 .33345 L
.46056 .33346 L
.46057 .33347 L
.46058 .33348 L
.46059 .33348 L
.4606 .33349 L
.46061 .3335 L
.46062 .33351 L
.46063 .33352 L
.46064 .33352 L
.46065 .33353 L
.46066 .33354 L
.46067 .33355 L
.46068 .33355 L
Mistroke
.46069 .33356 L
.4607 .33357 L
.46071 .33358 L
.46072 .33359 L
.46073 .33359 L
.46074 .3336 L
.46075 .33361 L
.46076 .33362 L
.46077 .33363 L
.46078 .33363 L
.46079 .33364 L
.4608 .33365 L
.46081 .33366 L
.46082 .33367 L
.46083 .33368 L
.46084 .33368 L
.46085 .33369 L
.46086 .3337 L
.46087 .33371 L
.46088 .33372 L
.46089 .33372 L
.4609 .33373 L
.46091 .33374 L
.46092 .33375 L
.46093 .33376 L
.46094 .33376 L
.46095 .33377 L
.46095 .33378 L
.46096 .33379 L
.46097 .3338 L
.46098 .33381 L
.46099 .33381 L
.461 .33382 L
.46101 .33383 L
.46102 .33384 L
.46103 .33385 L
.46104 .33386 L
.46105 .33386 L
.46106 .33387 L
.46107 .33388 L
.46108 .33389 L
.46109 .3339 L
.46109 .33391 L
.4611 .33391 L
.46111 .33392 L
.46112 .33393 L
.46113 .33394 L
.46114 .33395 L
.46115 .33396 L
.46116 .33396 L
Mistroke
.46117 .33397 L
.46118 .33398 L
.46118 .33399 L
.46119 .334 L
.4612 .33401 L
.46121 .33401 L
.46122 .33402 L
.46123 .33403 L
.46124 .33404 L
.46125 .33405 L
.46126 .33406 L
.46127 .33407 L
.46127 .33407 L
.46128 .33408 L
.46129 .33409 L
.4613 .3341 L
.46131 .33411 L
.46132 .33412 L
.46133 .33413 L
.46133 .33413 L
.46134 .33414 L
.46135 .33415 L
.46136 .33416 L
.46137 .33417 L
.46138 .33418 L
.46139 .33419 L
.46139 .33419 L
.4614 .3342 L
.46141 .33421 L
.46142 .33422 L
.46143 .33423 L
.46144 .33424 L
.46145 .33425 L
.46145 .33425 L
.46146 .33426 L
.46147 .33427 L
.46148 .33428 L
.46149 .33429 L
.4615 .3343 L
.4615 .33431 L
.46151 .33432 L
.46152 .33432 L
.46153 .33433 L
.46154 .33434 L
.46155 .33435 L
.46155 .33436 L
.46156 .33437 L
.46157 .33438 L
.46158 .33439 L
.46159 .3344 L
Mistroke
.46159 .3344 L
.4616 .33441 L
.46161 .33442 L
.46162 .33443 L
.46163 .33444 L
.46163 .33445 L
.46164 .33446 L
.46165 .33447 L
.46166 .33447 L
.46167 .33448 L
.46167 .33449 L
.46168 .3345 L
.46169 .33451 L
.4617 .33452 L
.46171 .33453 L
.46171 .33454 L
.46172 .33455 L
.46173 .33456 L
.46174 .33456 L
.46174 .33457 L
.46175 .33458 L
.46176 .33459 L
.46177 .3346 L
.46177 .33461 L
.46178 .33462 L
.46179 .33463 L
.4618 .33464 L
.46181 .33465 L
.46181 .33465 L
.46182 .33466 L
.46183 .33467 L
.46184 .33468 L
.46184 .33469 L
.46185 .3347 L
.46186 .33471 L
.46187 .33472 L
.46187 .33473 L
.46188 .33474 L
.46189 .33475 L
.46189 .33475 L
.4619 .33476 L
.46191 .33477 L
.46192 .33478 L
.46192 .33479 L
.46193 .3348 L
.46194 .33481 L
.46195 .33482 L
.46195 .33483 L
.46196 .33484 L
.46197 .33485 L
Mistroke
.46197 .33485 L
.46198 .33486 L
.46199 .33487 L
.462 .33488 L
.462 .33489 L
.46201 .3349 L
.46202 .33491 L
.46202 .33492 L
.46203 .33493 L
.46204 .33494 L
.46205 .33495 L
.46205 .33496 L
.46206 .33497 L
.46207 .33498 L
.46207 .33498 L
.46208 .33499 L
.46209 .335 L
.46209 .33501 L
.4621 .33502 L
.46211 .33503 L
.46211 .33504 L
.46212 .33505 L
.46213 .33506 L
.46213 .33507 L
.46214 .33508 L
.46215 .33509 L
.46215 .3351 L
.46216 .33511 L
.46217 .33512 L
.46217 .33512 L
.46218 .33513 L
.46219 .33514 L
.46219 .33515 L
.4622 .33516 L
.46221 .33517 L
.46221 .33518 L
.46222 .33519 L
.46223 .3352 L
.46223 .33521 L
.46224 .33522 L
.46225 .33523 L
.46225 .33524 L
.46226 .33525 L
.46227 .33526 L
.46227 .33527 L
.46228 .33528 L
.46228 .33529 L
.46229 .33529 L
.4623 .3353 L
.4623 .33531 L
Mistroke
.46231 .33532 L
.46232 .33533 L
.46232 .33534 L
.46233 .33535 L
.46233 .33536 L
.46234 .33537 L
.46235 .33538 L
.46235 .33539 L
.46236 .3354 L
.46237 .33541 L
.46237 .33542 L
.46238 .33543 L
.46238 .33544 L
.46239 .33545 L
.4624 .33546 L
.4624 .33547 L
.46241 .33548 L
.46241 .33549 L
.46242 .3355 L
.46243 .33551 L
.46243 .33552 L
.46244 .33552 L
.46244 .33553 L
.46245 .33554 L
.46245 .33555 L
.46246 .33556 L
.46247 .33557 L
.46247 .33558 L
.46248 .33559 L
.46248 .3356 L
.46249 .33561 L
.46249 .33562 L
.4625 .33563 L
.46251 .33564 L
.46251 .33565 L
.46252 .33566 L
.46252 .33567 L
.46253 .33568 L
.46253 .33569 L
.46254 .3357 L
.46255 .33571 L
.46255 .33572 L
.46256 .33573 L
.46256 .33574 L
.46257 .33575 L
.46257 .33576 L
.46258 .33577 L
.46258 .33578 L
.46259 .33579 L
.46259 .3358 L
Mistroke
.4626 .33581 L
.46261 .33582 L
.46261 .33583 L
.46262 .33584 L
.46262 .33585 L
.46263 .33586 L
.46263 .33587 L
.46264 .33588 L
.46264 .33589 L
.46265 .3359 L
.46265 .33591 L
.46266 .33592 L
.46266 .33593 L
.46267 .33594 L
.46267 .33595 L
.46268 .33596 L
.46268 .33597 L
.46269 .33597 L
.46269 .33598 L
.4627 .33599 L
.4627 .336 L
.46271 .33601 L
.46271 .33602 L
.46272 .33603 L
.46272 .33604 L
.46273 .33605 L
.46273 .33606 L
.46274 .33607 L
.46274 .33608 L
.46275 .33609 L
.46275 .3361 L
.46276 .33611 L
.46276 .33612 L
.46277 .33613 L
.46277 .33614 L
.46278 .33615 L
.46278 .33616 L
.46279 .33617 L
.46279 .33618 L
.4628 .33619 L
.4628 .3362 L
.46281 .33621 L
.46281 .33622 L
.46282 .33623 L
.46282 .33624 L
.46282 .33625 L
.46283 .33626 L
.46283 .33627 L
.46284 .33628 L
.46284 .33629 L
Mistroke
.46285 .3363 L
.46285 .33631 L
.46286 .33632 L
.46286 .33633 L
.46287 .33634 L
.46287 .33635 L
.46287 .33637 L
.46288 .33638 L
.46288 .33639 L
.46289 .3364 L
.46289 .33641 L
.4629 .33642 L
.4629 .33643 L
.4629 .33644 L
.46291 .33645 L
.46291 .33646 L
.46292 .33647 L
.46292 .33648 L
.46293 .33649 L
.46293 .3365 L
.46293 .33651 L
.46294 .33652 L
.46294 .33653 L
.46295 .33654 L
.46295 .33655 L
.46296 .33656 L
.46296 .33657 L
.46296 .33658 L
.46297 .33659 L
.46297 .3366 L
.46298 .33661 L
.46298 .33662 L
.46298 .33663 L
.46299 .33664 L
.46299 .33665 L
.463 .33666 L
.463 .33667 L
.463 .33668 L
.46301 .33669 L
.46301 .3367 L
.46301 .33671 L
.46302 .33672 L
.46302 .33673 L
.46303 .33674 L
.46303 .33675 L
.46303 .33676 L
.46304 .33677 L
.46304 .33678 L
.46304 .33679 L
.46305 .3368 L
Mistroke
.46305 .33681 L
.46306 .33682 L
.46306 .33683 L
.46306 .33684 L
.46307 .33685 L
.46307 .33686 L
.46307 .33687 L
.46308 .33689 L
.46308 .3369 L
.46308 .33691 L
.46309 .33692 L
.46309 .33693 L
.4631 .33694 L
.4631 .33695 L
.4631 .33696 L
.46311 .33697 L
.46311 .33698 L
.46311 .33699 L
.46312 .337 L
.46312 .33701 L
.46312 .33702 L
.46313 .33703 L
.46313 .33704 L
.46313 .33705 L
.46314 .33706 L
.46314 .33707 L
.46314 .33708 L
.46315 .33709 L
.46315 .3371 L
.46315 .33711 L
.46316 .33712 L
.46316 .33713 L
.46316 .33714 L
.46317 .33715 L
.46317 .33716 L
.46317 .33718 L
.46317 .33719 L
.46318 .3372 L
.46318 .33721 L
.46318 .33722 L
.46319 .33723 L
.46319 .33724 L
.46319 .33725 L
.4632 .33726 L
.4632 .33727 L
.4632 .33728 L
.4632 .33729 L
.46321 .3373 L
.46321 .33731 L
.46321 .33732 L
Mistroke
.46322 .33733 L
.46322 .33734 L
.46322 .33735 L
.46323 .33736 L
.46323 .33737 L
.46323 .33738 L
.46323 .33739 L
.46324 .3374 L
.46324 .33741 L
.46324 .33743 L
.46324 .33744 L
.46325 .33745 L
.46325 .33746 L
.46325 .33747 L
.46326 .33748 L
.46326 .33749 L
.46326 .3375 L
.46326 .33751 L
.46327 .33752 L
.46327 .33753 L
.46327 .33754 L
.46327 .33755 L
.46328 .33756 L
.46328 .33757 L
.46328 .33758 L
.46328 .33759 L
.46329 .3376 L
.46329 .33761 L
.46329 .33762 L
.46329 .33764 L
.4633 .33765 L
.4633 .33766 L
.4633 .33767 L
.4633 .33768 L
.46331 .33769 L
.46331 .3377 L
.46331 .33771 L
.46331 .33772 L
.46331 .33773 L
.46332 .33774 L
.46332 .33775 L
.46332 .33776 L
.46332 .33777 L
.46333 .33778 L
.46333 .33779 L
.46333 .3378 L
.46333 .33781 L
.46334 .33783 L
.46334 .33784 L
.46334 .33785 L
Mistroke
.46334 .33786 L
.46334 .33787 L
.46335 .33788 L
.46335 .33789 L
.46335 .3379 L
.46335 .33791 L
.46335 .33792 L
.46336 .33793 L
.46336 .33794 L
.46336 .33795 L
.46336 .33796 L
.46336 .33797 L
.46337 .33798 L
.46337 .33799 L
.46337 .33801 L
.46337 .33802 L
.46337 .33803 L
.46338 .33804 L
.46338 .33805 L
.46338 .33806 L
.46338 .33807 L
.46338 .33808 L
.46338 .33809 L
.46339 .3381 L
.46339 .33811 L
.46339 .33812 L
.46339 .33813 L
.46339 .33814 L
.46339 .33815 L
.4634 .33816 L
.4634 .33818 L
.4634 .33819 L
.4634 .3382 L
.4634 .33821 L
.4634 .33822 L
.46341 .33823 L
.46341 .33824 L
.46341 .33825 L
.46341 .33826 L
.46341 .33827 L
.46341 .33828 L
.46342 .33829 L
.46342 .3383 L
.46342 .33831 L
.46342 .33832 L
.46342 .33834 L
.46342 .33835 L
.46342 .33836 L
.46343 .33837 L
.46343 .33838 L
Mistroke
.46343 .33839 L
.46343 .3384 L
.46343 .33841 L
.46343 .33842 L
.46343 .33843 L
.46343 .33844 L
.46344 .33845 L
.46344 .33846 L
.46344 .33847 L
.46344 .33848 L
.46344 .3385 L
.46344 .33851 L
.46344 .33852 L
.46344 .33853 L
.46345 .33854 L
.46345 .33855 L
.46345 .33856 L
.46345 .33857 L
.46345 .33858 L
.46345 .33859 L
.46345 .3386 L
.46345 .33861 L
.46345 .33862 L
.46346 .33863 L
.46346 .33865 L
.46346 .33866 L
.46346 .33867 L
.46346 .33868 L
.46346 .33869 L
.46346 .3387 L
.46346 .33871 L
.46346 .33872 L
.46346 .33873 L
.46347 .33874 L
.46347 .33875 L
.46347 .33876 L
.46347 .33877 L
.46347 .33878 L
.46347 .3388 L
.46347 .33881 L
.46347 .33882 L
.46347 .33883 L
.46347 .33884 L
.46347 .33885 L
.46347 .33886 L
.46347 .33887 L
.46348 .33888 L
.46348 .33889 L
.46348 .3389 L
.46348 .33891 L
Mistroke
.46348 .33892 L
.46348 .33894 L
.46348 .33895 L
.46348 .33896 L
.46348 .33897 L
.46348 .33898 L
.46348 .33899 L
.46348 .339 L
.46348 .33901 L
.46348 .33902 L
.46348 .33903 L
.46348 .33904 L
.46349 .33905 L
.46349 .33906 L
.46349 .33907 L
.46349 .33909 L
.46349 .3391 L
.46349 .33911 L
.46349 .33912 L
.46349 .33913 L
.46349 .33914 L
.46349 .33915 L
.46349 .33916 L
.46349 .33917 L
.46349 .33918 L
.46349 .33919 L
.46349 .3392 L
.46349 .33921 L
.46349 .33923 L
.46349 .33924 L
.46349 .33925 L
.46349 .33926 L
.46349 .33927 L
.46349 .33928 L
.46349 .33929 L
.46349 .3393 L
.46349 .33931 L
.46349 .33932 L
.46349 .33933 L
.46349 .33934 L
.46349 .33935 L
.46349 .33937 L
.46349 .33938 L
.46349 .33939 L
.46349 .3394 L
.46349 .33941 L
.46349 .33942 L
.46349 .33943 L
.46349 .33944 L
.46349 .33945 L
Mistroke
.46349 .33946 L
.46349 .33947 L
.46349 .33948 L
.46349 .33949 L
.46349 .33951 L
.46349 .33952 L
.46349 .33953 L
.46349 .33954 L
.46349 .33955 L
.46349 .33956 L
.46349 .33957 L
.46349 .33958 L
.46349 .33959 L
.46349 .3396 L
.46349 .33961 L
.46349 .33962 L
.46349 .33963 L
.46349 .33965 L
.46349 .33966 L
.46349 .33967 L
.46349 .33968 L
.46349 .33969 L
.46349 .3397 L
.46349 .33971 L
.46349 .33972 L
.46349 .33973 L
.46349 .33974 L
.46349 .33975 L
.46349 .33976 L
.46349 .33977 L
.46349 .33979 L
.46349 .3398 L
.46349 .33981 L
.46349 .33982 L
.46348 .33983 L
.46348 .33984 L
.46348 .33985 L
.46348 .33986 L
.46348 .33987 L
.46348 .33988 L
.46348 .33989 L
.46348 .3399 L
.46348 .33991 L
.46348 .33993 L
.46348 .33994 L
.46348 .33995 L
.46348 .33996 L
.46348 .33997 L
.46348 .33998 L
.46348 .33999 L
Mistroke
.46348 .34 L
.46347 .34001 L
.46347 .34002 L
.46347 .34003 L
.46347 .34004 L
.46347 .34005 L
.46347 .34007 L
.46347 .34008 L
.46347 .34009 L
.46347 .3401 L
.46347 .34011 L
.46347 .34012 L
.46347 .34013 L
.46347 .34014 L
.46346 .34015 L
.46346 .34016 L
.46346 .34017 L
.46346 .34018 L
.46346 .34019 L
.46346 .34021 L
.46346 .34022 L
.46346 .34023 L
.46346 .34024 L
.46346 .34025 L
.46345 .34026 L
.46345 .34027 L
.46345 .34028 L
.46345 .34029 L
.46345 .3403 L
.46345 .34031 L
.46345 .34032 L
.46345 .34033 L
.46345 .34035 L
.46345 .34036 L
.46344 .34037 L
.46344 .34038 L
.46344 .34039 L
.46344 .3404 L
.46344 .34041 L
.46344 .34042 L
.46344 .34043 L
.46344 .34044 L
.46344 .34045 L
.46343 .34046 L
.46343 .34047 L
.46343 .34049 L
.46343 .3405 L
.46343 .34051 L
.46343 .34052 L
.46343 .34053 L
Mistroke
.46342 .34054 L
.46342 .34055 L
.46342 .34056 L
.46342 .34057 L
.46342 .34058 L
.46342 .34059 L
.46342 .3406 L
.46342 .34061 L
.46341 .34062 L
.46341 .34064 L
.46341 .34065 L
.46341 .34066 L
.46341 .34067 L
.46341 .34068 L
.46341 .34069 L
.4634 .3407 L
.4634 .34071 L
.4634 .34072 L
.4634 .34073 L
.4634 .34074 L
.4634 .34075 L
.46339 .34076 L
.46339 .34077 L
.46339 .34079 L
.46339 .3408 L
.46339 .34081 L
.46339 .34082 L
.46339 .34083 L
.46338 .34084 L
.46338 .34085 L
.46338 .34086 L
.46338 .34087 L
.46338 .34088 L
.46338 .34089 L
.46337 .3409 L
.46337 .34091 L
.46337 .34092 L
.46337 .34094 L
.46337 .34095 L
.46336 .34096 L
.46336 .34097 L
.46336 .34098 L
.46336 .34099 L
.46336 .341 L
.46336 .34101 L
.46335 .34102 L
.46335 .34103 L
.46335 .34104 L
.46335 .34105 L
.46335 .34106 L
Mistroke
.46334 .34107 L
.46334 .34109 L
.46334 .3411 L
.46334 .34111 L
.46334 .34112 L
.46333 .34113 L
.46333 .34114 L
.46333 .34115 L
.46333 .34116 L
.46333 .34117 L
.46332 .34118 L
.46332 .34119 L
.46332 .3412 L
.46332 .34121 L
.46332 .34122 L
.46331 .34123 L
.46331 .34125 L
.46331 .34126 L
.46331 .34127 L
.46331 .34128 L
.4633 .34129 L
.4633 .3413 L
.4633 .34131 L
.4633 .34132 L
.4633 .34133 L
.46329 .34134 L
.46329 .34135 L
.46329 .34136 L
.46329 .34137 L
.46328 .34138 L
.46328 .34139 L
.46328 .3414 L
.46328 .34142 L
.46328 .34143 L
.46327 .34144 L
.46327 .34145 L
.46327 .34146 L
.46327 .34147 L
.46326 .34148 L
.46326 .34149 L
.46326 .3415 L
.46326 .34151 L
.46325 .34152 L
.46325 .34153 L
.46325 .34154 L
.46325 .34155 L
.46324 .34156 L
.46324 .34157 L
.46324 .34159 L
.46324 .3416 L
Mistroke
.46324 .34161 L
.46323 .34162 L
.46323 .34163 L
.46323 .34164 L
.46323 .34165 L
.46322 .34166 L
.46322 .34167 L
.46322 .34168 L
.46322 .34169 L
.46321 .3417 L
.46321 .34171 L
.46321 .34172 L
.4632 .34173 L
.4632 .34174 L
.4632 .34175 L
.4632 .34176 L
.46319 .34178 L
.46319 .34179 L
.46319 .3418 L
.46319 .34181 L
.46318 .34182 L
.46318 .34183 L
.46318 .34184 L
.46318 .34185 L
.46317 .34186 L
.46317 .34187 L
.46317 .34188 L
.46316 .34189 L
.46316 .3419 L
.46316 .34191 L
.46316 .34192 L
.46315 .34193 L
.46315 .34194 L
.46315 .34195 L
.46315 .34197 L
.46314 .34198 L
.46314 .34199 L
.46314 .342 L
.46313 .34201 L
.46313 .34202 L
.46313 .34203 L
.46313 .34204 L
.46312 .34205 L
.46312 .34206 L
.46312 .34207 L
.46311 .34208 L
.46311 .34209 L
.46311 .3421 L
.4631 .34211 L
.4631 .34212 L
Mistroke
.4631 .34213 L
.4631 .34214 L
.46309 .34215 L
.46309 .34216 L
.46309 .34217 L
.46308 .34219 L
.46308 .3422 L
.46308 .34221 L
.46307 .34222 L
.46307 .34223 L
.46307 .34224 L
.46307 .34225 L
.46306 .34226 L
.46306 .34227 L
.46306 .34228 L
.46305 .34229 L
.46305 .3423 L
.46305 .34231 L
.46304 .34232 L
.46304 .34233 L
.46304 .34234 L
.46303 .34235 L
.46303 .34236 L
.46303 .34237 L
.46302 .34238 L
.46302 .34239 L
.46302 .3424 L
.46301 .34241 L
.46301 .34243 L
.46301 .34244 L
.463 .34245 L
.463 .34246 L
.463 .34247 L
.46299 .34248 L
.46299 .34249 L
.46299 .3425 L
.46298 .34251 L
.46298 .34252 L
.46298 .34253 L
.46297 .34254 L
.46297 .34255 L
.46297 .34256 L
.46296 .34257 L
.46296 .34258 L
.46296 .34259 L
.46295 .3426 L
.46295 .34261 L
.46295 .34262 L
.46294 .34263 L
.46294 .34264 L
Mistroke
.46294 .34265 L
.46293 .34266 L
.46293 .34267 L
.46293 .34268 L
.46292 .34269 L
.46292 .3427 L
.46292 .34272 L
.46291 .34273 L
.46291 .34274 L
.46291 .34275 L
.4629 .34276 L
.4629 .34277 L
.46289 .34278 L
.46289 .34279 L
.46289 .3428 L
.46288 .34281 L
.46288 .34282 L
.46288 .34283 L
.46287 .34284 L
.46287 .34285 L
.46287 .34286 L
.46286 .34287 L
.46286 .34288 L
.46285 .34289 L
.46285 .3429 L
.46285 .34291 L
.46284 .34292 L
.46284 .34293 L
.46284 .34294 L
.46283 .34295 L
.46283 .34296 L
.46283 .34297 L
.46282 .34298 L
.46282 .34299 L
.46281 .343 L
.46281 .34301 L
.46281 .34302 L
.4628 .34303 L
.4628 .34304 L
.46279 .34305 L
.46279 .34306 L
.46279 .34307 L
.46278 .34308 L
.46278 .34309 L
.46278 .3431 L
.46277 .34312 L
.46277 .34313 L
.46276 .34314 L
.46276 .34315 L
.46276 .34316 L
Mistroke
.46275 .34317 L
.46275 .34318 L
.46274 .34319 L
.46274 .3432 L
.46274 .34321 L
.46273 .34322 L
.46273 .34323 L
.46272 .34324 L
.46272 .34325 L
.46272 .34326 L
.46271 .34327 L
.46271 .34328 L
.4627 .34329 L
.4627 .3433 L
.4627 .34331 L
.46269 .34332 L
.46269 .34333 L
.46268 .34334 L
.46268 .34335 L
.46268 .34336 L
.46267 .34337 L
.46267 .34338 L
.46266 .34339 L
.46266 .3434 L
.46265 .34341 L
.46265 .34342 L
.46265 .34343 L
.46264 .34344 L
.46264 .34345 L
.46263 .34346 L
.46263 .34347 L
.46263 .34348 L
.46262 .34349 L
.46262 .3435 L
.46261 .34351 L
.46261 .34352 L
.4626 .34353 L
.4626 .34354 L
.4626 .34355 L
.46259 .34356 L
.46259 .34357 L
.46258 .34358 L
.46258 .34359 L
.46257 .3436 L
.46257 .34361 L
.46257 .34362 L
.46256 .34363 L
.46256 .34364 L
.46255 .34365 L
.46255 .34366 L
Mistroke
.46254 .34367 L
.46254 .34368 L
.46254 .34369 L
.46253 .3437 L
.46253 .34371 L
.46252 .34372 L
.46252 .34373 L
.46251 .34374 L
.46251 .34375 L
.4625 .34376 L
.4625 .34377 L
.4625 .34378 L
.46249 .34379 L
.46249 .3438 L
.46248 .34381 L
.46248 .34382 L
.46247 .34383 L
.46247 .34384 L
.46246 .34385 L
.46246 .34386 L
.46246 .34387 L
.46245 .34388 L
.46245 .34389 L
.46244 .3439 L
.46244 .34391 L
.46243 .34392 L
.46243 .34393 L
.46242 .34394 L
.46242 .34395 L
.46241 .34396 L
.46241 .34397 L
.46241 .34398 L
.4624 .34399 L
.4624 .344 L
.46239 .34401 L
.46239 .34402 L
.46238 .34403 L
.46238 .34404 L
.46237 .34405 L
.46237 .34406 L
.46236 .34407 L
.46236 .34408 L
.46235 .34409 L
.46235 .3441 L
.46234 .34411 L
.46234 .34411 L
.46234 .34412 L
.46233 .34413 L
.46233 .34414 L
.46232 .34415 L
Mistroke
.46232 .34416 L
.46231 .34417 L
.46231 .34418 L
.4623 .34419 L
.4623 .3442 L
.46229 .34421 L
.46229 .34422 L
.46228 .34423 L
.46228 .34424 L
.46227 .34425 L
.46227 .34426 L
.46226 .34427 L
.46226 .34428 L
.46225 .34429 L
.46225 .3443 L
.46224 .34431 L
.46224 .34432 L
.46223 .34433 L
.46223 .34434 L
.46222 .34435 L
.46222 .34436 L
.46221 .34437 L
.46221 .34438 L
.46221 .34439 L
.4622 .3444 L
.4622 .34441 L
.46219 .34442 L
.46219 .34443 L
.46218 .34444 L
.46218 .34445 L
.46217 .34446 L
.46217 .34446 L
.46216 .34447 L
.46216 .34448 L
.46215 .34449 L
.46215 .3445 L
.46214 .34451 L
.46214 .34452 L
.46213 .34453 L
.46213 .34454 L
.46212 .34455 L
.46212 .34456 L
.46211 .34457 L
.46211 .34458 L
.4621 .34459 L
.4621 .3446 L
.46209 .34461 L
.46208 .34462 L
.46208 .34463 L
.46207 .34464 L
Mistroke
.46207 .34465 L
.46206 .34466 L
.46206 .34467 L
.46205 .34468 L
.46205 .34469 L
.46204 .34469 L
.46204 .3447 L
.46203 .34471 L
.46203 .34472 L
.46202 .34473 L
.46202 .34474 L
.46201 .34475 L
.46201 .34476 L
.462 .34477 L
.462 .34478 L
.46199 .34479 L
.46199 .3448 L
.46198 .34481 L
.46198 .34482 L
.46197 .34483 L
.46197 .34484 L
.46196 .34485 L
.46196 .34486 L
.46195 .34487 L
.46195 .34488 L
.46194 .34488 L
.46193 .34489 L
.46193 .3449 L
.46192 .34491 L
.46192 .34492 L
.46191 .34493 L
.46191 .34494 L
.4619 .34495 L
.4619 .34496 L
.46189 .34497 L
.46189 .34498 L
.46188 .34499 L
.46188 .345 L
.46187 .34501 L
.46187 .34502 L
.46186 .34503 L
.46185 .34503 L
.46185 .34504 L
.46184 .34505 L
.46184 .34506 L
.46183 .34507 L
.46183 .34508 L
.46182 .34509 L
.46182 .3451 L
.46181 .34511 L
Mistroke
.46181 .34512 L
.4618 .34513 L
.46179 .34514 L
.46179 .34515 L
.46178 .34516 L
.46178 .34517 L
.46177 .34517 L
.46177 .34518 L
.46176 .34519 L
.46176 .3452 L
.46175 .34521 L
.46175 .34522 L
.46174 .34523 L
.46173 .34524 L
.46173 .34525 L
.46172 .34526 L
.46172 .34527 L
.46171 .34528 L
.46171 .34529 L
.4617 .34529 L
.4617 .3453 L
.46169 .34531 L
.46168 .34532 L
.46168 .34533 L
.46167 .34534 L
.46167 .34535 L
.46166 .34536 L
.46166 .34537 L
.46165 .34538 L
.46165 .34539 L
.46164 .3454 L
.46163 .3454 L
.46163 .34541 L
.46162 .34542 L
.46162 .34543 L
.46161 .34544 L
.46161 .34545 L
.4616 .34546 L
.46159 .34547 L
.46159 .34548 L
.46158 .34549 L
.46158 .3455 L
.46157 .34551 L
.46157 .34551 L
.46156 .34552 L
.46155 .34553 L
.46155 .34554 L
.46154 .34555 L
.46154 .34556 L
.46153 .34557 L
Mistroke
.46153 .34558 L
.46152 .34559 L
.46151 .3456 L
.46151 .3456 L
.4615 .34561 L
.4615 .34562 L
.46149 .34563 L
.46149 .34564 L
.46148 .34565 L
.46147 .34566 L
.46147 .34567 L
.46146 .34568 L
.46146 .34569 L
.46145 .34569 L
.46145 .3457 L
.46144 .34571 L
.46143 .34572 L
.46143 .34573 L
.46142 .34574 L
.46142 .34575 L
.46141 .34576 L
.4614 .34577 L
.4614 .34578 L
.46139 .34578 L
.46139 .34579 L
.46138 .3458 L
.46138 .34581 L
.46137 .34582 L
.46136 .34583 L
.46136 .34584 L
.46135 .34585 L
.46135 .34586 L
.46134 .34586 L
.46133 .34587 L
.46133 .34588 L
.46132 .34589 L
.46132 .3459 L
.46131 .34591 L
.4613 .34592 L
.4613 .34593 L
.46129 .34594 L
.46129 .34594 L
.46128 .34595 L
.46127 .34596 L
.46127 .34597 L
.46126 .34598 L
.46126 .34599 L
.46125 .346 L
.46124 .34601 L
.46124 .34601 L
Mistroke
.46123 .34602 L
.46123 .34603 L
.46122 .34604 L
.46121 .34605 L
.46121 .34606 L
.4612 .34607 L
.4612 .34608 L
.46119 .34608 L
.46118 .34609 L
.46118 .3461 L
.46117 .34611 L
.46117 .34612 L
.46116 .34613 L
.46115 .34614 L
.46115 .34615 L
.46114 .34615 L
.46114 .34616 L
.46113 .34617 L
.46112 .34618 L
.46112 .34619 L
.46111 .3462 L
.46111 .34621 L
.4611 .34621 L
.46109 .34622 L
.46109 .34623 L
.46108 .34624 L
.46107 .34625 L
.46107 .34626 L
.46106 .34627 L
.46106 .34628 L
.46105 .34628 L
.46104 .34629 L
.46104 .3463 L
.46103 .34631 L
.46103 .34632 L
.46102 .34633 L
.46101 .34634 L
.46101 .34634 L
.461 .34635 L
.46099 .34636 L
.46099 .34637 L
.46098 .34638 L
.46098 .34639 L
.46097 .3464 L
.46096 .3464 L
.46096 .34641 L
.46095 .34642 L
.46094 .34643 L
.46094 .34644 L
.46093 .34645 L
Mistroke
.46093 .34645 L
.46092 .34646 L
.46091 .34647 L
.46091 .34648 L
.4609 .34649 L
.4609 .3465 L
.46089 .34651 L
.46088 .34651 L
.46088 .34652 L
.46087 .34653 L
.46086 .34654 L
.46086 .34655 L
.46085 .34656 L
.46084 .34656 L
.46084 .34657 L
.46083 .34658 L
.46083 .34659 L
.46082 .3466 L
.46081 .34661 L
.46081 .34662 L
.4608 .34662 L
.46079 .34663 L
.46079 .34664 L
.46078 .34665 L
.46078 .34666 L
.46077 .34667 L
.46076 .34667 L
.46076 .34668 L
.46075 .34669 L
.46074 .3467 L
.46074 .34671 L
.46073 .34672 L
.46072 .34672 L
.46072 .34673 L
.46071 .34674 L
.46071 .34675 L
.4607 .34676 L
.46069 .34676 L
.46069 .34677 L
.46068 .34678 L
.46067 .34679 L
.46067 .3468 L
.46066 .34681 L
.46065 .34681 L
.46065 .34682 L
.46064 .34683 L
.46063 .34684 L
.46063 .34685 L
.46062 .34686 L
.46062 .34686 L
Mistroke
.46061 .34687 L
.4606 .34688 L
.4606 .34689 L
.46059 .3469 L
.46058 .3469 L
.46058 .34691 L
.46057 .34692 L
.46056 .34693 L
.46056 .34694 L
.46055 .34695 L
.46054 .34695 L
.46054 .34696 L
.46053 .34697 L
.46052 .34698 L
.46052 .34699 L
.46051 .34699 L
.46051 .347 L
.4605 .34701 L
.46049 .34702 L
.46049 .34703 L
.46048 .34703 L
.46047 .34704 L
.46047 .34705 L
.46046 .34706 L
.46045 .34707 L
.46045 .34707 L
.46044 .34708 L
.46043 .34709 L
.46043 .3471 L
.46042 .34711 L
.46041 .34711 L
.46041 .34712 L
.4604 .34713 L
.46039 .34714 L
.46039 .34715 L
.46038 .34715 L
.46037 .34716 L
.46037 .34717 L
.46036 .34718 L
.46035 .34719 L
.46035 .34719 L
.46034 .3472 L
.46034 .34721 L
.46033 .34722 L
.46032 .34723 L
.46032 .34723 L
.46031 .34724 L
.4603 .34725 L
.4603 .34726 L
.46029 .34727 L
Mistroke
.46028 .34727 L
.46028 .34728 L
.46027 .34729 L
.46026 .3473 L
.46026 .3473 L
.46025 .34731 L
.46024 .34732 L
.46024 .34733 L
.46023 .34734 L
.46022 .34734 L
.46022 .34735 L
.46021 .34736 L
.4602 .34737 L
.4602 .34738 L
.46019 .34738 L
.46018 .34739 L
.46018 .3474 L
.46017 .34741 L
.46016 .34741 L
.46016 .34742 L
.46015 .34743 L
.46014 .34744 L
.46014 .34745 L
.46013 .34745 L
.46012 .34746 L
.46012 .34747 L
.46011 .34748 L
.4601 .34748 L
.4601 .34749 L
.46009 .3475 L
.46008 .34751 L
.46008 .34751 L
.46007 .34752 L
.46006 .34753 L
.46006 .34754 L
.46005 .34755 L
.46004 .34755 L
.46004 .34756 L
.46003 .34757 L
.46002 .34758 L
.46002 .34758 L
.46001 .34759 L
.46 .3476 L
.45999 .34761 L
.45999 .34761 L
.45998 .34762 L
.45997 .34763 L
.45997 .34764 L
.45996 .34764 L
.45995 .34765 L
Mistroke
.45995 .34766 L
.45994 .34767 L
.45993 .34767 L
.45993 .34768 L
.45992 .34769 L
.45991 .3477 L
.45991 .3477 L
.4599 .34771 L
.45989 .34772 L
.45989 .34773 L
.45988 .34773 L
.45987 .34774 L
.45987 .34775 L
.45986 .34776 L
.45985 .34776 L
.45985 .34777 L
.45984 .34778 L
.45983 .34779 L
.45983 .34779 L
.45982 .3478 L
.45981 .34781 L
.4598 .34782 L
.4598 .34782 L
.45979 .34783 L
.45978 .34784 L
.45978 .34785 L
.45977 .34785 L
.45976 .34786 L
.45976 .34787 L
.45975 .34788 L
.45974 .34788 L
.45974 .34789 L
.45973 .3479 L
.45972 .34791 L
.45972 .34791 L
.45971 .34792 L
.4597 .34793 L
.4597 .34793 L
.45969 .34794 L
.45968 .34795 L
.45967 .34796 L
.45967 .34796 L
.45966 .34797 L
.45965 .34798 L
.45965 .34799 L
.45964 .34799 L
.45963 .348 L
.45963 .34801 L
.45962 .34801 L
.45961 .34802 L
Mistroke
.45961 .34803 L
.4596 .34804 L
.45959 .34804 L
.45959 .34805 L
.45958 .34806 L
.45957 .34807 L
.45956 .34807 L
.45956 .34808 L
.45955 .34809 L
.45954 .34809 L
.45954 .3481 L
.45953 .34811 L
.45952 .34812 L
.45952 .34812 L
.45951 .34813 L
.4595 .34814 L
.4595 .34814 L
.45949 .34815 L
.45948 .34816 L
.45947 .34817 L
.45947 .34817 L
.45946 .34818 L
.45945 .34819 L
.45945 .34819 L
.45944 .3482 L
.45943 .34821 L
.45943 .34822 L
.45942 .34822 L
.45941 .34823 L
.45941 .34824 L
.4594 .34824 L
.45939 .34825 L
.45938 .34826 L
.45938 .34826 L
.45937 .34827 L
.45936 .34828 L
.45936 .34829 L
.45935 .34829 L
.45934 .3483 L
.45934 .34831 L
.45933 .34831 L
.45932 .34832 L
.45931 .34833 L
.45931 .34833 L
.4593 .34834 L
.45929 .34835 L
.45929 .34836 L
.45928 .34836 L
.45927 .34837 L
.45927 .34838 L
Mistroke
.45926 .34838 L
.45925 .34839 L
.45924 .3484 L
.45924 .3484 L
.45923 .34841 L
.45922 .34842 L
.45922 .34842 L
.45921 .34843 L
.4592 .34844 L
.4592 .34844 L
.45919 .34845 L
.45918 .34846 L
.45917 .34847 L
.45917 .34847 L
.45916 .34848 L
.45915 .34849 L
.45915 .34849 L
.45914 .3485 L
.45913 .34851 L
.45913 .34851 L
.45912 .34852 L
.45911 .34853 L
.4591 .34853 L
.4591 .34854 L
.45909 .34855 L
.45908 .34855 L
.45908 .34856 L
.45907 .34857 L
.45906 .34857 L
.45906 .34858 L
.45905 .34859 L
.45904 .34859 L
.45903 .3486 L
.45903 .34861 L
.45902 .34861 L
.45901 .34862 L
.45901 .34863 L
.459 .34863 L
.45899 .34864 L
.45899 .34865 L
.45898 .34865 L
.45897 .34866 L
.45896 .34867 L
.45896 .34867 L
.45895 .34868 L
.45894 .34869 L
.45894 .34869 L
.45893 .3487 L
.45892 .34871 L
.45891 .34871 L
Mistroke
.45891 .34872 L
.4589 .34873 L
.45889 .34873 L
.45889 .34874 L
.45888 .34875 L
.45887 .34875 L
.45887 .34876 L
.45886 .34877 L
.45885 .34877 L
.45884 .34878 L
.45884 .34878 L
.45883 .34879 L
.45882 .3488 L
.45882 .3488 L
.45881 .34881 L
.4588 .34882 L
.45879 .34882 L
.45879 .34883 L
.45878 .34884 L
.45877 .34884 L
.45877 .34885 L
.45876 .34886 L
.45875 .34886 L
.45875 .34887 L
.45874 .34888 L
.45873 .34888 L
.45872 .34889 L
.45872 .34889 L
.45871 .3489 L
.4587 .34891 L
.4587 .34891 L
.45869 .34892 L
.45868 .34893 L
.45867 .34893 L
.45867 .34894 L
.45866 .34895 L
.45865 .34895 L
.45865 .34896 L
.45864 .34896 L
.45863 .34897 L
.45862 .34898 L
.45862 .34898 L
.45861 .34899 L
.4586 .349 L
.4586 .349 L
.45859 .34901 L
.45858 .34901 L
.45858 .34902 L
.45857 .34903 L
.45856 .34903 L
Mistroke
.45855 .34904 L
.45855 .34905 L
.45854 .34905 L
.45853 .34906 L
.45853 .34906 L
.45852 .34907 L
.45851 .34908 L
.4585 .34908 L
.4585 .34909 L
.45849 .34909 L
.45848 .3491 L
.45848 .34911 L
.45847 .34911 L
.45846 .34912 L
.45845 .34913 L
.45845 .34913 L
.45844 .34914 L
.45843 .34914 L
.45843 .34915 L
.45842 .34916 L
.45841 .34916 L
.4584 .34917 L
.4584 .34917 L
.45839 .34918 L
.45838 .34919 L
.45838 .34919 L
.45837 .3492 L
.45836 .3492 L
.45835 .34921 L
.45835 .34922 L
.45834 .34922 L
.45833 .34923 L
.45833 .34923 L
.45832 .34924 L
.45831 .34925 L
.4583 .34925 L
.4583 .34926 L
.45829 .34926 L
.45828 .34927 L
.45828 .34928 L
.45827 .34928 L
.45826 .34929 L
.45826 .34929 L
.45825 .3493 L
.45824 .34931 L
.45823 .34931 L
.45823 .34932 L
.45822 .34932 L
.45821 .34933 L
.45821 .34934 L
Mistroke
.4582 .34934 L
.45819 .34935 L
.45818 .34935 L
.45818 .34936 L
.45817 .34937 L
.45816 .34937 L
.45816 .34938 L
.45815 .34938 L
.45814 .34939 L
.45813 .34939 L
.45813 .3494 L
.45812 .34941 L
.45811 .34941 L
.45811 .34942 L
.4581 .34942 L
.45809 .34943 L
.45808 .34943 L
.45808 .34944 L
.45807 .34945 L
.45806 .34945 L
.45806 .34946 L
.45805 .34946 L
.45804 .34947 L
.45803 .34948 L
.45803 .34948 L
.45802 .34949 L
.45801 .34949 L
.45801 .3495 L
.458 .3495 L
.45799 .34951 L
.45798 .34952 L
.45798 .34952 L
.45797 .34953 L
.45796 .34953 L
.45796 .34954 L
.45795 .34954 L
.45794 .34955 L
.45793 .34955 L
.45793 .34956 L
.45792 .34957 L
.45791 .34957 L
.45791 .34958 L
.4579 .34958 L
.45789 .34959 L
.45788 .34959 L
.45788 .3496 L
.45787 .3496 L
.45786 .34961 L
.45786 .34962 L
.45785 .34962 L
Mistroke
.45784 .34963 L
.45783 .34963 L
.45783 .34964 L
.45782 .34964 L
.45781 .34965 L
.45781 .34965 L
.4578 .34966 L
.45779 .34967 L
.45779 .34967 L
.45778 .34968 L
.45777 .34968 L
.45776 .34969 L
.45776 .34969 L
.45775 .3497 L
.45774 .3497 L
.45774 .34971 L
.45773 .34971 L
.45772 .34972 L
.45771 .34973 L
.45771 .34973 L
.4577 .34974 L
.45769 .34974 L
.45769 .34975 L
.45768 .34975 L
.45767 .34976 L
.45766 .34976 L
.45766 .34977 L
.45765 .34977 L
.45764 .34978 L
.45764 .34978 L
.45763 .34979 L
.45762 .3498 L
.45761 .3498 L
.45761 .34981 L
.4576 .34981 L
.45759 .34982 L
.45759 .34982 L
.45758 .34983 L
.45757 .34983 L
.45756 .34984 L
.45756 .34984 L
.45755 .34985 L
.45754 .34985 L
.45754 .34986 L
.45753 .34986 L
.45752 .34987 L
.45751 .34987 L
.45751 .34988 L
.4575 .34988 L
.45749 .34989 L
Mistroke
.45749 .3499 L
.45748 .3499 L
.45747 .34991 L
.45747 .34991 L
.45746 .34992 L
.45745 .34992 L
.45744 .34993 L
.45744 .34993 L
.45743 .34994 L
.45742 .34994 L
.45742 .34995 L
.45741 .34995 L
.4574 .34996 L
.45739 .34996 L
.45739 .34997 L
.45738 .34997 L
.45737 .34998 L
.45737 .34998 L
.45736 .34999 L
.45735 .34999 L
.45734 .35 L
.45734 .35 L
.45733 .35001 L
.45732 .35001 L
.45732 .35002 L
.45731 .35002 L
.4573 .35003 L
.45729 .35003 L
.45729 .35004 L
.45728 .35004 L
.45727 .35005 L
.45727 .35005 L
.45726 .35006 L
.45725 .35006 L
.45725 .35007 L
.45724 .35007 L
.45723 .35008 L
.45722 .35008 L
.45722 .35009 L
.45721 .35009 L
.4572 .3501 L
.4572 .3501 L
.45719 .35011 L
.45718 .35011 L
.45717 .35012 L
.45717 .35012 L
.45716 .35013 L
.45715 .35013 L
.45715 .35014 L
.45714 .35014 L
Mistroke
.45713 .35015 L
.45713 .35015 L
.45712 .35016 L
.45711 .35016 L
.4571 .35017 L
.4571 .35017 L
.45709 .35018 L
.45708 .35018 L
.45708 .35018 L
.45707 .35019 L
.45706 .35019 L
.45705 .3502 L
.45705 .3502 L
.45704 .35021 L
.45703 .35021 L
.45703 .35022 L
.45702 .35022 L
.45701 .35023 L
.45701 .35023 L
.457 .35024 L
.45699 .35024 L
.45698 .35025 L
.45698 .35025 L
.45697 .35026 L
.45696 .35026 L
.45696 .35027 L
.45695 .35027 L
.45694 .35027 L
.45694 .35028 L
.45693 .35028 L
.45692 .35029 L
.45691 .35029 L
.45691 .3503 L
.4569 .3503 L
.45689 .35031 L
.45689 .35031 L
.45688 .35032 L
.45687 .35032 L
.45687 .35033 L
.45686 .35033 L
.45685 .35033 L
.45684 .35034 L
.45684 .35034 L
.45683 .35035 L
.45682 .35035 L
.45682 .35036 L
.45681 .35036 L
.4568 .35037 L
.45679 .35037 L
.45679 .35038 L
Mistroke
.45678 .35038 L
.45677 .35038 L
.45677 .35039 L
.45676 .35039 L
.45675 .3504 L
.45675 .3504 L
.45674 .35041 L
.45673 .35041 L
.45673 .35042 L
.45672 .35042 L
.45671 .35042 L
.4567 .35043 L
.4567 .35043 L
.45669 .35044 L
.45668 .35044 L
.45668 .35045 L
.45667 .35045 L
.45666 .35046 L
.45666 .35046 L
.45665 .35046 L
.45664 .35047 L
.45663 .35047 L
.45663 .35048 L
.45662 .35048 L
.45661 .35049 L
.45661 .35049 L
.4566 .35049 L
.45659 .3505 L
.45659 .3505 L
.45658 .35051 L
.45657 .35051 L
.45656 .35052 L
.45656 .35052 L
.45655 .35052 L
.45654 .35053 L
.45654 .35053 L
.45653 .35054 L
.45652 .35054 L
.45652 .35055 L
.45651 .35055 L
.4565 .35055 L
.4565 .35056 L
.45649 .35056 L
.45648 .35057 L
.45647 .35057 L
.45647 .35058 L
.45646 .35058 L
.45645 .35058 L
.45645 .35059 L
.45644 .35059 L
Mistroke
.45643 .3506 L
.45643 .3506 L
.45642 .3506 L
.45641 .35061 L
.45641 .35061 L
.4564 .35062 L
.45639 .35062 L
.45638 .35063 L
.45638 .35063 L
.45637 .35063 L
.45636 .35064 L
.45636 .35064 L
.45635 .35065 L
.45634 .35065 L
.45634 .35065 L
.45633 .35066 L
.45632 .35066 L
.45632 .35067 L
.45631 .35067 L
.4563 .35067 L
.4563 .35068 L
.45629 .35068 L
.45628 .35069 L
.45627 .35069 L
.45627 .35069 L
.45626 .3507 L
.45625 .3507 L
.45625 .35071 L
.45624 .35071 L
.45623 .35071 L
.45623 .35072 L
.45622 .35072 L
.45621 .35073 L
.45621 .35073 L
.4562 .35073 L
.45619 .35074 L
.45619 .35074 L
.45618 .35075 L
.45617 .35075 L
.45616 .35075 L
.45616 .35076 L
.45615 .35076 L
.45614 .35077 L
.45614 .35077 L
.45613 .35077 L
.45612 .35078 L
.45612 .35078 L
.45611 .35078 L
.4561 .35079 L
.4561 .35079 L
Mistroke
.45609 .3508 L
.45608 .3508 L
.45608 .3508 L
.45607 .35081 L
.45606 .35081 L
.45606 .35082 L
.45605 .35082 L
.45604 .35082 L
.45603 .35083 L
.45603 .35083 L
.45602 .35083 L
.45601 .35084 L
.45601 .35084 L
.456 .35085 L
.45599 .35085 L
.45599 .35085 L
.45598 .35086 L
.45597 .35086 L
.45597 .35086 L
.45596 .35087 L
.45595 .35087 L
.45595 .35088 L
.45594 .35088 L
.45593 .35088 L
.45593 .35089 L
.45592 .35089 L
.45591 .35089 L
.45591 .3509 L
.4559 .3509 L
.45589 .3509 L
.45589 .35091 L
.45588 .35091 L
.45587 .35092 L
.45587 .35092 L
.45586 .35092 L
.45585 .35093 L
.45585 .35093 L
.45584 .35093 L
.45583 .35094 L
.45583 .35094 L
.45582 .35094 L
.45581 .35095 L
.4558 .35095 L
.4558 .35095 L
.45579 .35096 L
.45578 .35096 L
.45578 .35097 L
.45577 .35097 L
.45576 .35097 L
.45576 .35098 L
Mistroke
.45575 .35098 L
.45574 .35098 L
.45574 .35099 L
.45573 .35099 L
.45572 .35099 L
.45572 .351 L
.45571 .351 L
.4557 .351 L
.4557 .35101 L
.45569 .35101 L
.45568 .35101 L
.45568 .35102 L
.45567 .35102 L
.45566 .35102 L
.45566 .35103 L
.45565 .35103 L
.45564 .35103 L
.45564 .35104 L
.45563 .35104 L
.45562 .35104 L
.45562 .35105 L
.45561 .35105 L
.4556 .35105 L
.4556 .35106 L
.45559 .35106 L
.45558 .35106 L
.45558 .35107 L
.45557 .35107 L
.45556 .35107 L
.45556 .35108 L
.45555 .35108 L
.45554 .35108 L
.45554 .35109 L
.45553 .35109 L
.45552 .35109 L
.45552 .3511 L
.45551 .3511 L
.4555 .3511 L
.4555 .35111 L
.45549 .35111 L
.45548 .35111 L
.45548 .35112 L
.45547 .35112 L
.45546 .35112 L
.45546 .35113 L
.45545 .35113 L
.45544 .35113 L
.45544 .35114 L
.45543 .35114 L
.45543 .35114 L
Mistroke
.45542 .35115 L
.45541 .35115 L
.45541 .35115 L
.4554 .35116 L
.45539 .35116 L
.45539 .35116 L
.45538 .35117 L
.45537 .35117 L
.45537 .35117 L
.45536 .35117 L
.45535 .35118 L
.45535 .35118 L
.45534 .35118 L
.45533 .35119 L
.45533 .35119 L
.45532 .35119 L
.45531 .3512 L
.45531 .3512 L
.4553 .3512 L
.45529 .35121 L
.45529 .35121 L
.45528 .35121 L
.45527 .35121 L
.45527 .35122 L
.45526 .35122 L
.45525 .35122 L
.45525 .35123 L
.45524 .35123 L
.45524 .35123 L
.45523 .35124 L
.45522 .35124 L
.45522 .35124 L
.45521 .35124 L
.4552 .35125 L
.4552 .35125 L
.45519 .35125 L
.45518 .35126 L
.45518 .35126 L
.45517 .35126 L
.45516 .35127 L
.45516 .35127 L
.45515 .35127 L
.45514 .35127 L
.45514 .35128 L
.45513 .35128 L
.45513 .35128 L
.45512 .35129 L
.45511 .35129 L
.45511 .35129 L
.4551 .35129 L
Mistroke
.45509 .3513 L
.45509 .3513 L
.45508 .3513 L
.45507 .35131 L
.45507 .35131 L
.45506 .35131 L
.45505 .35131 L
.45505 .35132 L
.45504 .35132 L
.45503 .35132 L
.45503 .35133 L
.45502 .35133 L
.45502 .35133 L
.45501 .35133 L
.455 .35134 L
.455 .35134 L
.45499 .35134 L
.45498 .35134 L
.45498 .35135 L
.45497 .35135 L
.45496 .35135 L
.45496 .35136 L
.45495 .35136 L
.45495 .35136 L
.45494 .35136 L
.45493 .35137 L
.45493 .35137 L
.45492 .35137 L
.45491 .35137 L
.45491 .35138 L
.4549 .35138 L
.45489 .35138 L
.45489 .35138 L
.45488 .35139 L
.45488 .35139 L
.45487 .35139 L
.45486 .3514 L
.45486 .3514 L
.45485 .3514 L
.45484 .3514 L
.45484 .35141 L
.45483 .35141 L
.45482 .35141 L
.45482 .35141 L
.45481 .35142 L
.45481 .35142 L
.4548 .35142 L
.45479 .35142 L
.45479 .35143 L
.45478 .35143 L
Mistroke
.45477 .35143 L
.45477 .35143 L
.45476 .35144 L
.45476 .35144 L
.45475 .35144 L
.45474 .35144 L
.45474 .35145 L
.45473 .35145 L
.45472 .35145 L
.45472 .35145 L
.45471 .35146 L
.45471 .35146 L
.4547 .35146 L
.45469 .35146 L
.45469 .35147 L
.45468 .35147 L
.45467 .35147 L
.45467 .35147 L
.45466 .35148 L
.45466 .35148 L
.45465 .35148 L
.45464 .35148 L
.45464 .35149 L
.45463 .35149 L
.45462 .35149 L
.45462 .35149 L
.45461 .3515 L
.45461 .3515 L
.4546 .3515 L
.45459 .3515 L
.45459 .35151 L
.45458 .35151 L
.45457 .35151 L
.45457 .35151 L
.45456 .35151 L
.45456 .35152 L
.45455 .35152 L
.45454 .35152 L
.45454 .35152 L
.45453 .35153 L
.45453 .35153 L
.45452 .35153 L
.45451 .35153 L
.45451 .35154 L
.4545 .35154 L
.45449 .35154 L
.45449 .35154 L
.45448 .35154 L
.45448 .35155 L
.45447 .35155 L
Mistroke
.45446 .35155 L
.45446 .35155 L
.45445 .35156 L
.45445 .35156 L
.45444 .35156 L
.45443 .35156 L
.45443 .35156 L
.45442 .35157 L
.45441 .35157 L
.45441 .35157 L
.4544 .35157 L
.4544 .35158 L
.45439 .35158 L
.45438 .35158 L
.45438 .35158 L
.45437 .35158 L
.45437 .35159 L
.45436 .35159 L
.45435 .35159 L
.45435 .35159 L
.45434 .35159 L
.45434 .3516 L
.45433 .3516 L
.45432 .3516 L
.45432 .3516 L
.45431 .3516 L
.45431 .35161 L
.4543 .35161 L
.45429 .35161 L
.45429 .35161 L
.45428 .35162 L
.45428 .35162 L
.45427 .35162 L
.45426 .35162 L
.45426 .35162 L
.45425 .35163 L
.45425 .35163 L
.45424 .35163 L
.45423 .35163 L
.45423 .35163 L
.45422 .35164 L
.45422 .35164 L
.45421 .35164 L
.4542 .35164 L
.4542 .35164 L
.45419 .35165 L
.45419 .35165 L
.45418 .35165 L
.45417 .35165 L
.45417 .35165 L
Mistroke
.45416 .35166 L
.45416 .35166 L
.45415 .35166 L
.45414 .35166 L
.45414 .35166 L
.45413 .35166 L
.45413 .35167 L
.45412 .35167 L
.45411 .35167 L
.45411 .35167 L
.4541 .35167 L
.4541 .35168 L
.45409 .35168 L
.45408 .35168 L
.45408 .35168 L
.45407 .35168 L
.45407 .35169 L
.45406 .35169 L
.45405 .35169 L
.45405 .35169 L
.45404 .35169 L
.45404 .35169 L
.45403 .3517 L
.45403 .3517 L
.45402 .3517 L
.45401 .3517 L
.45401 .3517 L
.454 .35171 L
.454 .35171 L
.45399 .35171 L
.45398 .35171 L
.45398 .35171 L
.45397 .35171 L
.45397 .35172 L
.45396 .35172 L
.45395 .35172 L
.45395 .35172 L
.45394 .35172 L
.45394 .35172 L
.45393 .35173 L
.45393 .35173 L
.45392 .35173 L
.45391 .35173 L
.45391 .35173 L
.4539 .35173 L
.4539 .35174 L
.45389 .35174 L
.45389 .35174 L
.45388 .35174 L
.45387 .35174 L
Mistroke
.45387 .35174 L
.45386 .35175 L
.45386 .35175 L
.45385 .35175 L
.45384 .35175 L
.45384 .35175 L
.45383 .35175 L
.45383 .35176 L
.45382 .35176 L
.45382 .35176 L
.45381 .35176 L
.4538 .35176 L
.4538 .35176 L
.45379 .35177 L
.45379 .35177 L
.45378 .35177 L
.45378 .35177 L
.45377 .35177 L
.45376 .35177 L
.45376 .35177 L
.45375 .35178 L
.45375 .35178 L
.45374 .35178 L
.45374 .35178 L
.45373 .35178 L
.45372 .35178 L
.45372 .35179 L
.45371 .35179 L
.45371 .35179 L
.4537 .35179 L
.4537 .35179 L
.45369 .35179 L
.45369 .35179 L
.45368 .3518 L
.45367 .3518 L
.45367 .3518 L
.45366 .3518 L
.45366 .3518 L
.45365 .3518 L
.45365 .3518 L
.45364 .35181 L
.45363 .35181 L
.45363 .35181 L
.45362 .35181 L
.45362 .35181 L
.45361 .35181 L
.45361 .35181 L
.4536 .35182 L
.4536 .35182 L
.45359 .35182 L
Mistroke
.45358 .35182 L
.45358 .35182 L
.45357 .35182 L
.45357 .35182 L
.45356 .35183 L
.45356 .35183 L
.45355 .35183 L
.45354 .35183 L
.45354 .35183 L
.45353 .35183 L
.45353 .35183 L
.45352 .35183 L
.45352 .35184 L
.45351 .35184 L
.45351 .35184 L
.4535 .35184 L
.4535 .35184 L
.45349 .35184 L
.45348 .35184 L
.45348 .35184 L
.45347 .35185 L
.45347 .35185 L
.45346 .35185 L
.45346 .35185 L
.45345 .35185 L
.45345 .35185 L
.45344 .35185 L
.45343 .35185 L
.45343 .35186 L
.45342 .35186 L
.45342 .35186 L
.45341 .35186 L
.45341 .35186 L
.4534 .35186 L
.4534 .35186 L
.45339 .35186 L
.45339 .35187 L
.45338 .35187 L
.45337 .35187 L
.45337 .35187 L
.45336 .35187 L
.45336 .35187 L
.45335 .35187 L
.45335 .35187 L
.45334 .35187 L
.45334 .35188 L
.45333 .35188 L
.45333 .35188 L
.45332 .35188 L
.45331 .35188 L
Mistroke
.45331 .35188 L
.4533 .35188 L
.4533 .35188 L
.45329 .35188 L
.45329 .35189 L
.45328 .35189 L
.45328 .35189 L
.45327 .35189 L
.45327 .35189 L
.45326 .35189 L
.45326 .35189 L
.45325 .35189 L
.45325 .35189 L
.45324 .3519 L
.45323 .3519 L
.45323 .3519 L
.45322 .3519 L
.45322 .3519 L
.45321 .3519 L
.45321 .3519 L
.4532 .3519 L
.4532 .3519 L
.45319 .3519 L
.45319 .35191 L
.45318 .35191 L
.45318 .35191 L
.45317 .35191 L
.45317 .35191 L
.45316 .35191 L
.45316 .35191 L
.45315 .35191 L
.45314 .35191 L
.45314 .35191 L
.45313 .35191 L
.45313 .35192 L
.45312 .35192 L
.45312 .35192 L
.45311 .35192 L
.45311 .35192 L
.4531 .35192 L
.4531 .35192 L
.45309 .35192 L
.45309 .35192 L
.45308 .35192 L
.45308 .35192 L
.45307 .35193 L
.45307 .35193 L
.45306 .35193 L
.45306 .35193 L
.45305 .35193 L
Mistroke
.45305 .35193 L
.45304 .35193 L
.45303 .35193 L
.45303 .35193 L
.45302 .35193 L
.45302 .35193 L
.45301 .35193 L
.45301 .35194 L
.453 .35194 L
.453 .35194 L
.45299 .35194 L
.45299 .35194 L
.45298 .35194 L
.45298 .35194 L
.45297 .35194 L
.45297 .35194 L
.45296 .35194 L
.45296 .35194 L
.45295 .35194 L
.45295 .35194 L
.45294 .35195 L
.45294 .35195 L
.45293 .35195 L
.45293 .35195 L
.45292 .35195 L
.45292 .35195 L
.45291 .35195 L
.45291 .35195 L
.4529 .35195 L
.4529 .35195 L
.45289 .35195 L
.45289 .35195 L
.45288 .35195 L
.45288 .35195 L
.45287 .35196 L
.45287 .35196 L
.45286 .35196 L
.45286 .35196 L
.45285 .35196 L
.45285 .35196 L
.45284 .35196 L
.45284 .35196 L
.45283 .35196 L
.45283 .35196 L
.45282 .35196 L
.45282 .35196 L
.45281 .35196 L
.45281 .35196 L
.4528 .35196 L
.4528 .35196 L
Mistroke
.45279 .35197 L
.45279 .35197 L
.45278 .35197 L
.45278 .35197 L
.45277 .35197 L
.45277 .35197 L
.45276 .35197 L
.45276 .35197 L
.45275 .35197 L
.45275 .35197 L
.45274 .35197 L
.45274 .35197 L
.45273 .35197 L
.45273 .35197 L
.45272 .35197 L
.45272 .35197 L
.45271 .35197 L
.45271 .35197 L
.4527 .35197 L
.4527 .35198 L
.45269 .35198 L
.45269 .35198 L
.45268 .35198 L
.45268 .35198 L
.45267 .35198 L
.45267 .35198 L
.45266 .35198 L
.45266 .35198 L
.45265 .35198 L
.45265 .35198 L
.45264 .35198 L
.45264 .35198 L
.45263 .35198 L
.45263 .35198 L
.45262 .35198 L
.45262 .35198 L
.45262 .35198 L
.45261 .35198 L
.45261 .35198 L
.4526 .35198 L
.4526 .35198 L
.45259 .35199 L
.45259 .35199 L
.45258 .35199 L
.45258 .35199 L
.45257 .35199 L
.45257 .35199 L
.45256 .35199 L
.45256 .35199 L
.45255 .35199 L
Mistroke
.45255 .35199 L
.45254 .35199 L
.45254 .35199 L
.45253 .35199 L
.45253 .35199 L
.45252 .35199 L
.45252 .35199 L
.45251 .35199 L
.45251 .35199 L
.45251 .35199 L
.4525 .35199 L
.4525 .35199 L
.45249 .35199 L
.45249 .35199 L
.45248 .35199 L
.45248 .35199 L
.45247 .35199 L
.45247 .35199 L
.45246 .35199 L
.45246 .35199 L
.45245 .35199 L
.45245 .35199 L
.45244 .35199 L
.45244 .352 L
.45244 .352 L
.45243 .352 L
.45243 .352 L
.45242 .352 L
.45242 .352 L
.45241 .352 L
.45241 .352 L
.4524 .352 L
.4524 .352 L
.45239 .352 L
.45239 .352 L
.45238 .352 L
.45238 .352 L
.45237 .352 L
.45237 .352 L
.45237 .352 L
.45236 .352 L
.45236 .352 L
.45235 .352 L
.45235 .352 L
.45234 .352 L
.45234 .352 L
.45233 .352 L
.45233 .352 L
.45232 .352 L
.45232 .352 L
Mistroke
.45232 .352 L
.45231 .352 L
.45231 .352 L
.4523 .352 L
.4523 .352 L
.45229 .352 L
.45229 .352 L
.45228 .352 L
.45228 .352 L
.45227 .352 L
.45227 .352 L
.45227 .352 L
.45226 .352 L
.45226 .352 L
.45225 .352 L
.45225 .352 L
.45224 .352 L
.45224 .352 L
.45223 .352 L
.45223 .352 L
.45223 .352 L
.45222 .352 L
.45222 .352 L
.45221 .352 L
.45221 .352 L
.4522 .352 L
.4522 .352 L
.45219 .352 L
.45219 .352 L
.45219 .352 L
.45218 .352 L
.45218 .352 L
.45217 .352 L
.45217 .352 L
.45216 .352 L
.45216 .352 L
.45215 .352 L
.45215 .352 L
.45215 .352 L
.45214 .352 L
.45214 .352 L
.45213 .352 L
.45213 .352 L
.45212 .352 L
.45212 .352 L
.45212 .352 L
.45211 .352 L
.45211 .352 L
.4521 .352 L
.4521 .352 L
Mistroke
.45209 .352 L
.45209 .352 L
.45209 .352 L
.45208 .352 L
.45208 .352 L
.45207 .352 L
.45207 .352 L
.45206 .352 L
.45206 .352 L
.45206 .352 L
.45205 .352 L
.45205 .352 L
.45204 .352 L
.45204 .352 L
.45203 .352 L
.45203 .352 L
.45203 .352 L
.45202 .352 L
.45202 .352 L
.45201 .352 L
.45201 .352 L
.452 .352 L
.452 .352 L
.452 .352 L
.45199 .352 L
.45199 .352 L
.45198 .352 L
.45198 .352 L
.45197 .352 L
.45197 .352 L
.45197 .352 L
.45196 .35199 L
.45196 .35199 L
.45195 .35199 L
.45195 .35199 L
.45195 .35199 L
.45194 .35199 L
.45194 .35199 L
.45193 .35199 L
.45193 .35199 L
.45192 .35199 L
.45192 .35199 L
.45192 .35199 L
.45191 .35199 L
.45191 .35199 L
.4519 .35199 L
.4519 .35199 L
.4519 .35199 L
.45189 .35199 L
.45189 .35199 L
Mistroke
.45188 .35199 L
.45188 .35199 L
.45188 .35199 L
.45187 .35199 L
.45187 .35199 L
.45186 .35199 L
.45186 .35199 L
.45185 .35199 L
.45185 .35199 L
.45185 .35199 L
.45184 .35199 L
.45184 .35199 L
.45183 .35199 L
.45183 .35199 L
.45183 .35199 L
.45182 .35198 L
.45182 .35198 L
.45181 .35198 L
.45181 .35198 L
.45181 .35198 L
.4518 .35198 L
.4518 .35198 L
.45179 .35198 L
.45179 .35198 L
.45179 .35198 L
.45178 .35198 L
.45178 .35198 L
.45177 .35198 L
.45177 .35198 L
.45177 .35198 L
.45176 .35198 L
.45176 .35198 L
.45175 .35198 L
.45175 .35198 L
.45175 .35198 L
.45174 .35198 L
.45174 .35198 L
.45173 .35198 L
.45173 .35198 L
.45173 .35197 L
.45172 .35197 L
.45172 .35197 L
.45172 .35197 L
.45171 .35197 L
.45171 .35197 L
.4517 .35197 L
.4517 .35197 L
.4517 .35197 L
.45169 .35197 L
.45169 .35197 L
Mistroke
.45168 .35197 L
.45168 .35197 L
.45168 .35197 L
.45167 .35197 L
.45167 .35197 L
.45166 .35197 L
.45166 .35197 L
.45166 .35197 L
.45165 .35197 L
.45165 .35196 L
.45165 .35196 L
.45164 .35196 L
.45164 .35196 L
.45163 .35196 L
.45163 .35196 L
.45163 .35196 L
.45162 .35196 L
.45162 .35196 L
.45162 .35196 L
.45161 .35196 L
.45161 .35196 L
.4516 .35196 L
.4516 .35196 L
.4516 .35196 L
.45159 .35196 L
.45159 .35196 L
.45158 .35195 L
.45158 .35195 L
.45158 .35195 L
.45157 .35195 L
.45157 .35195 L
.45157 .35195 L
.45156 .35195 L
.45156 .35195 L
.45155 .35195 L
.45155 .35195 L
.45155 .35195 L
.45154 .35195 L
.45154 .35195 L
.45154 .35195 L
.45153 .35195 L
.45153 .35195 L
.45153 .35194 L
.45152 .35194 L
.45152 .35194 L
.45151 .35194 L
.45151 .35194 L
.45151 .35194 L
.4515 .35194 L
.4515 .35194 L
Mistroke
.4515 .35194 L
.45149 .35194 L
.45149 .35194 L
.45149 .35194 L
.45148 .35194 L
.45148 .35194 L
.45147 .35193 L
.45147 .35193 L
.45147 .35193 L
.45146 .35193 L
.45146 .35193 L
.45146 .35193 L
.45145 .35193 L
.45145 .35193 L
.45145 .35193 L
.45144 .35193 L
.45144 .35193 L
.45143 .35193 L
.45143 .35193 L
.45143 .35193 L
.45142 .35192 L
.45142 .35192 L
.45142 .35192 L
.45141 .35192 L
.45141 .35192 L
.45141 .35192 L
.4514 .35192 L
.4514 .35192 L
.4514 .35192 L
.45139 .35192 L
.45139 .35192 L
.45138 .35192 L
.45138 .35192 L
.45138 .35191 L
.45137 .35191 L
.45137 .35191 L
.45137 .35191 L
.45136 .35191 L
.45136 .35191 L
.45136 .35191 L
.45135 .35191 L
.45135 .35191 L
.45135 .35191 L
.45134 .35191 L
.45134 .35191 L
.45134 .3519 L
.45133 .3519 L
.45133 .3519 L
.45133 .3519 L
.45132 .3519 L
Mistroke
.45132 .3519 L
.45132 .3519 L
.45131 .3519 L
.45131 .3519 L
.45131 .3519 L
.4513 .3519 L
.4513 .35189 L
.4513 .35189 L
.45129 .35189 L
.45129 .35189 L
.45128 .35189 L
.45128 .35189 L
.45128 .35189 L
.45127 .35189 L
.45127 .35189 L
.45127 .35189 L
.45126 .35189 L
.45126 .35188 L
.45126 .35188 L
.45125 .35188 L
.45125 .35188 L
.45125 .35188 L
.45124 .35188 L
.45124 .35188 L
.45124 .35188 L
.45123 .35188 L
.45123 .35188 L
.45123 .35188 L
.45122 .35187 L
.45122 .35187 L
.45122 .35187 L
.45121 .35187 L
.45121 .35187 L
.45121 .35187 L
.45121 .35187 L
.4512 .35187 L
.4512 .35187 L
.4512 .35187 L
.45119 .35186 L
.45119 .35186 L
.45119 .35186 L
.45118 .35186 L
.45118 .35186 L
.45118 .35186 L
.45117 .35186 L
.45117 .35186 L
.45117 .35186 L
.45116 .35186 L
.45116 .35185 L
.45116 .35185 L
Mistroke
.45115 .35185 L
.45115 .35185 L
.45115 .35185 L
.45114 .35185 L
.45114 .35185 L
.45114 .35185 L
.45113 .35185 L
.45113 .35185 L
.45113 .35184 L
.45112 .35184 L
.45112 .35184 L
.45112 .35184 L
.45112 .35184 L
.45111 .35184 L
.45111 .35184 L
.45111 .35184 L
.4511 .35184 L
.4511 .35183 L
.4511 .35183 L
.45109 .35183 L
.45109 .35183 L
.45109 .35183 L
.45108 .35183 L
.45108 .35183 L
.45108 .35183 L
.45107 .35183 L
.45107 .35182 L
.45107 .35182 L
.45107 .35182 L
.45106 .35182 L
.45106 .35182 L
.45106 .35182 L
.45105 .35182 L
.45105 .35182 L
.45105 .35182 L
.45104 .35181 L
.45104 .35181 L
.45104 .35181 L
.45103 .35181 L
.45103 .35181 L
.45103 .35181 L
.45103 .35181 L
.45102 .35181 L
.45102 .35181 L
.45102 .3518 L
.45101 .3518 L
.45101 .3518 L
.45101 .3518 L
.451 .3518 L
.451 .3518 L
Mistroke
.451 .3518 L
.451 .3518 L
.45099 .35179 L
.45099 .35179 L
.45099 .35179 L
.45098 .35179 L
.45098 .35179 L
.45098 .35179 L
.45097 .35179 L
.45097 .35179 L
.45097 .35179 L
.45097 .35178 L
.45096 .35178 L
.45096 .35178 L
.45096 .35178 L
.45095 .35178 L
.45095 .35178 L
.45095 .35178 L
.45095 .35178 L
.45094 .35177 L
.45094 .35177 L
.45094 .35177 L
.45093 .35177 L
.45093 .35177 L
.45093 .35177 L
.45093 .35177 L
.45092 .35177 L
.45092 .35176 L
.45092 .35176 L
.45091 .35176 L
.45091 .35176 L
.45091 .35176 L
.45091 .35176 L
.4509 .35176 L
.4509 .35176 L
.4509 .35175 L
.45089 .35175 L
.45089 .35175 L
.45089 .35175 L
.45089 .35175 L
.45088 .35175 L
.45088 .35175 L
.45088 .35174 L
.45087 .35174 L
.45087 .35174 L
.45087 .35174 L
.45087 .35174 L
.45086 .35174 L
.45086 .35174 L
.45086 .35174 L
Mistroke
.45085 .35173 L
.45085 .35173 L
.45085 .35173 L
.45085 .35173 L
.45084 .35173 L
.45084 .35173 L
.45084 .35173 L
.45084 .35172 L
.45083 .35172 L
.45083 .35172 L
.45083 .35172 L
.45082 .35172 L
.45082 .35172 L
.45082 .35172 L
.45082 .35172 L
.45081 .35171 L
.45081 .35171 L
.45081 .35171 L
.45081 .35171 L
.4508 .35171 L
.4508 .35171 L
.4508 .35171 L
.4508 .3517 L
.45079 .3517 L
.45079 .3517 L
.45079 .3517 L
.45078 .3517 L
.45078 .3517 L
.45078 .3517 L
.45078 .35169 L
.45077 .35169 L
.45077 .35169 L
.45077 .35169 L
.45077 .35169 L
.45076 .35169 L
.45076 .35169 L
.45076 .35168 L
.45076 .35168 L
.45075 .35168 L
.45075 .35168 L
.45075 .35168 L
.45075 .35168 L
.45074 .35168 L
.45074 .35167 L
.45074 .35167 L
.45073 .35167 L
.45073 .35167 L
.45073 .35167 L
.45073 .35167 L
.45072 .35167 L
Mistroke
.45072 .35166 L
.45072 .35166 L
.45072 .35166 L
.45071 .35166 L
.45071 .35166 L
.45071 .35166 L
.45071 .35166 L
.4507 .35165 L
.4507 .35165 L
.4507 .35165 L
.4507 .35165 L
.45069 .35165 L
.45069 .35165 L
.45069 .35165 L
.45069 .35164 L
.45068 .35164 L
.45068 .35164 L
.45068 .35164 L
.45068 .35164 L
.45067 .35164 L
.45067 .35164 L
.45067 .35163 L
.45067 .35163 L
.45066 .35163 L
.45066 .35163 L
.45066 .35163 L
.45066 .35163 L
.45065 .35162 L
.45065 .35162 L
.45065 .35162 L
.45065 .35162 L
.45065 .35162 L
.45064 .35162 L
.45064 .35162 L
.45064 .35161 L
.45064 .35161 L
.45063 .35161 L
.45063 .35161 L
.45063 .35161 L
.45063 .35161 L
.45062 .3516 L
.45062 .3516 L
.45062 .3516 L
.45062 .3516 L
.45061 .3516 L
.45061 .3516 L
.45061 .3516 L
.45061 .35159 L
.4506 .35159 L
.4506 .35159 L
Mistroke
.4506 .35159 L
.4506 .35159 L
.4506 .35159 L
.45059 .35158 L
.45059 .35158 L
.45059 .35158 L
.45059 .35158 L
.45058 .35158 L
.45058 .35158 L
.45058 .35157 L
.45058 .35157 L
.45057 .35157 L
.45057 .35157 L
.45057 .35157 L
.45057 .35157 L
.45057 .35156 L
.45056 .35156 L
.45056 .35156 L
.45056 .35156 L
.45056 .35156 L
.45055 .35156 L
.45055 .35156 L
.45055 .35155 L
.45055 .35155 L
.45055 .35155 L
.45054 .35155 L
.45054 .35155 L
.45054 .35155 L
.45054 .35154 L
.45053 .35154 L
.45053 .35154 L
.45053 .35154 L
.45053 .35154 L
.45053 .35154 L
.45052 .35153 L
.45052 .35153 L
.45052 .35153 L
.45052 .35153 L
.45051 .35153 L
.45051 .35153 L
.45051 .35152 L
.45051 .35152 L
.45051 .35152 L
.4505 .35152 L
.4505 .35152 L
.4505 .35152 L
.4505 .35151 L
.45049 .35151 L
.45049 .35151 L
.45049 .35151 L
Mistroke
.45049 .35151 L
.45049 .35151 L
.45048 .3515 L
.45048 .3515 L
.45048 .3515 L
.45048 .3515 L
.45048 .3515 L
.45047 .3515 L
.45047 .35149 L
.45047 .35149 L
.45047 .35149 L
.45047 .35149 L
.45046 .35149 L
.45046 .35149 L
.45046 .35148 L
.45046 .35148 L
.45046 .35148 L
.45045 .35148 L
.45045 .35148 L
.45045 .35147 L
.45045 .35147 L
.45044 .35147 L
.45044 .35147 L
.45044 .35147 L
.45044 .35147 L
.45044 .35146 L
.45043 .35146 L
.45043 .35146 L
.45043 .35146 L
.45043 .35146 L
.45043 .35146 L
.45042 .35145 L
.45042 .35145 L
.45042 .35145 L
.45042 .35145 L
.45042 .35145 L
.45041 .35145 L
.45041 .35144 L
.45041 .35144 L
.45041 .35144 L
.45041 .35144 L
.4504 .35144 L
.4504 .35143 L
.4504 .35143 L
.4504 .35143 L
.4504 .35143 L
.4504 .35143 L
.45039 .35143 L
.45039 .35142 L
.45039 .35142 L
Mistroke
.45039 .35142 L
.45039 .35142 L
.45038 .35142 L
.45038 .35141 L
.45038 .35141 L
.45038 .35141 L
.45038 .35141 L
.45037 .35141 L
.45037 .35141 L
.45037 .3514 L
.45037 .3514 L
.45037 .3514 L
.45036 .3514 L
.45036 .3514 L
.45036 .3514 L
.45036 .35139 L
.45036 .35139 L
.45036 .35139 L
.45035 .35139 L
.45035 .35139 L
.45035 .35138 L
.45035 .35138 L
.45035 .35138 L
.45034 .35138 L
.45034 .35138 L
.45034 .35138 L
.45034 .35137 L
.45034 .35137 L
.45034 .35137 L
.45033 .35137 L
.45033 .35137 L
.45033 .35136 L
.45033 .35136 L
.45033 .35136 L
.45032 .35136 L
.45032 .35136 L
.45032 .35135 L
.45032 .35135 L
.45032 .35135 L
.45032 .35135 L
.45031 .35135 L
.45031 .35135 L
.45031 .35134 L
.45031 .35134 L
.45031 .35134 L
.45031 .35134 L
.4503 .35134 L
.4503 .35133 L
.4503 .35133 L
.4503 .35133 L
Mistroke
.4503 .35133 L
.45029 .35133 L
.45029 .35133 L
.45029 .35132 L
.45029 .35132 L
.45029 .35132 L
.45029 .35132 L
.45028 .35132 L
.45028 .35131 L
.45028 .35131 L
.45028 .35131 L
.45028 .35131 L
.45028 .35131 L
.45027 .3513 L
.45027 .3513 L
.45027 .3513 L
.45027 .3513 L
.45027 .3513 L
.45027 .35129 L
.45026 .35129 L
.45026 .35129 L
.45026 .35129 L
.45026 .35129 L
.45026 .35129 L
.45026 .35128 L
.45025 .35128 L
.45025 .35128 L
.45025 .35128 L
.45025 .35128 L
.45025 .35127 L
.45025 .35127 L
.45025 .35127 L
.45024 .35127 L
.45024 .35127 L
.45024 .35126 L
.45024 .35126 L
.45024 .35126 L
.45024 .35126 L
.45023 .35126 L
.45023 .35125 L
.45023 .35125 L
.45023 .35125 L
.45023 .35125 L
.45023 .35125 L
.45022 .35124 L
.45022 .35124 L
.45022 .35124 L
.45022 .35124 L
.45022 .35124 L
.45022 .35123 L
Mistroke
.45022 .35123 L
.45021 .35123 L
.45021 .35123 L
.45021 .35123 L
.45021 .35123 L
.45021 .35122 L
.45021 .35122 L
.45021 .35122 L
.4502 .35122 L
.4502 .35122 L
.4502 .35121 L
.4502 .35121 L
.4502 .35121 L
.4502 .35121 L
.45019 .35121 L
.45019 .3512 L
.45019 .3512 L
.45019 .3512 L
.45019 .3512 L
.45019 .3512 L
.45019 .35119 L
.45018 .35119 L
.45018 .35119 L
.45018 .35119 L
.45018 .35119 L
.45018 .35118 L
.45018 .35118 L
.45018 .35118 L
.45017 .35118 L
.45017 .35118 L
.45017 .35117 L
.45017 .35117 L
.45017 .35117 L
.45017 .35117 L
.45017 .35117 L
.45016 .35116 L
.45016 .35116 L
.45016 .35116 L
.45016 .35116 L
.45016 .35116 L
.45016 .35115 L
.45016 .35115 L
.45016 .35115 L
.45015 .35115 L
.45015 .35115 L
.45015 .35114 L
.45015 .35114 L
.45015 .35114 L
.45015 .35114 L
.45015 .35114 L
Mistroke
.45014 .35113 L
.45014 .35113 L
.45014 .35113 L
.45014 .35113 L
.45014 .35113 L
.45014 .35112 L
.45014 .35112 L
.45014 .35112 L
.45013 .35112 L
.45013 .35112 L
.45013 .35111 L
.45013 .35111 L
.45013 .35111 L
.45013 .35111 L
.45013 .35111 L
.45012 .3511 L
.45012 .3511 L
.45012 .3511 L
.45012 .3511 L
.45012 .35109 L
.45012 .35109 L
.45012 .35109 L
.45012 .35109 L
.45011 .35109 L
.45011 .35108 L
.45011 .35108 L
.45011 .35108 L
.45011 .35108 L
.45011 .35108 L
.45011 .35107 L
.45011 .35107 L
.45011 .35107 L
.4501 .35107 L
.4501 .35107 L
.4501 .35106 L
.4501 .35106 L
.4501 .35106 L
.4501 .35106 L
.4501 .35106 L
.4501 .35105 L
.45009 .35105 L
.45009 .35105 L
.45009 .35105 L
.45009 .35105 L
.45009 .35104 L
.45009 .35104 L
.45009 .35104 L
.45009 .35104 L
.45008 .35103 L
.45008 .35103 L
Mistroke
.45008 .35103 L
.45008 .35103 L
.45008 .35103 L
.45008 .35102 L
.45008 .35102 L
.45008 .35102 L
.45008 .35102 L
.45007 .35102 L
.45007 .35101 L
.45007 .35101 L
.45007 .35101 L
.45007 .35101 L
.45007 .35101 L
.45007 .351 L
.45007 .351 L
.45007 .351 L
.45006 .351 L
.45006 .351 L
.45006 .35099 L
.45006 .35099 L
.45006 .35099 L
.45006 .35099 L
.45006 .35098 L
.45006 .35098 L
.45006 .35098 L
.45006 .35098 L
.45005 .35098 L
.45005 .35097 L
.45005 .35097 L
.45005 .35097 L
.45005 .35097 L
.45005 .35097 L
.45005 .35096 L
.45005 .35096 L
.45005 .35096 L
.45004 .35096 L
.45004 .35096 L
.45004 .35095 L
.45004 .35095 L
.45004 .35095 L
.45004 .35095 L
.45004 .35094 L
.45004 .35094 L
.45004 .35094 L
.45004 .35094 L
.45003 .35094 L
.45003 .35093 L
.45003 .35093 L
.45003 .35093 L
.45003 .35093 L
Mistroke
.45003 .35093 L
.45003 .35092 L
.45003 .35092 L
.45003 .35092 L
.45003 .35092 L
.45003 .35091 L
.45002 .35091 L
.45002 .35091 L
.45002 .35091 L
.45002 .35091 L
.45002 .3509 L
.45002 .3509 L
.45002 .3509 L
.45002 .3509 L
.45002 .3509 L
.45002 .35089 L
.45002 .35089 L
.45001 .35089 L
.45001 .35089 L
.45001 .35088 L
.45001 .35088 L
.45001 .35088 L
.45001 .35088 L
.45001 .35088 L
.45001 .35087 L
.45001 .35087 L
.45001 .35087 L
.45001 .35087 L
.45 .35087 L
.45 .35086 L
.45 .35086 L
.45 .35086 L
.45 .35086 L
.45 .35085 L
.45 .35085 L
.45 .35085 L
.45 .35085 L
.45 .35085 L
.45 .35084 L
.45 .35084 L
.44999 .35084 L
.44999 .35084 L
.44999 .35083 L
.44999 .35083 L
.44999 .35083 L
.44999 .35083 L
.44999 .35083 L
.44999 .35082 L
.44999 .35082 L
.44999 .35082 L
Mistroke
.44999 .35082 L
.44999 .35082 L
.44998 .35081 L
.44998 .35081 L
.44998 .35081 L
.44998 .35081 L
.44998 .3508 L
.44998 .3508 L
.44998 .3508 L
.44998 .3508 L
.44998 .3508 L
.44998 .35079 L
.44998 .35079 L
.44998 .35079 L
.44998 .35079 L
.44997 .35078 L
.44997 .35078 L
.44997 .35078 L
.44997 .35078 L
.44997 .35078 L
.44997 .35077 L
.44997 .35077 L
.44997 .35077 L
.44997 .35077 L
.44997 .35076 L
.44997 .35076 L
.44997 .35076 L
.44997 .35076 L
.44997 .35076 L
.44996 .35075 L
.44996 .35075 L
.44996 .35075 L
.44996 .35075 L
.44996 .35075 L
.44996 .35074 L
.44996 .35074 L
.44996 .35074 L
.44996 .35074 L
.44996 .35073 L
.44996 .35073 L
.44996 .35073 L
.44996 .35073 L
.44996 .35073 L
.44996 .35072 L
.44995 .35072 L
.44995 .35072 L
.44995 .35072 L
.44995 .35071 L
.44995 .35071 L
.44995 .35071 L
Mistroke
.44995 .35071 L
.44995 .35071 L
.44995 .3507 L
.44995 .3507 L
.44995 .3507 L
.44995 .3507 L
.44995 .35069 L
.44995 .35069 L
.44995 .35069 L
.44995 .35069 L
.44994 .35069 L
.44994 .35068 L
.44994 .35068 L
.44994 .35068 L
.44994 .35068 L
.44994 .35067 L
.44994 .35067 L
.44994 .35067 L
.44994 .35067 L
.44994 .35067 L
.44994 .35066 L
.44994 .35066 L
.44994 .35066 L
.44994 .35066 L
.44994 .35065 L
.44994 .35065 L
.44994 .35065 L
.44994 .35065 L
.44993 .35065 L
.44993 .35064 L
.44993 .35064 L
.44993 .35064 L
.44993 .35064 L
.44993 .35063 L
.44993 .35063 L
.44993 .35063 L
.44993 .35063 L
.44993 .35063 L
.44993 .35062 L
.44993 .35062 L
.44993 .35062 L
.44993 .35062 L
.44993 .35061 L
.44993 .35061 L
.44993 .35061 L
.44993 .35061 L
.44993 .35061 L
.44993 .3506 L
.44992 .3506 L
.44992 .3506 L
Mistroke
.44992 .3506 L
.44992 .35059 L
.44992 .35059 L
.44992 .35059 L
.44992 .35059 L
.44992 .35059 L
.44992 .35058 L
.44992 .35058 L
.44992 .35058 L
.44992 .35058 L
.44992 .35057 L
.44992 .35057 L
.44992 .35057 L
.44992 .35057 L
.44992 .35056 L
.44992 .35056 L
.44992 .35056 L
.44992 .35056 L
.44992 .35056 L
.44992 .35055 L
.44992 .35055 L
.44992 .35055 L
.44991 .35055 L
.44991 .35054 L
.44991 .35054 L
.44991 .35054 L
.44991 .35054 L
.44991 .35054 L
.44991 .35053 L
.44991 .35053 L
.44991 .35053 L
.44991 .35053 L
.44991 .35052 L
.44991 .35052 L
.44991 .35052 L
.44991 .35052 L
.44991 .35052 L
.44991 .35051 L
.44991 .35051 L
.44991 .35051 L
.44991 .35051 L
.44991 .3505 L
.44991 .3505 L
.44991 .3505 L
.44991 .3505 L
.44991 .3505 L
.44991 .35049 L
.44991 .35049 L
.44991 .35049 L
.44991 .35049 L
Mistroke
.4499 .35048 L
.4499 .35048 L
.4499 .35048 L
.4499 .35048 L
.4499 .35047 L
.4499 .35047 L
.4499 .35047 L
.4499 .35047 L
.4499 .35047 L
.4499 .35046 L
.4499 .35046 L
.4499 .35046 L
.4499 .35046 L
.4499 .35045 L
.4499 .35045 L
.4499 .35045 L
.4499 .35045 L
.4499 .35045 L
.4499 .35044 L
.4499 .35044 L
.4499 .35044 L
.4499 .35044 L
.4499 .35043 L
.4499 .35043 L
.4499 .35043 L
.4499 .35043 L
.4499 .35043 L
.4499 .35042 L
.4499 .35042 L
.4499 .35042 L
.4499 .35042 L
.4499 .35041 L
.4499 .35041 L
.4499 .35041 L
.4499 .35041 L
.4499 .3504 L
.4499 .3504 L
.4499 .3504 L
.4499 .3504 L
.4499 .3504 L
.4499 .35039 L
.44989 .35039 L
.44989 .35039 L
.44989 .35039 L
.44989 .35038 L
.44989 .35038 L
.44989 .35038 L
.44989 .35038 L
.44989 .35038 L
.44989 .35037 L
Mistroke
.44989 .35037 L
.44989 .35037 L
.44989 .35037 L
.44989 .35036 L
.44989 .35036 L
.44989 .35036 L
.44989 .35036 L
.44989 .35035 L
.44989 .35035 L
.44989 .35035 L
.44989 .35035 L
.44989 .35035 L
.44989 .35034 L
.44989 .35034 L
.44989 .35034 L
.44989 .35034 L
.44989 .35033 L
.44989 .35033 L
.44989 .35033 L
.44989 .35033 L
.44989 .35033 L
.44989 .35032 L
.44989 .35032 L
.44989 .35032 L
.44989 .35032 L
.44989 .35031 L
.44989 .35031 L
.44989 .35031 L
.44989 .35031 L
.44989 .3503 L
.44989 .3503 L
.44989 .3503 L
.44989 .3503 L
.44989 .3503 L
.44989 .35029 L
.44989 .35029 L
.44989 .35029 L
.44989 .35029 L
.44989 .35028 L
.44989 .35028 L
.44989 .35028 L
.44989 .35028 L
.44989 .35028 L
.44989 .35027 L
.44989 .35027 L
.44989 .35027 L
.44989 .35027 L
.44989 .35026 L
.44989 .35026 L
.44989 .35026 L
Mistroke
.44989 .35026 L
.44989 .35025 L
.44989 .35025 L
.44989 .35025 L
.44989 .35025 L
.44989 .35025 L
.44989 .35024 L
.44989 .35024 L
.44989 .35024 L
.44989 .35024 L
.44989 .35023 L
.44989 .35023 L
.44989 .35023 L
.44989 .35023 L
.44989 .35023 L
.44989 .35022 L
.44989 .35022 L
.44989 .35022 L
.44989 .35022 L
.44989 .35021 L
.44989 .35021 L
.44989 .35021 L
.44989 .35021 L
.44989 .35021 L
.44989 .3502 L
.44989 .3502 L
.44989 .3502 L
.44989 .3502 L
.44989 .35019 L
.44989 .35019 L
.44989 .35019 L
.44989 .35019 L
.44989 .35018 L
.44989 .35018 L
.44989 .35018 L
.44989 .35018 L
.44989 .35018 L
.44989 .35017 L
.44989 .35017 L
.44989 .35017 L
.44989 .35017 L
.44989 .35016 L
.44989 .35016 L
.44989 .35016 L
.44989 .35016 L
.44989 .35016 L
.44989 .35015 L
.44989 .35015 L
.44989 .35015 L
.44989 .35015 L
Mistroke
.44989 .35014 L
.44989 .35014 L
.44989 .35014 L
.44989 .35014 L
.44989 .35013 L
.44989 .35013 L
.44989 .35013 L
.44989 .35013 L
.44989 .35013 L
.44989 .35012 L
.44989 .35012 L
.44989 .35012 L
.44989 .35012 L
.44989 .35011 L
.44989 .35011 L
.44989 .35011 L
.44989 .35011 L
.44989 .35011 L
.44989 .3501 L
.44989 .3501 L
.44989 .3501 L
.44989 .3501 L
.4499 .35009 L
.4499 .35009 L
.4499 .35009 L
.4499 .35009 L
.4499 .35008 L
.4499 .35008 L
.4499 .35008 L
.4499 .35008 L
.4499 .35008 L
.4499 .35007 L
.4499 .35007 L
.4499 .35007 L
.4499 .35007 L
.4499 .35006 L
.4499 .35006 L
.4499 .35006 L
.4499 .35006 L
.4499 .35006 L
.4499 .35005 L
.4499 .35005 L
.4499 .35005 L
.4499 .35005 L
.4499 .35004 L
.4499 .35004 L
.4499 .35004 L
.4499 .35004 L
.4499 .35004 L
.4499 .35003 L
Mistroke
.4499 .35003 L
.4499 .35003 L
.4499 .35003 L
.4499 .35002 L
.4499 .35002 L
.4499 .35002 L
.4499 .35002 L
.4499 .35001 L
.4499 .35001 L
.4499 .35001 L
.4499 .35001 L
.4499 .35001 L
.4499 .35 L
.4499 .35 L
.4499 .35 L
.44991 .35 L
.44991 .34999 L
.44991 .34999 L
.44991 .34999 L
.44991 .34999 L
.44991 .34999 L
.44991 .34998 L
.44991 .34998 L
.44991 .34998 L
.44991 .34998 L
.44991 .34997 L
.44991 .34997 L
.44991 .34997 L
.44991 .34997 L
.44991 .34997 L
.44991 .34996 L
.44991 .34996 L
.44991 .34996 L
.44991 .34996 L
.44991 .34995 L
.44991 .34995 L
.44991 .34995 L
.44991 .34995 L
.44991 .34995 L
.44991 .34994 L
.44991 .34994 L
.44991 .34994 L
.44991 .34994 L
.44991 .34993 L
.44991 .34993 L
.44991 .34993 L
.44992 .34993 L
.44992 .34992 L
.44992 .34992 L
.44992 .34992 L
Mistroke
.44992 .34992 L
.44992 .34992 L
.44992 .34991 L
.44992 .34991 L
.44992 .34991 L
.44992 .34991 L
.44992 .3499 L
.44992 .3499 L
.44992 .3499 L
.44992 .3499 L
.44992 .3499 L
.44992 .34989 L
.44992 .34989 L
.44992 .34989 L
.44992 .34989 L
.44992 .34988 L
.44992 .34988 L
.44992 .34988 L
.44992 .34988 L
.44992 .34988 L
.44992 .34987 L
.44992 .34987 L
.44993 .34987 L
.44993 .34987 L
.44993 .34986 L
.44993 .34986 L
.44993 .34986 L
.44993 .34986 L
.44993 .34986 L
.44993 .34985 L
.44993 .34985 L
.44993 .34985 L
.44993 .34985 L
.44993 .34984 L
.44993 .34984 L
.44993 .34984 L
.44993 .34984 L
.44993 .34984 L
.44993 .34983 L
.44993 .34983 L
.44993 .34983 L
.44993 .34983 L
.44993 .34982 L
.44993 .34982 L
.44994 .34982 L
.44994 .34982 L
.44994 .34982 L
.44994 .34981 L
.44994 .34981 L
.44994 .34981 L
Mistroke
.44994 .34981 L
.44994 .3498 L
.44994 .3498 L
.44994 .3498 L
.44994 .3498 L
.44994 .3498 L
.44994 .34979 L
.44994 .34979 L
.44994 .34979 L
.44994 .34979 L
.44994 .34978 L
.44994 .34978 L
.44994 .34978 L
.44994 .34978 L
.44994 .34978 L
.44995 .34977 L
.44995 .34977 L
.44995 .34977 L
.44995 .34977 L
.44995 .34976 L
.44995 .34976 L
.44995 .34976 L
.44995 .34976 L
.44995 .34976 L
.44995 .34975 L
.44995 .34975 L
.44995 .34975 L
.44995 .34975 L
.44995 .34974 L
.44995 .34974 L
.44995 .34974 L
.44995 .34974 L
.44995 .34974 L
.44996 .34973 L
.44996 .34973 L
.44996 .34973 L
.44996 .34973 L
.44996 .34972 L
.44996 .34972 L
.44996 .34972 L
.44996 .34972 L
.44996 .34972 L
.44996 .34971 L
.44996 .34971 L
.44996 .34971 L
.44996 .34971 L
.44996 .3497 L
.44996 .3497 L
.44996 .3497 L
.44996 .3497 L
Mistroke
.44996 .3497 L
.44997 .34969 L
.44997 .34969 L
.44997 .34969 L
.44997 .34969 L
.44997 .34969 L
.44997 .34968 L
.44997 .34968 L
.44997 .34968 L
.44997 .34968 L
.44997 .34967 L
.44997 .34967 L
.44997 .34967 L
.44997 .34967 L
.44997 .34967 L
.44997 .34966 L
.44997 .34966 L
.44998 .34966 L
.44998 .34966 L
.44998 .34965 L
.44998 .34965 L
.44998 .34965 L
.44998 .34965 L
.44998 .34965 L
.44998 .34964 L
.44998 .34964 L
.44998 .34964 L
.44998 .34964 L
.44998 .34963 L
.44998 .34963 L
.44998 .34963 L
.44998 .34963 L
.44998 .34963 L
.44999 .34962 L
.44999 .34962 L
.44999 .34962 L
.44999 .34962 L
.44999 .34962 L
.44999 .34961 L
.44999 .34961 L
.44999 .34961 L
.44999 .34961 L
.44999 .3496 L
.44999 .3496 L
.44999 .3496 L
.44999 .3496 L
.44999 .3496 L
.44999 .34959 L
.45 .34959 L
.45 .34959 L
Mistroke
.45 .34959 L
.45 .34959 L
.45 .34958 L
.45 .34958 L
.45 .34958 L
.45 .34958 L
.45 .34957 L
.45 .34957 L
.45 .34957 L
.45 .34957 L
.45 .34957 L
.45 .34956 L
.45001 .34956 L
.45001 .34956 L
.45001 .34956 L
.45001 .34955 L
.45001 .34955 L
.45001 .34955 L
.45001 .34955 L
.45001 .34955 L
.45001 .34954 L
.45001 .34954 L
.45001 .34954 L
.45001 .34954 L
.45001 .34954 L
.45001 .34953 L
.45002 .34953 L
.45002 .34953 L
.45002 .34953 L
.45002 .34952 L
.45002 .34952 L
.45002 .34952 L
.45002 .34952 L
.45002 .34952 L
.45002 .34951 L
.45002 .34951 L
.45002 .34951 L
.45002 .34951 L
.45002 .34951 L
.45003 .3495 L
.45003 .3495 L
.45003 .3495 L
.45003 .3495 L
.45003 .34949 L
.45003 .34949 L
.45003 .34949 L
.45003 .34949 L
.45003 .34949 L
.45003 .34948 L
.45003 .34948 L
Mistroke
.45003 .34948 L
.45003 .34948 L
.45004 .34948 L
.45004 .34947 L
.45004 .34947 L
.45004 .34947 L
.45004 .34947 L
.45004 .34947 L
.45004 .34946 L
.45004 .34946 L
.45004 .34946 L
.45004 .34946 L
.45004 .34945 L
.45004 .34945 L
.45004 .34945 L
.45005 .34945 L
.45005 .34945 L
.45005 .34944 L
.45005 .34944 L
.45005 .34944 L
.45005 .34944 L
.45005 .34944 L
.45005 .34943 L
.45005 .34943 L
.45005 .34943 L
.45005 .34943 L
.45005 .34943 L
.45006 .34942 L
.45006 .34942 L
.45006 .34942 L
.45006 .34942 L
.45006 .34941 L
.45006 .34941 L
.45006 .34941 L
.45006 .34941 L
.45006 .34941 L
.45006 .3494 L
.45006 .3494 L
.45006 .3494 L
.45007 .3494 L
.45007 .3494 L
.45007 .34939 L
.45007 .34939 L
.45007 .34939 L
.45007 .34939 L
.45007 .34939 L
.45007 .34938 L
.45007 .34938 L
.45007 .34938 L
.45007 .34938 L
Mistroke
.45008 .34937 L
.45008 .34937 L
.45008 .34937 L
.45008 .34937 L
.45008 .34937 L
.45008 .34936 L
.45008 .34936 L
.45008 .34936 L
.45008 .34936 L
.45008 .34936 L
.45008 .34935 L
.45008 .34935 L
.45009 .34935 L
.45009 .34935 L
.45009 .34935 L
.45009 .34934 L
.45009 .34934 L
.45009 .34934 L
.45009 .34934 L
.45009 .34934 L
.45009 .34933 L
.45009 .34933 L
.45009 .34933 L
.4501 .34933 L
.4501 .34933 L
.4501 .34932 L
.4501 .34932 L
.4501 .34932 L
.4501 .34932 L
.4501 .34931 L
.4501 .34931 L
.4501 .34931 L
.4501 .34931 L
.4501 .34931 L
.45011 .3493 L
.45011 .3493 L
.45011 .3493 L
.45011 .3493 L
.45011 .3493 L
.45011 .34929 L
.45011 .34929 L
.45011 .34929 L
.45011 .34929 L
.45011 .34929 L
.45011 .34928 L
.45012 .34928 L
.45012 .34928 L
.45012 .34928 L
.45012 .34928 L
.45012 .34927 L
Mistroke
.45012 .34927 L
.45012 .34927 L
.45012 .34927 L
.45012 .34927 L
.45012 .34926 L
.45013 .34926 L
.45013 .34926 L
.45013 .34926 L
.45013 .34926 L
.45013 .34925 L
.45013 .34925 L
.45013 .34925 L
.45013 .34925 L
.45013 .34925 L
.45013 .34924 L
.45014 .34924 L
.45014 .34924 L
.45014 .34924 L
.45014 .34924 L
.45014 .34923 L
.45014 .34923 L
.45014 .34923 L
.45014 .34923 L
.45014 .34923 L
.45014 .34922 L
.45014 .34922 L
.45015 .34922 L
.45015 .34922 L
.45015 .34922 L
.45015 .34921 L
.45015 .34921 L
.45015 .34921 L
.45015 .34921 L
.45015 .34921 L
.45015 .3492 L
.45015 .3492 L
.45016 .3492 L
.45016 .3492 L
.45016 .3492 L
.45016 .34919 L
.45016 .34919 L
.45016 .34919 L
.45016 .34919 L
.45016 .34919 L
.45016 .34918 L
.45016 .34918 L
.45017 .34918 L
.45017 .34918 L
.45017 .34918 L
.45017 .34917 L
Mistroke
.45017 .34917 L
.45017 .34917 L
.45017 .34917 L
.45017 .34917 L
.45017 .34916 L
.45018 .34916 L
.45018 .34916 L
.45018 .34916 L
.45018 .34916 L
.45018 .34915 L
.45018 .34915 L
.45018 .34915 L
.45018 .34915 L
.45018 .34915 L
.45018 .34914 L
.45019 .34914 L
.45019 .34914 L
.45019 .34914 L
.45019 .34914 L
.45019 .34913 L
.45019 .34913 L
.45019 .34913 L
.45019 .34913 L
.45019 .34913 L
.45019 .34912 L
.4502 .34912 L
.4502 .34912 L
.4502 .34912 L
.4502 .34912 L
.4502 .34911 L
.4502 .34911 L
.4502 .34911 L
.4502 .34911 L
.4502 .34911 L
.45021 .3491 L
.45021 .3491 L
.45021 .3491 L
.45021 .3491 L
.45021 .3491 L
.45021 .34909 L
.45021 .34909 L
.45021 .34909 L
.45021 .34909 L
.45022 .34909 L
.45022 .34908 L
.45022 .34908 L
.45022 .34908 L
.45022 .34908 L
.45022 .34908 L
.45022 .34907 L
Mistroke
.45022 .34907 L
.45022 .34907 L
.45022 .34907 L
.45023 .34907 L
.45023 .34907 L
.45023 .34906 L
.45023 .34906 L
.45023 .34906 L
.45023 .34906 L
.45023 .34906 L
.45023 .34905 L
.45023 .34905 L
.45024 .34905 L
.45024 .34905 L
.45024 .34905 L
.45024 .34904 L
.45024 .34904 L
.45024 .34904 L
.45024 .34904 L
.45024 .34904 L
.45024 .34903 L
.45025 .34903 L
.45025 .34903 L
.45025 .34903 L
.45025 .34903 L
.45025 .34902 L
.45025 .34902 L
.45025 .34902 L
.45025 .34902 L
.45025 .34902 L
.45026 .34902 L
.45026 .34901 L
.45026 .34901 L
.45026 .34901 L
.45026 .34901 L
.45026 .34901 L
.45026 .349 L
.45026 .349 L
.45027 .349 L
.45027 .349 L
.45027 .349 L
.45027 .34899 L
.45027 .34899 L
.45027 .34899 L
.45027 .34899 L
.45027 .34899 L
.45027 .34898 L
.45028 .34898 L
.45028 .34898 L
.45028 .34898 L
Mistroke
.45028 .34898 L
.45028 .34898 L
.45028 .34897 L
.45028 .34897 L
.45028 .34897 L
.45028 .34897 L
.45029 .34897 L
.45029 .34896 L
.45029 .34896 L
.45029 .34896 L
.45029 .34896 L
.45029 .34896 L
.45029 .34895 L
.45029 .34895 L
.4503 .34895 L
.4503 .34895 L
.4503 .34895 L
.4503 .34895 L
.4503 .34894 L
.4503 .34894 L
.4503 .34894 L
.4503 .34894 L
.4503 .34894 L
.45031 .34893 L
.45031 .34893 L
.45031 .34893 L
.45031 .34893 L
.45031 .34893 L
.45031 .34893 L
.45031 .34892 L
.45031 .34892 L
.45032 .34892 L
.45032 .34892 L
.45032 .34892 L
.45032 .34891 L
.45032 .34891 L
.45032 .34891 L
.45032 .34891 L
.45032 .34891 L
.45032 .3489 L
.45033 .3489 L
.45033 .3489 L
.45033 .3489 L
.45033 .3489 L
.45033 .3489 L
.45033 .34889 L
.45033 .34889 L
.45033 .34889 L
.45034 .34889 L
.45034 .34889 L
Mistroke
.45034 .34888 L
.45034 .34888 L
.45034 .34888 L
.45034 .34888 L
.45034 .34888 L
.45034 .34888 L
.45034 .34887 L
.45035 .34887 L
.45035 .34887 L
.45035 .34887 L
.45035 .34887 L
.45035 .34886 L
.45035 .34886 L
.45035 .34886 L
.45035 .34886 L
.45036 .34886 L
.45036 .34886 L
.45036 .34885 L
.45036 .34885 L
.45036 .34885 L
.45036 .34885 L
.45036 .34885 L
.45036 .34884 L
.45037 .34884 L
.45037 .34884 L
.45037 .34884 L
.45037 .34884 L
.45037 .34884 L
.45037 .34883 L
.45037 .34883 L
.45037 .34883 L
.45038 .34883 L
.45038 .34883 L
.45038 .34883 L
.45038 .34882 L
.45038 .34882 L
.45038 .34882 L
.45038 .34882 L
.45038 .34882 L
.45039 .34881 L
.45039 .34881 L
.45039 .34881 L
.45039 .34881 L
.45039 .34881 L
.45039 .34881 L
.45039 .3488 L
.45039 .3488 L
.4504 .3488 L
.4504 .3488 L
.4504 .3488 L
Mistroke
.4504 .3488 L
.4504 .34879 L
.4504 .34879 L
.4504 .34879 L
.4504 .34879 L
.45041 .34879 L
.45041 .34878 L
.45041 .34878 L
.45041 .34878 L
.45041 .34878 L
.45041 .34878 L
.45041 .34878 L
.45041 .34877 L
.45042 .34877 L
.45042 .34877 L
.45042 .34877 L
.45042 .34877 L
.45042 .34877 L
.45042 .34876 L
.45042 .34876 L
.45042 .34876 L
.45043 .34876 L
.45043 .34876 L
.45043 .34875 L
.45043 .34875 L
.45043 .34875 L
.45043 .34875 L
.45043 .34875 L
.45043 .34875 L
.45044 .34874 L
.45044 .34874 L
.45044 .34874 L
.45044 .34874 L
.45044 .34874 L
.45044 .34874 L
.45044 .34873 L
.45044 .34873 L
.45045 .34873 L
.45045 .34873 L
.45045 .34873 L
.45045 .34873 L
.45045 .34872 L
.45045 .34872 L
.45045 .34872 L
.45046 .34872 L
.45046 .34872 L
.45046 .34872 L
.45046 .34871 L
.45046 .34871 L
.45046 .34871 L
Mistroke
.45046 .34871 L
.45046 .34871 L
.45047 .34871 L
.45047 .3487 L
.45047 .3487 L
.45047 .3487 L
.45047 .3487 L
.45047 .3487 L
.45047 .34869 L
.45047 .34869 L
.45048 .34869 L
.45048 .34869 L
.45048 .34869 L
.45048 .34869 L
.45048 .34868 L
.45048 .34868 L
.45048 .34868 L
.45049 .34868 L
.45049 .34868 L
.45049 .34868 L
.45049 .34867 L
.45049 .34867 L
.45049 .34867 L
.45049 .34867 L
.45049 .34867 L
.4505 .34867 L
.4505 .34866 L
.4505 .34866 L
.4505 .34866 L
.4505 .34866 L
.4505 .34866 L
.4505 .34866 L
.4505 .34865 L
.45051 .34865 L
.45051 .34865 L
.45051 .34865 L
.45051 .34865 L
.45051 .34865 L
.45051 .34864 L
.45051 .34864 L
.45052 .34864 L
.45052 .34864 L
.45052 .34864 L
.45052 .34864 L
.45052 .34863 L
.45052 .34863 L
.45052 .34863 L
.45052 .34863 L
.45053 .34863 L
.45053 .34863 L
Mistroke
.45053 .34863 L
.45053 .34862 L
.45053 .34862 L
.45053 .34862 L
.45053 .34862 L
.45054 .34862 L
.45054 .34862 L
.45054 .34861 L
.45054 .34861 L
.45054 .34861 L
.45054 .34861 L
.45054 .34861 L
.45054 .34861 L
.45055 .3486 L
.45055 .3486 L
.45055 .3486 L
.45055 .3486 L
.45055 .3486 L
.45055 .3486 L
.45055 .34859 L
.45056 .34859 L
.45056 .34859 L
.45056 .34859 L
.45056 .34859 L
.45056 .34859 L
.45056 .34858 L
.45056 .34858 L
.45056 .34858 L
.45057 .34858 L
.45057 .34858 L
.45057 .34858 L
.45057 .34857 L
.45057 .34857 L
.45057 .34857 L
.45057 .34857 L
.45058 .34857 L
.45058 .34857 L
.45058 .34857 L
.45058 .34856 L
.45058 .34856 L
.45058 .34856 L
.45058 .34856 L
.45059 .34856 L
.45059 .34856 L
.45059 .34855 L
.45059 .34855 L
.45059 .34855 L
.45059 .34855 L
.45059 .34855 L
.45059 .34855 L
Mistroke
.4506 .34854 L
.4506 .34854 L
.4506 .34854 L
.4506 .34854 L
.4506 .34854 L
.4506 .34854 L
.4506 .34854 L
.45061 .34853 L
.45061 .34853 L
.45061 .34853 L
.45061 .34853 L
.45061 .34853 L
.45061 .34853 L
.45061 .34852 L
.45062 .34852 L
.45062 .34852 L
.45062 .34852 L
.45062 .34852 L
.45062 .34852 L
.45062 .34852 L
.45062 .34851 L
.45062 .34851 L
.45063 .34851 L
.45063 .34851 L
.45063 .34851 L
.45063 .34851 L
.45063 .3485 L
.45063 .3485 L
.45063 .3485 L
.45064 .3485 L
.45064 .3485 L
.45064 .3485 L
.45064 .3485 L
.45064 .34849 L
.45064 .34849 L
.45064 .34849 L
.45065 .34849 L
.45065 .34849 L
.45065 .34849 L
.45065 .34848 L
.45065 .34848 L
.45065 .34848 L
.45065 .34848 L
.45065 .34848 L
.45066 .34848 L
.45066 .34848 L
.45066 .34847 L
.45066 .34847 L
.45066 .34847 L
.45066 .34847 L
Mistroke
.45066 .34847 L
.45067 .34847 L
.45067 .34847 L
.45067 .34846 L
.45067 .34846 L
.45067 .34846 L
.45067 .34846 L
.45067 .34846 L
.45068 .34846 L
.45068 .34845 L
.45068 .34845 L
.45068 .34845 L
.45068 .34845 L
.45068 .34845 L
.45068 .34845 L
.45069 .34845 L
.45069 .34844 L
.45069 .34844 L
.45069 .34844 L
.45069 .34844 L
.45069 .34844 L
.45069 .34844 L
.4507 .34844 L
.4507 .34843 L
.4507 .34843 L
.4507 .34843 L
.4507 .34843 L
.4507 .34843 L
.4507 .34843 L
.45071 .34843 L
.45071 .34842 L
.45071 .34842 L
.45071 .34842 L
.45071 .34842 L
.45071 .34842 L
.45071 .34842 L
.45071 .34841 L
.45072 .34841 L
.45072 .34841 L
.45072 .34841 L
.45072 .34841 L
.45072 .34841 L
.45072 .34841 L
.45072 .3484 L
.45073 .3484 L
.45073 .3484 L
.45073 .3484 L
.45073 .3484 L
.45073 .3484 L
.45073 .3484 L
Mistroke
.45073 .34839 L
.45074 .34839 L
.45074 .34839 L
.45074 .34839 L
.45074 .34839 L
.45074 .34839 L
.45074 .34839 L
.45074 .34838 L
.45075 .34838 L
.45075 .34838 L
.45075 .34838 L
.45075 .34838 L
.45075 .34838 L
.45075 .34838 L
.45075 .34837 L
.45076 .34837 L
.45076 .34837 L
.45076 .34837 L
.45076 .34837 L
.45076 .34837 L
.45076 .34837 L
.45076 .34836 L
.45077 .34836 L
.45077 .34836 L
.45077 .34836 L
.45077 .34836 L
.45077 .34836 L
.45077 .34836 L
.45077 .34836 L
.45078 .34835 L
.45078 .34835 L
.45078 .34835 L
.45078 .34835 L
.45078 .34835 L
.45078 .34835 L
.45078 .34835 L
.45079 .34834 L
.45079 .34834 L
.45079 .34834 L
.45079 .34834 L
.45079 .34834 L
.45079 .34834 L
.45079 .34834 L
.4508 .34833 L
.4508 .34833 L
.4508 .34833 L
.4508 .34833 L
.4508 .34833 L
.4508 .34833 L
.4508 .34833 L
Mistroke
.45081 .34832 L
.45081 .34832 L
.45081 .34832 L
.45081 .34832 L
.45081 .34832 L
.45081 .34832 L
.45081 .34832 L
.45082 .34832 L
.45082 .34831 L
.45082 .34831 L
.45082 .34831 L
.45082 .34831 L
.45082 .34831 L
.45082 .34831 L
.45083 .34831 L
.45083 .3483 L
.45083 .3483 L
.45083 .3483 L
.45083 .3483 L
.45083 .3483 L
.45083 .3483 L
.45084 .3483 L
.45084 .34829 L
.45084 .34829 L
.45084 .34829 L
.45084 .34829 L
.45084 .34829 L
.45084 .34829 L
.45085 .34829 L
.45085 .34829 L
.45085 .34828 L
.45085 .34828 L
.45085 .34828 L
.45085 .34828 L
.45085 .34828 L
.45086 .34828 L
.45086 .34828 L
.45086 .34828 L
.45086 .34827 L
.45086 .34827 L
.45086 .34827 L
.45086 .34827 L
.45087 .34827 L
.45087 .34827 L
.45087 .34827 L
.45087 .34826 L
.45087 .34826 L
.45087 .34826 L
.45087 .34826 L
.45088 .34826 L
Mistroke
.45088 .34826 L
.45088 .34826 L
.45088 .34826 L
.45088 .34825 L
.45088 .34825 L
.45088 .34825 L
.45089 .34825 L
.45089 .34825 L
.45089 .34825 L
.45089 .34825 L
.45089 .34825 L
.45089 .34824 L
.45089 .34824 L
.4509 .34824 L
.4509 .34824 L
.4509 .34824 L
.4509 .34824 L
.4509 .34824 L
.4509 .34824 L
.4509 .34823 L
.45091 .34823 L
.45091 .34823 L
.45091 .34823 L
.45091 .34823 L
.45091 .34823 L
.45091 .34823 L
.45091 .34823 L
.45092 .34822 L
.45092 .34822 L
.45092 .34822 L
.45092 .34822 L
.45092 .34822 L
.45092 .34822 L
.45092 .34822 L
.45093 .34822 L
.45093 .34821 L
.45093 .34821 L
.45093 .34821 L
.45093 .34821 L
.45093 .34821 L
.45093 .34821 L
.45094 .34821 L
.45094 .34821 L
.45094 .3482 L
.45094 .3482 L
.45094 .3482 L
.45094 .3482 L
.45094 .3482 L
.45095 .3482 L
.45095 .3482 L
Mistroke
.45095 .3482 L
.45095 .34819 L
.45095 .34819 L
.45095 .34819 L
.45095 .34819 L
.45096 .34819 L
.45096 .34819 L
.45096 .34819 L
.45096 .34819 L
.45096 .34818 L
.45096 .34818 L
.45096 .34818 L
.45097 .34818 L
.45097 .34818 L
.45097 .34818 L
.45097 .34818 L
.45097 .34818 L
.45097 .34817 L
.45097 .34817 L
.45098 .34817 L
.45098 .34817 L
.45098 .34817 L
.45098 .34817 L
.45098 .34817 L
.45098 .34817 L
.45098 .34817 L
.45099 .34816 L
.45099 .34816 L
.45099 .34816 L
.45099 .34816 L
.45099 .34816 L
.45099 .34816 L
.45099 .34816 L
.451 .34816 L
.451 .34815 L
.451 .34815 L
.451 .34815 L
.451 .34815 L
.451 .34815 L
.451 .34815 L
.45101 .34815 L
.45101 .34815 L
.45101 .34815 L
.45101 .34814 L
.45101 .34814 L
.45101 .34814 L
.45101 .34814 L
.45102 .34814 L
.45102 .34814 L
.45102 .34814 L
Mistroke
.45102 .34814 L
.45102 .34813 L
.45102 .34813 L
.45102 .34813 L
.45103 .34813 L
.45103 .34813 L
.45103 .34813 L
.45103 .34813 L
.45103 .34813 L
.45103 .34813 L
.45103 .34812 L
.45104 .34812 L
.45104 .34812 L
.45104 .34812 L
.45104 .34812 L
.45104 .34812 L
.45104 .34812 L
.45104 .34812 L
.45105 .34812 L
.45105 .34811 L
.45105 .34811 L
.45105 .34811 L
.45105 .34811 L
.45105 .34811 L
.45106 .34811 L
.45106 .34811 L
.45106 .34811 L
.45106 .34811 L
.45106 .3481 L
.45106 .3481 L
.45106 .3481 L
.45107 .3481 L
.45107 .3481 L
.45107 .3481 L
.45107 .3481 L
.45107 .3481 L
.45107 .3481 L
.45107 .34809 L
.45108 .34809 L
.45108 .34809 L
.45108 .34809 L
.45108 .34809 L
.45108 .34809 L
.45108 .34809 L
.45108 .34809 L
.45109 .34809 L
.45109 .34808 L
.45109 .34808 L
.45109 .34808 L
.45109 .34808 L
Mistroke
.45109 .34808 L
.45109 .34808 L
.4511 .34808 L
.4511 .34808 L
.4511 .34808 L
.4511 .34807 L
.4511 .34807 L
.4511 .34807 L
.4511 .34807 L
.45111 .34807 L
.45111 .34807 L
.45111 .34807 L
.45111 .34807 L
.45111 .34807 L
.45111 .34806 L
.45111 .34806 L
.45112 .34806 L
.45112 .34806 L
.45112 .34806 L
.45112 .34806 L
.45112 .34806 L
.45112 .34806 L
.45112 .34806 L
.45113 .34806 L
.45113 .34805 L
.45113 .34805 L
.45113 .34805 L
.45113 .34805 L
.45113 .34805 L
.45113 .34805 L
.45114 .34805 L
.45114 .34805 L
.45114 .34805 L
.45114 .34804 L
.45114 .34804 L
.45114 .34804 L
.45114 .34804 L
.45115 .34804 L
.45115 .34804 L
.45115 .34804 L
.45115 .34804 L
.45115 .34804 L
.45115 .34804 L
.45115 .34803 L
.45116 .34803 L
.45116 .34803 L
.45116 .34803 L
.45116 .34803 L
.45116 .34803 L
.45116 .34803 L
Mistroke
.45116 .34803 L
.45117 .34803 L
.45117 .34803 L
.45117 .34802 L
.45117 .34802 L
.45117 .34802 L
.45117 .34802 L
.45117 .34802 L
.45118 .34802 L
.45118 .34802 L
.45118 .34802 L
.45118 .34802 L
.45118 .34802 L
.45118 .34801 L
.45118 .34801 L
.45119 .34801 L
.45119 .34801 L
.45119 .34801 L
.45119 .34801 L
.45119 .34801 L
.45119 .34801 L
.45119 .34801 L
.4512 .34801 L
.4512 .348 L
.4512 .348 L
.4512 .348 L
.4512 .348 L
.4512 .348 L
.4512 .348 L
.45121 .348 L
.45121 .348 L
.45121 .348 L
.45121 .348 L
.45121 .34799 L
.45121 .34799 L
.45121 .34799 L
.45122 .34799 L
.45122 .34799 L
.45122 .34799 L
.45122 .34799 L
.45122 .34799 L
.45122 .34799 L
.45122 .34799 L
.45123 .34799 L
.45123 .34798 L
.45123 .34798 L
.45123 .34798 L
.45123 .34798 L
.45123 .34798 L
.45123 .34798 L
Mistroke
.45124 .34798 L
.45124 .34798 L
.45124 .34798 L
.45124 .34798 L
.45124 .34797 L
.45124 .34797 L
.45124 .34797 L
.45125 .34797 L
.45125 .34797 L
.45125 .34797 L
.45125 .34797 L
.45125 .34797 L
.45125 .34797 L
.45125 .34797 L
.45126 .34797 L
.45126 .34796 L
.45126 .34796 L
.45126 .34796 L
.45126 .34796 L
.45126 .34796 L
.45126 .34796 L
.45127 .34796 L
.45127 .34796 L
.45127 .34796 L
.45127 .34796 L
.45127 .34796 L
.45127 .34795 L
.45127 .34795 L
.45127 .34795 L
.45128 .34795 L
.45128 .34795 L
.45128 .34795 L
.45128 .34795 L
.45128 .34795 L
.45128 .34795 L
.45128 .34795 L
.45129 .34795 L
.45129 .34794 L
.45129 .34794 L
.45129 .34794 L
.45129 .34794 L
.45129 .34794 L
.45129 .34794 L
.4513 .34794 L
.4513 .34794 L
.4513 .34794 L
.4513 .34794 L
.4513 .34794 L
.4513 .34793 L
.4513 .34793 L
Mistroke
.45131 .34793 L
.45131 .34793 L
.45131 .34793 L
.45131 .34793 L
.45131 .34793 L
.45131 .34793 L
.45131 .34793 L
.45132 .34793 L
.45132 .34793 L
.45132 .34793 L
.45132 .34792 L
.45132 .34792 L
.45132 .34792 L
.45132 .34792 L
.45133 .34792 L
.45133 .34792 L
.45133 .34792 L
.45133 .34792 L
.45133 .34792 L
.45133 .34792 L
.45133 .34792 L
.45134 .34792 L
.45134 .34791 L
.45134 .34791 L
.45134 .34791 L
.45134 .34791 L
.45134 .34791 L
.45134 .34791 L
.45135 .34791 L
.45135 .34791 L
.45135 .34791 L
.45135 .34791 L
.45135 .34791 L
.45135 .34791 L
.45135 .3479 L
.45135 .3479 L
.45136 .3479 L
.45136 .3479 L
.45136 .3479 L
.45136 .3479 L
.45136 .3479 L
.45136 .3479 L
.45136 .3479 L
.45137 .3479 L
.45137 .3479 L
.45137 .3479 L
.45137 .34789 L
.45137 .34789 L
.45137 .34789 L
.45137 .34789 L
Mistroke
.45138 .34789 L
.45138 .34789 L
.45138 .34789 L
.45138 .34789 L
.45138 .34789 L
.45138 .34789 L
.45138 .34789 L
.45139 .34789 L
.45139 .34788 L
.45139 .34788 L
.45139 .34788 L
.45139 .34788 L
.45139 .34788 L
.45139 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34788 L
.4514 .34787 L
.45141 .34787 L
.45141 .34787 L
.45141 .34787 L
.45141 .34787 L
.45141 .34787 L
.45141 .34787 L
.45141 .34787 L
.45142 .34787 L
.45142 .34787 L
.45142 .34787 L
.45142 .34787 L
.45142 .34787 L
.45142 .34786 L
.45142 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45143 .34786 L
.45144 .34786 L
.45144 .34786 L
.45144 .34786 L
.45144 .34785 L
.45144 .34785 L
.45144 .34785 L
Mistroke
.45144 .34785 L
.45145 .34785 L
.45145 .34785 L
.45145 .34785 L
.45145 .34785 L
.45145 .34785 L
.45145 .34785 L
.45145 .34785 L
.45146 .34785 L
.45146 .34785 L
.45146 .34785 L
.45146 .34784 L
.45146 .34784 L
.45146 .34784 L
.45146 .34784 L
.45146 .34784 L
.45147 .34784 L
.45147 .34784 L
.45147 .34784 L
.45147 .34784 L
.45147 .34784 L
.45147 .34784 L
.45147 .34784 L
.45148 .34784 L
.45148 .34784 L
.45148 .34783 L
.45148 .34783 L
.45148 .34783 L
.45148 .34783 L
.45148 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.45149 .34783 L
.4515 .34783 L
.4515 .34782 L
.4515 .34782 L
.4515 .34782 L
.4515 .34782 L
.4515 .34782 L
.4515 .34782 L
.45151 .34782 L
.45151 .34782 L
.45151 .34782 L
.45151 .34782 L
.45151 .34782 L
Mistroke
.45151 .34782 L
.45151 .34782 L
.45151 .34782 L
.45152 .34782 L
.45152 .34781 L
.45152 .34781 L
.45152 .34781 L
.45152 .34781 L
.45152 .34781 L
.45152 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45153 .34781 L
.45154 .34781 L
.45154 .3478 L
.45154 .3478 L
.45154 .3478 L
.45154 .3478 L
.45154 .3478 L
.45154 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45155 .3478 L
.45156 .3478 L
.45156 .3478 L
.45156 .34779 L
.45156 .34779 L
.45156 .34779 L
.45156 .34779 L
.45156 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45157 .34779 L
.45158 .34779 L
.45158 .34779 L
Mistroke
.45158 .34779 L
.45158 .34778 L
.45158 .34778 L
.45158 .34778 L
.45158 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.45159 .34778 L
.4516 .34778 L
.4516 .34778 L
.4516 .34778 L
.4516 .34778 L
.4516 .34778 L
.4516 .34777 L
.4516 .34777 L
.4516 .34777 L
.45161 .34777 L
.45161 .34777 L
.45161 .34777 L
.45161 .34777 L
.45161 .34777 L
.45161 .34777 L
.45161 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34777 L
.45162 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45163 .34776 L
.45164 .34776 L
.45164 .34776 L
.45164 .34776 L
.45164 .34776 L
.45164 .34776 L
.45164 .34776 L
Mistroke
.45164 .34776 L
.45165 .34776 L
.45165 .34776 L
.45165 .34775 L
.45165 .34775 L
.45165 .34775 L
.45165 .34775 L
.45165 .34775 L
.45165 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45166 .34775 L
.45167 .34775 L
.45167 .34775 L
.45167 .34775 L
.45167 .34775 L
.45167 .34775 L
.45167 .34774 L
.45167 .34774 L
.45167 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45168 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.45169 .34774 L
.4517 .34774 L
.4517 .34773 L
.4517 .34773 L
.4517 .34773 L
.4517 .34773 L
.4517 .34773 L
.4517 .34773 L
.4517 .34773 L
.45171 .34773 L
Mistroke
.45171 .34773 L
.45171 .34773 L
.45171 .34773 L
.45171 .34773 L
.45171 .34773 L
.45171 .34773 L
.45171 .34773 L
.45172 .34773 L
.45172 .34773 L
.45172 .34773 L
.45172 .34773 L
.45172 .34773 L
.45172 .34773 L
.45172 .34772 L
.45172 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45173 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45174 .34772 L
.45175 .34772 L
.45175 .34772 L
.45175 .34772 L
.45175 .34772 L
.45175 .34771 L
.45175 .34771 L
.45175 .34771 L
.45175 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45176 .34771 L
.45177 .34771 L
.45177 .34771 L
.45177 .34771 L
Mistroke
.45177 .34771 L
.45177 .34771 L
.45177 .34771 L
.45177 .34771 L
.45177 .34771 L
.45178 .34771 L
.45178 .34771 L
.45178 .34771 L
.45178 .3477 L
.45178 .3477 L
.45178 .3477 L
.45178 .3477 L
.45178 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.45179 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.4518 .3477 L
.45181 .3477 L
.45181 .3477 L
.45181 .3477 L
.45181 .34769 L
.45181 .34769 L
.45181 .34769 L
.45181 .34769 L
.45181 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45182 .34769 L
.45183 .34769 L
.45183 .34769 L
.45183 .34769 L
Mistroke
.45183 .34769 L
.45183 .34769 L
.45183 .34769 L
.45183 .34769 L
.45183 .34769 L
.45184 .34769 L
.45184 .34769 L
.45184 .34769 L
.45184 .34769 L
.45184 .34769 L
.45184 .34769 L
.45184 .34768 L
.45184 .34768 L
.45184 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45185 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45186 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45187 .34768 L
.45188 .34768 L
.45188 .34768 L
.45188 .34767 L
.45188 .34767 L
.45188 .34767 L
.45188 .34767 L
.45188 .34767 L
.45188 .34767 L
.45188 .34767 L
.45189 .34767 L
.45189 .34767 L
Mistroke
.45189 .34767 L
.45189 .34767 L
.45189 .34767 L
.45189 .34767 L
.45189 .34767 L
.45189 .34767 L
.45189 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.4519 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45191 .34767 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45192 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45193 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
.45194 .34766 L
Mistroke
.45194 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45195 .34766 L
.45196 .34766 L
.45196 .34766 L
.45196 .34766 L
.45196 .34765 L
.45196 .34765 L
.45196 .34765 L
.45196 .34765 L
.45196 .34765 L
.45196 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45197 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45198 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.45199 .34765 L
.452 .34765 L
.452 .34765 L
.452 .34765 L
Mistroke
.452 .34765 L
.452 .34765 L
.452 .34765 L
.452 .34765 L
.452 .34765 L
.452 .34765 L
.45201 .34765 L
.45201 .34765 L
.45201 .34765 L
.45201 .34765 L
.45201 .34764 L
.45201 .34764 L
.45201 .34764 L
.45201 .34764 L
.45201 .34764 L
.45201 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45202 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45203 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45204 .34764 L
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
Mistroke
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
.45205 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45206 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45207 .34764 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45208 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.45209 .34763 L
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
Mistroke
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
.4521 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45211 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45212 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45213 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45214 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
Mistroke
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45215 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45216 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45217 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45218 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.45219 .34763 L
.4522 .34763 L
Mistroke
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.4522 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45221 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45222 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45223 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
Mistroke
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45224 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45225 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45226 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45227 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
Mistroke
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45228 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.45229 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.4523 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45231 .34763 L
.45232 .34763 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
Mistroke
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45232 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45233 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45234 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45235 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
Mistroke
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45236 .34764 L
.45237 .34764 L
.45237 .34764 L
.45237 .34764 L
.45237 .34764 L
.45237 .34764 L
.45237 .34764 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45237 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45238 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
Mistroke
.45239 .34765 L
.45239 .34765 L
.45239 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.4524 .34765 L
.45241 .34765 L
.45241 .34765 L
.45241 .34765 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45241 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45242 .34766 L
.45243 .34766 L
Mistroke
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45243 .34766 L
.45244 .34766 L
.45244 .34766 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45244 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45245 .34767 L
.45246 .34767 L
.45246 .34767 L
Mistroke
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34767 L
.45246 .34768 L
.45246 .34768 L
.45246 .34768 L
.45246 .34768 L
.45246 .34768 L
.45246 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45247 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34768 L
.45248 .34769 L
.45248 .34769 L
.45248 .34769 L
Mistroke
.45248 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.45249 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .34769 L
.4525 .3477 L
.4525 .3477 L
.4525 .3477 L
.4525 .3477 L
.4525 .3477 L
.4525 .3477 L
.4525 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
Mistroke
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45251 .3477 L
.45252 .3477 L
.45252 .3477 L
.45252 .3477 L
.45252 .3477 L
.45252 .3477 L
.45252 .3477 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45252 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34771 L
.45253 .34772 L
.45253 .34772 L
.45253 .34772 L
Mistroke
.45253 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45254 .34772 L
.45255 .34772 L
.45255 .34772 L
.45255 .34772 L
.45255 .34772 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45255 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
Mistroke
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34773 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45256 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34774 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45257 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
Mistroke
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34775 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45258 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34776 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
Mistroke
.45259 .34777 L
.45259 .34777 L
.45259 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34777 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.4526 .34778 L
.45261 .34778 L
.45261 .34778 L
.45261 .34778 L
.45261 .34778 L
.45261 .34778 L
.45261 .34778 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
Mistroke
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .34779 L
.45261 .3478 L
.45261 .3478 L
.45261 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .3478 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
Mistroke
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45262 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34781 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34782 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45263 .34783 L
.45264 .34783 L
.45264 .34783 L
Mistroke
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34783 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34784 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45264 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
Mistroke
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34785 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34786 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
Mistroke
.45265 .34787 L
.45265 .34787 L
.45265 .34787 L
.45265 .34788 L
.45265 .34788 L
.45265 .34788 L
.45265 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34788 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .34789 L
.45266 .3479 L
.45266 .3479 L
Mistroke
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .3479 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34791 L
.45266 .34792 L
.45266 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
Mistroke
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34792 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34793 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
Mistroke
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34794 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34795 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
.45267 .34796 L
Mistroke
.45267 .34796 L
.45267 .34796 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34797 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34798 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
Mistroke
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .34799 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .348 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
Mistroke
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34801 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34802 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
Mistroke
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34803 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34804 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45267 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34805 L
.45266 .34806 L
.45266 .34806 L
Mistroke
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34806 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34807 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
Mistroke
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34808 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .34809 L
.45266 .3481 L
.45266 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
Mistroke
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .3481 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34811 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
Mistroke
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34812 L
.45265 .34813 L
.45265 .34813 L
.45265 .34813 L
.45265 .34813 L
.45265 .34813 L
.45265 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34813 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
.45264 .34814 L
Mistroke
.45264 .34814 L
.45264 .34814 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45264 .34815 L
.45263 .34815 L
.45263 .34815 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34816 L
.45263 .34817 L
Mistroke
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34817 L
.45263 .34818 L
.45263 .34818 L
.45263 .34818 L
.45263 .34818 L
.45263 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34818 L
.45262 .34819 L
.45262 .34819 L
Mistroke
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .34819 L
.45262 .3482 L
.45262 .3482 L
.45262 .3482 L
.45262 .3482 L
.45262 .3482 L
.45262 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .3482 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
Mistroke
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34821 L
.45261 .34822 L
.45261 .34822 L
.45261 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34822 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
Mistroke
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.4526 .34823 L
.45259 .34823 L
.45259 .34823 L
.45259 .34823 L
.45259 .34823 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34824 L
.45259 .34825 L
Mistroke
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45259 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34825 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
.45258 .34826 L
Mistroke
.45258 .34826 L
.45258 .34826 L
.45257 .34826 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34827 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45257 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
Mistroke
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34828 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45256 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .34829 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
Mistroke
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .3483 L
.45255 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34831 L
.45254 .34832 L
.45254 .34832 L
.45254 .34832 L
Mistroke
.45254 .34832 L
.45254 .34832 L
.45254 .34832 L
.45254 .34832 L
.45254 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34832 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45253 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
Mistroke
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34833 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45252 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34834 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
Mistroke
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.45251 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34835 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.4525 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
Mistroke
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34836 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45249 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34837 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
Mistroke
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45248 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34838 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
.45247 .34839 L
Mistroke
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .34839 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45246 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
Mistroke
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .3484 L
.45245 .34841 L
.45245 .34841 L
.45245 .34841 L
.45245 .34841 L
.45245 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
.45244 .34841 L
Mistroke
.45244 .34841 L
.45244 .34841 L
.45243 .34841 L
.45243 .34841 L
.45243 .34841 L
.45243 .34841 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45243 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
.45242 .34842 L
Mistroke
.45242 .34842 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45242 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34843 L
.45241 .34844 L
Mistroke
.45241 .34844 L
.45241 .34844 L
.45241 .34844 L
.45241 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.4524 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
.45239 .34844 L
Mistroke
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45239 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
Mistroke
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34845 L
.45238 .34846 L
.45238 .34846 L
.45238 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45237 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
Mistroke
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34846 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45236 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
Mistroke
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45235 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34847 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
.45234 .34848 L
Mistroke
.45234 .34848 L
.45234 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45233 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
Mistroke
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34848 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45232 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
Mistroke
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.45231 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
Mistroke
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.4523 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .34849 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45229 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
Mistroke
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45228 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
Mistroke
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45227 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
.45226 .3485 L
Mistroke
.45226 .3485 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45226 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
Mistroke
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45225 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
Mistroke
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45224 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
Mistroke
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45223 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
Mistroke
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45222 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
Mistroke
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.45221 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
Mistroke
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.4522 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
Mistroke
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45219 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
Mistroke
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45218 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
Mistroke
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
Mistroke
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45217 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
Mistroke
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45216 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .34851 L
.45215 .3485 L
.45215 .3485 L
Mistroke
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
Mistroke
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45215 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
Mistroke
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
Mistroke
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45214 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .3485 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
Mistroke
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
Mistroke
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45213 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
Mistroke
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34849 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
Mistroke
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
Mistroke
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45212 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34848 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
Mistroke
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
Mistroke
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
.45211 .34847 L
Mistroke
.45211 .34847 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
Mistroke
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
Mistroke
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34846 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
Mistroke
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
Mistroke
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34845 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
Mistroke
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.4521 .34844 L
.45211 .34844 L
.45211 .34844 L
Mistroke
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34844 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
Mistroke
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
Mistroke
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34843 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
Mistroke
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
Mistroke
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34842 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
Mistroke
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
Mistroke
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
Mistroke
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .34841 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
Mistroke
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45211 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
Mistroke
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .3484 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
Mistroke
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
Mistroke
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
.45212 .34839 L
Mistroke
.45212 .34839 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
Mistroke
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
Mistroke
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34838 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
Mistroke
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
Mistroke
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45213 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
Mistroke
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34837 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
Mistroke
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
Mistroke
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45214 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
Mistroke
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
Mistroke
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34836 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
Mistroke
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
Mistroke
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
Mistroke
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
Mistroke
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
Mistroke
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34835 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
Mistroke
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
Mistroke
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
Mistroke
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
Mistroke
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45217 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
Mistroke
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
Mistroke
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
Mistroke
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
Mistroke
.45218 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
Mistroke
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
Mistroke
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
Mistroke
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
Mistroke
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
Mistroke
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.4522 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
Mistroke
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
Mistroke
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45221 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
.45222 .34835 L
Mistroke
.45222 .34835 L
Mfstroke
0 1 .389 r
.13349 .23869 m
.13384 .23847 L
.1342 .23825 L
.13455 .23803 L
.13491 .23781 L
.13526 .23759 L
.13562 .23738 L
.13597 .23716 L
.13632 .23694 L
.13668 .23673 L
.13703 .23651 L
.13738 .2363 L
.13774 .23608 L
.13809 .23587 L
.13844 .23565 L
.1388 .23544 L
.13915 .23522 L
.1395 .23501 L
.13985 .2348 L
.14021 .23459 L
.14056 .23438 L
.14091 .23416 L
.14126 .23395 L
.14161 .23374 L
.14196 .23353 L
.14232 .23332 L
.14267 .23311 L
.14302 .23291 L
.14337 .2327 L
.14372 .23249 L
.14407 .23228 L
.14442 .23207 L
.14477 .23187 L
.14512 .23166 L
.14547 .23146 L
.14582 .23125 L
.14617 .23105 L
.14652 .23084 L
.14687 .23064 L
.14722 .23043 L
.14756 .23023 L
.14791 .23003 L
.14826 .22982 L
.14861 .22962 L
.14896 .22942 L
.14931 .22922 L
.14965 .22902 L
.15 .22881 L
.15035 .22861 L
.1507 .22841 L
Mistroke
.15105 .22821 L
.15139 .22802 L
.15174 .22782 L
.15209 .22762 L
.15243 .22742 L
.15278 .22722 L
.15313 .22702 L
.15347 .22683 L
.15382 .22663 L
.15417 .22644 L
.15451 .22624 L
.15486 .22604 L
.1552 .22585 L
.15555 .22565 L
.15589 .22546 L
.15624 .22527 L
.15658 .22507 L
.15693 .22488 L
.15727 .22469 L
.15762 .22449 L
.15796 .2243 L
.15831 .22411 L
.15865 .22392 L
.15899 .22373 L
.15934 .22354 L
.15968 .22335 L
.16003 .22316 L
.16037 .22297 L
.16071 .22278 L
.16106 .22259 L
.1614 .2224 L
.16174 .22221 L
.16208 .22203 L
.16243 .22184 L
.16277 .22165 L
.16311 .22147 L
.16345 .22128 L
.1638 .22109 L
.16414 .22091 L
.16448 .22072 L
.16482 .22054 L
.16516 .22036 L
.16551 .22017 L
.16585 .21999 L
.16619 .2198 L
.16653 .21962 L
.16687 .21944 L
.16721 .21926 L
.16755 .21907 L
.16789 .21889 L
Mistroke
.16823 .21871 L
.16857 .21853 L
.16891 .21835 L
.16925 .21817 L
.16959 .21799 L
.16993 .21781 L
.17027 .21763 L
.17061 .21745 L
.17095 .21728 L
.17129 .2171 L
.17163 .21692 L
.17197 .21674 L
.1723 .21657 L
.17264 .21639 L
.17298 .21621 L
.17332 .21604 L
.17366 .21586 L
.174 .21569 L
.17433 .21551 L
.17467 .21534 L
.17501 .21516 L
.17535 .21499 L
.17568 .21482 L
.17602 .21464 L
.17636 .21447 L
.1767 .2143 L
.17703 .21412 L
.17737 .21395 L
.17771 .21378 L
.17804 .21361 L
.17838 .21344 L
.17871 .21327 L
.17905 .2131 L
.17939 .21293 L
.17972 .21276 L
.18006 .21259 L
.18039 .21242 L
.18073 .21225 L
.18107 .21208 L
.1814 .21192 L
.18174 .21175 L
.18207 .21158 L
.18241 .21141 L
.18274 .21125 L
.18307 .21108 L
.18341 .21092 L
.18374 .21075 L
.18408 .21058 L
.18441 .21042 L
.18475 .21026 L
Mistroke
.18508 .21009 L
.18541 .20993 L
.18575 .20976 L
.18608 .2096 L
.18641 .20944 L
.18675 .20927 L
.18708 .20911 L
.18741 .20895 L
.18775 .20879 L
.18808 .20863 L
.18841 .20847 L
.18874 .2083 L
.18908 .20814 L
.18941 .20798 L
.18974 .20782 L
.19007 .20766 L
.1904 .2075 L
.19074 .20735 L
.19107 .20719 L
.1914 .20703 L
.19173 .20687 L
.19206 .20671 L
.19239 .20656 L
.19272 .2064 L
.19306 .20624 L
.19339 .20609 L
.19372 .20593 L
.19405 .20577 L
.19438 .20562 L
.19471 .20546 L
.19504 .20531 L
.19537 .20515 L
.1957 .205 L
.19603 .20484 L
.19636 .20469 L
.19669 .20454 L
.19702 .20438 L
.19735 .20423 L
.19768 .20408 L
.19801 .20393 L
.19833 .20377 L
.19866 .20362 L
.19899 .20347 L
.19932 .20332 L
.19965 .20317 L
.19998 .20302 L
.20031 .20287 L
.20063 .20272 L
.20096 .20257 L
.20129 .20242 L
Mistroke
.20162 .20227 L
.20195 .20212 L
.20227 .20197 L
.2026 .20183 L
.20293 .20168 L
.20326 .20153 L
.20358 .20138 L
.20391 .20124 L
.20424 .20109 L
.20456 .20094 L
.20489 .2008 L
.20522 .20065 L
.20554 .20051 L
.20587 .20036 L
.2062 .20022 L
.20652 .20007 L
.20685 .19993 L
.20718 .19978 L
.2075 .19964 L
.20783 .1995 L
.20815 .19935 L
.20848 .19921 L
.2088 .19907 L
.20913 .19892 L
.20945 .19878 L
.20978 .19864 L
.2101 .1985 L
.21043 .19836 L
.21075 .19822 L
.21108 .19808 L
.2114 .19794 L
.21173 .1978 L
.21205 .19766 L
.21238 .19752 L
.2127 .19738 L
.21302 .19724 L
.21335 .1971 L
.21367 .19696 L
.214 .19682 L
.21432 .19668 L
.21464 .19655 L
.21497 .19641 L
.21529 .19627 L
.21561 .19614 L
.21594 .196 L
.21626 .19586 L
.21658 .19573 L
.2169 .19559 L
.21723 .19545 L
.21755 .19532 L
Mistroke
.21787 .19518 L
.21819 .19505 L
.21852 .19492 L
.21884 .19478 L
.21916 .19465 L
.21948 .19451 L
.2198 .19438 L
.22013 .19425 L
.22045 .19411 L
.22077 .19398 L
.22109 .19385 L
.22141 .19372 L
.22173 .19359 L
.22205 .19345 L
.22237 .19332 L
.22269 .19319 L
.22302 .19306 L
.22334 .19293 L
.22366 .1928 L
.22398 .19267 L
.2243 .19254 L
.22462 .19241 L
.22494 .19228 L
.22526 .19215 L
.22558 .19203 L
.2259 .1919 L
.22622 .19177 L
.22654 .19164 L
.22686 .19151 L
.22717 .19139 L
.22749 .19126 L
.22781 .19113 L
.22813 .19101 L
.22845 .19088 L
.22877 .19075 L
.22909 .19063 L
.22941 .1905 L
.22973 .19038 L
.23004 .19025 L
.23036 .19013 L
.23068 .19 L
.231 .18988 L
.23132 .18975 L
.23163 .18963 L
.23195 .18951 L
.23227 .18938 L
.23259 .18926 L
.23291 .18914 L
.23322 .18901 L
.23354 .18889 L
Mistroke
.23386 .18877 L
.23417 .18865 L
.23449 .18853 L
.23481 .18841 L
.23512 .18828 L
.23544 .18816 L
.23576 .18804 L
.23607 .18792 L
.23639 .1878 L
.23671 .18768 L
.23702 .18756 L
.23734 .18744 L
.23766 .18732 L
.23797 .18721 L
.23829 .18709 L
.2386 .18697 L
.23892 .18685 L
.23923 .18673 L
.23955 .18661 L
.23986 .1865 L
.24018 .18638 L
.2405 .18626 L
.24081 .18615 L
.24113 .18603 L
.24144 .18591 L
.24175 .1858 L
.24207 .18568 L
.24238 .18557 L
.2427 .18545 L
.24301 .18534 L
.24333 .18522 L
.24364 .18511 L
.24395 .18499 L
.24427 .18488 L
.24458 .18476 L
.2449 .18465 L
.24521 .18454 L
.24552 .18442 L
.24584 .18431 L
.24615 .1842 L
.24646 .18409 L
.24678 .18397 L
.24709 .18386 L
.2474 .18375 L
.24772 .18364 L
.24803 .18353 L
.24834 .18342 L
.24865 .1833 L
.24897 .18319 L
.24928 .18308 L
Mistroke
.24959 .18297 L
.2499 .18286 L
.25021 .18275 L
.25053 .18264 L
.25084 .18253 L
.25115 .18243 L
.25146 .18232 L
.25177 .18221 L
.25209 .1821 L
.2524 .18199 L
.25271 .18188 L
.25302 .18178 L
.25333 .18167 L
.25364 .18156 L
.25395 .18145 L
.25426 .18135 L
.25457 .18124 L
.25488 .18113 L
.25519 .18103 L
.25551 .18092 L
.25582 .18082 L
.25613 .18071 L
.25644 .18061 L
.25675 .1805 L
.25706 .1804 L
.25737 .18029 L
.25768 .18019 L
.25799 .18008 L
.2583 .17998 L
.2586 .17988 L
.25891 .17977 L
.25922 .17967 L
.25953 .17957 L
.25984 .17946 L
.26015 .17936 L
.26046 .17926 L
.26077 .17916 L
.26108 .17905 L
.26139 .17895 L
.26169 .17885 L
.262 .17875 L
.26231 .17865 L
.26262 .17855 L
.26293 .17845 L
.26324 .17835 L
.26354 .17825 L
.26385 .17815 L
.26416 .17805 L
.26447 .17795 L
.26478 .17785 L
Mistroke
.26508 .17775 L
.26539 .17765 L
.2657 .17755 L
.266 .17745 L
.26631 .17735 L
.26662 .17726 L
.26693 .17716 L
.26723 .17706 L
.26754 .17696 L
.26785 .17686 L
.26815 .17677 L
.26846 .17667 L
.26877 .17657 L
.26907 .17648 L
.26938 .17638 L
.26968 .17629 L
.26999 .17619 L
.2703 .17609 L
.2706 .176 L
.27091 .1759 L
.27121 .17581 L
.27152 .17571 L
.27183 .17562 L
.27213 .17552 L
.27244 .17543 L
.27274 .17534 L
.27305 .17524 L
.27335 .17515 L
.27366 .17506 L
.27396 .17496 L
.27427 .17487 L
.27457 .17478 L
.27488 .17468 L
.27518 .17459 L
.27548 .1745 L
.27579 .17441 L
.27609 .17432 L
.2764 .17422 L
.2767 .17413 L
.27701 .17404 L
.27731 .17395 L
.27761 .17386 L
.27792 .17377 L
.27822 .17368 L
.27852 .17359 L
.27883 .1735 L
.27913 .17341 L
.27943 .17332 L
.27974 .17323 L
.28004 .17314 L
Mistroke
.28034 .17305 L
.28065 .17296 L
.28095 .17287 L
.28125 .17279 L
.28155 .1727 L
.28186 .17261 L
.28216 .17252 L
.28246 .17243 L
.28276 .17235 L
.28307 .17226 L
.28337 .17217 L
.28367 .17209 L
.28397 .172 L
.28427 .17191 L
.28457 .17183 L
.28488 .17174 L
.28518 .17165 L
.28548 .17157 L
.28578 .17148 L
.28608 .1714 L
.28638 .17131 L
.28668 .17123 L
.28699 .17114 L
.28729 .17106 L
.28759 .17097 L
.28789 .17089 L
.28819 .17081 L
.28849 .17072 L
.28879 .17064 L
.28909 .17056 L
.28939 .17047 L
.28969 .17039 L
.28999 .17031 L
.29029 .17022 L
.29059 .17014 L
.29089 .17006 L
.29119 .16998 L
.29149 .1699 L
.29179 .16981 L
.29209 .16973 L
.29239 .16965 L
.29269 .16957 L
.29299 .16949 L
.29329 .16941 L
.29358 .16933 L
.29388 .16925 L
.29418 .16917 L
.29448 .16909 L
.29478 .16901 L
.29508 .16893 L
Mistroke
.29538 .16885 L
.29568 .16877 L
.29597 .16869 L
.29627 .16861 L
.29657 .16853 L
.29687 .16845 L
.29717 .16837 L
.29746 .1683 L
.29776 .16822 L
.29806 .16814 L
.29836 .16806 L
.29865 .16799 L
.29895 .16791 L
.29925 .16783 L
.29955 .16775 L
.29984 .16768 L
.30014 .1676 L
.30044 .16752 L
.30073 .16745 L
.30103 .16737 L
.30133 .1673 L
.30162 .16722 L
.30192 .16715 L
.30222 .16707 L
.30251 .167 L
.30281 .16692 L
.30311 .16685 L
.3034 .16677 L
.3037 .1667 L
.30399 .16662 L
.30429 .16655 L
.30459 .16647 L
.30488 .1664 L
.30518 .16633 L
.30547 .16625 L
.30577 .16618 L
.30606 .16611 L
.30636 .16603 L
.30665 .16596 L
.30695 .16589 L
.30724 .16582 L
.30754 .16574 L
.30783 .16567 L
.30813 .1656 L
.30842 .16553 L
.30872 .16546 L
.30901 .16539 L
.30931 .16532 L
.3096 .16524 L
.30989 .16517 L
Mistroke
.31019 .1651 L
.31048 .16503 L
.31078 .16496 L
.31107 .16489 L
.31136 .16482 L
.31166 .16475 L
.31195 .16468 L
.31224 .16461 L
.31254 .16455 L
.31283 .16448 L
.31312 .16441 L
.31342 .16434 L
.31371 .16427 L
.314 .1642 L
.3143 .16413 L
.31459 .16407 L
.31488 .164 L
.31517 .16393 L
.31547 .16386 L
.31576 .1638 L
.31605 .16373 L
.31634 .16366 L
.31664 .16359 L
.31693 .16353 L
.31722 .16346 L
.31751 .16339 L
.3178 .16333 L
.3181 .16326 L
.31839 .1632 L
.31868 .16313 L
.31897 .16307 L
.31926 .163 L
.31955 .16293 L
.31984 .16287 L
.32014 .16281 L
.32043 .16274 L
.32072 .16268 L
.32101 .16261 L
.3213 .16255 L
.32159 .16248 L
.32188 .16242 L
.32217 .16236 L
.32246 .16229 L
.32275 .16223 L
.32304 .16217 L
.32333 .1621 L
.32362 .16204 L
.32391 .16198 L
.3242 .16191 L
.32449 .16185 L
Mistroke
.32478 .16179 L
.32507 .16173 L
.32536 .16167 L
.32565 .1616 L
.32594 .16154 L
.32623 .16148 L
.32652 .16142 L
.32681 .16136 L
.3271 .1613 L
.32738 .16124 L
.32767 .16118 L
.32796 .16112 L
.32825 .16106 L
.32854 .161 L
.32883 .16094 L
.32912 .16088 L
.3294 .16082 L
.32969 .16076 L
.32998 .1607 L
.33027 .16064 L
.33056 .16058 L
.33084 .16052 L
.33113 .16046 L
.33142 .1604 L
.33171 .16034 L
.33199 .16029 L
.33228 .16023 L
.33257 .16017 L
.33286 .16011 L
.33314 .16006 L
.33343 .16 L
.33372 .15994 L
.334 .15988 L
.33429 .15983 L
.33458 .15977 L
.33486 .15971 L
.33515 .15966 L
.33544 .1596 L
.33572 .15954 L
.33601 .15949 L
.3363 .15943 L
.33658 .15938 L
.33687 .15932 L
.33715 .15927 L
.33744 .15921 L
.33773 .15915 L
.33801 .1591 L
.3383 .15905 L
.33858 .15899 L
.33887 .15894 L
Mistroke
.33915 .15888 L
.33944 .15883 L
.33972 .15877 L
.34001 .15872 L
.34029 .15867 L
.34058 .15861 L
.34086 .15856 L
.34115 .15851 L
.34143 .15845 L
.34172 .1584 L
.342 .15835 L
.34229 .15829 L
.34257 .15824 L
.34285 .15819 L
.34314 .15814 L
.34342 .15808 L
.34371 .15803 L
.34399 .15798 L
.34427 .15793 L
.34456 .15788 L
.34484 .15783 L
.34512 .15778 L
.34541 .15772 L
.34569 .15767 L
.34597 .15762 L
.34626 .15757 L
.34654 .15752 L
.34682 .15747 L
.34711 .15742 L
.34739 .15737 L
.34767 .15732 L
.34795 .15727 L
.34824 .15722 L
.34852 .15717 L
.3488 .15712 L
.34908 .15707 L
.34937 .15703 L
.34965 .15698 L
.34993 .15693 L
.35021 .15688 L
.35049 .15683 L
.35077 .15678 L
.35106 .15674 L
.35134 .15669 L
.35162 .15664 L
.3519 .15659 L
.35218 .15654 L
.35246 .1565 L
.35274 .15645 L
.35302 .1564 L
Mistroke
.35331 .15636 L
.35359 .15631 L
.35387 .15626 L
.35415 .15622 L
.35443 .15617 L
.35471 .15612 L
.35499 .15608 L
.35527 .15603 L
.35555 .15599 L
.35583 .15594 L
.35611 .15589 L
.35639 .15585 L
.35667 .1558 L
.35695 .15576 L
.35723 .15571 L
.35751 .15567 L
.35779 .15563 L
.35807 .15558 L
.35835 .15554 L
.35862 .15549 L
.3589 .15545 L
.35918 .1554 L
.35946 .15536 L
.35974 .15532 L
.36002 .15527 L
.3603 .15523 L
.36058 .15519 L
.36085 .15514 L
.36113 .1551 L
.36141 .15506 L
.36169 .15502 L
.36197 .15497 L
.36225 .15493 L
.36252 .15489 L
.3628 .15485 L
.36308 .1548 L
.36336 .15476 L
.36363 .15472 L
.36391 .15468 L
.36419 .15464 L
.36447 .1546 L
.36474 .15456 L
.36502 .15452 L
.3653 .15447 L
.36557 .15443 L
.36585 .15439 L
.36613 .15435 L
.3664 .15431 L
.36668 .15427 L
.36696 .15423 L
Mistroke
.36723 .15419 L
.36751 .15415 L
.36779 .15411 L
.36806 .15407 L
.36834 .15403 L
.36861 .154 L
.36889 .15396 L
.36917 .15392 L
.36944 .15388 L
.36972 .15384 L
.36999 .1538 L
.37027 .15376 L
.37054 .15373 L
.37082 .15369 L
.37109 .15365 L
.37137 .15361 L
.37164 .15357 L
.37192 .15354 L
.37219 .1535 L
.37247 .15346 L
.37274 .15343 L
.37302 .15339 L
.37329 .15335 L
.37356 .15331 L
.37384 .15328 L
.37411 .15324 L
.37439 .15321 L
.37466 .15317 L
.37493 .15313 L
.37521 .1531 L
.37548 .15306 L
.37576 .15303 L
.37603 .15299 L
.3763 .15296 L
.37658 .15292 L
.37685 .15288 L
.37712 .15285 L
.37739 .15282 L
.37767 .15278 L
.37794 .15275 L
.37821 .15271 L
.37849 .15268 L
.37876 .15264 L
.37903 .15261 L
.3793 .15258 L
.37958 .15254 L
.37985 .15251 L
.38012 .15247 L
.38039 .15244 L
.38066 .15241 L
Mistroke
.38094 .15237 L
.38121 .15234 L
.38148 .15231 L
.38175 .15228 L
.38202 .15224 L
.38229 .15221 L
.38256 .15218 L
.38284 .15215 L
.38311 .15211 L
.38338 .15208 L
.38365 .15205 L
.38392 .15202 L
.38419 .15199 L
.38446 .15196 L
.38473 .15193 L
.385 .15189 L
.38527 .15186 L
.38554 .15183 L
.38581 .1518 L
.38608 .15177 L
.38635 .15174 L
.38662 .15171 L
.38689 .15168 L
.38716 .15165 L
.38743 .15162 L
.3877 .15159 L
.38797 .15156 L
.38824 .15153 L
.38851 .1515 L
.38878 .15147 L
.38904 .15144 L
.38931 .15141 L
.38958 .15139 L
.38985 .15136 L
.39012 .15133 L
.39039 .1513 L
.39066 .15127 L
.39093 .15124 L
.39119 .15121 L
.39146 .15119 L
.39173 .15116 L
.392 .15113 L
.39227 .1511 L
.39253 .15108 L
.3928 .15105 L
.39307 .15102 L
.39334 .15099 L
.3936 .15097 L
.39387 .15094 L
.39414 .15091 L
Mistroke
.3944 .15089 L
.39467 .15086 L
.39494 .15083 L
.39521 .15081 L
.39547 .15078 L
.39574 .15076 L
.396 .15073 L
.39627 .1507 L
.39654 .15068 L
.3968 .15065 L
.39707 .15063 L
.39734 .1506 L
.3976 .15058 L
.39787 .15055 L
.39813 .15053 L
.3984 .1505 L
.39866 .15048 L
.39893 .15045 L
.3992 .15043 L
.39946 .1504 L
.39973 .15038 L
.39999 .15036 L
.40026 .15033 L
.40052 .15031 L
.40079 .15029 L
.40105 .15026 L
.40131 .15024 L
.40158 .15022 L
.40184 .15019 L
.40211 .15017 L
.40237 .15015 L
.40264 .15012 L
.4029 .1501 L
.40316 .15008 L
.40343 .15006 L
.40369 .15003 L
.40396 .15001 L
.40422 .14999 L
.40448 .14997 L
.40475 .14995 L
.40501 .14992 L
.40527 .1499 L
.40553 .14988 L
.4058 .14986 L
.40606 .14984 L
.40632 .14982 L
.40659 .1498 L
.40685 .14978 L
.40711 .14976 L
.40737 .14974 L
Mistroke
.40764 .14972 L
.4079 .14969 L
.40816 .14967 L
.40842 .14965 L
.40868 .14963 L
.40895 .14961 L
.40921 .1496 L
.40947 .14958 L
.40973 .14956 L
.40999 .14954 L
.41025 .14952 L
.41051 .1495 L
.41077 .14948 L
.41104 .14946 L
.4113 .14944 L
.41156 .14942 L
.41182 .1494 L
.41208 .14939 L
.41234 .14937 L
.4126 .14935 L
.41286 .14933 L
.41312 .14931 L
.41338 .1493 L
.41364 .14928 L
.4139 .14926 L
.41416 .14924 L
.41442 .14923 L
.41468 .14921 L
.41494 .14919 L
.4152 .14918 L
.41546 .14916 L
.41572 .14914 L
.41598 .14913 L
.41623 .14911 L
.41649 .14909 L
.41675 .14908 L
.41701 .14906 L
.41727 .14904 L
.41753 .14903 L
.41779 .14901 L
.41804 .149 L
.4183 .14898 L
.41856 .14897 L
.41882 .14895 L
.41908 .14894 L
.41933 .14892 L
.41959 .14891 L
.41985 .14889 L
.42011 .14888 L
.42036 .14886 L
Mistroke
.42062 .14885 L
.42088 .14883 L
.42114 .14882 L
.42139 .14881 L
.42165 .14879 L
.42191 .14878 L
.42216 .14876 L
.42242 .14875 L
.42268 .14874 L
.42293 .14872 L
.42319 .14871 L
.42344 .1487 L
.4237 .14868 L
.42396 .14867 L
.42421 .14866 L
.42447 .14865 L
.42472 .14863 L
.42498 .14862 L
.42523 .14861 L
.42549 .1486 L
.42575 .14858 L
.426 .14857 L
.42626 .14856 L
.42651 .14855 L
.42676 .14854 L
.42702 .14853 L
.42727 .14851 L
.42753 .1485 L
.42778 .14849 L
.42804 .14848 L
.42829 .14847 L
.42855 .14846 L
.4288 .14845 L
.42905 .14844 L
.42931 .14843 L
.42956 .14842 L
.42981 .14841 L
.43007 .1484 L
.43032 .14839 L
.43057 .14838 L
.43083 .14837 L
.43108 .14836 L
.43133 .14835 L
.43159 .14834 L
.43184 .14833 L
.43209 .14832 L
.43234 .14831 L
.4326 .1483 L
.43285 .14829 L
.4331 .14828 L
Mistroke
.43335 .14828 L
.43361 .14827 L
.43386 .14826 L
.43411 .14825 L
.43436 .14824 L
.43461 .14823 L
.43486 .14823 L
.43512 .14822 L
.43537 .14821 L
.43562 .1482 L
.43587 .1482 L
.43612 .14819 L
.43637 .14818 L
.43662 .14817 L
.43687 .14817 L
.43712 .14816 L
.43737 .14815 L
.43762 .14815 L
.43787 .14814 L
.43812 .14813 L
.43837 .14813 L
.43862 .14812 L
.43887 .14811 L
.43912 .14811 L
.43937 .1481 L
.43962 .1481 L
.43987 .14809 L
.44012 .14809 L
.44037 .14808 L
.44062 .14807 L
.44087 .14807 L
.44112 .14806 L
.44137 .14806 L
.44161 .14805 L
.44186 .14805 L
.44211 .14805 L
.44236 .14804 L
.44261 .14804 L
.44286 .14803 L
.4431 .14803 L
.44335 .14802 L
.4436 .14802 L
.44385 .14802 L
.44409 .14801 L
.44434 .14801 L
.44459 .148 L
.44484 .148 L
.44508 .148 L
.44533 .14799 L
.44558 .14799 L
Mistroke
.44582 .14799 L
.44607 .14799 L
.44632 .14798 L
.44656 .14798 L
.44681 .14798 L
.44706 .14798 L
.4473 .14797 L
.44755 .14797 L
.44779 .14797 L
.44804 .14797 L
.44829 .14796 L
.44853 .14796 L
.44878 .14796 L
.44902 .14796 L
.44927 .14796 L
.44951 .14796 L
.44976 .14796 L
.45 .14795 L
.45025 .14795 L
.45049 .14795 L
.45074 .14795 L
.45098 .14795 L
.45123 .14795 L
.45147 .14795 L
.45171 .14795 L
.45196 .14795 L
.4522 .14795 L
.45245 .14795 L
.45269 .14795 L
.45293 .14795 L
.45318 .14795 L
.45342 .14795 L
.45366 .14795 L
.45391 .14795 L
.45415 .14795 L
.45439 .14795 L
.45463 .14795 L
.45488 .14796 L
.45512 .14796 L
.45536 .14796 L
.4556 .14796 L
.45585 .14796 L
.45609 .14796 L
.45633 .14796 L
.45657 .14797 L
.45682 .14797 L
.45706 .14797 L
.4573 .14797 L
.45754 .14798 L
.45778 .14798 L
Mistroke
.45802 .14798 L
.45826 .14798 L
.4585 .14799 L
.45875 .14799 L
.45899 .14799 L
.45923 .14799 L
.45947 .148 L
.45971 .148 L
.45995 .148 L
.46019 .14801 L
.46043 .14801 L
.46067 .14801 L
.46091 .14802 L
.46115 .14802 L
.46139 .14803 L
.46163 .14803 L
.46187 .14804 L
.46211 .14804 L
.46235 .14804 L
.46258 .14805 L
.46282 .14805 L
.46306 .14806 L
.4633 .14806 L
.46354 .14807 L
.46378 .14807 L
.46402 .14808 L
.46425 .14808 L
.46449 .14809 L
.46473 .14809 L
.46497 .1481 L
.46521 .14811 L
.46544 .14811 L
.46568 .14812 L
.46592 .14812 L
.46616 .14813 L
.46639 .14814 L
.46663 .14814 L
.46687 .14815 L
.46711 .14816 L
.46734 .14816 L
.46758 .14817 L
.46782 .14818 L
.46805 .14818 L
.46829 .14819 L
.46852 .1482 L
.46876 .14821 L
.469 .14821 L
.46923 .14822 L
.46947 .14823 L
.4697 .14824 L
Mistroke
.46994 .14824 L
.47017 .14825 L
.47041 .14826 L
.47064 .14827 L
.47088 .14828 L
.47111 .14828 L
.47135 .14829 L
.47158 .1483 L
.47182 .14831 L
.47205 .14832 L
.47229 .14833 L
.47252 .14834 L
.47276 .14835 L
.47299 .14836 L
.47322 .14837 L
.47346 .14837 L
.47369 .14838 L
.47392 .14839 L
.47416 .1484 L
.47439 .14841 L
.47462 .14842 L
.47486 .14843 L
.47509 .14844 L
.47532 .14845 L
.47556 .14847 L
.47579 .14848 L
.47602 .14849 L
.47625 .1485 L
.47648 .14851 L
.47672 .14852 L
.47695 .14853 L
.47718 .14854 L
.47741 .14855 L
.47764 .14856 L
.47788 .14858 L
.47811 .14859 L
.47834 .1486 L
.47857 .14861 L
.4788 .14862 L
.47903 .14863 L
.47926 .14865 L
.47949 .14866 L
.47972 .14867 L
.47995 .14868 L
.48018 .1487 L
.48041 .14871 L
.48064 .14872 L
.48087 .14873 L
.4811 .14875 L
.48133 .14876 L
Mistroke
.48156 .14877 L
.48179 .14879 L
.48202 .1488 L
.48225 .14881 L
.48248 .14883 L
.48271 .14884 L
.48294 .14886 L
.48317 .14887 L
.48339 .14888 L
.48362 .1489 L
.48385 .14891 L
.48408 .14893 L
.48431 .14894 L
.48453 .14895 L
.48476 .14897 L
.48499 .14898 L
.48522 .149 L
.48544 .14901 L
.48567 .14903 L
.4859 .14904 L
.48613 .14906 L
.48635 .14908 L
.48658 .14909 L
.48681 .14911 L
.48703 .14912 L
.48726 .14914 L
.48749 .14915 L
.48771 .14917 L
.48794 .14919 L
.48816 .1492 L
.48839 .14922 L
.48862 .14923 L
.48884 .14925 L
.48907 .14927 L
.48929 .14928 L
.48952 .1493 L
.48974 .14932 L
.48997 .14934 L
.49019 .14935 L
.49042 .14937 L
.49064 .14939 L
.49087 .1494 L
.49109 .14942 L
.49131 .14944 L
.49154 .14946 L
.49176 .14948 L
.49199 .14949 L
.49221 .14951 L
.49243 .14953 L
.49266 .14955 L
Mistroke
.49288 .14957 L
.4931 .14959 L
.49333 .1496 L
.49355 .14962 L
.49377 .14964 L
.49399 .14966 L
.49422 .14968 L
.49444 .1497 L
.49466 .14972 L
.49488 .14974 L
.49511 .14976 L
.49533 .14978 L
.49555 .1498 L
.49577 .14982 L
.49599 .14984 L
.49621 .14986 L
.49644 .14988 L
.49666 .1499 L
.49688 .14992 L
.4971 .14994 L
.49732 .14996 L
.49754 .14998 L
.49776 .15 L
.49798 .15002 L
.4982 .15004 L
.49842 .15006 L
.49864 .15008 L
.49886 .1501 L
.49908 .15012 L
.4993 .15015 L
.49952 .15017 L
.49974 .15019 L
.49996 .15021 L
.50018 .15023 L
.5004 .15025 L
.50061 .15028 L
.50083 .1503 L
.50105 .15032 L
.50127 .15034 L
.50149 .15036 L
.50171 .15039 L
.50192 .15041 L
.50214 .15043 L
.50236 .15046 L
.50258 .15048 L
.5028 .1505 L
.50301 .15052 L
.50323 .15055 L
.50345 .15057 L
.50366 .15059 L
Mistroke
.50388 .15062 L
.5041 .15064 L
.50431 .15067 L
.50453 .15069 L
.50475 .15071 L
.50496 .15074 L
.50518 .15076 L
.5054 .15079 L
.50561 .15081 L
.50583 .15083 L
.50604 .15086 L
.50626 .15088 L
.50647 .15091 L
.50669 .15093 L
.5069 .15096 L
.50712 .15098 L
.50733 .15101 L
.50755 .15103 L
.50776 .15106 L
.50798 .15109 L
.50819 .15111 L
.5084 .15114 L
.50862 .15116 L
.50883 .15119 L
.50905 .15121 L
.50926 .15124 L
.50947 .15127 L
.50969 .15129 L
.5099 .15132 L
.51011 .15135 L
.51032 .15137 L
.51054 .1514 L
.51075 .15143 L
.51096 .15145 L
.51117 .15148 L
.51139 .15151 L
.5116 .15153 L
.51181 .15156 L
.51202 .15159 L
.51223 .15162 L
.51244 .15164 L
.51266 .15167 L
.51287 .1517 L
.51308 .15173 L
.51329 .15176 L
.5135 .15178 L
.51371 .15181 L
.51392 .15184 L
.51413 .15187 L
.51434 .1519 L
Mistroke
.51455 .15193 L
.51476 .15195 L
.51497 .15198 L
.51518 .15201 L
.51539 .15204 L
.5156 .15207 L
.51581 .1521 L
.51602 .15213 L
.51623 .15216 L
.51644 .15219 L
.51665 .15222 L
.51685 .15225 L
.51706 .15228 L
.51727 .15231 L
.51748 .15234 L
.51769 .15237 L
.51789 .1524 L
.5181 .15243 L
.51831 .15246 L
.51852 .15249 L
.51873 .15252 L
.51893 .15255 L
.51914 .15258 L
.51935 .15261 L
.51955 .15264 L
.51976 .15268 L
.51997 .15271 L
.52017 .15274 L
.52038 .15277 L
.52058 .1528 L
.52079 .15283 L
.521 .15286 L
.5212 .1529 L
.52141 .15293 L
.52161 .15296 L
.52182 .15299 L
.52202 .15302 L
.52223 .15306 L
.52243 .15309 L
.52264 .15312 L
.52284 .15316 L
.52305 .15319 L
.52325 .15322 L
.52345 .15325 L
.52366 .15329 L
.52386 .15332 L
.52407 .15335 L
.52427 .15339 L
.52447 .15342 L
.52468 .15345 L
Mistroke
.52488 .15349 L
.52508 .15352 L
.52529 .15356 L
.52549 .15359 L
.52569 .15362 L
.52589 .15366 L
.5261 .15369 L
.5263 .15373 L
.5265 .15376 L
.5267 .1538 L
.5269 .15383 L
.5271 .15387 L
.52731 .1539 L
.52751 .15394 L
.52771 .15397 L
.52791 .15401 L
.52811 .15404 L
.52831 .15408 L
.52851 .15411 L
.52871 .15415 L
.52891 .15418 L
.52911 .15422 L
.52931 .15425 L
.52951 .15429 L
.52971 .15433 L
.52991 .15436 L
.53011 .1544 L
.53031 .15444 L
.53051 .15447 L
.53071 .15451 L
.53091 .15455 L
.5311 .15458 L
.5313 .15462 L
.5315 .15466 L
.5317 .15469 L
.5319 .15473 L
.5321 .15477 L
.53229 .15481 L
.53249 .15484 L
.53269 .15488 L
.53289 .15492 L
.53308 .15496 L
.53328 .15499 L
.53348 .15503 L
.53367 .15507 L
.53387 .15511 L
.53407 .15515 L
.53426 .15519 L
.53446 .15522 L
.53465 .15526 L
Mistroke
.53485 .1553 L
.53505 .15534 L
.53524 .15538 L
.53544 .15542 L
.53563 .15546 L
.53583 .1555 L
.53602 .15554 L
.53622 .15558 L
.53641 .15562 L
.53661 .15565 L
.5368 .15569 L
.53699 .15573 L
.53719 .15577 L
.53738 .15581 L
.53758 .15585 L
.53777 .15589 L
.53796 .15594 L
.53816 .15598 L
.53835 .15602 L
.53854 .15606 L
.53873 .1561 L
.53893 .15614 L
.53912 .15618 L
.53931 .15622 L
.5395 .15626 L
.5397 .1563 L
.53989 .15634 L
.54008 .15639 L
.54027 .15643 L
.54046 .15647 L
.54065 .15651 L
.54085 .15655 L
.54104 .15659 L
.54123 .15664 L
.54142 .15668 L
.54161 .15672 L
.5418 .15676 L
.54199 .15681 L
.54218 .15685 L
.54237 .15689 L
.54256 .15693 L
.54275 .15698 L
.54294 .15702 L
.54313 .15706 L
.54332 .15711 L
.54351 .15715 L
.5437 .15719 L
.54388 .15724 L
.54407 .15728 L
.54426 .15732 L
Mistroke
.54445 .15737 L
.54464 .15741 L
.54483 .15745 L
.54501 .1575 L
.5452 .15754 L
.54539 .15759 L
.54558 .15763 L
.54576 .15768 L
.54595 .15772 L
.54614 .15777 L
.54632 .15781 L
.54651 .15785 L
.5467 .1579 L
.54688 .15794 L
.54707 .15799 L
.54725 .15804 L
.54744 .15808 L
.54763 .15813 L
.54781 .15817 L
.548 .15822 L
.54818 .15826 L
.54837 .15831 L
.54855 .15835 L
.54874 .1584 L
.54892 .15845 L
.5491 .15849 L
.54929 .15854 L
.54947 .15859 L
.54966 .15863 L
.54984 .15868 L
.55002 .15873 L
.55021 .15877 L
.55039 .15882 L
.55057 .15887 L
.55076 .15891 L
.55094 .15896 L
.55112 .15901 L
.55131 .15906 L
.55149 .1591 L
.55167 .15915 L
.55185 .1592 L
.55203 .15925 L
.55221 .15929 L
.5524 .15934 L
.55258 .15939 L
.55276 .15944 L
.55294 .15949 L
.55312 .15954 L
.5533 .15958 L
.55348 .15963 L
Mistroke
.55366 .15968 L
.55384 .15973 L
.55402 .15978 L
.5542 .15983 L
.55438 .15988 L
.55456 .15993 L
.55474 .15998 L
.55492 .16003 L
.5551 .16008 L
.55528 .16013 L
.55546 .16018 L
.55564 .16022 L
.55581 .16027 L
.55599 .16032 L
.55617 .16038 L
.55635 .16043 L
.55653 .16048 L
.5567 .16053 L
.55688 .16058 L
.55706 .16063 L
.55724 .16068 L
.55741 .16073 L
.55759 .16078 L
.55777 .16083 L
.55794 .16088 L
.55812 .16093 L
.5583 .16098 L
.55847 .16104 L
.55865 .16109 L
.55882 .16114 L
.559 .16119 L
.55918 .16124 L
.55935 .16129 L
.55953 .16135 L
.5597 .1614 L
.55987 .16145 L
.56005 .1615 L
.56022 .16156 L
.5604 .16161 L
.56057 .16166 L
.56075 .16171 L
.56092 .16177 L
.56109 .16182 L
.56127 .16187 L
.56144 .16193 L
.56161 .16198 L
.56179 .16203 L
.56196 .16209 L
.56213 .16214 L
.5623 .16219 L
Mistroke
.56248 .16225 L
.56265 .1623 L
.56282 .16235 L
.56299 .16241 L
.56316 .16246 L
.56333 .16252 L
.56351 .16257 L
.56368 .16263 L
.56385 .16268 L
.56402 .16274 L
.56419 .16279 L
.56436 .16284 L
.56453 .1629 L
.5647 .16295 L
.56487 .16301 L
.56504 .16306 L
.56521 .16312 L
.56538 .16318 L
.56555 .16323 L
.56572 .16329 L
.56589 .16334 L
.56605 .1634 L
.56622 .16345 L
.56639 .16351 L
.56656 .16357 L
.56673 .16362 L
.5669 .16368 L
.56706 .16374 L
.56723 .16379 L
.5674 .16385 L
.56757 .16391 L
.56773 .16396 L
.5679 .16402 L
.56807 .16408 L
.56823 .16413 L
.5684 .16419 L
.56857 .16425 L
.56873 .16431 L
.5689 .16436 L
.56906 .16442 L
.56923 .16448 L
.56939 .16454 L
.56956 .16459 L
.56972 .16465 L
.56989 .16471 L
.57005 .16477 L
.57022 .16483 L
.57038 .16489 L
.57055 .16494 L
.57071 .165 L
Mistroke
.57087 .16506 L
.57104 .16512 L
.5712 .16518 L
.57136 .16524 L
.57153 .1653 L
.57169 .16536 L
.57185 .16542 L
.57202 .16547 L
.57218 .16553 L
.57234 .16559 L
.5725 .16565 L
.57267 .16571 L
.57283 .16577 L
.57299 .16583 L
.57315 .16589 L
.57331 .16595 L
.57347 .16601 L
.57363 .16607 L
.57379 .16613 L
.57395 .1662 L
.57411 .16626 L
.57427 .16632 L
.57443 .16638 L
.57459 .16644 L
.57475 .1665 L
.57491 .16656 L
.57507 .16662 L
.57523 .16668 L
.57539 .16675 L
.57555 .16681 L
.57571 .16687 L
.57587 .16693 L
.57603 .16699 L
.57618 .16705 L
.57634 .16712 L
.5765 .16718 L
.57666 .16724 L
.57681 .1673 L
.57697 .16737 L
.57713 .16743 L
.57728 .16749 L
.57744 .16755 L
.5776 .16762 L
.57775 .16768 L
.57791 .16774 L
.57807 .16781 L
.57822 .16787 L
.57838 .16793 L
.57853 .168 L
.57869 .16806 L
Mistroke
.57884 .16812 L
.579 .16819 L
.57915 .16825 L
.57931 .16832 L
.57946 .16838 L
.57962 .16844 L
.57977 .16851 L
.57992 .16857 L
.58008 .16864 L
.58023 .1687 L
.58038 .16877 L
.58054 .16883 L
.58069 .1689 L
.58084 .16896 L
.581 .16903 L
.58115 .16909 L
.5813 .16916 L
.58145 .16922 L
.5816 .16929 L
.58176 .16935 L
.58191 .16942 L
.58206 .16948 L
.58221 .16955 L
.58236 .16962 L
.58251 .16968 L
.58266 .16975 L
.58281 .16981 L
.58296 .16988 L
.58311 .16995 L
.58326 .17001 L
.58341 .17008 L
.58356 .17015 L
.58371 .17021 L
.58386 .17028 L
.58401 .17035 L
.58416 .17042 L
.58431 .17048 L
.58446 .17055 L
.5846 .17062 L
.58475 .17068 L
.5849 .17075 L
.58505 .17082 L
.58519 .17089 L
.58534 .17096 L
.58549 .17102 L
.58564 .17109 L
.58578 .17116 L
.58593 .17123 L
.58608 .1713 L
.58622 .17137 L
Mistroke
.58637 .17143 L
.58651 .1715 L
.58666 .17157 L
.58681 .17164 L
.58695 .17171 L
.5871 .17178 L
.58724 .17185 L
.58739 .17192 L
.58753 .17199 L
.58767 .17206 L
.58782 .17213 L
.58796 .1722 L
.58811 .17227 L
.58825 .17234 L
.58839 .17241 L
.58854 .17248 L
.58868 .17255 L
.58882 .17262 L
.58897 .17269 L
.58911 .17276 L
.58925 .17283 L
.58939 .1729 L
.58953 .17297 L
.58968 .17304 L
.58982 .17311 L
.58996 .17318 L
.5901 .17325 L
.59024 .17333 L
.59038 .1734 L
.59052 .17347 L
.59066 .17354 L
.5908 .17361 L
.59094 .17368 L
.59108 .17376 L
.59122 .17383 L
.59136 .1739 L
.5915 .17397 L
.59164 .17404 L
.59178 .17412 L
.59192 .17419 L
.59206 .17426 L
.5922 .17433 L
.59234 .17441 L
.59247 .17448 L
.59261 .17455 L
.59275 .17463 L
.59289 .1747 L
.59302 .17477 L
.59316 .17485 L
.5933 .17492 L
Mistroke
.59343 .17499 L
.59357 .17507 L
.59371 .17514 L
.59384 .17521 L
.59398 .17529 L
.59412 .17536 L
.59425 .17544 L
.59439 .17551 L
.59452 .17559 L
.59466 .17566 L
.59479 .17573 L
.59493 .17581 L
.59506 .17588 L
.59519 .17596 L
.59533 .17603 L
.59546 .17611 L
.5956 .17618 L
.59573 .17626 L
.59586 .17633 L
.596 .17641 L
.59613 .17649 L
.59626 .17656 L
.59639 .17664 L
.59653 .17671 L
.59666 .17679 L
.59679 .17686 L
.59692 .17694 L
.59705 .17702 L
.59719 .17709 L
.59732 .17717 L
.59745 .17725 L
.59758 .17732 L
.59771 .1774 L
.59784 .17748 L
.59797 .17755 L
.5981 .17763 L
.59823 .17771 L
.59836 .17778 L
.59849 .17786 L
.59862 .17794 L
.59875 .17802 L
.59888 .17809 L
.59901 .17817 L
.59913 .17825 L
.59926 .17833 L
.59939 .17841 L
.59952 .17848 L
.59965 .17856 L
.59977 .17864 L
.5999 .17872 L
Mistroke
.60003 .1788 L
.60016 .17888 L
.60028 .17896 L
.60041 .17903 L
.60053 .17911 L
.60066 .17919 L
.60079 .17927 L
.60091 .17935 L
.60104 .17943 L
.60116 .17951 L
.60129 .17959 L
.60141 .17967 L
.60154 .17975 L
.60166 .17983 L
.60179 .17991 L
.60191 .17999 L
.60204 .18007 L
.60216 .18015 L
.60228 .18023 L
.60241 .18031 L
.60253 .18039 L
.60265 .18047 L
.60278 .18055 L
.6029 .18063 L
.60302 .18071 L
.60314 .18079 L
.60327 .18087 L
.60339 .18095 L
.60351 .18104 L
.60363 .18112 L
.60375 .1812 L
.60387 .18128 L
.60399 .18136 L
.60411 .18144 L
.60423 .18153 L
.60436 .18161 L
.60448 .18169 L
.6046 .18177 L
.60471 .18185 L
.60483 .18194 L
.60495 .18202 L
.60507 .1821 L
.60519 .18218 L
.60531 .18227 L
.60543 .18235 L
.60555 .18243 L
.60567 .18251 L
.60578 .1826 L
.6059 .18268 L
.60602 .18276 L
Mistroke
.60614 .18285 L
.60625 .18293 L
.60637 .18302 L
.60649 .1831 L
.6066 .18318 L
.60672 .18327 L
.60684 .18335 L
.60695 .18343 L
.60707 .18352 L
.60718 .1836 L
.6073 .18369 L
.60741 .18377 L
.60753 .18386 L
.60764 .18394 L
.60776 .18403 L
.60787 .18411 L
.60799 .1842 L
.6081 .18428 L
.60821 .18437 L
.60833 .18445 L
.60844 .18454 L
.60855 .18462 L
.60867 .18471 L
.60878 .18479 L
.60889 .18488 L
.609 .18496 L
.60912 .18505 L
.60923 .18514 L
.60934 .18522 L
.60945 .18531 L
.60956 .18539 L
.60967 .18548 L
.60978 .18557 L
.60989 .18565 L
.61 .18574 L
.61011 .18583 L
.61022 .18591 L
.61033 .186 L
.61044 .18609 L
.61055 .18618 L
.61066 .18626 L
.61077 .18635 L
.61088 .18644 L
.61099 .18653 L
.6111 .18661 L
.61121 .1867 L
.61131 .18679 L
.61142 .18688 L
.61153 .18696 L
.61164 .18705 L
Mistroke
.61174 .18714 L
.61185 .18723 L
.61196 .18732 L
.61206 .18741 L
.61217 .1875 L
.61228 .18758 L
.61238 .18767 L
.61249 .18776 L
.61259 .18785 L
.6127 .18794 L
.6128 .18803 L
.61291 .18812 L
.61301 .18821 L
.61312 .1883 L
.61322 .18839 L
.61333 .18848 L
.61343 .18857 L
.61353 .18866 L
.61364 .18875 L
.61374 .18884 L
.61384 .18893 L
.61395 .18902 L
.61405 .18911 L
.61415 .1892 L
.61426 .18929 L
.61436 .18938 L
.61446 .18947 L
.61456 .18956 L
.61466 .18965 L
.61476 .18974 L
.61486 .18983 L
.61497 .18992 L
.61507 .19002 L
.61517 .19011 L
.61527 .1902 L
.61537 .19029 L
.61547 .19038 L
.61557 .19047 L
.61567 .19057 L
.61576 .19066 L
.61586 .19075 L
.61596 .19084 L
.61606 .19093 L
.61616 .19103 L
.61626 .19112 L
.61635 .19121 L
.61645 .1913 L
.61655 .1914 L
.61665 .19149 L
.61674 .19158 L
Mistroke
.61684 .19168 L
.61694 .19177 L
.61703 .19186 L
.61713 .19196 L
.61723 .19205 L
.61732 .19214 L
.61742 .19224 L
.61751 .19233 L
.61761 .19242 L
.6177 .19252 L
.6178 .19261 L
.61789 .1927 L
.61799 .1928 L
.61808 .19289 L
.61818 .19299 L
.61827 .19308 L
.61836 .19318 L
.61846 .19327 L
.61855 .19337 L
.61864 .19346 L
.61873 .19356 L
.61883 .19365 L
.61892 .19375 L
.61901 .19384 L
.6191 .19394 L
.61919 .19403 L
.61929 .19413 L
.61938 .19422 L
.61947 .19432 L
.61956 .19441 L
.61965 .19451 L
.61974 .19461 L
.61983 .1947 L
.61992 .1948 L
.62001 .19489 L
.6201 .19499 L
.62019 .19509 L
.62028 .19518 L
.62037 .19528 L
.62045 .19538 L
.62054 .19547 L
.62063 .19557 L
.62072 .19567 L
.62081 .19576 L
.62089 .19586 L
.62098 .19596 L
.62107 .19606 L
.62116 .19615 L
.62124 .19625 L
.62133 .19635 L
Mistroke
.62142 .19645 L
.6215 .19654 L
.62159 .19664 L
.62167 .19674 L
.62176 .19684 L
.62184 .19694 L
.62193 .19704 L
.62201 .19713 L
.6221 .19723 L
.62218 .19733 L
.62227 .19743 L
.62235 .19753 L
.62243 .19763 L
.62252 .19773 L
.6226 .19782 L
.62268 .19792 L
.62277 .19802 L
.62285 .19812 L
.62293 .19822 L
.62301 .19832 L
.6231 .19842 L
.62318 .19852 L
.62326 .19862 L
.62334 .19872 L
.62342 .19882 L
.6235 .19892 L
.62358 .19902 L
.62367 .19912 L
.62375 .19922 L
.62383 .19932 L
.62391 .19942 L
.62398 .19952 L
.62406 .19962 L
.62414 .19972 L
.62422 .19983 L
.6243 .19993 L
.62438 .20003 L
.62446 .20013 L
.62454 .20023 L
.62461 .20033 L
.62469 .20043 L
.62477 .20053 L
.62485 .20064 L
.62492 .20074 L
.625 .20084 L
.62508 .20094 L
.62515 .20104 L
.62523 .20114 L
.62531 .20125 L
.62538 .20135 L
Mistroke
.62546 .20145 L
.62553 .20155 L
.62561 .20166 L
.62568 .20176 L
.62576 .20186 L
.62583 .20196 L
.62591 .20207 L
.62598 .20217 L
.62605 .20227 L
.62613 .20238 L
.6262 .20248 L
.62627 .20258 L
.62635 .20269 L
.62642 .20279 L
.62649 .20289 L
.62656 .203 L
.62664 .2031 L
.62671 .20321 L
.62678 .20331 L
.62685 .20341 L
.62692 .20352 L
.62699 .20362 L
.62707 .20373 L
.62714 .20383 L
.62721 .20394 L
.62728 .20404 L
.62735 .20414 L
.62742 .20425 L
.62749 .20435 L
.62755 .20446 L
.62762 .20456 L
.62769 .20467 L
.62776 .20477 L
.62783 .20488 L
.6279 .20499 L
.62797 .20509 L
.62803 .2052 L
.6281 .2053 L
.62817 .20541 L
.62823 .20551 L
.6283 .20562 L
.62837 .20573 L
.62843 .20583 L
.6285 .20594 L
.62857 .20604 L
.62863 .20615 L
.6287 .20626 L
.62876 .20636 L
.62883 .20647 L
.62889 .20658 L
Mistroke
.62896 .20668 L
.62902 .20679 L
.62909 .2069 L
.62915 .20701 L
.62921 .20711 L
.62928 .20722 L
.62934 .20733 L
.6294 .20743 L
.62947 .20754 L
.62953 .20765 L
.62959 .20776 L
.62965 .20787 L
.62972 .20797 L
.62978 .20808 L
.62984 .20819 L
.6299 .2083 L
.62996 .20841 L
.63002 .20851 L
.63008 .20862 L
.63014 .20873 L
.63021 .20884 L
.63027 .20895 L
.63032 .20906 L
.63038 .20917 L
.63044 .20928 L
.6305 .20938 L
.63056 .20949 L
.63062 .2096 L
.63068 .20971 L
.63074 .20982 L
.6308 .20993 L
.63085 .21004 L
.63091 .21015 L
.63097 .21026 L
.63103 .21037 L
.63108 .21048 L
.63114 .21059 L
.6312 .2107 L
.63125 .21081 L
.63131 .21092 L
.63136 .21103 L
.63142 .21114 L
.63147 .21125 L
.63153 .21136 L
.63159 .21147 L
.63164 .21158 L
.63169 .21169 L
.63175 .21181 L
.6318 .21192 L
.63186 .21203 L
Mistroke
.63191 .21214 L
.63196 .21225 L
.63202 .21236 L
.63207 .21247 L
.63212 .21258 L
.63217 .2127 L
.63223 .21281 L
.63228 .21292 L
.63233 .21303 L
.63238 .21314 L
.63243 .21326 L
.63249 .21337 L
.63254 .21348 L
.63259 .21359 L
.63264 .2137 L
.63269 .21382 L
.63274 .21393 L
.63279 .21404 L
.63284 .21416 L
.63289 .21427 L
.63294 .21438 L
.63298 .21449 L
.63303 .21461 L
.63308 .21472 L
.63313 .21483 L
.63318 .21495 L
.63323 .21506 L
.63327 .21517 L
.63332 .21529 L
.63337 .2154 L
.63342 .21552 L
.63346 .21563 L
.63351 .21574 L
.63355 .21586 L
.6336 .21597 L
.63365 .21609 L
.63369 .2162 L
.63374 .21631 L
.63378 .21643 L
.63383 .21654 L
.63387 .21666 L
.63392 .21677 L
.63396 .21689 L
.63401 .217 L
.63405 .21712 L
.63409 .21723 L
.63414 .21735 L
.63418 .21746 L
.63422 .21758 L
.63427 .21769 L
Mistroke
.63431 .21781 L
.63435 .21792 L
.63439 .21804 L
.63443 .21815 L
.63448 .21827 L
.63452 .21839 L
.63456 .2185 L
.6346 .21862 L
.63464 .21873 L
.63468 .21885 L
.63472 .21897 L
.63476 .21908 L
.6348 .2192 L
.63484 .21932 L
.63488 .21943 L
.63492 .21955 L
.63496 .21967 L
.635 .21978 L
.63503 .2199 L
.63507 .22002 L
.63511 .22013 L
.63515 .22025 L
.63519 .22037 L
.63522 .22048 L
.63526 .2206 L
.6353 .22072 L
.63533 .22084 L
.63537 .22095 L
.63541 .22107 L
.63544 .22119 L
.63548 .22131 L
.63551 .22143 L
.63555 .22154 L
.63558 .22166 L
.63562 .22178 L
.63565 .2219 L
.63569 .22202 L
.63572 .22214 L
.63576 .22225 L
.63579 .22237 L
.63582 .22249 L
.63586 .22261 L
.63589 .22273 L
.63592 .22285 L
.63596 .22297 L
.63599 .22309 L
.63602 .2232 L
.63605 .22332 L
.63608 .22344 L
.63612 .22356 L
Mistroke
.63615 .22368 L
.63618 .2238 L
.63621 .22392 L
.63624 .22404 L
.63627 .22416 L
.6363 .22428 L
.63633 .2244 L
.63636 .22452 L
.63639 .22464 L
.63642 .22476 L
.63645 .22488 L
.63648 .225 L
.63651 .22512 L
.63653 .22524 L
.63656 .22536 L
.63659 .22548 L
.63662 .2256 L
.63664 .22572 L
.63667 .22584 L
.6367 .22597 L
.63673 .22609 L
.63675 .22621 L
.63678 .22633 L
.6368 .22645 L
.63683 .22657 L
.63686 .22669 L
.63688 .22681 L
.63691 .22694 L
.63693 .22706 L
.63696 .22718 L
.63698 .2273 L
.63701 .22742 L
.63703 .22754 L
.63705 .22767 L
.63708 .22779 L
.6371 .22791 L
.63712 .22803 L
.63715 .22815 L
.63717 .22828 L
.63719 .2284 L
.63722 .22852 L
.63724 .22864 L
.63726 .22877 L
.63728 .22889 L
.6373 .22901 L
.63732 .22914 L
.63734 .22926 L
.63737 .22938 L
.63739 .2295 L
.63741 .22963 L
Mistroke
.63743 .22975 L
.63745 .22987 L
.63747 .23 L
.63749 .23012 L
.6375 .23024 L
.63752 .23037 L
.63754 .23049 L
.63756 .23062 L
.63758 .23074 L
.6376 .23086 L
.63761 .23099 L
.63763 .23111 L
.63765 .23124 L
.63767 .23136 L
.63768 .23148 L
.6377 .23161 L
.63772 .23173 L
.63773 .23186 L
.63775 .23198 L
.63777 .23211 L
.63778 .23223 L
.6378 .23236 L
.63781 .23248 L
.63783 .2326 L
.63784 .23273 L
.63786 .23285 L
.63787 .23298 L
.63788 .2331 L
.6379 .23323 L
.63791 .23336 L
.63793 .23348 L
.63794 .23361 L
.63795 .23373 L
.63796 .23386 L
.63798 .23398 L
.63799 .23411 L
.638 .23423 L
.63801 .23436 L
.63802 .23449 L
.63804 .23461 L
.63805 .23474 L
.63806 .23486 L
.63807 .23499 L
.63808 .23512 L
.63809 .23524 L
.6381 .23537 L
.63811 .2355 L
.63812 .23562 L
.63813 .23575 L
.63814 .23588 L
Mistroke
.63815 .236 L
.63815 .23613 L
.63816 .23626 L
.63817 .23638 L
.63818 .23651 L
.63819 .23664 L
.63819 .23676 L
.6382 .23689 L
.63821 .23702 L
.63822 .23715 L
.63822 .23727 L
.63823 .2374 L
.63824 .23753 L
.63824 .23766 L
.63825 .23778 L
.63825 .23791 L
.63826 .23804 L
.63826 .23817 L
.63827 .2383 L
.63827 .23842 L
.63828 .23855 L
.63828 .23868 L
.63829 .23881 L
.63829 .23894 L
.63829 .23907 L
.6383 .23919 L
.6383 .23932 L
.6383 .23945 L
.63831 .23958 L
.63831 .23971 L
.63831 .23984 L
.63831 .23997 L
.63831 .24009 L
.63832 .24022 L
.63832 .24035 L
.63832 .24048 L
.63832 .24061 L
.63832 .24074 L
.63832 .24087 L
.63832 .241 L
.63832 .24113 L
.63832 .24126 L
.63832 .24139 L
.63832 .24152 L
.63832 .24165 L
.63832 .24178 L
.63832 .24191 L
.63831 .24204 L
.63831 .24217 L
.63831 .2423 L
Mistroke
.63831 .24243 L
.63831 .24256 L
.6383 .24269 L
.6383 .24282 L
.6383 .24295 L
.63829 .24308 L
.63829 .24321 L
.63829 .24334 L
.63828 .24347 L
.63828 .2436 L
.63827 .24373 L
.63827 .24386 L
.63827 .24399 L
.63826 .24412 L
.63826 .24425 L
.63825 .24438 L
.63824 .24451 L
.63824 .24464 L
.63823 .24478 L
.63823 .24491 L
.63822 .24504 L
.63821 .24517 L
.63821 .2453 L
.6382 .24543 L
.63819 .24556 L
.63818 .2457 L
.63817 .24583 L
.63817 .24596 L
.63816 .24609 L
.63815 .24622 L
.63814 .24635 L
.63813 .24649 L
.63812 .24662 L
.63811 .24675 L
.6381 .24688 L
.63809 .24701 L
.63808 .24715 L
.63807 .24728 L
.63806 .24741 L
.63805 .24754 L
.63804 .24768 L
.63803 .24781 L
.63802 .24794 L
.63801 .24807 L
.638 .24821 L
.63798 .24834 L
.63797 .24847 L
.63796 .2486 L
.63795 .24874 L
.63793 .24887 L
Mistroke
.63792 .249 L
.63791 .24914 L
.63789 .24927 L
.63788 .2494 L
.63787 .24953 L
.63785 .24967 L
.63784 .2498 L
.63782 .24993 L
.63781 .25007 L
.63779 .2502 L
.63778 .25034 L
.63776 .25047 L
.63775 .2506 L
.63773 .25074 L
.63771 .25087 L
.6377 .251 L
.63768 .25114 L
.63766 .25127 L
.63765 .25141 L
.63763 .25154 L
.63761 .25167 L
.63759 .25181 L
.63758 .25194 L
.63756 .25208 L
.63754 .25221 L
.63752 .25234 L
.6375 .25248 L
.63748 .25261 L
.63746 .25275 L
.63744 .25288 L
.63742 .25302 L
.6374 .25315 L
.63738 .25329 L
.63736 .25342 L
.63734 .25356 L
.63732 .25369 L
.6373 .25382 L
.63728 .25396 L
.63726 .25409 L
.63724 .25423 L
.63722 .25436 L
.63719 .2545 L
.63717 .25464 L
.63715 .25477 L
.63713 .25491 L
.6371 .25504 L
.63708 .25518 L
.63706 .25531 L
.63703 .25545 L
.63701 .25558 L
Mistroke
.63699 .25572 L
.63696 .25585 L
.63694 .25599 L
.63691 .25613 L
.63689 .25626 L
.63686 .2564 L
.63684 .25653 L
.63681 .25667 L
.63679 .2568 L
.63676 .25694 L
.63674 .25708 L
.63671 .25721 L
.63668 .25735 L
.63666 .25748 L
.63663 .25762 L
.6366 .25776 L
.63657 .25789 L
.63655 .25803 L
.63652 .25817 L
.63649 .2583 L
.63646 .25844 L
.63643 .25858 L
.63641 .25871 L
.63638 .25885 L
.63635 .25899 L
.63632 .25912 L
.63629 .25926 L
.63626 .2594 L
.63623 .25953 L
.6362 .25967 L
.63617 .25981 L
.63614 .25994 L
.63611 .26008 L
.63608 .26022 L
.63605 .26035 L
.63602 .26049 L
.63598 .26063 L
.63595 .26077 L
.63592 .2609 L
.63589 .26104 L
.63586 .26118 L
.63582 .26132 L
.63579 .26145 L
.63576 .26159 L
.63572 .26173 L
.63569 .26187 L
.63566 .262 L
.63562 .26214 L
.63559 .26228 L
.63555 .26242 L
Mistroke
.63552 .26255 L
.63548 .26269 L
.63545 .26283 L
.63541 .26297 L
.63538 .26311 L
.63534 .26324 L
.63531 .26338 L
.63527 .26352 L
.63524 .26366 L
.6352 .2638 L
.63516 .26393 L
.63513 .26407 L
.63509 .26421 L
.63505 .26435 L
.63501 .26449 L
.63498 .26463 L
.63494 .26476 L
.6349 .2649 L
.63486 .26504 L
.63482 .26518 L
.63479 .26532 L
.63475 .26546 L
.63471 .2656 L
.63467 .26573 L
.63463 .26587 L
.63459 .26601 L
.63455 .26615 L
.63451 .26629 L
.63447 .26643 L
.63443 .26657 L
.63439 .26671 L
.63435 .26685 L
.63431 .26698 L
.63427 .26712 L
.63422 .26726 L
.63418 .2674 L
.63414 .26754 L
.6341 .26768 L
.63406 .26782 L
.63401 .26796 L
.63397 .2681 L
.63393 .26824 L
.63388 .26838 L
.63384 .26852 L
.6338 .26865 L
.63375 .26879 L
.63371 .26893 L
.63367 .26907 L
.63362 .26921 L
.63358 .26935 L
Mistroke
.63353 .26949 L
.63349 .26963 L
.63344 .26977 L
.6334 .26991 L
.63335 .27005 L
.6333 .27019 L
.63326 .27033 L
.63321 .27047 L
.63317 .27061 L
.63312 .27075 L
.63307 .27089 L
.63303 .27103 L
.63298 .27117 L
.63293 .27131 L
.63288 .27145 L
.63284 .27159 L
.63279 .27173 L
.63274 .27187 L
.63269 .27201 L
.63264 .27215 L
.63259 .27229 L
.63255 .27243 L
.6325 .27257 L
.63245 .27271 L
.6324 .27285 L
.63235 .27299 L
.6323 .27313 L
.63225 .27327 L
.6322 .27341 L
.63215 .27355 L
.6321 .27369 L
.63204 .27383 L
.63199 .27398 L
.63194 .27412 L
.63189 .27426 L
.63184 .2744 L
.63179 .27454 L
.63173 .27468 L
.63168 .27482 L
.63163 .27496 L
.63158 .2751 L
.63152 .27524 L
.63147 .27538 L
.63142 .27552 L
.63136 .27566 L
.63131 .2758 L
.63126 .27595 L
.6312 .27609 L
.63115 .27623 L
.63109 .27637 L
Mistroke
.63104 .27651 L
.63098 .27665 L
.63093 .27679 L
.63087 .27693 L
.63082 .27707 L
.63076 .27721 L
.63071 .27736 L
.63065 .2775 L
.63059 .27764 L
.63054 .27778 L
.63048 .27792 L
.63042 .27806 L
.63037 .2782 L
.63031 .27834 L
.63025 .27849 L
.63019 .27863 L
.63014 .27877 L
.63008 .27891 L
.63002 .27905 L
.62996 .27919 L
.6299 .27933 L
.62985 .27948 L
.62979 .27962 L
.62973 .27976 L
.62967 .2799 L
.62961 .28004 L
.62955 .28018 L
.62949 .28032 L
.62943 .28047 L
.62937 .28061 L
.62931 .28075 L
.62925 .28089 L
.62919 .28103 L
.62913 .28117 L
.62906 .28132 L
.629 .28146 L
.62894 .2816 L
.62888 .28174 L
.62882 .28188 L
.62875 .28202 L
.62869 .28217 L
.62863 .28231 L
.62857 .28245 L
.6285 .28259 L
.62844 .28273 L
.62838 .28288 L
.62831 .28302 L
.62825 .28316 L
.62819 .2833 L
.62812 .28344 L
Mistroke
.62806 .28358 L
.62799 .28373 L
.62793 .28387 L
.62786 .28401 L
.6278 .28415 L
.62773 .28429 L
.62767 .28444 L
.6276 .28458 L
.62754 .28472 L
.62747 .28486 L
.62741 .285 L
.62734 .28515 L
.62727 .28529 L
.62721 .28543 L
.62714 .28557 L
.62707 .28571 L
.62701 .28586 L
.62694 .286 L
.62687 .28614 L
.6268 .28628 L
.62673 .28643 L
.62667 .28657 L
.6266 .28671 L
.62653 .28685 L
.62646 .28699 L
.62639 .28714 L
.62632 .28728 L
.62625 .28742 L
.62618 .28756 L
.62611 .28771 L
.62605 .28785 L
.62598 .28799 L
.62591 .28813 L
.62583 .28827 L
.62576 .28842 L
.62569 .28856 L
.62562 .2887 L
.62555 .28884 L
.62548 .28899 L
.62541 .28913 L
.62534 .28927 L
.62527 .28941 L
.62519 .28956 L
.62512 .2897 L
.62505 .28984 L
.62498 .28998 L
.6249 .29012 L
.62483 .29027 L
.62476 .29041 L
.62469 .29055 L
Mistroke
.62461 .29069 L
.62454 .29084 L
.62446 .29098 L
.62439 .29112 L
.62432 .29126 L
.62424 .29141 L
.62417 .29155 L
.62409 .29169 L
.62402 .29183 L
.62394 .29198 L
.62387 .29212 L
.62379 .29226 L
.62372 .2924 L
.62364 .29255 L
.62357 .29269 L
.62349 .29283 L
.62341 .29297 L
.62334 .29311 L
.62326 .29326 L
.62319 .2934 L
.62311 .29354 L
.62303 .29368 L
.62295 .29383 L
.62288 .29397 L
.6228 .29411 L
.62272 .29425 L
.62264 .2944 L
.62257 .29454 L
.62249 .29468 L
.62241 .29482 L
.62233 .29497 L
.62225 .29511 L
.62217 .29525 L
.62209 .29539 L
.62201 .29554 L
.62193 .29568 L
.62186 .29582 L
.62178 .29596 L
.6217 .29611 L
.62162 .29625 L
.62154 .29639 L
.62145 .29653 L
.62137 .29667 L
.62129 .29682 L
.62121 .29696 L
.62113 .2971 L
.62105 .29724 L
.62097 .29739 L
.62089 .29753 L
.62081 .29767 L
Mistroke
.62072 .29781 L
.62064 .29796 L
.62056 .2981 L
.62048 .29824 L
.62039 .29838 L
.62031 .29852 L
.62023 .29867 L
.62014 .29881 L
.62006 .29895 L
.61998 .29909 L
.61989 .29924 L
.61981 .29938 L
.61973 .29952 L
.61964 .29966 L
.61956 .29981 L
.61947 .29995 L
.61939 .30009 L
.6193 .30023 L
.61922 .30037 L
.61913 .30052 L
.61905 .30066 L
.61896 .3008 L
.61888 .30094 L
.61879 .30108 L
.61871 .30123 L
.61862 .30137 L
.61853 .30151 L
.61845 .30165 L
.61836 .3018 L
.61827 .30194 L
.61819 .30208 L
.6181 .30222 L
.61801 .30236 L
.61793 .30251 L
.61784 .30265 L
.61775 .30279 L
.61766 .30293 L
.61758 .30307 L
.61749 .30322 L
.6174 .30336 L
.61731 .3035 L
.61722 .30364 L
.61713 .30378 L
.61704 .30392 L
.61695 .30407 L
.61687 .30421 L
.61678 .30435 L
.61669 .30449 L
.6166 .30463 L
.61651 .30478 L
Mistroke
.61642 .30492 L
.61633 .30506 L
.61624 .3052 L
.61615 .30534 L
.61606 .30548 L
.61596 .30563 L
.61587 .30577 L
.61578 .30591 L
.61569 .30605 L
.6156 .30619 L
.61551 .30633 L
.61542 .30648 L
.61532 .30662 L
.61523 .30676 L
.61514 .3069 L
.61505 .30704 L
.61496 .30718 L
.61486 .30732 L
.61477 .30747 L
.61468 .30761 L
.61458 .30775 L
.61449 .30789 L
.6144 .30803 L
.6143 .30817 L
.61421 .30831 L
.61412 .30846 L
.61402 .3086 L
.61393 .30874 L
.61383 .30888 L
.61374 .30902 L
.61364 .30916 L
.61355 .3093 L
.61345 .30944 L
.61336 .30958 L
.61326 .30973 L
.61317 .30987 L
.61307 .31001 L
.61298 .31015 L
.61288 .31029 L
.61279 .31043 L
.61269 .31057 L
.61259 .31071 L
.6125 .31085 L
.6124 .31099 L
.6123 .31114 L
.61221 .31128 L
.61211 .31142 L
.61201 .31156 L
.61192 .3117 L
.61182 .31184 L
Mistroke
.61172 .31198 L
.61162 .31212 L
.61153 .31226 L
.61143 .3124 L
.61133 .31254 L
.61123 .31268 L
.61113 .31282 L
.61103 .31296 L
.61094 .3131 L
.61084 .31324 L
.61074 .31339 L
.61064 .31353 L
.61054 .31367 L
.61044 .31381 L
.61034 .31395 L
.61024 .31409 L
.61014 .31423 L
.61004 .31437 L
.60994 .31451 L
.60984 .31465 L
.60974 .31479 L
.60964 .31493 L
.60954 .31507 L
.60944 .31521 L
.60934 .31535 L
.60924 .31549 L
.60914 .31563 L
.60903 .31577 L
.60893 .31591 L
.60883 .31605 L
.60873 .31619 L
.60863 .31633 L
.60853 .31647 L
.60842 .31661 L
.60832 .31675 L
.60822 .31689 L
.60812 .31702 L
.60801 .31716 L
.60791 .3173 L
.60781 .31744 L
.6077 .31758 L
.6076 .31772 L
.6075 .31786 L
.60739 .318 L
.60729 .31814 L
.60719 .31828 L
.60708 .31842 L
.60698 .31856 L
.60687 .3187 L
.60677 .31884 L
Mistroke
.60667 .31897 L
.60656 .31911 L
.60646 .31925 L
.60635 .31939 L
.60625 .31953 L
.60614 .31967 L
.60604 .31981 L
.60593 .31995 L
.60583 .32009 L
.60572 .32022 L
.60561 .32036 L
.60551 .3205 L
.6054 .32064 L
.6053 .32078 L
.60519 .32092 L
.60508 .32106 L
.60498 .32119 L
.60487 .32133 L
.60476 .32147 L
.60466 .32161 L
.60455 .32175 L
.60444 .32189 L
.60434 .32202 L
.60423 .32216 L
.60412 .3223 L
.60401 .32244 L
.60391 .32258 L
.6038 .32272 L
.60369 .32285 L
.60358 .32299 L
.60347 .32313 L
.60336 .32327 L
.60326 .3234 L
.60315 .32354 L
.60304 .32368 L
.60293 .32382 L
.60282 .32395 L
.60271 .32409 L
.6026 .32423 L
.60249 .32437 L
.60238 .3245 L
.60227 .32464 L
.60216 .32478 L
.60205 .32492 L
.60194 .32505 L
.60183 .32519 L
.60172 .32533 L
.60161 .32547 L
.6015 .3256 L
.60139 .32574 L
Mistroke
.60128 .32588 L
.60117 .32601 L
.60106 .32615 L
.60095 .32629 L
.60084 .32642 L
.60073 .32656 L
.60062 .3267 L
.6005 .32683 L
.60039 .32697 L
.60028 .32711 L
.60017 .32724 L
.60006 .32738 L
.59995 .32752 L
.59983 .32765 L
.59972 .32779 L
.59961 .32792 L
.5995 .32806 L
.59938 .3282 L
.59927 .32833 L
.59916 .32847 L
.59904 .3286 L
.59893 .32874 L
.59882 .32888 L
.59871 .32901 L
.59859 .32915 L
.59848 .32928 L
.59836 .32942 L
.59825 .32955 L
.59814 .32969 L
.59802 .32983 L
.59791 .32996 L
.59779 .3301 L
.59768 .33023 L
.59757 .33037 L
.59745 .3305 L
.59734 .33064 L
.59722 .33077 L
.59711 .33091 L
.59699 .33104 L
.59688 .33118 L
.59676 .33131 L
.59665 .33145 L
.59653 .33158 L
.59642 .33172 L
.5963 .33185 L
.59618 .33199 L
.59607 .33212 L
.59595 .33225 L
.59584 .33239 L
.59572 .33252 L
Mistroke
.5956 .33266 L
.59549 .33279 L
.59537 .33293 L
.59525 .33306 L
.59514 .33319 L
.59502 .33333 L
.5949 .33346 L
.59479 .3336 L
.59467 .33373 L
.59455 .33386 L
.59444 .334 L
.59432 .33413 L
.5942 .33426 L
.59408 .3344 L
.59397 .33453 L
.59385 .33467 L
.59373 .3348 L
.59361 .33493 L
.59349 .33507 L
.59338 .3352 L
.59326 .33533 L
.59314 .33546 L
.59302 .3356 L
.5929 .33573 L
.59278 .33586 L
.59266 .336 L
.59255 .33613 L
.59243 .33626 L
.59231 .33639 L
.59219 .33653 L
.59207 .33666 L
.59195 .33679 L
.59183 .33692 L
.59171 .33706 L
.59159 .33719 L
.59147 .33732 L
.59135 .33745 L
.59123 .33758 L
.59111 .33772 L
.59099 .33785 L
.59087 .33798 L
.59075 .33811 L
.59063 .33824 L
.59051 .33837 L
.59039 .33851 L
.59027 .33864 L
.59015 .33877 L
.59003 .3389 L
.58991 .33903 L
.58978 .33916 L
Mistroke
.58966 .33929 L
.58954 .33943 L
.58942 .33956 L
.5893 .33969 L
.58918 .33982 L
.58906 .33995 L
.58893 .34008 L
.58881 .34021 L
.58869 .34034 L
.58857 .34047 L
.58845 .3406 L
.58832 .34073 L
.5882 .34086 L
.58808 .34099 L
.58796 .34112 L
.58784 .34125 L
.58771 .34138 L
.58759 .34151 L
.58747 .34164 L
.58734 .34177 L
.58722 .3419 L
.5871 .34203 L
.58698 .34216 L
.58685 .34229 L
.58673 .34242 L
.58661 .34255 L
.58648 .34268 L
.58636 .34281 L
.58624 .34294 L
.58611 .34307 L
.58599 .3432 L
.58586 .34332 L
.58574 .34345 L
.58562 .34358 L
.58549 .34371 L
.58537 .34384 L
.58524 .34397 L
.58512 .3441 L
.58499 .34423 L
.58487 .34435 L
.58475 .34448 L
.58462 .34461 L
.5845 .34474 L
.58437 .34487 L
.58425 .34499 L
.58412 .34512 L
.584 .34525 L
.58387 .34538 L
.58375 .34551 L
.58362 .34563 L
Mistroke
.5835 .34576 L
.58337 .34589 L
.58324 .34601 L
.58312 .34614 L
.58299 .34627 L
.58287 .3464 L
.58274 .34652 L
.58262 .34665 L
.58249 .34678 L
.58236 .3469 L
.58224 .34703 L
.58211 .34716 L
.58199 .34728 L
.58186 .34741 L
.58173 .34754 L
.58161 .34766 L
.58148 .34779 L
.58135 .34792 L
.58123 .34804 L
.5811 .34817 L
.58097 .34829 L
.58085 .34842 L
.58072 .34855 L
.58059 .34867 L
.58047 .3488 L
.58034 .34892 L
.58021 .34905 L
.58008 .34917 L
.57996 .3493 L
.57983 .34942 L
.5797 .34955 L
.57957 .34967 L
.57945 .3498 L
.57932 .34992 L
.57919 .35005 L
.57906 .35017 L
.57893 .3503 L
.57881 .35042 L
.57868 .35055 L
.57855 .35067 L
.57842 .35079 L
.57829 .35092 L
.57817 .35104 L
.57804 .35117 L
.57791 .35129 L
.57778 .35141 L
.57765 .35154 L
.57752 .35166 L
.57739 .35179 L
.57727 .35191 L
Mistroke
.57714 .35203 L
.57701 .35216 L
.57688 .35228 L
.57675 .3524 L
.57662 .35252 L
.57649 .35265 L
.57636 .35277 L
.57623 .35289 L
.5761 .35302 L
.57597 .35314 L
.57584 .35326 L
.57572 .35338 L
.57559 .35351 L
.57546 .35363 L
.57533 .35375 L
.5752 .35387 L
.57507 .35399 L
.57494 .35412 L
.57481 .35424 L
.57468 .35436 L
.57455 .35448 L
.57442 .3546 L
.57429 .35472 L
.57416 .35485 L
.57403 .35497 L
.5739 .35509 L
.57377 .35521 L
.57363 .35533 L
.5735 .35545 L
.57337 .35557 L
.57324 .35569 L
.57311 .35581 L
.57298 .35593 L
.57285 .35605 L
.57272 .35617 L
.57259 .3563 L
.57246 .35642 L
.57233 .35654 L
.5722 .35666 L
.57207 .35678 L
.57193 .3569 L
.5718 .35701 L
.57167 .35713 L
.57154 .35725 L
.57141 .35737 L
.57128 .35749 L
.57115 .35761 L
.57101 .35773 L
.57088 .35785 L
.57075 .35797 L
Mistroke
.57062 .35809 L
.57049 .35821 L
.57036 .35833 L
.57023 .35844 L
.57009 .35856 L
.56996 .35868 L
.56983 .3588 L
.5697 .35892 L
.56957 .35904 L
.56943 .35915 L
.5693 .35927 L
.56917 .35939 L
.56904 .35951 L
.5689 .35962 L
.56877 .35974 L
.56864 .35986 L
.56851 .35998 L
.56838 .36009 L
.56824 .36021 L
.56811 .36033 L
.56798 .36044 L
.56785 .36056 L
.56771 .36068 L
.56758 .3608 L
.56745 .36091 L
.56731 .36103 L
.56718 .36114 L
.56705 .36126 L
.56692 .36138 L
.56678 .36149 L
.56665 .36161 L
.56652 .36172 L
.56638 .36184 L
.56625 .36196 L
.56612 .36207 L
.56598 .36219 L
.56585 .3623 L
.56572 .36242 L
.56558 .36253 L
.56545 .36265 L
.56532 .36276 L
.56518 .36288 L
.56505 .36299 L
.56492 .36311 L
.56478 .36322 L
.56465 .36334 L
.56452 .36345 L
.56438 .36356 L
.56425 .36368 L
.56412 .36379 L
Mistroke
.56398 .36391 L
.56385 .36402 L
.56371 .36413 L
.56358 .36425 L
.56345 .36436 L
.56331 .36447 L
.56318 .36459 L
.56305 .3647 L
.56291 .36481 L
.56278 .36493 L
.56264 .36504 L
.56251 .36515 L
.56237 .36527 L
.56224 .36538 L
.56211 .36549 L
.56197 .3656 L
.56184 .36571 L
.5617 .36583 L
.56157 .36594 L
.56143 .36605 L
.5613 .36616 L
.56117 .36627 L
.56103 .36639 L
.5609 .3665 L
.56076 .36661 L
.56063 .36672 L
.56049 .36683 L
.56036 .36694 L
.56022 .36705 L
.56009 .36716 L
.55996 .36728 L
.55982 .36739 L
.55969 .3675 L
.55955 .36761 L
.55942 .36772 L
.55928 .36783 L
.55915 .36794 L
.55901 .36805 L
.55888 .36816 L
.55874 .36827 L
.55861 .36838 L
.55847 .36849 L
.55834 .3686 L
.5582 .36871 L
.55807 .36881 L
.55793 .36892 L
.5578 .36903 L
.55766 .36914 L
.55753 .36925 L
.55739 .36936 L
Mistroke
.55726 .36947 L
.55712 .36958 L
.55699 .36969 L
.55685 .36979 L
.55672 .3699 L
.55658 .37001 L
.55645 .37012 L
.55631 .37023 L
.55617 .37033 L
.55604 .37044 L
.5559 .37055 L
.55577 .37066 L
.55563 .37076 L
.5555 .37087 L
.55536 .37098 L
.55523 .37108 L
.55509 .37119 L
.55496 .3713 L
.55482 .3714 L
.55468 .37151 L
.55455 .37162 L
.55441 .37172 L
.55428 .37183 L
.55414 .37194 L
.55401 .37204 L
.55387 .37215 L
.55374 .37225 L
.5536 .37236 L
.55346 .37246 L
.55333 .37257 L
.55319 .37267 L
.55306 .37278 L
.55292 .37289 L
.55279 .37299 L
.55265 .37309 L
.55251 .3732 L
.55238 .3733 L
.55224 .37341 L
.55211 .37351 L
.55197 .37362 L
.55184 .37372 L
.5517 .37383 L
.55156 .37393 L
.55143 .37403 L
.55129 .37414 L
.55116 .37424 L
.55102 .37434 L
.55088 .37445 L
.55075 .37455 L
.55061 .37465 L
Mistroke
.55048 .37476 L
.55034 .37486 L
.55021 .37496 L
.55007 .37506 L
.54993 .37517 L
.5498 .37527 L
.54966 .37537 L
.54953 .37547 L
.54939 .37558 L
.54925 .37568 L
.54912 .37578 L
.54898 .37588 L
.54885 .37598 L
.54871 .37608 L
.54857 .37619 L
.54844 .37629 L
.5483 .37639 L
.54817 .37649 L
.54803 .37659 L
.54789 .37669 L
.54776 .37679 L
.54762 .37689 L
.54749 .37699 L
.54735 .37709 L
.54721 .37719 L
.54708 .37729 L
.54694 .37739 L
.5468 .37749 L
.54667 .37759 L
.54653 .37769 L
.5464 .37779 L
.54626 .37789 L
.54612 .37799 L
.54599 .37809 L
.54585 .37819 L
.54572 .37829 L
.54558 .37839 L
.54544 .37848 L
.54531 .37858 L
.54517 .37868 L
.54504 .37878 L
.5449 .37888 L
.54476 .37898 L
.54463 .37907 L
.54449 .37917 L
.54436 .37927 L
.54422 .37937 L
.54408 .37946 L
.54395 .37956 L
.54381 .37966 L
Mistroke
.54368 .37976 L
.54354 .37985 L
.5434 .37995 L
.54327 .38005 L
.54313 .38014 L
.543 .38024 L
.54286 .38034 L
.54272 .38043 L
.54259 .38053 L
.54245 .38062 L
.54232 .38072 L
.54218 .38082 L
.54204 .38091 L
.54191 .38101 L
.54177 .3811 L
.54164 .3812 L
.5415 .38129 L
.54136 .38139 L
.54123 .38148 L
.54109 .38158 L
.54096 .38167 L
.54082 .38177 L
.54068 .38186 L
.54055 .38195 L
.54041 .38205 L
.54028 .38214 L
.54014 .38224 L
.54001 .38233 L
.53987 .38242 L
.53973 .38252 L
.5396 .38261 L
.53946 .3827 L
.53933 .3828 L
.53919 .38289 L
.53905 .38298 L
.53892 .38308 L
.53878 .38317 L
.53865 .38326 L
.53851 .38335 L
.53838 .38345 L
.53824 .38354 L
.5381 .38363 L
.53797 .38372 L
.53783 .38381 L
.5377 .38391 L
.53756 .384 L
.53743 .38409 L
.53729 .38418 L
.53716 .38427 L
.53702 .38436 L
Mistroke
.53688 .38445 L
.53675 .38454 L
.53661 .38463 L
.53648 .38473 L
.53634 .38482 L
.53621 .38491 L
.53607 .385 L
.53594 .38509 L
.5358 .38518 L
.53566 .38527 L
.53553 .38536 L
.53539 .38545 L
.53526 .38553 L
.53512 .38562 L
.53499 .38571 L
.53485 .3858 L
.53472 .38589 L
.53458 .38598 L
.53445 .38607 L
.53431 .38616 L
.53418 .38625 L
.53404 .38633 L
.53391 .38642 L
.53377 .38651 L
.53364 .3866 L
.5335 .38669 L
.53337 .38677 L
.53323 .38686 L
.5331 .38695 L
.53296 .38704 L
.53283 .38712 L
.53269 .38721 L
.53256 .3873 L
.53242 .38738 L
.53229 .38747 L
.53215 .38756 L
.53202 .38764 L
.53188 .38773 L
.53175 .38781 L
.53161 .3879 L
.53148 .38799 L
.53134 .38807 L
.53121 .38816 L
.53107 .38824 L
.53094 .38833 L
.5308 .38841 L
.53067 .3885 L
.53053 .38858 L
.5304 .38867 L
.53027 .38875 L
Mistroke
.53013 .38884 L
.53 .38892 L
.52986 .38901 L
.52973 .38909 L
.52959 .38918 L
.52946 .38926 L
.52932 .38934 L
.52919 .38943 L
.52906 .38951 L
.52892 .38959 L
.52879 .38968 L
.52865 .38976 L
.52852 .38984 L
.52839 .38993 L
.52825 .39001 L
.52812 .39009 L
.52798 .39017 L
.52785 .39026 L
.52771 .39034 L
.52758 .39042 L
.52745 .3905 L
.52731 .39058 L
.52718 .39067 L
.52705 .39075 L
.52691 .39083 L
.52678 .39091 L
.52664 .39099 L
.52651 .39107 L
.52638 .39115 L
.52624 .39123 L
.52611 .39132 L
.52598 .3914 L
.52584 .39148 L
.52571 .39156 L
.52558 .39164 L
.52544 .39172 L
.52531 .3918 L
.52518 .39188 L
.52504 .39196 L
.52491 .39204 L
.52478 .39212 L
.52464 .39219 L
.52451 .39227 L
.52438 .39235 L
.52424 .39243 L
.52411 .39251 L
.52398 .39259 L
.52384 .39267 L
.52371 .39275 L
.52358 .39282 L
Mistroke
.52344 .3929 L
.52331 .39298 L
.52318 .39306 L
.52305 .39314 L
.52291 .39321 L
.52278 .39329 L
.52265 .39337 L
.52252 .39345 L
.52238 .39352 L
.52225 .3936 L
.52212 .39368 L
.52199 .39375 L
.52185 .39383 L
.52172 .39391 L
.52159 .39398 L
.52146 .39406 L
.52132 .39413 L
.52119 .39421 L
.52106 .39429 L
.52093 .39436 L
.52079 .39444 L
.52066 .39451 L
.52053 .39459 L
.5204 .39466 L
.52027 .39474 L
.52013 .39481 L
.52 .39489 L
.51987 .39496 L
.51974 .39504 L
.51961 .39511 L
.51948 .39518 L
.51934 .39526 L
.51921 .39533 L
.51908 .39541 L
.51895 .39548 L
.51882 .39555 L
.51869 .39563 L
.51855 .3957 L
.51842 .39577 L
.51829 .39585 L
.51816 .39592 L
.51803 .39599 L
.5179 .39606 L
.51777 .39614 L
.51764 .39621 L
.51751 .39628 L
.51737 .39635 L
.51724 .39642 L
.51711 .3965 L
.51698 .39657 L
Mistroke
.51685 .39664 L
.51672 .39671 L
.51659 .39678 L
.51646 .39685 L
.51633 .39692 L
.5162 .397 L
.51607 .39707 L
.51594 .39714 L
.51581 .39721 L
.51568 .39728 L
.51555 .39735 L
.51541 .39742 L
.51528 .39749 L
.51515 .39756 L
.51502 .39763 L
.51489 .3977 L
.51476 .39777 L
.51463 .39784 L
.5145 .3979 L
.51437 .39797 L
.51424 .39804 L
.51411 .39811 L
.51398 .39818 L
.51386 .39825 L
.51373 .39832 L
.5136 .39838 L
.51347 .39845 L
.51334 .39852 L
.51321 .39859 L
.51308 .39866 L
.51295 .39872 L
.51282 .39879 L
.51269 .39886 L
.51256 .39893 L
.51243 .39899 L
.5123 .39906 L
.51217 .39913 L
.51204 .39919 L
.51192 .39926 L
.51179 .39933 L
.51166 .39939 L
.51153 .39946 L
.5114 .39952 L
.51127 .39959 L
.51114 .39966 L
.51101 .39972 L
.51089 .39979 L
.51076 .39985 L
.51063 .39992 L
.5105 .39998 L
Mistroke
.51037 .40005 L
.51024 .40011 L
.51012 .40018 L
.50999 .40024 L
.50986 .4003 L
.50973 .40037 L
.5096 .40043 L
.50948 .4005 L
.50935 .40056 L
.50922 .40062 L
.50909 .40069 L
.50897 .40075 L
.50884 .40082 L
.50871 .40088 L
.50858 .40094 L
.50846 .401 L
.50833 .40107 L
.5082 .40113 L
.50807 .40119 L
.50795 .40125 L
.50782 .40132 L
.50769 .40138 L
.50756 .40144 L
.50744 .4015 L
.50731 .40156 L
.50718 .40163 L
.50706 .40169 L
.50693 .40175 L
.5068 .40181 L
.50668 .40187 L
.50655 .40193 L
.50642 .40199 L
.5063 .40205 L
.50617 .40211 L
.50604 .40217 L
.50592 .40223 L
.50579 .40229 L
.50567 .40235 L
.50554 .40241 L
.50541 .40247 L
.50529 .40253 L
.50516 .40259 L
.50504 .40265 L
.50491 .40271 L
.50479 .40277 L
.50466 .40283 L
.50453 .40289 L
.50441 .40295 L
.50428 .40301 L
.50416 .40306 L
Mistroke
.50403 .40312 L
.50391 .40318 L
.50378 .40324 L
.50366 .4033 L
.50353 .40335 L
.50341 .40341 L
.50328 .40347 L
.50316 .40353 L
.50303 .40358 L
.50291 .40364 L
.50278 .4037 L
.50266 .40375 L
.50253 .40381 L
.50241 .40387 L
.50228 .40392 L
.50216 .40398 L
.50204 .40404 L
.50191 .40409 L
.50179 .40415 L
.50166 .4042 L
.50154 .40426 L
.50142 .40431 L
.50129 .40437 L
.50117 .40442 L
.50104 .40448 L
.50092 .40453 L
.5008 .40459 L
.50067 .40464 L
.50055 .4047 L
.50043 .40475 L
.5003 .40481 L
.50018 .40486 L
.50006 .40492 L
.49993 .40497 L
.49981 .40502 L
.49969 .40508 L
.49956 .40513 L
.49944 .40518 L
.49932 .40524 L
.49919 .40529 L
.49907 .40534 L
.49895 .4054 L
.49883 .40545 L
.4987 .4055 L
.49858 .40555 L
.49846 .40561 L
.49834 .40566 L
.49822 .40571 L
.49809 .40576 L
.49797 .40581 L
Mistroke
.49785 .40587 L
.49773 .40592 L
.49761 .40597 L
.49748 .40602 L
.49736 .40607 L
.49724 .40612 L
.49712 .40617 L
.497 .40622 L
.49688 .40627 L
.49675 .40632 L
.49663 .40637 L
.49651 .40642 L
.49639 .40647 L
.49627 .40652 L
.49615 .40657 L
.49603 .40662 L
.49591 .40667 L
.49579 .40672 L
.49566 .40677 L
.49554 .40682 L
.49542 .40687 L
.4953 .40692 L
.49518 .40697 L
.49506 .40702 L
.49494 .40707 L
.49482 .40711 L
.4947 .40716 L
.49458 .40721 L
.49446 .40726 L
.49434 .40731 L
.49422 .40735 L
.4941 .4074 L
.49398 .40745 L
.49386 .4075 L
.49374 .40754 L
.49362 .40759 L
.4935 .40764 L
.49338 .40768 L
.49327 .40773 L
.49315 .40778 L
.49303 .40782 L
.49291 .40787 L
.49279 .40792 L
.49267 .40796 L
.49255 .40801 L
.49243 .40805 L
.49231 .4081 L
.4922 .40814 L
.49208 .40819 L
.49196 .40824 L
Mistroke
.49184 .40828 L
.49172 .40833 L
.4916 .40837 L
.49149 .40842 L
.49137 .40846 L
.49125 .4085 L
.49113 .40855 L
.49101 .40859 L
.4909 .40864 L
.49078 .40868 L
.49066 .40872 L
.49054 .40877 L
.49043 .40881 L
.49031 .40886 L
.49019 .4089 L
.49007 .40894 L
.48996 .40898 L
.48984 .40903 L
.48972 .40907 L
.48961 .40911 L
.48949 .40916 L
.48937 .4092 L
.48926 .40924 L
.48914 .40928 L
.48902 .40932 L
.48891 .40937 L
.48879 .40941 L
.48867 .40945 L
.48856 .40949 L
.48844 .40953 L
.48833 .40957 L
.48821 .40962 L
.48809 .40966 L
.48798 .4097 L
.48786 .40974 L
.48775 .40978 L
.48763 .40982 L
.48752 .40986 L
.4874 .4099 L
.48728 .40994 L
.48717 .40998 L
.48705 .41002 L
.48694 .41006 L
.48682 .4101 L
.48671 .41014 L
.48659 .41018 L
.48648 .41022 L
.48636 .41026 L
.48625 .41029 L
.48614 .41033 L
Mistroke
.48602 .41037 L
.48591 .41041 L
.48579 .41045 L
.48568 .41049 L
.48556 .41053 L
.48545 .41056 L
.48534 .4106 L
.48522 .41064 L
.48511 .41068 L
.48499 .41071 L
.48488 .41075 L
.48477 .41079 L
.48465 .41083 L
.48454 .41086 L
.48443 .4109 L
.48431 .41094 L
.4842 .41097 L
.48409 .41101 L
.48398 .41105 L
.48386 .41108 L
.48375 .41112 L
.48364 .41116 L
.48352 .41119 L
.48341 .41123 L
.4833 .41126 L
.48319 .4113 L
.48307 .41133 L
.48296 .41137 L
.48285 .4114 L
.48274 .41144 L
.48263 .41147 L
.48251 .41151 L
.4824 .41154 L
.48229 .41158 L
.48218 .41161 L
.48207 .41165 L
.48196 .41168 L
.48184 .41171 L
.48173 .41175 L
.48162 .41178 L
.48151 .41182 L
.4814 .41185 L
.48129 .41188 L
.48118 .41192 L
.48107 .41195 L
.48096 .41198 L
.48085 .41202 L
.48074 .41205 L
.48063 .41208 L
.48051 .41211 L
Mistroke
.4804 .41215 L
.48029 .41218 L
.48018 .41221 L
.48007 .41224 L
.47996 .41227 L
.47985 .41231 L
.47974 .41234 L
.47964 .41237 L
.47953 .4124 L
.47942 .41243 L
.47931 .41246 L
.4792 .41249 L
.47909 .41253 L
.47898 .41256 L
.47887 .41259 L
.47876 .41262 L
.47865 .41265 L
.47854 .41268 L
.47843 .41271 L
.47833 .41274 L
.47822 .41277 L
.47811 .4128 L
.478 .41283 L
.47789 .41286 L
.47778 .41289 L
.47768 .41292 L
.47757 .41295 L
.47746 .41297 L
.47735 .413 L
.47724 .41303 L
.47714 .41306 L
.47703 .41309 L
.47692 .41312 L
.47681 .41315 L
.47671 .41317 L
.4766 .4132 L
.47649 .41323 L
.47639 .41326 L
.47628 .41329 L
.47617 .41331 L
.47606 .41334 L
.47596 .41337 L
.47585 .4134 L
.47574 .41342 L
.47564 .41345 L
.47553 .41348 L
.47543 .4135 L
.47532 .41353 L
.47521 .41356 L
.47511 .41358 L
Mistroke
.475 .41361 L
.4749 .41364 L
.47479 .41366 L
.47468 .41369 L
.47458 .41371 L
.47447 .41374 L
.47437 .41377 L
.47426 .41379 L
.47416 .41382 L
.47405 .41384 L
.47395 .41387 L
.47384 .41389 L
.47374 .41392 L
.47363 .41394 L
.47353 .41397 L
.47342 .41399 L
.47332 .41401 L
.47322 .41404 L
.47311 .41406 L
.47301 .41409 L
.4729 .41411 L
.4728 .41414 L
.47269 .41416 L
.47259 .41418 L
.47249 .41421 L
.47238 .41423 L
.47228 .41425 L
.47218 .41428 L
.47207 .4143 L
.47197 .41432 L
.47187 .41434 L
.47176 .41437 L
.47166 .41439 L
.47156 .41441 L
.47145 .41443 L
.47135 .41446 L
.47125 .41448 L
.47115 .4145 L
.47104 .41452 L
.47094 .41454 L
.47084 .41457 L
.47074 .41459 L
.47064 .41461 L
.47053 .41463 L
.47043 .41465 L
.47033 .41467 L
.47023 .41469 L
.47013 .41471 L
.47002 .41473 L
.46992 .41475 L
Mistroke
.46982 .41477 L
.46972 .41479 L
.46962 .41481 L
.46952 .41484 L
.46942 .41485 L
.46932 .41487 L
.46922 .41489 L
.46911 .41491 L
.46901 .41493 L
.46891 .41495 L
.46881 .41497 L
.46871 .41499 L
.46861 .41501 L
.46851 .41503 L
.46841 .41505 L
.46831 .41507 L
.46821 .41509 L
.46811 .4151 L
.46801 .41512 L
.46791 .41514 L
.46781 .41516 L
.46771 .41518 L
.46762 .41519 L
.46752 .41521 L
.46742 .41523 L
.46732 .41525 L
.46722 .41526 L
.46712 .41528 L
.46702 .4153 L
.46692 .41532 L
.46682 .41533 L
.46673 .41535 L
.46663 .41537 L
.46653 .41538 L
.46643 .4154 L
.46633 .41542 L
.46623 .41543 L
.46614 .41545 L
.46604 .41547 L
.46594 .41548 L
.46584 .4155 L
.46575 .41551 L
.46565 .41553 L
.46555 .41554 L
.46545 .41556 L
.46536 .41557 L
.46526 .41559 L
.46516 .4156 L
.46507 .41562 L
.46497 .41563 L
Mistroke
.46487 .41565 L
.46478 .41566 L
.46468 .41568 L
.46458 .41569 L
.46449 .41571 L
.46439 .41572 L
.46429 .41574 L
.4642 .41575 L
.4641 .41576 L
.46401 .41578 L
.46391 .41579 L
.46381 .4158 L
.46372 .41582 L
.46362 .41583 L
.46353 .41584 L
.46343 .41586 L
.46334 .41587 L
.46324 .41588 L
.46315 .4159 L
.46305 .41591 L
.46296 .41592 L
.46286 .41593 L
.46277 .41595 L
.46267 .41596 L
.46258 .41597 L
.46248 .41598 L
.46239 .41599 L
.4623 .41601 L
.4622 .41602 L
.46211 .41603 L
.46201 .41604 L
.46192 .41605 L
.46183 .41606 L
.46173 .41607 L
.46164 .41608 L
.46155 .4161 L
.46145 .41611 L
.46136 .41612 L
.46127 .41613 L
.46117 .41614 L
.46108 .41615 L
.46099 .41616 L
.4609 .41617 L
.4608 .41618 L
.46071 .41619 L
.46062 .4162 L
.46053 .41621 L
.46043 .41622 L
.46034 .41623 L
.46025 .41624 L
Mistroke
.46016 .41625 L
.46007 .41626 L
.45997 .41626 L
.45988 .41627 L
.45979 .41628 L
.4597 .41629 L
.45961 .4163 L
.45952 .41631 L
.45942 .41632 L
.45933 .41633 L
.45924 .41633 L
.45915 .41634 L
.45906 .41635 L
.45897 .41636 L
.45888 .41637 L
.45879 .41637 L
.4587 .41638 L
.45861 .41639 L
.45852 .4164 L
.45843 .4164 L
.45834 .41641 L
.45825 .41642 L
.45816 .41642 L
.45807 .41643 L
.45798 .41644 L
.45789 .41644 L
.4578 .41645 L
.45771 .41646 L
.45762 .41646 L
.45753 .41647 L
.45744 .41648 L
.45735 .41648 L
.45726 .41649 L
.45718 .41649 L
.45709 .4165 L
.457 .41651 L
.45691 .41651 L
.45682 .41652 L
.45673 .41652 L
.45665 .41653 L
.45656 .41653 L
.45647 .41654 L
.45638 .41654 L
.45629 .41655 L
.45621 .41655 L
.45612 .41656 L
.45603 .41656 L
.45594 .41657 L
.45586 .41657 L
.45577 .41657 L
Mistroke
.45568 .41658 L
.45559 .41658 L
.45551 .41659 L
.45542 .41659 L
.45533 .41659 L
.45525 .4166 L
.45516 .4166 L
.45507 .4166 L
.45499 .41661 L
.4549 .41661 L
.45482 .41661 L
.45473 .41662 L
.45464 .41662 L
.45456 .41662 L
.45447 .41663 L
.45439 .41663 L
.4543 .41663 L
.45421 .41663 L
.45413 .41664 L
.45404 .41664 L
.45396 .41664 L
.45387 .41664 L
.45379 .41664 L
.4537 .41665 L
.45362 .41665 L
.45353 .41665 L
.45345 .41665 L
.45337 .41665 L
.45328 .41665 L
.4532 .41665 L
.45311 .41666 L
.45303 .41666 L
.45294 .41666 L
.45286 .41666 L
.45278 .41666 L
.45269 .41666 L
.45261 .41666 L
.45253 .41666 L
.45244 .41666 L
.45236 .41666 L
.45227 .41666 L
.45219 .41666 L
.45211 .41666 L
.45203 .41666 L
.45194 .41666 L
.45186 .41666 L
.45178 .41666 L
.45169 .41666 L
.45161 .41666 L
.45153 .41666 L
Mistroke
.45145 .41666 L
.45137 .41666 L
.45128 .41666 L
.4512 .41666 L
.45112 .41665 L
.45104 .41665 L
.45096 .41665 L
.45087 .41665 L
.45079 .41665 L
.45071 .41665 L
.45063 .41665 L
.45055 .41664 L
.45047 .41664 L
.45039 .41664 L
.45031 .41664 L
.45022 .41664 L
.45014 .41663 L
.45006 .41663 L
.44998 .41663 L
.4499 .41663 L
.44982 .41662 L
.44974 .41662 L
.44966 .41662 L
.44958 .41661 L
.4495 .41661 L
.44942 .41661 L
.44934 .41661 L
.44926 .4166 L
.44918 .4166 L
.4491 .4166 L
.44902 .41659 L
.44894 .41659 L
.44887 .41658 L
.44879 .41658 L
.44871 .41658 L
.44863 .41657 L
.44855 .41657 L
.44847 .41656 L
.44839 .41656 L
.44831 .41656 L
.44823 .41655 L
.44816 .41655 L
.44808 .41654 L
.448 .41654 L
.44792 .41653 L
.44784 .41653 L
.44777 .41652 L
.44769 .41652 L
.44761 .41651 L
.44753 .41651 L
Mistroke
.44746 .4165 L
.44738 .4165 L
.4473 .41649 L
.44722 .41648 L
.44715 .41648 L
.44707 .41647 L
.44699 .41647 L
.44692 .41646 L
.44684 .41645 L
.44676 .41645 L
.44669 .41644 L
.44661 .41644 L
.44653 .41643 L
.44646 .41642 L
.44638 .41642 L
.44631 .41641 L
.44623 .4164 L
.44615 .4164 L
.44608 .41639 L
.446 .41638 L
.44593 .41637 L
.44585 .41637 L
.44578 .41636 L
.4457 .41635 L
.44563 .41634 L
.44555 .41634 L
.44548 .41633 L
.4454 .41632 L
.44533 .41631 L
.44525 .41631 L
.44518 .4163 L
.4451 .41629 L
.44503 .41628 L
.44495 .41627 L
.44488 .41626 L
.44481 .41626 L
.44473 .41625 L
.44466 .41624 L
.44458 .41623 L
.44451 .41622 L
.44444 .41621 L
.44436 .4162 L
.44429 .41619 L
.44422 .41619 L
.44414 .41618 L
.44407 .41617 L
.444 .41616 L
.44392 .41615 L
.44385 .41614 L
.44378 .41613 L
Mistroke
.44371 .41612 L
.44363 .41611 L
.44356 .4161 L
.44349 .41609 L
.44342 .41608 L
.44335 .41607 L
.44327 .41606 L
.4432 .41605 L
.44313 .41604 L
.44306 .41603 L
.44299 .41602 L
.44291 .41601 L
.44284 .416 L
.44277 .41599 L
.4427 .41597 L
.44263 .41596 L
.44256 .41595 L
.44249 .41594 L
.44242 .41593 L
.44235 .41592 L
.44227 .41591 L
.4422 .4159 L
.44213 .41588 L
.44206 .41587 L
.44199 .41586 L
.44192 .41585 L
.44185 .41584 L
.44178 .41583 L
.44171 .41581 L
.44164 .4158 L
.44157 .41579 L
.4415 .41578 L
.44143 .41576 L
.44136 .41575 L
.44129 .41574 L
.44123 .41573 L
.44116 .41571 L
.44109 .4157 L
.44102 .41569 L
.44095 .41568 L
.44088 .41566 L
.44081 .41565 L
.44074 .41564 L
.44067 .41562 L
.44061 .41561 L
.44054 .4156 L
.44047 .41558 L
.4404 .41557 L
.44033 .41556 L
.44027 .41554 L
Mistroke
.4402 .41553 L
.44013 .41551 L
.44006 .4155 L
.44 .41549 L
.43993 .41547 L
.43986 .41546 L
.43979 .41544 L
.43973 .41543 L
.43966 .41542 L
.43959 .4154 L
.43953 .41539 L
.43946 .41537 L
.43939 .41536 L
.43932 .41534 L
.43926 .41533 L
.43919 .41531 L
.43913 .4153 L
.43906 .41528 L
.43899 .41527 L
.43893 .41525 L
.43886 .41524 L
.4388 .41522 L
.43873 .41521 L
.43866 .41519 L
.4386 .41517 L
.43853 .41516 L
.43847 .41514 L
.4384 .41513 L
.43834 .41511 L
.43827 .4151 L
.43821 .41508 L
.43814 .41506 L
.43808 .41505 L
.43801 .41503 L
.43795 .41501 L
.43788 .415 L
.43782 .41498 L
.43776 .41497 L
.43769 .41495 L
.43763 .41493 L
.43756 .41492 L
.4375 .4149 L
.43743 .41488 L
.43737 .41486 L
.43731 .41485 L
.43724 .41483 L
.43718 .41481 L
.43712 .4148 L
.43705 .41478 L
.43699 .41476 L
Mistroke
.43693 .41474 L
.43686 .41473 L
.4368 .41471 L
.43674 .41469 L
.43668 .41467 L
.43661 .41465 L
.43655 .41464 L
.43649 .41462 L
.43643 .4146 L
.43636 .41458 L
.4363 .41456 L
.43624 .41455 L
.43618 .41453 L
.43612 .41451 L
.43605 .41449 L
.43599 .41447 L
.43593 .41445 L
.43587 .41443 L
.43581 .41442 L
.43575 .4144 L
.43569 .41438 L
.43562 .41436 L
.43556 .41434 L
.4355 .41432 L
.43544 .4143 L
.43538 .41428 L
.43532 .41426 L
.43526 .41424 L
.4352 .41422 L
.43514 .4142 L
.43508 .41418 L
.43502 .41416 L
.43496 .41415 L
.4349 .41413 L
.43484 .41411 L
.43478 .41409 L
.43472 .41407 L
.43466 .41405 L
.4346 .41403 L
.43454 .414 L
.43448 .41398 L
.43442 .41396 L
.43436 .41394 L
.4343 .41392 L
.43424 .4139 L
.43418 .41388 L
.43413 .41386 L
.43407 .41384 L
.43401 .41382 L
.43395 .4138 L
Mistroke
.43389 .41378 L
.43383 .41376 L
.43378 .41374 L
.43372 .41371 L
.43366 .41369 L
.4336 .41367 L
.43354 .41365 L
.43349 .41363 L
.43343 .41361 L
.43337 .41359 L
.43331 .41356 L
.43326 .41354 L
.4332 .41352 L
.43314 .4135 L
.43308 .41348 L
.43303 .41346 L
.43297 .41343 L
.43291 .41341 L
.43286 .41339 L
.4328 .41337 L
.43274 .41334 L
.43269 .41332 L
.43263 .4133 L
.43257 .41328 L
.43252 .41325 L
.43246 .41323 L
.4324 .41321 L
.43235 .41319 L
.43229 .41316 L
.43224 .41314 L
.43218 .41312 L
.43213 .4131 L
.43207 .41307 L
.43201 .41305 L
.43196 .41303 L
.4319 .413 L
.43185 .41298 L
.43179 .41296 L
.43174 .41293 L
.43168 .41291 L
.43163 .41289 L
.43157 .41286 L
.43152 .41284 L
.43147 .41281 L
.43141 .41279 L
.43136 .41277 L
.4313 .41274 L
.43125 .41272 L
.43119 .4127 L
.43114 .41267 L
Mistroke
.43109 .41265 L
.43103 .41262 L
.43098 .4126 L
.43093 .41257 L
.43087 .41255 L
.43082 .41253 L
.43077 .4125 L
.43071 .41248 L
.43066 .41245 L
.43061 .41243 L
.43055 .4124 L
.4305 .41238 L
.43045 .41235 L
.43039 .41233 L
.43034 .4123 L
.43029 .41228 L
.43024 .41225 L
.43018 .41223 L
.43013 .4122 L
.43008 .41218 L
.43003 .41215 L
.42998 .41213 L
.42992 .4121 L
.42987 .41208 L
.42982 .41205 L
.42977 .41202 L
.42972 .412 L
.42967 .41197 L
.42961 .41195 L
.42956 .41192 L
.42951 .4119 L
.42946 .41187 L
.42941 .41184 L
.42936 .41182 L
.42931 .41179 L
.42926 .41176 L
.42921 .41174 L
.42916 .41171 L
.42911 .41169 L
.42906 .41166 L
.42901 .41163 L
.42896 .41161 L
.42891 .41158 L
.42886 .41155 L
.42881 .41153 L
.42876 .4115 L
.42871 .41147 L
.42866 .41145 L
.42861 .41142 L
.42856 .41139 L
Mistroke
.42851 .41137 L
.42846 .41134 L
.42841 .41131 L
.42836 .41128 L
.42831 .41126 L
.42826 .41123 L
.42821 .4112 L
.42816 .41117 L
.42812 .41115 L
.42807 .41112 L
.42802 .41109 L
.42797 .41106 L
.42792 .41104 L
.42787 .41101 L
.42783 .41098 L
.42778 .41095 L
.42773 .41093 L
.42768 .4109 L
.42763 .41087 L
.42759 .41084 L
.42754 .41081 L
.42749 .41079 L
.42744 .41076 L
.4274 .41073 L
.42735 .4107 L
.4273 .41067 L
.42725 .41064 L
.42721 .41062 L
.42716 .41059 L
.42711 .41056 L
.42707 .41053 L
.42702 .4105 L
.42697 .41047 L
.42693 .41044 L
.42688 .41041 L
.42683 .41039 L
.42679 .41036 L
.42674 .41033 L
.42669 .4103 L
.42665 .41027 L
.4266 .41024 L
.42656 .41021 L
.42651 .41018 L
.42647 .41015 L
.42642 .41012 L
.42637 .41009 L
.42633 .41006 L
.42628 .41004 L
.42624 .41001 L
.42619 .40998 L
Mistroke
.42615 .40995 L
.4261 .40992 L
.42606 .40989 L
.42601 .40986 L
.42597 .40983 L
.42592 .4098 L
.42588 .40977 L
.42584 .40974 L
.42579 .40971 L
.42575 .40968 L
.4257 .40965 L
.42566 .40962 L
.42561 .40959 L
.42557 .40956 L
.42553 .40953 L
.42548 .4095 L
.42544 .40947 L
.4254 .40944 L
.42535 .40941 L
.42531 .40937 L
.42527 .40934 L
.42522 .40931 L
.42518 .40928 L
.42514 .40925 L
.42509 .40922 L
.42505 .40919 L
.42501 .40916 L
.42496 .40913 L
.42492 .4091 L
.42488 .40907 L
.42484 .40904 L
.42479 .409 L
.42475 .40897 L
.42471 .40894 L
.42467 .40891 L
.42463 .40888 L
.42458 .40885 L
.42454 .40882 L
.4245 .40879 L
.42446 .40875 L
.42442 .40872 L
.42437 .40869 L
.42433 .40866 L
.42429 .40863 L
.42425 .4086 L
.42421 .40856 L
.42417 .40853 L
.42413 .4085 L
.42409 .40847 L
.42404 .40844 L
Mistroke
.424 .4084 L
.42396 .40837 L
.42392 .40834 L
.42388 .40831 L
.42384 .40828 L
.4238 .40824 L
.42376 .40821 L
.42372 .40818 L
.42368 .40815 L
.42364 .40812 L
.4236 .40808 L
.42356 .40805 L
.42352 .40802 L
.42348 .40799 L
.42344 .40795 L
.4234 .40792 L
.42336 .40789 L
.42332 .40785 L
.42328 .40782 L
.42324 .40779 L
.42321 .40776 L
.42317 .40772 L
.42313 .40769 L
.42309 .40766 L
.42305 .40762 L
.42301 .40759 L
.42297 .40756 L
.42293 .40753 L
.42289 .40749 L
.42286 .40746 L
.42282 .40743 L
.42278 .40739 L
.42274 .40736 L
.4227 .40733 L
.42267 .40729 L
.42263 .40726 L
.42259 .40723 L
.42255 .40719 L
.42251 .40716 L
.42248 .40712 L
.42244 .40709 L
.4224 .40706 L
.42236 .40702 L
.42233 .40699 L
.42229 .40696 L
.42225 .40692 L
.42222 .40689 L
.42218 .40685 L
.42214 .40682 L
.4221 .40679 L
Mistroke
.42207 .40675 L
.42203 .40672 L
.42199 .40668 L
.42196 .40665 L
.42192 .40662 L
.42189 .40658 L
.42185 .40655 L
.42181 .40651 L
.42178 .40648 L
.42174 .40644 L
.4217 .40641 L
.42167 .40638 L
.42163 .40634 L
.4216 .40631 L
.42156 .40627 L
.42153 .40624 L
.42149 .4062 L
.42146 .40617 L
.42142 .40613 L
.42139 .4061 L
.42135 .40606 L
.42132 .40603 L
.42128 .40599 L
.42125 .40596 L
.42121 .40592 L
.42118 .40589 L
.42114 .40585 L
.42111 .40582 L
.42107 .40578 L
.42104 .40575 L
.421 .40571 L
.42097 .40568 L
.42093 .40564 L
.4209 .40561 L
.42087 .40557 L
.42083 .40554 L
.4208 .4055 L
.42077 .40547 L
.42073 .40543 L
.4207 .4054 L
.42066 .40536 L
.42063 .40532 L
.4206 .40529 L
.42056 .40525 L
.42053 .40522 L
.4205 .40518 L
.42046 .40515 L
.42043 .40511 L
.4204 .40508 L
.42037 .40504 L
Mistroke
.42033 .405 L
.4203 .40497 L
.42027 .40493 L
.42024 .4049 L
.4202 .40486 L
.42017 .40482 L
.42014 .40479 L
.42011 .40475 L
.42007 .40472 L
.42004 .40468 L
.42001 .40464 L
.41998 .40461 L
.41995 .40457 L
.41991 .40453 L
.41988 .4045 L
.41985 .40446 L
.41982 .40443 L
.41979 .40439 L
.41976 .40435 L
.41973 .40432 L
.41969 .40428 L
.41966 .40424 L
.41963 .40421 L
.4196 .40417 L
.41957 .40413 L
.41954 .4041 L
.41951 .40406 L
.41948 .40402 L
.41945 .40399 L
.41942 .40395 L
.41939 .40391 L
.41936 .40388 L
.41933 .40384 L
.4193 .4038 L
.41926 .40376 L
.41923 .40373 L
.4192 .40369 L
.41917 .40365 L
.41915 .40362 L
.41912 .40358 L
.41909 .40354 L
.41906 .40351 L
.41903 .40347 L
.419 .40343 L
.41897 .40339 L
.41894 .40336 L
.41891 .40332 L
.41888 .40328 L
.41885 .40324 L
.41882 .40321 L
Mistroke
.41879 .40317 L
.41876 .40313 L
.41874 .40309 L
.41871 .40306 L
.41868 .40302 L
.41865 .40298 L
.41862 .40294 L
.41859 .40291 L
.41856 .40287 L
.41854 .40283 L
.41851 .40279 L
.41848 .40276 L
.41845 .40272 L
.41842 .40268 L
.4184 .40264 L
.41837 .4026 L
.41834 .40257 L
.41831 .40253 L
.41828 .40249 L
.41826 .40245 L
.41823 .40241 L
.4182 .40238 L
.41817 .40234 L
.41815 .4023 L
.41812 .40226 L
.41809 .40222 L
.41807 .40219 L
.41804 .40215 L
.41801 .40211 L
.41799 .40207 L
.41796 .40203 L
.41793 .402 L
.41791 .40196 L
.41788 .40192 L
.41785 .40188 L
.41783 .40184 L
.4178 .4018 L
.41777 .40176 L
.41775 .40173 L
.41772 .40169 L
.4177 .40165 L
.41767 .40161 L
.41764 .40157 L
.41762 .40153 L
.41759 .40149 L
.41757 .40146 L
.41754 .40142 L
.41752 .40138 L
.41749 .40134 L
.41747 .4013 L
Mistroke
.41744 .40126 L
.41741 .40122 L
.41739 .40118 L
.41736 .40115 L
.41734 .40111 L
.41731 .40107 L
.41729 .40103 L
.41727 .40099 L
.41724 .40095 L
.41722 .40091 L
.41719 .40087 L
.41717 .40083 L
.41714 .4008 L
.41712 .40076 L
.41709 .40072 L
.41707 .40068 L
.41705 .40064 L
.41702 .4006 L
.417 .40056 L
.41697 .40052 L
.41695 .40048 L
.41693 .40044 L
.4169 .4004 L
.41688 .40036 L
.41686 .40032 L
.41683 .40029 L
.41681 .40025 L
.41678 .40021 L
.41676 .40017 L
.41674 .40013 L
.41672 .40009 L
.41669 .40005 L
.41667 .40001 L
.41665 .39997 L
.41662 .39993 L
.4166 .39989 L
.41658 .39985 L
.41656 .39981 L
.41653 .39977 L
.41651 .39973 L
.41649 .39969 L
.41647 .39965 L
.41644 .39961 L
.41642 .39957 L
.4164 .39953 L
.41638 .39949 L
.41635 .39945 L
.41633 .39941 L
.41631 .39937 L
.41629 .39933 L
Mistroke
.41627 .39929 L
.41625 .39925 L
.41622 .39921 L
.4162 .39917 L
.41618 .39913 L
.41616 .39909 L
.41614 .39905 L
.41612 .39901 L
.4161 .39897 L
.41607 .39893 L
.41605 .39889 L
.41603 .39885 L
.41601 .39881 L
.41599 .39877 L
.41597 .39873 L
.41595 .39869 L
.41593 .39865 L
.41591 .39861 L
.41589 .39857 L
.41587 .39853 L
.41585 .39849 L
.41583 .39845 L
.41581 .39841 L
.41579 .39837 L
.41577 .39833 L
.41575 .39829 L
.41573 .39825 L
.41571 .39821 L
.41569 .39817 L
.41567 .39813 L
.41565 .39809 L
.41563 .39805 L
.41561 .39801 L
.41559 .39797 L
.41557 .39793 L
.41555 .39788 L
.41553 .39784 L
.41551 .3978 L
.41549 .39776 L
.41547 .39772 L
.41545 .39768 L
.41544 .39764 L
.41542 .3976 L
.4154 .39756 L
.41538 .39752 L
.41536 .39748 L
.41534 .39744 L
.41532 .3974 L
.4153 .39736 L
.41529 .39732 L
Mistroke
.41527 .39727 L
.41525 .39723 L
.41523 .39719 L
.41521 .39715 L
.41519 .39711 L
.41518 .39707 L
.41516 .39703 L
.41514 .39699 L
.41512 .39695 L
.41511 .39691 L
.41509 .39687 L
.41507 .39682 L
.41505 .39678 L
.41503 .39674 L
.41502 .3967 L
.415 .39666 L
.41498 .39662 L
.41497 .39658 L
.41495 .39654 L
.41493 .3965 L
.41491 .39645 L
.4149 .39641 L
.41488 .39637 L
.41486 .39633 L
.41485 .39629 L
.41483 .39625 L
.41481 .39621 L
.4148 .39617 L
.41478 .39612 L
.41476 .39608 L
.41475 .39604 L
.41473 .396 L
.41471 .39596 L
.4147 .39592 L
.41468 .39588 L
.41467 .39584 L
.41465 .39579 L
.41463 .39575 L
.41462 .39571 L
.4146 .39567 L
.41459 .39563 L
.41457 .39559 L
.41456 .39555 L
.41454 .3955 L
.41452 .39546 L
.41451 .39542 L
.41449 .39538 L
.41448 .39534 L
.41446 .3953 L
.41445 .39526 L
Mistroke
.41443 .39521 L
.41442 .39517 L
.4144 .39513 L
.41439 .39509 L
.41437 .39505 L
.41436 .39501 L
.41434 .39496 L
.41433 .39492 L
.41431 .39488 L
.4143 .39484 L
.41429 .3948 L
.41427 .39476 L
.41426 .39471 L
.41424 .39467 L
.41423 .39463 L
.41421 .39459 L
.4142 .39455 L
.41419 .39451 L
.41417 .39446 L
.41416 .39442 L
.41414 .39438 L
.41413 .39434 L
.41412 .3943 L
.4141 .39425 L
.41409 .39421 L
.41408 .39417 L
.41406 .39413 L
.41405 .39409 L
.41404 .39405 L
.41402 .394 L
.41401 .39396 L
.414 .39392 L
.41398 .39388 L
.41397 .39384 L
.41396 .39379 L
.41394 .39375 L
.41393 .39371 L
.41392 .39367 L
.4139 .39363 L
.41389 .39358 L
.41388 .39354 L
.41387 .3935 L
.41385 .39346 L
.41384 .39342 L
.41383 .39337 L
.41382 .39333 L
.4138 .39329 L
.41379 .39325 L
.41378 .39321 L
.41377 .39316 L
Mistroke
.41376 .39312 L
.41374 .39308 L
.41373 .39304 L
.41372 .393 L
.41371 .39295 L
.4137 .39291 L
.41369 .39287 L
.41367 .39283 L
.41366 .39278 L
.41365 .39274 L
.41364 .3927 L
.41363 .39266 L
.41362 .39262 L
.41361 .39257 L
.41359 .39253 L
.41358 .39249 L
.41357 .39245 L
.41356 .39241 L
.41355 .39236 L
.41354 .39232 L
.41353 .39228 L
.41352 .39224 L
.41351 .39219 L
.4135 .39215 L
.41349 .39211 L
.41348 .39207 L
.41346 .39202 L
.41345 .39198 L
.41344 .39194 L
.41343 .3919 L
.41342 .39186 L
.41341 .39181 L
.4134 .39177 L
.41339 .39173 L
.41338 .39169 L
.41337 .39164 L
.41336 .3916 L
.41335 .39156 L
.41334 .39152 L
.41333 .39147 L
.41332 .39143 L
.41331 .39139 L
.4133 .39135 L
.4133 .3913 L
.41329 .39126 L
.41328 .39122 L
.41327 .39118 L
.41326 .39113 L
.41325 .39109 L
.41324 .39105 L
Mistroke
.41323 .39101 L
.41322 .39097 L
.41321 .39092 L
.4132 .39088 L
.41319 .39084 L
.41319 .3908 L
.41318 .39075 L
.41317 .39071 L
.41316 .39067 L
.41315 .39063 L
.41314 .39058 L
.41313 .39054 L
.41313 .3905 L
.41312 .39046 L
.41311 .39041 L
.4131 .39037 L
.41309 .39033 L
.41308 .39029 L
.41308 .39024 L
.41307 .3902 L
.41306 .39016 L
.41305 .39012 L
.41304 .39007 L
.41304 .39003 L
.41303 .38999 L
.41302 .38994 L
.41301 .3899 L
.41301 .38986 L
.413 .38982 L
.41299 .38977 L
.41298 .38973 L
.41298 .38969 L
.41297 .38965 L
.41296 .3896 L
.41295 .38956 L
.41295 .38952 L
.41294 .38948 L
.41293 .38943 L
.41293 .38939 L
.41292 .38935 L
.41291 .38931 L
.41291 .38926 L
.4129 .38922 L
.41289 .38918 L
.41289 .38914 L
.41288 .38909 L
.41287 .38905 L
.41287 .38901 L
.41286 .38896 L
.41285 .38892 L
Mistroke
.41285 .38888 L
.41284 .38884 L
.41284 .38879 L
.41283 .38875 L
.41282 .38871 L
.41282 .38867 L
.41281 .38862 L
.4128 .38858 L
.4128 .38854 L
.41279 .3885 L
.41279 .38845 L
.41278 .38841 L
.41278 .38837 L
.41277 .38832 L
.41276 .38828 L
.41276 .38824 L
.41275 .3882 L
.41275 .38815 L
.41274 .38811 L
.41274 .38807 L
.41273 .38803 L
.41273 .38798 L
.41272 .38794 L
.41272 .3879 L
.41271 .38786 L
.41271 .38781 L
.4127 .38777 L
.4127 .38773 L
.41269 .38768 L
.41269 .38764 L
.41268 .3876 L
.41268 .38756 L
.41267 .38751 L
.41267 .38747 L
.41267 .38743 L
.41266 .38739 L
.41266 .38734 L
.41265 .3873 L
.41265 .38726 L
.41264 .38721 L
.41264 .38717 L
.41264 .38713 L
.41263 .38709 L
.41263 .38704 L
.41262 .387 L
.41262 .38696 L
.41262 .38692 L
.41261 .38687 L
.41261 .38683 L
.4126 .38679 L
Mistroke
.4126 .38675 L
.4126 .3867 L
.41259 .38666 L
.41259 .38662 L
.41259 .38657 L
.41258 .38653 L
.41258 .38649 L
.41258 .38645 L
.41257 .3864 L
.41257 .38636 L
.41257 .38632 L
.41256 .38628 L
.41256 .38623 L
.41256 .38619 L
.41255 .38615 L
.41255 .3861 L
.41255 .38606 L
.41255 .38602 L
.41254 .38598 L
.41254 .38593 L
.41254 .38589 L
.41254 .38585 L
.41253 .38581 L
.41253 .38576 L
.41253 .38572 L
.41253 .38568 L
.41252 .38564 L
.41252 .38559 L
.41252 .38555 L
.41252 .38551 L
.41251 .38546 L
.41251 .38542 L
.41251 .38538 L
.41251 .38534 L
.41251 .38529 L
.4125 .38525 L
.4125 .38521 L
.4125 .38517 L
.4125 .38512 L
.4125 .38508 L
.4125 .38504 L
.41249 .385 L
.41249 .38495 L
.41249 .38491 L
.41249 .38487 L
.41249 .38483 L
.41249 .38478 L
.41249 .38474 L
.41248 .3847 L
.41248 .38465 L
Mistroke
.41248 .38461 L
.41248 .38457 L
.41248 .38453 L
.41248 .38448 L
.41248 .38444 L
.41248 .3844 L
.41248 .38436 L
.41248 .38431 L
.41247 .38427 L
.41247 .38423 L
.41247 .38419 L
.41247 .38414 L
.41247 .3841 L
.41247 .38406 L
.41247 .38402 L
.41247 .38397 L
.41247 .38393 L
.41247 .38389 L
.41247 .38385 L
.41247 .3838 L
.41247 .38376 L
.41247 .38372 L
.41247 .38368 L
.41247 .38363 L
.41247 .38359 L
.41247 .38355 L
.41247 .38351 L
.41247 .38346 L
.41247 .38342 L
.41247 .38338 L
.41247 .38334 L
.41247 .38329 L
.41247 .38325 L
.41247 .38321 L
.41247 .38317 L
.41247 .38312 L
.41247 .38308 L
.41247 .38304 L
.41247 .383 L
.41247 .38295 L
.41248 .38291 L
.41248 .38287 L
.41248 .38283 L
.41248 .38278 L
.41248 .38274 L
.41248 .3827 L
.41248 .38266 L
.41248 .38261 L
.41248 .38257 L
.41248 .38253 L
Mistroke
.41249 .38249 L
.41249 .38244 L
.41249 .3824 L
.41249 .38236 L
.41249 .38232 L
.41249 .38228 L
.41249 .38223 L
.41249 .38219 L
.4125 .38215 L
.4125 .38211 L
.4125 .38206 L
.4125 .38202 L
.4125 .38198 L
.4125 .38194 L
.41251 .38189 L
.41251 .38185 L
.41251 .38181 L
.41251 .38177 L
.41251 .38173 L
.41252 .38168 L
.41252 .38164 L
.41252 .3816 L
.41252 .38156 L
.41253 .38151 L
.41253 .38147 L
.41253 .38143 L
.41253 .38139 L
.41253 .38135 L
.41254 .3813 L
.41254 .38126 L
.41254 .38122 L
.41254 .38118 L
.41255 .38113 L
.41255 .38109 L
.41255 .38105 L
.41256 .38101 L
.41256 .38097 L
.41256 .38092 L
.41256 .38088 L
.41257 .38084 L
.41257 .3808 L
.41257 .38075 L
.41258 .38071 L
.41258 .38067 L
.41258 .38063 L
.41259 .38059 L
.41259 .38054 L
.41259 .3805 L
.4126 .38046 L
.4126 .38042 L
Mistroke
.4126 .38038 L
.41261 .38033 L
.41261 .38029 L
.41261 .38025 L
.41262 .38021 L
.41262 .38017 L
.41262 .38012 L
.41263 .38008 L
.41263 .38004 L
.41264 .38 L
.41264 .37996 L
.41264 .37991 L
.41265 .37987 L
.41265 .37983 L
.41266 .37979 L
.41266 .37975 L
.41266 .3797 L
.41267 .37966 L
.41267 .37962 L
.41268 .37958 L
.41268 .37954 L
.41268 .3795 L
.41269 .37945 L
.41269 .37941 L
.4127 .37937 L
.4127 .37933 L
.41271 .37929 L
.41271 .37924 L
.41272 .3792 L
.41272 .37916 L
.41273 .37912 L
.41273 .37908 L
.41273 .37904 L
.41274 .37899 L
.41274 .37895 L
.41275 .37891 L
.41275 .37887 L
.41276 .37883 L
.41276 .37879 L
.41277 .37874 L
.41277 .3787 L
.41278 .37866 L
.41278 .37862 L
.41279 .37858 L
.4128 .37854 L
.4128 .37849 L
.41281 .37845 L
.41281 .37841 L
.41282 .37837 L
.41282 .37833 L
Mistroke
.41283 .37829 L
.41283 .37824 L
.41284 .3782 L
.41284 .37816 L
.41285 .37812 L
.41286 .37808 L
.41286 .37804 L
.41287 .37799 L
.41287 .37795 L
.41288 .37791 L
.41289 .37787 L
.41289 .37783 L
.4129 .37779 L
.4129 .37775 L
.41291 .3777 L
.41292 .37766 L
.41292 .37762 L
.41293 .37758 L
.41293 .37754 L
.41294 .3775 L
.41295 .37746 L
.41295 .37741 L
.41296 .37737 L
.41297 .37733 L
.41297 .37729 L
.41298 .37725 L
.41299 .37721 L
.41299 .37717 L
.413 .37713 L
.41301 .37708 L
.41301 .37704 L
.41302 .377 L
.41303 .37696 L
.41303 .37692 L
.41304 .37688 L
.41305 .37684 L
.41305 .3768 L
.41306 .37675 L
.41307 .37671 L
.41307 .37667 L
.41308 .37663 L
.41309 .37659 L
.4131 .37655 L
.4131 .37651 L
.41311 .37647 L
.41312 .37643 L
.41312 .37638 L
.41313 .37634 L
.41314 .3763 L
.41315 .37626 L
Mistroke
.41315 .37622 L
.41316 .37618 L
.41317 .37614 L
.41318 .3761 L
.41318 .37606 L
.41319 .37601 L
.4132 .37597 L
.41321 .37593 L
.41322 .37589 L
.41322 .37585 L
.41323 .37581 L
.41324 .37577 L
.41325 .37573 L
.41325 .37569 L
.41326 .37565 L
.41327 .37561 L
.41328 .37556 L
.41329 .37552 L
.41329 .37548 L
.4133 .37544 L
.41331 .3754 L
.41332 .37536 L
.41333 .37532 L
.41334 .37528 L
.41334 .37524 L
.41335 .3752 L
.41336 .37516 L
.41337 .37512 L
.41338 .37508 L
.41339 .37504 L
.4134 .37499 L
.4134 .37495 L
.41341 .37491 L
.41342 .37487 L
.41343 .37483 L
.41344 .37479 L
.41345 .37475 L
.41346 .37471 L
.41347 .37467 L
.41347 .37463 L
.41348 .37459 L
.41349 .37455 L
.4135 .37451 L
.41351 .37447 L
.41352 .37443 L
.41353 .37439 L
.41354 .37435 L
.41355 .37431 L
.41356 .37427 L
.41357 .37422 L
Mistroke
.41357 .37418 L
.41358 .37414 L
.41359 .3741 L
.4136 .37406 L
.41361 .37402 L
.41362 .37398 L
.41363 .37394 L
.41364 .3739 L
.41365 .37386 L
.41366 .37382 L
.41367 .37378 L
.41368 .37374 L
.41369 .3737 L
.4137 .37366 L
.41371 .37362 L
.41372 .37358 L
.41373 .37354 L
.41374 .3735 L
.41375 .37346 L
.41376 .37342 L
.41377 .37338 L
.41378 .37334 L
.41379 .3733 L
.4138 .37326 L
.41381 .37322 L
.41382 .37318 L
.41383 .37314 L
.41384 .3731 L
.41385 .37306 L
.41386 .37302 L
.41387 .37298 L
.41388 .37294 L
.41389 .3729 L
.4139 .37286 L
.41391 .37282 L
.41392 .37278 L
.41393 .37274 L
.41394 .3727 L
.41395 .37266 L
.41396 .37262 L
.41397 .37258 L
.41399 .37254 L
.414 .3725 L
.41401 .37246 L
.41402 .37242 L
.41403 .37238 L
.41404 .37234 L
.41405 .3723 L
.41406 .37226 L
.41407 .37222 L
Mistroke
.41408 .37218 L
.41409 .37214 L
.41411 .3721 L
.41412 .37206 L
.41413 .37202 L
.41414 .37199 L
.41415 .37195 L
.41416 .37191 L
.41417 .37187 L
.41418 .37183 L
.41419 .37179 L
.41421 .37175 L
.41422 .37171 L
.41423 .37167 L
.41424 .37163 L
.41425 .37159 L
.41426 .37155 L
.41427 .37151 L
.41429 .37147 L
.4143 .37143 L
.41431 .37139 L
.41432 .37135 L
.41433 .37131 L
.41434 .37128 L
.41436 .37124 L
.41437 .3712 L
.41438 .37116 L
.41439 .37112 L
.4144 .37108 L
.41442 .37104 L
.41443 .371 L
.41444 .37096 L
.41445 .37092 L
.41446 .37088 L
.41448 .37084 L
.41449 .37081 L
.4145 .37077 L
.41451 .37073 L
.41452 .37069 L
.41454 .37065 L
.41455 .37061 L
.41456 .37057 L
.41457 .37053 L
.41459 .37049 L
.4146 .37045 L
.41461 .37042 L
.41462 .37038 L
.41464 .37034 L
.41465 .3703 L
.41466 .37026 L
Mistroke
.41467 .37022 L
.41469 .37018 L
.4147 .37014 L
.41471 .3701 L
.41472 .37007 L
.41474 .37003 L
.41475 .36999 L
.41476 .36995 L
.41477 .36991 L
.41479 .36987 L
.4148 .36983 L
.41481 .36979 L
.41483 .36976 L
.41484 .36972 L
.41485 .36968 L
.41487 .36964 L
.41488 .3696 L
.41489 .36956 L
.4149 .36952 L
.41492 .36949 L
.41493 .36945 L
.41494 .36941 L
.41496 .36937 L
.41497 .36933 L
.41498 .36929 L
.415 .36926 L
.41501 .36922 L
.41502 .36918 L
.41504 .36914 L
.41505 .3691 L
.41506 .36906 L
.41508 .36903 L
.41509 .36899 L
.4151 .36895 L
.41512 .36891 L
.41513 .36887 L
.41515 .36883 L
.41516 .3688 L
.41517 .36876 L
.41519 .36872 L
.4152 .36868 L
.41521 .36864 L
.41523 .3686 L
.41524 .36857 L
.41526 .36853 L
.41527 .36849 L
.41528 .36845 L
.4153 .36841 L
.41531 .36838 L
.41533 .36834 L
Mistroke
.41534 .3683 L
.41535 .36826 L
.41537 .36822 L
.41538 .36819 L
.4154 .36815 L
.41541 .36811 L
.41542 .36807 L
.41544 .36804 L
.41545 .368 L
.41547 .36796 L
.41548 .36792 L
.4155 .36788 L
.41551 .36785 L
.41552 .36781 L
.41554 .36777 L
.41555 .36773 L
.41557 .3677 L
.41558 .36766 L
.4156 .36762 L
.41561 .36758 L
.41563 .36754 L
.41564 .36751 L
.41565 .36747 L
.41567 .36743 L
.41568 .36739 L
.4157 .36736 L
.41571 .36732 L
.41573 .36728 L
.41574 .36724 L
.41576 .36721 L
.41577 .36717 L
.41579 .36713 L
.4158 .36709 L
.41582 .36706 L
.41583 .36702 L
.41585 .36698 L
.41586 .36695 L
.41588 .36691 L
.41589 .36687 L
.41591 .36683 L
.41592 .3668 L
.41594 .36676 L
.41595 .36672 L
.41597 .36668 L
.41598 .36665 L
.416 .36661 L
.41601 .36657 L
.41603 .36654 L
.41604 .3665 L
.41606 .36646 L
Mistroke
.41607 .36643 L
.41609 .36639 L
.41611 .36635 L
.41612 .36631 L
.41614 .36628 L
.41615 .36624 L
.41617 .3662 L
.41618 .36617 L
.4162 .36613 L
.41621 .36609 L
.41623 .36606 L
.41625 .36602 L
.41626 .36598 L
.41628 .36595 L
.41629 .36591 L
.41631 .36587 L
.41632 .36584 L
.41634 .3658 L
.41636 .36576 L
.41637 .36573 L
.41639 .36569 L
.4164 .36565 L
.41642 .36562 L
.41644 .36558 L
.41645 .36554 L
.41647 .36551 L
.41648 .36547 L
.4165 .36543 L
.41652 .3654 L
.41653 .36536 L
.41655 .36532 L
.41656 .36529 L
.41658 .36525 L
.4166 .36521 L
.41661 .36518 L
.41663 .36514 L
.41664 .3651 L
.41666 .36507 L
.41668 .36503 L
.41669 .365 L
.41671 .36496 L
.41673 .36492 L
.41674 .36489 L
.41676 .36485 L
.41678 .36481 L
.41679 .36478 L
.41681 .36474 L
.41683 .36471 L
.41684 .36467 L
.41686 .36463 L
Mistroke
.41687 .3646 L
.41689 .36456 L
.41691 .36453 L
.41692 .36449 L
.41694 .36445 L
.41696 .36442 L
.41697 .36438 L
.41699 .36435 L
.41701 .36431 L
.41703 .36427 L
.41704 .36424 L
.41706 .3642 L
.41708 .36417 L
.41709 .36413 L
.41711 .3641 L
.41713 .36406 L
.41714 .36402 L
.41716 .36399 L
.41718 .36395 L
.41719 .36392 L
.41721 .36388 L
.41723 .36385 L
.41725 .36381 L
.41726 .36377 L
.41728 .36374 L
.4173 .3637 L
.41731 .36367 L
.41733 .36363 L
.41735 .3636 L
.41737 .36356 L
.41738 .36353 L
.4174 .36349 L
.41742 .36346 L
.41744 .36342 L
.41745 .36338 L
.41747 .36335 L
.41749 .36331 L
.4175 .36328 L
.41752 .36324 L
.41754 .36321 L
.41756 .36317 L
.41757 .36314 L
.41759 .3631 L
.41761 .36307 L
.41763 .36303 L
.41764 .363 L
.41766 .36296 L
.41768 .36293 L
.4177 .36289 L
.41772 .36286 L
Mistroke
.41773 .36282 L
.41775 .36279 L
.41777 .36275 L
.41779 .36272 L
.4178 .36268 L
.41782 .36265 L
.41784 .36261 L
.41786 .36258 L
.41788 .36254 L
.41789 .36251 L
.41791 .36247 L
.41793 .36244 L
.41795 .3624 L
.41797 .36237 L
.41798 .36233 L
.418 .3623 L
.41802 .36226 L
.41804 .36223 L
.41806 .3622 L
.41807 .36216 L
.41809 .36213 L
.41811 .36209 L
.41813 .36206 L
.41815 .36202 L
.41816 .36199 L
.41818 .36195 L
.4182 .36192 L
.41822 .36188 L
.41824 .36185 L
.41826 .36182 L
.41827 .36178 L
.41829 .36175 L
.41831 .36171 L
.41833 .36168 L
.41835 .36164 L
.41837 .36161 L
.41838 .36158 L
.4184 .36154 L
.41842 .36151 L
.41844 .36147 L
.41846 .36144 L
.41848 .3614 L
.4185 .36137 L
.41851 .36134 L
.41853 .3613 L
.41855 .36127 L
.41857 .36123 L
.41859 .3612 L
.41861 .36117 L
.41863 .36113 L
Mistroke
.41864 .3611 L
.41866 .36106 L
.41868 .36103 L
.4187 .361 L
.41872 .36096 L
.41874 .36093 L
.41876 .3609 L
.41878 .36086 L
.4188 .36083 L
.41881 .36079 L
.41883 .36076 L
.41885 .36073 L
.41887 .36069 L
.41889 .36066 L
.41891 .36063 L
.41893 .36059 L
.41895 .36056 L
.41897 .36052 L
.41898 .36049 L
.419 .36046 L
.41902 .36042 L
.41904 .36039 L
.41906 .36036 L
.41908 .36032 L
.4191 .36029 L
.41912 .36026 L
.41914 .36022 L
.41916 .36019 L
.41918 .36016 L
.4192 .36012 L
.41921 .36009 L
.41923 .36006 L
.41925 .36002 L
.41927 .35999 L
.41929 .35996 L
.41931 .35992 L
.41933 .35989 L
.41935 .35986 L
.41937 .35982 L
.41939 .35979 L
.41941 .35976 L
.41943 .35973 L
.41945 .35969 L
.41947 .35966 L
.41949 .35963 L
.41951 .35959 L
.41953 .35956 L
.41955 .35953 L
.41956 .3595 L
.41958 .35946 L
Mistroke
.4196 .35943 L
.41962 .3594 L
.41964 .35936 L
.41966 .35933 L
.41968 .3593 L
.4197 .35927 L
.41972 .35923 L
.41974 .3592 L
.41976 .35917 L
.41978 .35914 L
.4198 .3591 L
.41982 .35907 L
.41984 .35904 L
.41986 .359 L
.41988 .35897 L
.4199 .35894 L
.41992 .35891 L
.41994 .35887 L
.41996 .35884 L
.41998 .35881 L
.42 .35878 L
.42002 .35875 L
.42004 .35871 L
.42006 .35868 L
.42008 .35865 L
.4201 .35862 L
.42012 .35858 L
.42014 .35855 L
.42016 .35852 L
.42018 .35849 L
.4202 .35846 L
.42022 .35842 L
.42024 .35839 L
.42026 .35836 L
.42028 .35833 L
.4203 .35829 L
.42032 .35826 L
.42034 .35823 L
.42036 .3582 L
.42038 .35817 L
.4204 .35814 L
.42042 .3581 L
.42044 .35807 L
.42046 .35804 L
.42048 .35801 L
.4205 .35798 L
.42052 .35794 L
.42055 .35791 L
.42057 .35788 L
.42059 .35785 L
Mistroke
.42061 .35782 L
.42063 .35779 L
.42065 .35775 L
.42067 .35772 L
.42069 .35769 L
.42071 .35766 L
.42073 .35763 L
.42075 .3576 L
.42077 .35756 L
.42079 .35753 L
.42081 .3575 L
.42083 .35747 L
.42085 .35744 L
.42087 .35741 L
.42089 .35738 L
.42091 .35734 L
.42094 .35731 L
.42096 .35728 L
.42098 .35725 L
.421 .35722 L
.42102 .35719 L
.42104 .35716 L
.42106 .35713 L
.42108 .35709 L
.4211 .35706 L
.42112 .35703 L
.42114 .357 L
.42116 .35697 L
.42118 .35694 L
.42121 .35691 L
.42123 .35688 L
.42125 .35685 L
.42127 .35682 L
.42129 .35678 L
.42131 .35675 L
.42133 .35672 L
.42135 .35669 L
.42137 .35666 L
.42139 .35663 L
.42142 .3566 L
.42144 .35657 L
.42146 .35654 L
.42148 .35651 L
.4215 .35648 L
.42152 .35645 L
.42154 .35642 L
.42156 .35638 L
.42158 .35635 L
.4216 .35632 L
.42163 .35629 L
Mistroke
.42165 .35626 L
.42167 .35623 L
.42169 .3562 L
.42171 .35617 L
.42173 .35614 L
.42175 .35611 L
.42177 .35608 L
.4218 .35605 L
.42182 .35602 L
.42184 .35599 L
.42186 .35596 L
.42188 .35593 L
.4219 .3559 L
.42192 .35587 L
.42194 .35584 L
.42197 .35581 L
.42199 .35578 L
.42201 .35575 L
.42203 .35572 L
.42205 .35569 L
.42207 .35566 L
.42209 .35563 L
.42212 .3556 L
.42214 .35557 L
.42216 .35554 L
.42218 .35551 L
.4222 .35548 L
.42222 .35545 L
.42224 .35542 L
.42227 .35539 L
.42229 .35536 L
.42231 .35533 L
.42233 .3553 L
.42235 .35527 L
.42237 .35524 L
.4224 .35521 L
.42242 .35518 L
.42244 .35515 L
.42246 .35512 L
.42248 .35509 L
.4225 .35506 L
.42253 .35503 L
.42255 .355 L
.42257 .35497 L
.42259 .35494 L
.42261 .35491 L
.42263 .35488 L
.42266 .35485 L
.42268 .35483 L
.4227 .3548 L
Mistroke
.42272 .35477 L
.42274 .35474 L
.42276 .35471 L
.42279 .35468 L
.42281 .35465 L
.42283 .35462 L
.42285 .35459 L
.42287 .35456 L
.4229 .35453 L
.42292 .3545 L
.42294 .35447 L
.42296 .35445 L
.42298 .35442 L
.423 .35439 L
.42303 .35436 L
.42305 .35433 L
.42307 .3543 L
.42309 .35427 L
.42311 .35424 L
.42314 .35421 L
.42316 .35419 L
.42318 .35416 L
.4232 .35413 L
.42322 .3541 L
.42325 .35407 L
.42327 .35404 L
.42329 .35401 L
.42331 .35398 L
.42334 .35396 L
.42336 .35393 L
.42338 .3539 L
.4234 .35387 L
.42342 .35384 L
.42345 .35381 L
.42347 .35378 L
.42349 .35376 L
.42351 .35373 L
.42353 .3537 L
.42356 .35367 L
.42358 .35364 L
.4236 .35361 L
.42362 .35358 L
.42365 .35356 L
.42367 .35353 L
.42369 .3535 L
.42371 .35347 L
.42373 .35344 L
.42376 .35342 L
.42378 .35339 L
.4238 .35336 L
Mistroke
.42382 .35333 L
.42385 .3533 L
.42387 .35327 L
.42389 .35325 L
.42391 .35322 L
.42394 .35319 L
.42396 .35316 L
.42398 .35313 L
.424 .35311 L
.42402 .35308 L
.42405 .35305 L
.42407 .35302 L
.42409 .353 L
.42411 .35297 L
.42414 .35294 L
.42416 .35291 L
.42418 .35288 L
.4242 .35286 L
.42423 .35283 L
.42425 .3528 L
.42427 .35277 L
.42429 .35275 L
.42432 .35272 L
.42434 .35269 L
.42436 .35266 L
.42438 .35264 L
.42441 .35261 L
.42443 .35258 L
.42445 .35255 L
.42447 .35253 L
.4245 .3525 L
.42452 .35247 L
.42454 .35244 L
.42456 .35242 L
.42459 .35239 L
.42461 .35236 L
.42463 .35233 L
.42466 .35231 L
.42468 .35228 L
.4247 .35225 L
.42472 .35223 L
.42475 .3522 L
.42477 .35217 L
.42479 .35214 L
.42481 .35212 L
.42484 .35209 L
.42486 .35206 L
.42488 .35204 L
.42491 .35201 L
.42493 .35198 L
Mistroke
.42495 .35196 L
.42497 .35193 L
.425 .3519 L
.42502 .35187 L
.42504 .35185 L
.42506 .35182 L
.42509 .35179 L
.42511 .35177 L
.42513 .35174 L
.42516 .35171 L
.42518 .35169 L
.4252 .35166 L
.42522 .35163 L
.42525 .35161 L
.42527 .35158 L
.42529 .35155 L
.42532 .35153 L
.42534 .3515 L
.42536 .35148 L
.42538 .35145 L
.42541 .35142 L
.42543 .3514 L
.42545 .35137 L
.42548 .35134 L
.4255 .35132 L
.42552 .35129 L
.42555 .35126 L
.42557 .35124 L
.42559 .35121 L
.42561 .35119 L
.42564 .35116 L
.42566 .35113 L
.42568 .35111 L
.42571 .35108 L
.42573 .35105 L
.42575 .35103 L
.42578 .351 L
.4258 .35098 L
.42582 .35095 L
.42584 .35092 L
.42587 .3509 L
.42589 .35087 L
.42591 .35085 L
.42594 .35082 L
.42596 .3508 L
.42598 .35077 L
.42601 .35074 L
.42603 .35072 L
.42605 .35069 L
.42608 .35067 L
Mistroke
.4261 .35064 L
.42612 .35062 L
.42614 .35059 L
.42617 .35056 L
.42619 .35054 L
.42621 .35051 L
.42624 .35049 L
.42626 .35046 L
.42628 .35044 L
.42631 .35041 L
.42633 .35039 L
.42635 .35036 L
.42638 .35033 L
.4264 .35031 L
.42642 .35028 L
.42645 .35026 L
.42647 .35023 L
.42649 .35021 L
.42652 .35018 L
.42654 .35016 L
.42656 .35013 L
.42659 .35011 L
.42661 .35008 L
.42663 .35006 L
.42666 .35003 L
.42668 .35001 L
.4267 .34998 L
.42673 .34996 L
.42675 .34993 L
.42677 .34991 L
.42679 .34988 L
.42682 .34986 L
.42684 .34983 L
.42686 .34981 L
.42689 .34978 L
.42691 .34976 L
.42693 .34973 L
.42696 .34971 L
.42698 .34968 L
.427 .34966 L
.42703 .34963 L
.42705 .34961 L
.42708 .34958 L
.4271 .34956 L
.42712 .34953 L
.42715 .34951 L
.42717 .34949 L
.42719 .34946 L
.42722 .34944 L
.42724 .34941 L
Mistroke
.42726 .34939 L
.42729 .34936 L
.42731 .34934 L
.42733 .34931 L
.42736 .34929 L
.42738 .34927 L
.4274 .34924 L
.42743 .34922 L
.42745 .34919 L
.42747 .34917 L
.4275 .34914 L
.42752 .34912 L
.42754 .3491 L
.42757 .34907 L
.42759 .34905 L
.42761 .34902 L
.42764 .349 L
.42766 .34898 L
.42768 .34895 L
.42771 .34893 L
.42773 .3489 L
.42775 .34888 L
.42778 .34886 L
.4278 .34883 L
.42783 .34881 L
.42785 .34878 L
.42787 .34876 L
.4279 .34874 L
.42792 .34871 L
.42794 .34869 L
.42797 .34866 L
.42799 .34864 L
.42801 .34862 L
.42804 .34859 L
.42806 .34857 L
.42808 .34855 L
.42811 .34852 L
.42813 .3485 L
.42816 .34848 L
.42818 .34845 L
.4282 .34843 L
.42823 .34841 L
.42825 .34838 L
.42827 .34836 L
.4283 .34834 L
.42832 .34831 L
.42834 .34829 L
.42837 .34827 L
.42839 .34824 L
.42841 .34822 L
Mistroke
.42844 .3482 L
.42846 .34817 L
.42849 .34815 L
.42851 .34813 L
.42853 .3481 L
.42856 .34808 L
.42858 .34806 L
.4286 .34803 L
.42863 .34801 L
.42865 .34799 L
.42868 .34796 L
.4287 .34794 L
.42872 .34792 L
.42875 .3479 L
.42877 .34787 L
.42879 .34785 L
.42882 .34783 L
.42884 .3478 L
.42886 .34778 L
.42889 .34776 L
.42891 .34774 L
.42894 .34771 L
.42896 .34769 L
.42898 .34767 L
.42901 .34765 L
.42903 .34762 L
.42905 .3476 L
.42908 .34758 L
.4291 .34755 L
.42913 .34753 L
.42915 .34751 L
.42917 .34749 L
.4292 .34746 L
.42922 .34744 L
.42924 .34742 L
.42927 .3474 L
.42929 .34738 L
.42932 .34735 L
.42934 .34733 L
.42936 .34731 L
.42939 .34729 L
.42941 .34726 L
.42943 .34724 L
.42946 .34722 L
.42948 .3472 L
.4295 .34718 L
.42953 .34715 L
.42955 .34713 L
.42958 .34711 L
.4296 .34709 L
Mistroke
.42962 .34706 L
.42965 .34704 L
.42967 .34702 L
.4297 .347 L
.42972 .34698 L
.42974 .34696 L
.42977 .34693 L
.42979 .34691 L
.42981 .34689 L
.42984 .34687 L
.42986 .34685 L
.42989 .34682 L
.42991 .3468 L
.42993 .34678 L
.42996 .34676 L
.42998 .34674 L
.43 .34672 L
.43003 .34669 L
.43005 .34667 L
.43008 .34665 L
.4301 .34663 L
.43012 .34661 L
.43015 .34659 L
.43017 .34657 L
.43019 .34654 L
.43022 .34652 L
.43024 .3465 L
.43027 .34648 L
.43029 .34646 L
.43031 .34644 L
.43034 .34642 L
.43036 .34639 L
.43039 .34637 L
.43041 .34635 L
.43043 .34633 L
.43046 .34631 L
.43048 .34629 L
.4305 .34627 L
.43053 .34625 L
.43055 .34623 L
.43058 .3462 L
.4306 .34618 L
.43062 .34616 L
.43065 .34614 L
.43067 .34612 L
.4307 .3461 L
.43072 .34608 L
.43074 .34606 L
.43077 .34604 L
.43079 .34602 L
Mistroke
.43081 .346 L
.43084 .34597 L
.43086 .34595 L
.43089 .34593 L
.43091 .34591 L
.43093 .34589 L
.43096 .34587 L
.43098 .34585 L
.431 .34583 L
.43103 .34581 L
.43105 .34579 L
.43108 .34577 L
.4311 .34575 L
.43112 .34573 L
.43115 .34571 L
.43117 .34569 L
.4312 .34567 L
.43122 .34565 L
.43124 .34563 L
.43127 .3456 L
.43129 .34558 L
.43131 .34556 L
.43134 .34554 L
.43136 .34552 L
.43139 .3455 L
.43141 .34548 L
.43143 .34546 L
.43146 .34544 L
.43148 .34542 L
.43151 .3454 L
.43153 .34538 L
.43155 .34536 L
.43158 .34534 L
.4316 .34532 L
.43163 .3453 L
.43165 .34528 L
.43167 .34526 L
.4317 .34524 L
.43172 .34522 L
.43174 .3452 L
.43177 .34518 L
.43179 .34516 L
.43182 .34514 L
.43184 .34512 L
.43186 .3451 L
.43189 .34508 L
.43191 .34507 L
.43194 .34505 L
.43196 .34503 L
.43198 .34501 L
Mistroke
.43201 .34499 L
.43203 .34497 L
.43205 .34495 L
.43208 .34493 L
.4321 .34491 L
.43213 .34489 L
.43215 .34487 L
.43217 .34485 L
.4322 .34483 L
.43222 .34481 L
.43225 .34479 L
.43227 .34477 L
.43229 .34475 L
.43232 .34473 L
.43234 .34472 L
.43236 .3447 L
.43239 .34468 L
.43241 .34466 L
.43244 .34464 L
.43246 .34462 L
.43248 .3446 L
.43251 .34458 L
.43253 .34456 L
.43255 .34454 L
.43258 .34452 L
.4326 .34451 L
.43263 .34449 L
.43265 .34447 L
.43267 .34445 L
.4327 .34443 L
.43272 .34441 L
.43275 .34439 L
.43277 .34437 L
.43279 .34435 L
.43282 .34434 L
.43284 .34432 L
.43286 .3443 L
.43289 .34428 L
.43291 .34426 L
.43294 .34424 L
.43296 .34422 L
.43298 .3442 L
.43301 .34419 L
.43303 .34417 L
.43305 .34415 L
.43308 .34413 L
.4331 .34411 L
.43313 .34409 L
.43315 .34408 L
.43317 .34406 L
Mistroke
.4332 .34404 L
.43322 .34402 L
.43325 .344 L
.43327 .34398 L
.43329 .34397 L
.43332 .34395 L
.43334 .34393 L
.43336 .34391 L
.43339 .34389 L
.43341 .34387 L
.43344 .34386 L
.43346 .34384 L
.43348 .34382 L
.43351 .3438 L
.43353 .34378 L
.43355 .34377 L
.43358 .34375 L
.4336 .34373 L
.43363 .34371 L
.43365 .34369 L
.43367 .34368 L
.4337 .34366 L
.43372 .34364 L
.43374 .34362 L
.43377 .3436 L
.43379 .34359 L
.43382 .34357 L
.43384 .34355 L
.43386 .34353 L
.43389 .34352 L
.43391 .3435 L
.43393 .34348 L
.43396 .34346 L
.43398 .34345 L
.43401 .34343 L
.43403 .34341 L
.43405 .34339 L
.43408 .34338 L
.4341 .34336 L
.43412 .34334 L
.43415 .34332 L
.43417 .34331 L
.43419 .34329 L
.43422 .34327 L
.43424 .34325 L
.43427 .34324 L
.43429 .34322 L
.43431 .3432 L
.43434 .34318 L
.43436 .34317 L
Mistroke
.43438 .34315 L
.43441 .34313 L
.43443 .34312 L
.43446 .3431 L
.43448 .34308 L
.4345 .34306 L
.43453 .34305 L
.43455 .34303 L
.43457 .34301 L
.4346 .343 L
.43462 .34298 L
.43464 .34296 L
.43467 .34295 L
.43469 .34293 L
.43472 .34291 L
.43474 .34289 L
.43476 .34288 L
.43479 .34286 L
.43481 .34284 L
.43483 .34283 L
.43486 .34281 L
.43488 .34279 L
.4349 .34278 L
.43493 .34276 L
.43495 .34274 L
.43498 .34273 L
.435 .34271 L
.43502 .34269 L
.43505 .34268 L
.43507 .34266 L
.43509 .34264 L
.43512 .34263 L
.43514 .34261 L
.43516 .3426 L
.43519 .34258 L
.43521 .34256 L
.43523 .34255 L
.43526 .34253 L
.43528 .34251 L
.4353 .3425 L
.43533 .34248 L
.43535 .34247 L
.43538 .34245 L
.4354 .34243 L
.43542 .34242 L
.43545 .3424 L
.43547 .34238 L
.43549 .34237 L
.43552 .34235 L
.43554 .34234 L
Mistroke
.43556 .34232 L
.43559 .3423 L
.43561 .34229 L
.43563 .34227 L
.43566 .34226 L
.43568 .34224 L
.4357 .34222 L
.43573 .34221 L
.43575 .34219 L
.43577 .34218 L
.4358 .34216 L
.43582 .34215 L
.43585 .34213 L
.43587 .34211 L
.43589 .3421 L
.43592 .34208 L
.43594 .34207 L
.43596 .34205 L
.43599 .34204 L
.43601 .34202 L
.43603 .342 L
.43606 .34199 L
.43608 .34197 L
.4361 .34196 L
.43613 .34194 L
.43615 .34193 L
.43617 .34191 L
.4362 .3419 L
.43622 .34188 L
.43624 .34187 L
.43627 .34185 L
.43629 .34184 L
.43631 .34182 L
.43634 .3418 L
.43636 .34179 L
.43638 .34177 L
.43641 .34176 L
.43643 .34174 L
.43645 .34173 L
.43648 .34171 L
.4365 .3417 L
.43652 .34168 L
.43655 .34167 L
.43657 .34165 L
.43659 .34164 L
.43662 .34162 L
.43664 .34161 L
.43666 .34159 L
.43669 .34158 L
.43671 .34156 L
Mistroke
.43673 .34155 L
.43676 .34153 L
.43678 .34152 L
.4368 .3415 L
.43683 .34149 L
.43685 .34147 L
.43687 .34146 L
.4369 .34145 L
.43692 .34143 L
.43694 .34142 L
.43697 .3414 L
.43699 .34139 L
.43701 .34137 L
.43704 .34136 L
.43706 .34134 L
.43708 .34133 L
.4371 .34131 L
.43713 .3413 L
.43715 .34129 L
.43717 .34127 L
.4372 .34126 L
.43722 .34124 L
.43724 .34123 L
.43727 .34121 L
.43729 .3412 L
.43731 .34118 L
.43734 .34117 L
.43736 .34116 L
.43738 .34114 L
.43741 .34113 L
.43743 .34111 L
.43745 .3411 L
.43747 .34109 L
.4375 .34107 L
.43752 .34106 L
.43754 .34104 L
.43757 .34103 L
.43759 .34101 L
.43761 .341 L
.43764 .34099 L
.43766 .34097 L
.43768 .34096 L
.43771 .34095 L
.43773 .34093 L
.43775 .34092 L
.43777 .3409 L
.4378 .34089 L
.43782 .34088 L
.43784 .34086 L
.43787 .34085 L
Mistroke
.43789 .34083 L
.43791 .34082 L
.43794 .34081 L
.43796 .34079 L
.43798 .34078 L
.438 .34077 L
.43803 .34075 L
.43805 .34074 L
.43807 .34073 L
.4381 .34071 L
.43812 .3407 L
.43814 .34069 L
.43817 .34067 L
.43819 .34066 L
.43821 .34064 L
.43823 .34063 L
.43826 .34062 L
.43828 .3406 L
.4383 .34059 L
.43833 .34058 L
.43835 .34056 L
.43837 .34055 L
.43839 .34054 L
.43842 .34053 L
.43844 .34051 L
.43846 .3405 L
.43849 .34049 L
.43851 .34047 L
.43853 .34046 L
.43855 .34045 L
.43858 .34043 L
.4386 .34042 L
.43862 .34041 L
.43864 .34039 L
.43867 .34038 L
.43869 .34037 L
.43871 .34036 L
.43874 .34034 L
.43876 .34033 L
.43878 .34032 L
.4388 .3403 L
.43883 .34029 L
.43885 .34028 L
.43887 .34027 L
.4389 .34025 L
.43892 .34024 L
.43894 .34023 L
.43896 .34021 L
.43899 .3402 L
.43901 .34019 L
Mistroke
.43903 .34018 L
.43905 .34016 L
.43908 .34015 L
.4391 .34014 L
.43912 .34013 L
.43914 .34011 L
.43917 .3401 L
.43919 .34009 L
.43921 .34008 L
.43923 .34006 L
.43926 .34005 L
.43928 .34004 L
.4393 .34003 L
.43933 .34001 L
.43935 .34 L
.43937 .33999 L
.43939 .33998 L
.43942 .33997 L
.43944 .33995 L
.43946 .33994 L
.43948 .33993 L
.43951 .33992 L
.43953 .33991 L
.43955 .33989 L
.43957 .33988 L
.4396 .33987 L
.43962 .33986 L
.43964 .33984 L
.43966 .33983 L
.43969 .33982 L
.43971 .33981 L
.43973 .3398 L
.43975 .33978 L
.43978 .33977 L
.4398 .33976 L
.43982 .33975 L
.43984 .33974 L
.43986 .33973 L
.43989 .33971 L
.43991 .3397 L
.43993 .33969 L
.43995 .33968 L
.43998 .33967 L
.44 .33966 L
.44002 .33964 L
.44004 .33963 L
.44007 .33962 L
.44009 .33961 L
.44011 .3396 L
.44013 .33959 L
Mistroke
.44016 .33957 L
.44018 .33956 L
.4402 .33955 L
.44022 .33954 L
.44024 .33953 L
.44027 .33952 L
.44029 .33951 L
.44031 .33949 L
.44033 .33948 L
.44036 .33947 L
.44038 .33946 L
.4404 .33945 L
.44042 .33944 L
.44044 .33943 L
.44047 .33942 L
.44049 .3394 L
.44051 .33939 L
.44053 .33938 L
.44056 .33937 L
.44058 .33936 L
.4406 .33935 L
.44062 .33934 L
.44064 .33933 L
.44067 .33932 L
.44069 .3393 L
.44071 .33929 L
.44073 .33928 L
.44075 .33927 L
.44078 .33926 L
.4408 .33925 L
.44082 .33924 L
.44084 .33923 L
.44086 .33922 L
.44089 .33921 L
.44091 .3392 L
.44093 .33918 L
.44095 .33917 L
.44097 .33916 L
.441 .33915 L
.44102 .33914 L
.44104 .33913 L
.44106 .33912 L
.44108 .33911 L
.44111 .3391 L
.44113 .33909 L
.44115 .33908 L
.44117 .33907 L
.44119 .33906 L
.44122 .33905 L
.44124 .33904 L
Mistroke
.44126 .33903 L
.44128 .33902 L
.4413 .33901 L
.44133 .33899 L
.44135 .33898 L
.44137 .33897 L
.44139 .33896 L
.44141 .33895 L
.44143 .33894 L
.44146 .33893 L
.44148 .33892 L
.4415 .33891 L
.44152 .3389 L
.44154 .33889 L
.44157 .33888 L
.44159 .33887 L
.44161 .33886 L
.44163 .33885 L
.44165 .33884 L
.44167 .33883 L
.4417 .33882 L
.44172 .33881 L
.44174 .3388 L
.44176 .33879 L
.44178 .33878 L
.4418 .33877 L
.44183 .33876 L
.44185 .33875 L
.44187 .33874 L
.44189 .33873 L
.44191 .33872 L
.44193 .33871 L
.44196 .3387 L
.44198 .33869 L
.442 .33868 L
.44202 .33867 L
.44204 .33866 L
.44206 .33865 L
.44209 .33864 L
.44211 .33864 L
.44213 .33863 L
.44215 .33862 L
.44217 .33861 L
.44219 .3386 L
.44221 .33859 L
.44224 .33858 L
.44226 .33857 L
.44228 .33856 L
.4423 .33855 L
.44232 .33854 L
Mistroke
.44234 .33853 L
.44236 .33852 L
.44239 .33851 L
.44241 .3385 L
.44243 .33849 L
.44245 .33848 L
.44247 .33847 L
.44249 .33847 L
.44251 .33846 L
.44254 .33845 L
.44256 .33844 L
.44258 .33843 L
.4426 .33842 L
.44262 .33841 L
.44264 .3384 L
.44266 .33839 L
.44268 .33838 L
.44271 .33837 L
.44273 .33836 L
.44275 .33836 L
.44277 .33835 L
.44279 .33834 L
.44281 .33833 L
.44283 .33832 L
.44285 .33831 L
.44288 .3383 L
.4429 .33829 L
.44292 .33828 L
.44294 .33828 L
.44296 .33827 L
.44298 .33826 L
.443 .33825 L
.44302 .33824 L
.44305 .33823 L
.44307 .33822 L
.44309 .33821 L
.44311 .33821 L
.44313 .3382 L
.44315 .33819 L
.44317 .33818 L
.44319 .33817 L
.44321 .33816 L
.44323 .33815 L
.44326 .33815 L
.44328 .33814 L
.4433 .33813 L
.44332 .33812 L
.44334 .33811 L
.44336 .3381 L
.44338 .33809 L
Mistroke
.4434 .33809 L
.44342 .33808 L
.44344 .33807 L
.44347 .33806 L
.44349 .33805 L
.44351 .33804 L
.44353 .33804 L
.44355 .33803 L
.44357 .33802 L
.44359 .33801 L
.44361 .338 L
.44363 .338 L
.44365 .33799 L
.44367 .33798 L
.44369 .33797 L
.44372 .33796 L
.44374 .33796 L
.44376 .33795 L
.44378 .33794 L
.4438 .33793 L
.44382 .33792 L
.44384 .33792 L
.44386 .33791 L
.44388 .3379 L
.4439 .33789 L
.44392 .33788 L
.44394 .33788 L
.44396 .33787 L
.44399 .33786 L
.44401 .33785 L
.44403 .33784 L
.44405 .33784 L
.44407 .33783 L
.44409 .33782 L
.44411 .33781 L
.44413 .33781 L
.44415 .3378 L
.44417 .33779 L
.44419 .33778 L
.44421 .33778 L
.44423 .33777 L
.44425 .33776 L
.44427 .33775 L
.44429 .33775 L
.44431 .33774 L
.44433 .33773 L
.44436 .33772 L
.44438 .33772 L
.4444 .33771 L
.44442 .3377 L
Mistroke
.44444 .33769 L
.44446 .33769 L
.44448 .33768 L
.4445 .33767 L
.44452 .33766 L
.44454 .33766 L
.44456 .33765 L
.44458 .33764 L
.4446 .33763 L
.44462 .33763 L
.44464 .33762 L
.44466 .33761 L
.44468 .33761 L
.4447 .3376 L
.44472 .33759 L
.44474 .33758 L
.44476 .33758 L
.44478 .33757 L
.4448 .33756 L
.44482 .33756 L
.44484 .33755 L
.44486 .33754 L
.44488 .33754 L
.4449 .33753 L
.44492 .33752 L
.44494 .33751 L
.44496 .33751 L
.44498 .3375 L
.445 .33749 L
.44502 .33749 L
.44504 .33748 L
.44506 .33747 L
.44508 .33747 L
.44511 .33746 L
.44513 .33745 L
.44515 .33745 L
.44517 .33744 L
.44519 .33743 L
.44521 .33743 L
.44523 .33742 L
.44525 .33741 L
.44527 .33741 L
.44529 .3374 L
.44531 .33739 L
.44533 .33739 L
.44534 .33738 L
.44536 .33737 L
.44538 .33737 L
.4454 .33736 L
.44542 .33735 L
Mistroke
.44544 .33735 L
.44546 .33734 L
.44548 .33734 L
.4455 .33733 L
.44552 .33732 L
.44554 .33732 L
.44556 .33731 L
.44558 .3373 L
.4456 .3373 L
.44562 .33729 L
.44564 .33728 L
.44566 .33728 L
.44568 .33727 L
.4457 .33727 L
.44572 .33726 L
.44574 .33725 L
.44576 .33725 L
.44578 .33724 L
.4458 .33724 L
.44582 .33723 L
.44584 .33722 L
.44586 .33722 L
.44588 .33721 L
.4459 .33721 L
.44592 .3372 L
.44594 .33719 L
.44596 .33719 L
.44598 .33718 L
.446 .33718 L
.44602 .33717 L
.44604 .33716 L
.44606 .33716 L
.44607 .33715 L
.44609 .33715 L
.44611 .33714 L
.44613 .33714 L
.44615 .33713 L
.44617 .33712 L
.44619 .33712 L
.44621 .33711 L
.44623 .33711 L
.44625 .3371 L
.44627 .3371 L
.44629 .33709 L
.44631 .33708 L
.44633 .33708 L
.44635 .33707 L
.44637 .33707 L
.44639 .33706 L
.4464 .33706 L
Mistroke
.44642 .33705 L
.44644 .33705 L
.44646 .33704 L
.44648 .33703 L
.4465 .33703 L
.44652 .33702 L
.44654 .33702 L
.44656 .33701 L
.44658 .33701 L
.4466 .337 L
.44662 .337 L
.44664 .33699 L
.44665 .33699 L
.44667 .33698 L
.44669 .33698 L
.44671 .33697 L
.44673 .33697 L
.44675 .33696 L
.44677 .33695 L
.44679 .33695 L
.44681 .33694 L
.44683 .33694 L
.44685 .33693 L
.44686 .33693 L
.44688 .33692 L
.4469 .33692 L
.44692 .33691 L
.44694 .33691 L
.44696 .3369 L
.44698 .3369 L
.447 .33689 L
.44702 .33689 L
.44703 .33688 L
.44705 .33688 L
.44707 .33687 L
.44709 .33687 L
.44711 .33687 L
.44713 .33686 L
.44715 .33686 L
.44717 .33685 L
.44719 .33685 L
.4472 .33684 L
.44722 .33684 L
.44724 .33683 L
.44726 .33683 L
.44728 .33682 L
.4473 .33682 L
.44732 .33681 L
.44734 .33681 L
.44735 .3368 L
Mistroke
.44737 .3368 L
.44739 .33679 L
.44741 .33679 L
.44743 .33679 L
.44745 .33678 L
.44747 .33678 L
.44749 .33677 L
.4475 .33677 L
.44752 .33676 L
.44754 .33676 L
.44756 .33675 L
.44758 .33675 L
.4476 .33675 L
.44762 .33674 L
.44763 .33674 L
.44765 .33673 L
.44767 .33673 L
.44769 .33672 L
.44771 .33672 L
.44773 .33672 L
.44774 .33671 L
.44776 .33671 L
.44778 .3367 L
.4478 .3367 L
.44782 .33669 L
.44784 .33669 L
.44785 .33669 L
.44787 .33668 L
.44789 .33668 L
.44791 .33667 L
.44793 .33667 L
.44795 .33667 L
.44796 .33666 L
.44798 .33666 L
.448 .33665 L
.44802 .33665 L
.44804 .33665 L
.44806 .33664 L
.44807 .33664 L
.44809 .33663 L
.44811 .33663 L
.44813 .33663 L
.44815 .33662 L
.44817 .33662 L
.44818 .33661 L
.4482 .33661 L
.44822 .33661 L
.44824 .3366 L
.44826 .3366 L
.44827 .3366 L
Mistroke
.44829 .33659 L
.44831 .33659 L
.44833 .33658 L
.44835 .33658 L
.44836 .33658 L
.44838 .33657 L
.4484 .33657 L
.44842 .33657 L
.44844 .33656 L
.44845 .33656 L
.44847 .33656 L
.44849 .33655 L
.44851 .33655 L
.44853 .33655 L
.44854 .33654 L
.44856 .33654 L
.44858 .33654 L
.4486 .33653 L
.44862 .33653 L
.44863 .33652 L
.44865 .33652 L
.44867 .33652 L
.44869 .33651 L
.4487 .33651 L
.44872 .33651 L
.44874 .3365 L
.44876 .3365 L
.44877 .3365 L
.44879 .3365 L
.44881 .33649 L
.44883 .33649 L
.44885 .33649 L
.44886 .33648 L
.44888 .33648 L
.4489 .33648 L
.44892 .33647 L
.44893 .33647 L
.44895 .33647 L
.44897 .33646 L
.44899 .33646 L
.449 .33646 L
.44902 .33645 L
.44904 .33645 L
.44906 .33645 L
.44907 .33645 L
.44909 .33644 L
.44911 .33644 L
.44913 .33644 L
.44914 .33643 L
.44916 .33643 L
Mistroke
.44918 .33643 L
.4492 .33643 L
.44921 .33642 L
.44923 .33642 L
.44925 .33642 L
.44927 .33641 L
.44928 .33641 L
.4493 .33641 L
.44932 .33641 L
.44934 .3364 L
.44935 .3364 L
.44937 .3364 L
.44939 .33639 L
.4494 .33639 L
.44942 .33639 L
.44944 .33639 L
.44946 .33638 L
.44947 .33638 L
.44949 .33638 L
.44951 .33638 L
.44952 .33637 L
.44954 .33637 L
.44956 .33637 L
.44958 .33637 L
.44959 .33636 L
.44961 .33636 L
.44963 .33636 L
.44964 .33636 L
.44966 .33635 L
.44968 .33635 L
.4497 .33635 L
.44971 .33635 L
.44973 .33634 L
.44975 .33634 L
.44976 .33634 L
.44978 .33634 L
.4498 .33634 L
.44981 .33633 L
.44983 .33633 L
.44985 .33633 L
.44986 .33633 L
.44988 .33632 L
.4499 .33632 L
.44992 .33632 L
.44993 .33632 L
.44995 .33632 L
.44997 .33631 L
.44998 .33631 L
.45 .33631 L
.45002 .33631 L
Mistroke
.45003 .3363 L
.45005 .3363 L
.45007 .3363 L
.45008 .3363 L
.4501 .3363 L
.45012 .33629 L
.45013 .33629 L
.45015 .33629 L
.45017 .33629 L
.45018 .33629 L
.4502 .33629 L
.45022 .33628 L
.45023 .33628 L
.45025 .33628 L
.45027 .33628 L
.45028 .33628 L
.4503 .33627 L
.45032 .33627 L
.45033 .33627 L
.45035 .33627 L
.45037 .33627 L
.45038 .33627 L
.4504 .33626 L
.45041 .33626 L
.45043 .33626 L
.45045 .33626 L
.45046 .33626 L
.45048 .33626 L
.4505 .33625 L
.45051 .33625 L
.45053 .33625 L
.45055 .33625 L
.45056 .33625 L
.45058 .33625 L
.45059 .33624 L
.45061 .33624 L
.45063 .33624 L
.45064 .33624 L
.45066 .33624 L
.45068 .33624 L
.45069 .33624 L
.45071 .33623 L
.45072 .33623 L
.45074 .33623 L
.45076 .33623 L
.45077 .33623 L
.45079 .33623 L
.4508 .33623 L
.45082 .33622 L
.45084 .33622 L
Mistroke
.45085 .33622 L
.45087 .33622 L
.45089 .33622 L
.4509 .33622 L
.45092 .33622 L
.45093 .33622 L
.45095 .33621 L
.45097 .33621 L
.45098 .33621 L
.451 .33621 L
.45101 .33621 L
.45103 .33621 L
.45104 .33621 L
.45106 .33621 L
.45108 .33621 L
.45109 .3362 L
.45111 .3362 L
.45112 .3362 L
.45114 .3362 L
.45116 .3362 L
.45117 .3362 L
.45119 .3362 L
.4512 .3362 L
.45122 .3362 L
.45123 .3362 L
.45125 .33619 L
.45127 .33619 L
.45128 .33619 L
.4513 .33619 L
.45131 .33619 L
.45133 .33619 L
.45134 .33619 L
.45136 .33619 L
.45138 .33619 L
.45139 .33619 L
.45141 .33619 L
.45142 .33619 L
.45144 .33618 L
.45145 .33618 L
.45147 .33618 L
.45148 .33618 L
.4515 .33618 L
.45152 .33618 L
.45153 .33618 L
.45155 .33618 L
.45156 .33618 L
.45158 .33618 L
.45159 .33618 L
.45161 .33618 L
.45162 .33618 L
Mistroke
.45164 .33618 L
.45165 .33618 L
.45167 .33618 L
.45168 .33617 L
.4517 .33617 L
.45172 .33617 L
.45173 .33617 L
.45175 .33617 L
.45176 .33617 L
.45178 .33617 L
.45179 .33617 L
.45181 .33617 L
.45182 .33617 L
.45184 .33617 L
.45185 .33617 L
.45187 .33617 L
.45188 .33617 L
.4519 .33617 L
.45191 .33617 L
.45193 .33617 L
.45194 .33617 L
.45196 .33617 L
.45197 .33617 L
.45199 .33617 L
.452 .33617 L
.45202 .33617 L
.45203 .33617 L
.45205 .33617 L
.45206 .33617 L
.45208 .33617 L
.45209 .33617 L
.45211 .33617 L
.45212 .33617 L
.45214 .33617 L
.45215 .33617 L
.45217 .33617 L
.45218 .33617 L
.4522 .33617 L
.45221 .33617 L
.45223 .33617 L
.45224 .33617 L
.45226 .33617 L
.45227 .33617 L
.45229 .33617 L
.4523 .33617 L
.45232 .33617 L
.45233 .33617 L
.45235 .33617 L
.45236 .33617 L
.45238 .33617 L
Mistroke
.45239 .33617 L
.4524 .33617 L
.45242 .33617 L
.45243 .33617 L
.45245 .33617 L
.45246 .33617 L
.45248 .33617 L
.45249 .33617 L
.45251 .33617 L
.45252 .33617 L
.45254 .33617 L
.45255 .33617 L
.45256 .33617 L
.45258 .33617 L
.45259 .33617 L
.45261 .33617 L
.45262 .33617 L
.45264 .33617 L
.45265 .33617 L
.45267 .33617 L
.45268 .33617 L
.45269 .33617 L
.45271 .33617 L
.45272 .33617 L
.45274 .33618 L
.45275 .33618 L
.45277 .33618 L
.45278 .33618 L
.45279 .33618 L
.45281 .33618 L
.45282 .33618 L
.45284 .33618 L
.45285 .33618 L
.45287 .33618 L
.45288 .33618 L
.45289 .33618 L
.45291 .33618 L
.45292 .33618 L
.45294 .33618 L
.45295 .33618 L
.45296 .33619 L
.45298 .33619 L
.45299 .33619 L
.45301 .33619 L
.45302 .33619 L
.45304 .33619 L
.45305 .33619 L
.45306 .33619 L
.45308 .33619 L
.45309 .33619 L
Mistroke
.45311 .33619 L
.45312 .33619 L
.45313 .33619 L
.45315 .3362 L
.45316 .3362 L
.45317 .3362 L
.45319 .3362 L
.4532 .3362 L
.45322 .3362 L
.45323 .3362 L
.45324 .3362 L
.45326 .3362 L
.45327 .3362 L
.45329 .33621 L
.4533 .33621 L
.45331 .33621 L
.45333 .33621 L
.45334 .33621 L
.45335 .33621 L
.45337 .33621 L
.45338 .33621 L
.45339 .33621 L
.45341 .33621 L
.45342 .33622 L
.45344 .33622 L
.45345 .33622 L
.45346 .33622 L
.45348 .33622 L
.45349 .33622 L
.4535 .33622 L
.45352 .33622 L
.45353 .33623 L
.45354 .33623 L
.45356 .33623 L
.45357 .33623 L
.45358 .33623 L
.4536 .33623 L
.45361 .33623 L
.45362 .33623 L
.45364 .33624 L
.45365 .33624 L
.45366 .33624 L
.45368 .33624 L
.45369 .33624 L
.4537 .33624 L
.45372 .33624 L
.45373 .33625 L
.45374 .33625 L
.45376 .33625 L
.45377 .33625 L
Mistroke
.45378 .33625 L
.4538 .33625 L
.45381 .33625 L
.45382 .33626 L
.45384 .33626 L
.45385 .33626 L
.45386 .33626 L
.45388 .33626 L
.45389 .33626 L
.4539 .33627 L
.45392 .33627 L
.45393 .33627 L
.45394 .33627 L
.45396 .33627 L
.45397 .33627 L
.45398 .33628 L
.45399 .33628 L
.45401 .33628 L
.45402 .33628 L
.45403 .33628 L
.45405 .33628 L
.45406 .33629 L
.45407 .33629 L
.45409 .33629 L
.4541 .33629 L
.45411 .33629 L
.45412 .33629 L
.45414 .3363 L
.45415 .3363 L
.45416 .3363 L
.45418 .3363 L
.45419 .3363 L
.4542 .33631 L
.45421 .33631 L
.45423 .33631 L
.45424 .33631 L
.45425 .33631 L
.45426 .33632 L
.45428 .33632 L
.45429 .33632 L
.4543 .33632 L
.45431 .33632 L
.45433 .33633 L
.45434 .33633 L
.45435 .33633 L
.45437 .33633 L
.45438 .33633 L
.45439 .33634 L
.4544 .33634 L
.45442 .33634 L
Mistroke
.45443 .33634 L
.45444 .33634 L
.45445 .33635 L
.45447 .33635 L
.45448 .33635 L
.45449 .33635 L
.4545 .33635 L
.45452 .33636 L
.45453 .33636 L
.45454 .33636 L
.45455 .33636 L
.45456 .33637 L
.45458 .33637 L
.45459 .33637 L
.4546 .33637 L
.45461 .33637 L
.45463 .33638 L
.45464 .33638 L
.45465 .33638 L
.45466 .33638 L
.45468 .33639 L
.45469 .33639 L
.4547 .33639 L
.45471 .33639 L
.45472 .3364 L
.45474 .3364 L
.45475 .3364 L
.45476 .3364 L
.45477 .3364 L
.45478 .33641 L
.4548 .33641 L
.45481 .33641 L
.45482 .33641 L
.45483 .33642 L
.45484 .33642 L
.45486 .33642 L
.45487 .33642 L
.45488 .33643 L
.45489 .33643 L
.4549 .33643 L
.45492 .33643 L
.45493 .33644 L
.45494 .33644 L
.45495 .33644 L
.45496 .33645 L
.45498 .33645 L
.45499 .33645 L
.455 .33645 L
.45501 .33646 L
.45502 .33646 L
Mistroke
.45504 .33646 L
.45505 .33646 L
.45506 .33647 L
.45507 .33647 L
.45508 .33647 L
.45509 .33647 L
.45511 .33648 L
.45512 .33648 L
.45513 .33648 L
.45514 .33649 L
.45515 .33649 L
.45516 .33649 L
.45518 .33649 L
.45519 .3365 L
.4552 .3365 L
.45521 .3365 L
.45522 .33651 L
.45523 .33651 L
.45524 .33651 L
.45526 .33651 L
.45527 .33652 L
.45528 .33652 L
.45529 .33652 L
.4553 .33653 L
.45531 .33653 L
.45533 .33653 L
.45534 .33653 L
.45535 .33654 L
.45536 .33654 L
.45537 .33654 L
.45538 .33655 L
.45539 .33655 L
.4554 .33655 L
.45542 .33656 L
.45543 .33656 L
.45544 .33656 L
.45545 .33656 L
.45546 .33657 L
.45547 .33657 L
.45548 .33657 L
.45549 .33658 L
.45551 .33658 L
.45552 .33658 L
.45553 .33659 L
.45554 .33659 L
.45555 .33659 L
.45556 .3366 L
.45557 .3366 L
.45558 .3366 L
.4556 .33661 L
Mistroke
.45561 .33661 L
.45562 .33661 L
.45563 .33661 L
.45564 .33662 L
.45565 .33662 L
.45566 .33662 L
.45567 .33663 L
.45568 .33663 L
.45569 .33663 L
.4557 .33664 L
.45572 .33664 L
.45573 .33664 L
.45574 .33665 L
.45575 .33665 L
.45576 .33665 L
.45577 .33666 L
.45578 .33666 L
.45579 .33666 L
.4558 .33667 L
.45581 .33667 L
.45582 .33667 L
.45584 .33668 L
.45585 .33668 L
.45586 .33669 L
.45587 .33669 L
.45588 .33669 L
.45589 .3367 L
.4559 .3367 L
.45591 .3367 L
.45592 .33671 L
.45593 .33671 L
.45594 .33671 L
.45595 .33672 L
.45596 .33672 L
.45597 .33672 L
.45598 .33673 L
.45599 .33673 L
.45601 .33673 L
.45602 .33674 L
.45603 .33674 L
.45604 .33675 L
.45605 .33675 L
.45606 .33675 L
.45607 .33676 L
.45608 .33676 L
.45609 .33676 L
.4561 .33677 L
.45611 .33677 L
.45612 .33677 L
.45613 .33678 L
Mistroke
.45614 .33678 L
.45615 .33679 L
.45616 .33679 L
.45617 .33679 L
.45618 .3368 L
.45619 .3368 L
.4562 .3368 L
.45621 .33681 L
.45622 .33681 L
.45623 .33682 L
.45624 .33682 L
.45625 .33682 L
.45626 .33683 L
.45627 .33683 L
.45628 .33684 L
.45629 .33684 L
.4563 .33684 L
.45631 .33685 L
.45632 .33685 L
.45633 .33685 L
.45634 .33686 L
.45635 .33686 L
.45636 .33687 L
.45637 .33687 L
.45638 .33687 L
.45639 .33688 L
.4564 .33688 L
.45641 .33689 L
.45642 .33689 L
.45643 .33689 L
.45644 .3369 L
.45645 .3369 L
.45646 .33691 L
.45647 .33691 L
.45648 .33691 L
.45649 .33692 L
.4565 .33692 L
.45651 .33693 L
.45652 .33693 L
.45653 .33693 L
.45654 .33694 L
.45655 .33694 L
.45656 .33695 L
.45657 .33695 L
.45658 .33696 L
.45659 .33696 L
.4566 .33696 L
.45661 .33697 L
.45662 .33697 L
.45663 .33698 L
Mistroke
.45664 .33698 L
.45665 .33698 L
.45666 .33699 L
.45667 .33699 L
.45668 .337 L
.45669 .337 L
.4567 .33701 L
.45671 .33701 L
.45672 .33701 L
.45673 .33702 L
.45673 .33702 L
.45674 .33703 L
.45675 .33703 L
.45676 .33704 L
.45677 .33704 L
.45678 .33704 L
.45679 .33705 L
.4568 .33705 L
.45681 .33706 L
.45682 .33706 L
.45683 .33707 L
.45684 .33707 L
.45685 .33708 L
.45686 .33708 L
.45687 .33708 L
.45688 .33709 L
.45688 .33709 L
.45689 .3371 L
.4569 .3371 L
.45691 .33711 L
.45692 .33711 L
.45693 .33712 L
.45694 .33712 L
.45695 .33712 L
.45696 .33713 L
.45697 .33713 L
.45698 .33714 L
.45699 .33714 L
.45699 .33715 L
.457 .33715 L
.45701 .33716 L
.45702 .33716 L
.45703 .33716 L
.45704 .33717 L
.45705 .33717 L
.45706 .33718 L
.45707 .33718 L
.45708 .33719 L
.45708 .33719 L
.45709 .3372 L
Mistroke
.4571 .3372 L
.45711 .33721 L
.45712 .33721 L
.45713 .33722 L
.45714 .33722 L
.45715 .33722 L
.45715 .33723 L
.45716 .33723 L
.45717 .33724 L
.45718 .33724 L
.45719 .33725 L
.4572 .33725 L
.45721 .33726 L
.45722 .33726 L
.45723 .33727 L
.45723 .33727 L
.45724 .33728 L
.45725 .33728 L
.45726 .33729 L
.45727 .33729 L
.45728 .3373 L
.45729 .3373 L
.45729 .33731 L
.4573 .33731 L
.45731 .33732 L
.45732 .33732 L
.45733 .33733 L
.45734 .33733 L
.45735 .33733 L
.45735 .33734 L
.45736 .33734 L
.45737 .33735 L
.45738 .33735 L
.45739 .33736 L
.4574 .33736 L
.4574 .33737 L
.45741 .33737 L
.45742 .33738 L
.45743 .33738 L
.45744 .33739 L
.45745 .33739 L
.45745 .3374 L
.45746 .3374 L
.45747 .33741 L
.45748 .33741 L
.45749 .33742 L
.4575 .33742 L
.4575 .33743 L
.45751 .33743 L
.45752 .33744 L
Mistroke
.45753 .33744 L
.45754 .33745 L
.45755 .33745 L
.45755 .33746 L
.45756 .33746 L
.45757 .33747 L
.45758 .33747 L
.45759 .33748 L
.45759 .33748 L
.4576 .33749 L
.45761 .3375 L
.45762 .3375 L
.45763 .33751 L
.45763 .33751 L
.45764 .33752 L
.45765 .33752 L
.45766 .33753 L
.45767 .33753 L
.45767 .33754 L
.45768 .33754 L
.45769 .33755 L
.4577 .33755 L
.45771 .33756 L
.45771 .33756 L
.45772 .33757 L
.45773 .33757 L
.45774 .33758 L
.45774 .33758 L
.45775 .33759 L
.45776 .33759 L
.45777 .3376 L
.45778 .3376 L
.45778 .33761 L
.45779 .33761 L
.4578 .33762 L
.45781 .33763 L
.45781 .33763 L
.45782 .33764 L
.45783 .33764 L
.45784 .33765 L
.45785 .33765 L
.45785 .33766 L
.45786 .33766 L
.45787 .33767 L
.45788 .33767 L
.45788 .33768 L
.45789 .33768 L
.4579 .33769 L
.45791 .3377 L
.45791 .3377 L
Mistroke
.45792 .33771 L
.45793 .33771 L
.45794 .33772 L
.45794 .33772 L
.45795 .33773 L
.45796 .33773 L
.45797 .33774 L
.45797 .33774 L
.45798 .33775 L
.45799 .33776 L
.458 .33776 L
.458 .33777 L
.45801 .33777 L
.45802 .33778 L
.45802 .33778 L
.45803 .33779 L
.45804 .33779 L
.45805 .3378 L
.45805 .33781 L
.45806 .33781 L
.45807 .33782 L
.45808 .33782 L
.45808 .33783 L
.45809 .33783 L
.4581 .33784 L
.4581 .33784 L
.45811 .33785 L
.45812 .33786 L
.45813 .33786 L
.45813 .33787 L
.45814 .33787 L
.45815 .33788 L
.45815 .33788 L
.45816 .33789 L
.45817 .33789 L
.45817 .3379 L
.45818 .33791 L
.45819 .33791 L
.4582 .33792 L
.4582 .33792 L
.45821 .33793 L
.45822 .33793 L
.45822 .33794 L
.45823 .33795 L
.45824 .33795 L
.45824 .33796 L
.45825 .33796 L
.45826 .33797 L
.45826 .33797 L
.45827 .33798 L
Mistroke
.45828 .33799 L
.45829 .33799 L
.45829 .338 L
.4583 .338 L
.45831 .33801 L
.45831 .33802 L
.45832 .33802 L
.45833 .33803 L
.45833 .33803 L
.45834 .33804 L
.45835 .33804 L
.45835 .33805 L
.45836 .33806 L
.45837 .33806 L
.45837 .33807 L
.45838 .33807 L
.45839 .33808 L
.45839 .33809 L
.4584 .33809 L
.45841 .3381 L
.45841 .3381 L
.45842 .33811 L
.45842 .33811 L
.45843 .33812 L
.45844 .33813 L
.45844 .33813 L
.45845 .33814 L
.45846 .33814 L
.45846 .33815 L
.45847 .33816 L
.45848 .33816 L
.45848 .33817 L
.45849 .33817 L
.4585 .33818 L
.4585 .33819 L
.45851 .33819 L
.45851 .3382 L
.45852 .3382 L
.45853 .33821 L
.45853 .33822 L
.45854 .33822 L
.45855 .33823 L
.45855 .33823 L
.45856 .33824 L
.45856 .33825 L
.45857 .33825 L
.45858 .33826 L
.45858 .33826 L
.45859 .33827 L
.4586 .33828 L
Mistroke
.4586 .33828 L
.45861 .33829 L
.45861 .33829 L
.45862 .3383 L
.45863 .33831 L
.45863 .33831 L
.45864 .33832 L
.45864 .33833 L
.45865 .33833 L
.45866 .33834 L
.45866 .33834 L
.45867 .33835 L
.45867 .33836 L
.45868 .33836 L
.45869 .33837 L
.45869 .33837 L
.4587 .33838 L
.4587 .33839 L
.45871 .33839 L
.45872 .3384 L
.45872 .33841 L
.45873 .33841 L
.45873 .33842 L
.45874 .33842 L
.45874 .33843 L
.45875 .33844 L
.45876 .33844 L
.45876 .33845 L
.45877 .33846 L
.45877 .33846 L
.45878 .33847 L
.45879 .33847 L
.45879 .33848 L
.4588 .33849 L
.4588 .33849 L
.45881 .3385 L
.45881 .33851 L
.45882 .33851 L
.45882 .33852 L
.45883 .33852 L
.45884 .33853 L
.45884 .33854 L
.45885 .33854 L
.45885 .33855 L
.45886 .33856 L
.45886 .33856 L
.45887 .33857 L
.45887 .33857 L
.45888 .33858 L
.45889 .33859 L
Mistroke
.45889 .33859 L
.4589 .3386 L
.4589 .33861 L
.45891 .33861 L
.45891 .33862 L
.45892 .33863 L
.45892 .33863 L
.45893 .33864 L
.45893 .33865 L
.45894 .33865 L
.45895 .33866 L
.45895 .33866 L
.45896 .33867 L
.45896 .33868 L
.45897 .33868 L
.45897 .33869 L
.45898 .3387 L
.45898 .3387 L
.45899 .33871 L
.45899 .33872 L
.459 .33872 L
.459 .33873 L
.45901 .33874 L
.45901 .33874 L
.45902 .33875 L
.45902 .33875 L
.45903 .33876 L
.45903 .33877 L
.45904 .33877 L
.45904 .33878 L
.45905 .33879 L
.45905 .33879 L
.45906 .3388 L
.45906 .33881 L
.45907 .33881 L
.45907 .33882 L
.45908 .33883 L
.45908 .33883 L
.45909 .33884 L
.45909 .33885 L
.4591 .33885 L
.4591 .33886 L
.45911 .33887 L
.45911 .33887 L
.45912 .33888 L
.45912 .33889 L
.45913 .33889 L
.45913 .3389 L
.45914 .33891 L
.45914 .33891 L
Mistroke
.45915 .33892 L
.45915 .33893 L
.45916 .33893 L
.45916 .33894 L
.45917 .33895 L
.45917 .33895 L
.45918 .33896 L
.45918 .33897 L
.45919 .33897 L
.45919 .33898 L
.4592 .33899 L
.4592 .33899 L
.45921 .339 L
.45921 .33901 L
.45921 .33901 L
.45922 .33902 L
.45922 .33903 L
.45923 .33903 L
.45923 .33904 L
.45924 .33905 L
.45924 .33905 L
.45925 .33906 L
.45925 .33907 L
.45926 .33907 L
.45926 .33908 L
.45926 .33909 L
.45927 .33909 L
.45927 .3391 L
.45928 .33911 L
.45928 .33911 L
.45929 .33912 L
.45929 .33913 L
.4593 .33913 L
.4593 .33914 L
.4593 .33915 L
.45931 .33915 L
.45931 .33916 L
.45932 .33917 L
.45932 .33917 L
.45933 .33918 L
.45933 .33919 L
.45934 .33919 L
.45934 .3392 L
.45934 .33921 L
.45935 .33921 L
.45935 .33922 L
.45936 .33923 L
.45936 .33923 L
.45936 .33924 L
.45937 .33925 L
Mistroke
.45937 .33926 L
.45938 .33926 L
.45938 .33927 L
.45939 .33928 L
.45939 .33928 L
.45939 .33929 L
.4594 .3393 L
.4594 .3393 L
.45941 .33931 L
.45941 .33932 L
.45941 .33932 L
.45942 .33933 L
.45942 .33934 L
.45943 .33934 L
.45943 .33935 L
.45943 .33936 L
.45944 .33936 L
.45944 .33937 L
.45945 .33938 L
.45945 .33939 L
.45945 .33939 L
.45946 .3394 L
.45946 .33941 L
.45947 .33941 L
.45947 .33942 L
.45947 .33943 L
.45948 .33943 L
.45948 .33944 L
.45949 .33945 L
.45949 .33945 L
.45949 .33946 L
.4595 .33947 L
.4595 .33948 L
.4595 .33948 L
.45951 .33949 L
.45951 .3395 L
.45952 .3395 L
.45952 .33951 L
.45952 .33952 L
.45953 .33952 L
.45953 .33953 L
.45953 .33954 L
.45954 .33955 L
.45954 .33955 L
.45955 .33956 L
.45955 .33957 L
.45955 .33957 L
.45956 .33958 L
.45956 .33959 L
.45956 .33959 L
Mistroke
.45957 .3396 L
.45957 .33961 L
.45957 .33962 L
.45958 .33962 L
.45958 .33963 L
.45958 .33964 L
.45959 .33964 L
.45959 .33965 L
.4596 .33966 L
.4596 .33967 L
.4596 .33967 L
.45961 .33968 L
.45961 .33969 L
.45961 .33969 L
.45962 .3397 L
.45962 .33971 L
.45962 .33971 L
.45963 .33972 L
.45963 .33973 L
.45963 .33974 L
.45964 .33974 L
.45964 .33975 L
.45964 .33976 L
.45965 .33976 L
.45965 .33977 L
.45965 .33978 L
.45966 .33979 L
.45966 .33979 L
.45966 .3398 L
.45967 .33981 L
.45967 .33981 L
.45967 .33982 L
.45968 .33983 L
.45968 .33984 L
.45968 .33984 L
.45968 .33985 L
.45969 .33986 L
.45969 .33986 L
.45969 .33987 L
.4597 .33988 L
.4597 .33989 L
.4597 .33989 L
.45971 .3399 L
.45971 .33991 L
.45971 .33991 L
.45972 .33992 L
.45972 .33993 L
.45972 .33994 L
.45972 .33994 L
.45973 .33995 L
Mistroke
.45973 .33996 L
.45973 .33996 L
.45974 .33997 L
.45974 .33998 L
.45974 .33999 L
.45975 .33999 L
.45975 .34 L
.45975 .34001 L
.45975 .34001 L
.45976 .34002 L
.45976 .34003 L
.45976 .34004 L
.45977 .34004 L
.45977 .34005 L
.45977 .34006 L
.45977 .34007 L
.45978 .34007 L
.45978 .34008 L
.45978 .34009 L
.45978 .34009 L
.45979 .3401 L
.45979 .34011 L
.45979 .34012 L
.4598 .34012 L
.4598 .34013 L
.4598 .34014 L
.4598 .34015 L
.45981 .34015 L
.45981 .34016 L
.45981 .34017 L
.45981 .34017 L
.45982 .34018 L
.45982 .34019 L
.45982 .3402 L
.45982 .3402 L
.45983 .34021 L
.45983 .34022 L
.45983 .34023 L
.45984 .34023 L
.45984 .34024 L
.45984 .34025 L
.45984 .34025 L
.45985 .34026 L
.45985 .34027 L
.45985 .34028 L
.45985 .34028 L
.45985 .34029 L
.45986 .3403 L
.45986 .34031 L
.45986 .34031 L
Mistroke
.45986 .34032 L
.45987 .34033 L
.45987 .34034 L
.45987 .34034 L
.45987 .34035 L
.45988 .34036 L
.45988 .34036 L
.45988 .34037 L
.45988 .34038 L
.45989 .34039 L
.45989 .34039 L
.45989 .3404 L
.45989 .34041 L
.45989 .34042 L
.4599 .34042 L
.4599 .34043 L
.4599 .34044 L
.4599 .34045 L
.45991 .34045 L
.45991 .34046 L
.45991 .34047 L
.45991 .34047 L
.45991 .34048 L
.45992 .34049 L
.45992 .3405 L
.45992 .3405 L
.45992 .34051 L
.45993 .34052 L
.45993 .34053 L
.45993 .34053 L
.45993 .34054 L
.45993 .34055 L
.45994 .34056 L
.45994 .34056 L
.45994 .34057 L
.45994 .34058 L
.45994 .34059 L
.45995 .34059 L
.45995 .3406 L
.45995 .34061 L
.45995 .34062 L
.45995 .34062 L
.45996 .34063 L
.45996 .34064 L
.45996 .34065 L
.45996 .34065 L
.45996 .34066 L
.45996 .34067 L
.45997 .34067 L
.45997 .34068 L
Mistroke
.45997 .34069 L
.45997 .3407 L
.45997 .3407 L
.45998 .34071 L
.45998 .34072 L
.45998 .34073 L
.45998 .34073 L
.45998 .34074 L
.45998 .34075 L
.45999 .34076 L
.45999 .34076 L
.45999 .34077 L
.45999 .34078 L
.45999 .34079 L
.45999 .34079 L
.46 .3408 L
.46 .34081 L
.46 .34082 L
.46 .34082 L
.46 .34083 L
.46 .34084 L
.46001 .34085 L
.46001 .34085 L
.46001 .34086 L
.46001 .34087 L
.46001 .34088 L
.46001 .34088 L
.46002 .34089 L
.46002 .3409 L
.46002 .34091 L
.46002 .34091 L
.46002 .34092 L
.46002 .34093 L
.46002 .34094 L
.46003 .34094 L
.46003 .34095 L
.46003 .34096 L
.46003 .34097 L
.46003 .34097 L
.46003 .34098 L
.46004 .34099 L
.46004 .341 L
.46004 .341 L
.46004 .34101 L
.46004 .34102 L
.46004 .34103 L
.46004 .34103 L
.46004 .34104 L
.46005 .34105 L
.46005 .34106 L
Mistroke
.46005 .34106 L
.46005 .34107 L
.46005 .34108 L
.46005 .34109 L
.46005 .34109 L
.46005 .3411 L
.46006 .34111 L
.46006 .34112 L
.46006 .34112 L
.46006 .34113 L
.46006 .34114 L
.46006 .34115 L
.46006 .34115 L
.46006 .34116 L
.46007 .34117 L
.46007 .34118 L
.46007 .34118 L
.46007 .34119 L
.46007 .3412 L
.46007 .34121 L
.46007 .34121 L
.46007 .34122 L
.46007 .34123 L
.46008 .34124 L
.46008 .34124 L
.46008 .34125 L
.46008 .34126 L
.46008 .34127 L
.46008 .34127 L
.46008 .34128 L
.46008 .34129 L
.46008 .3413 L
.46008 .3413 L
.46009 .34131 L
.46009 .34132 L
.46009 .34133 L
.46009 .34134 L
.46009 .34134 L
.46009 .34135 L
.46009 .34136 L
.46009 .34137 L
.46009 .34137 L
.46009 .34138 L
.46009 .34139 L
.4601 .3414 L
.4601 .3414 L
.4601 .34141 L
.4601 .34142 L
.4601 .34143 L
.4601 .34143 L
Mistroke
.4601 .34144 L
.4601 .34145 L
.4601 .34146 L
.4601 .34146 L
.4601 .34147 L
.4601 .34148 L
.4601 .34149 L
.46011 .34149 L
.46011 .3415 L
.46011 .34151 L
.46011 .34152 L
.46011 .34152 L
.46011 .34153 L
.46011 .34154 L
.46011 .34155 L
.46011 .34155 L
.46011 .34156 L
.46011 .34157 L
.46011 .34158 L
.46011 .34159 L
.46011 .34159 L
.46011 .3416 L
.46012 .34161 L
.46012 .34162 L
.46012 .34162 L
.46012 .34163 L
.46012 .34164 L
.46012 .34165 L
.46012 .34165 L
.46012 .34166 L
.46012 .34167 L
.46012 .34168 L
.46012 .34168 L
.46012 .34169 L
.46012 .3417 L
.46012 .34171 L
.46012 .34171 L
.46012 .34172 L
.46012 .34173 L
.46012 .34174 L
.46012 .34174 L
.46012 .34175 L
.46012 .34176 L
.46012 .34177 L
.46012 .34178 L
.46013 .34178 L
.46013 .34179 L
.46013 .3418 L
.46013 .34181 L
.46013 .34181 L
Mistroke
.46013 .34182 L
.46013 .34183 L
.46013 .34184 L
.46013 .34184 L
.46013 .34185 L
.46013 .34186 L
.46013 .34187 L
.46013 .34187 L
.46013 .34188 L
.46013 .34189 L
.46013 .3419 L
.46013 .3419 L
.46013 .34191 L
.46013 .34192 L
.46013 .34193 L
.46013 .34193 L
.46013 .34194 L
.46013 .34195 L
.46013 .34196 L
.46013 .34197 L
.46013 .34197 L
.46013 .34198 L
.46013 .34199 L
.46013 .342 L
.46013 .342 L
.46013 .34201 L
.46013 .34202 L
.46013 .34203 L
.46013 .34203 L
.46013 .34204 L
.46013 .34205 L
.46013 .34206 L
.46013 .34206 L
.46013 .34207 L
.46013 .34208 L
.46013 .34209 L
.46013 .34209 L
.46013 .3421 L
.46013 .34211 L
.46013 .34212 L
.46013 .34213 L
.46013 .34213 L
.46013 .34214 L
.46013 .34215 L
.46013 .34216 L
.46013 .34216 L
.46013 .34217 L
.46013 .34218 L
.46013 .34219 L
.46013 .34219 L
Mistroke
.46013 .3422 L
.46013 .34221 L
.46013 .34222 L
.46013 .34222 L
.46013 .34223 L
.46013 .34224 L
.46013 .34225 L
.46013 .34225 L
.46013 .34226 L
.46013 .34227 L
.46013 .34228 L
.46013 .34229 L
.46013 .34229 L
.46013 .3423 L
.46013 .34231 L
.46013 .34232 L
.46012 .34232 L
.46012 .34233 L
.46012 .34234 L
.46012 .34235 L
.46012 .34235 L
.46012 .34236 L
.46012 .34237 L
.46012 .34238 L
.46012 .34238 L
.46012 .34239 L
.46012 .3424 L
.46012 .34241 L
.46012 .34241 L
.46012 .34242 L
.46012 .34243 L
.46012 .34244 L
.46012 .34245 L
.46012 .34245 L
.46012 .34246 L
.46012 .34247 L
.46012 .34248 L
.46012 .34248 L
.46012 .34249 L
.46011 .3425 L
.46011 .34251 L
.46011 .34251 L
.46011 .34252 L
.46011 .34253 L
.46011 .34254 L
.46011 .34254 L
.46011 .34255 L
.46011 .34256 L
.46011 .34257 L
.46011 .34257 L
Mistroke
.46011 .34258 L
.46011 .34259 L
.46011 .3426 L
.46011 .34261 L
.46011 .34261 L
.4601 .34262 L
.4601 .34263 L
.4601 .34264 L
.4601 .34264 L
.4601 .34265 L
.4601 .34266 L
.4601 .34267 L
.4601 .34267 L
.4601 .34268 L
.4601 .34269 L
.4601 .3427 L
.4601 .3427 L
.4601 .34271 L
.4601 .34272 L
.46009 .34273 L
.46009 .34273 L
.46009 .34274 L
.46009 .34275 L
.46009 .34276 L
.46009 .34276 L
.46009 .34277 L
.46009 .34278 L
.46009 .34279 L
.46009 .3428 L
.46009 .3428 L
.46009 .34281 L
.46008 .34282 L
.46008 .34283 L
.46008 .34283 L
.46008 .34284 L
.46008 .34285 L
.46008 .34286 L
.46008 .34286 L
.46008 .34287 L
.46008 .34288 L
.46008 .34289 L
.46007 .34289 L
.46007 .3429 L
.46007 .34291 L
.46007 .34292 L
.46007 .34292 L
.46007 .34293 L
.46007 .34294 L
.46007 .34295 L
.46007 .34295 L
Mistroke
.46007 .34296 L
.46006 .34297 L
.46006 .34298 L
.46006 .34298 L
.46006 .34299 L
.46006 .343 L
.46006 .34301 L
.46006 .34302 L
.46006 .34302 L
.46006 .34303 L
.46005 .34304 L
.46005 .34305 L
.46005 .34305 L
.46005 .34306 L
.46005 .34307 L
.46005 .34308 L
.46005 .34308 L
.46005 .34309 L
.46004 .3431 L
.46004 .34311 L
.46004 .34311 L
.46004 .34312 L
.46004 .34313 L
.46004 .34314 L
.46004 .34314 L
.46004 .34315 L
.46003 .34316 L
.46003 .34317 L
.46003 .34317 L
.46003 .34318 L
.46003 .34319 L
.46003 .3432 L
.46003 .3432 L
.46003 .34321 L
.46002 .34322 L
.46002 .34323 L
.46002 .34323 L
.46002 .34324 L
.46002 .34325 L
.46002 .34326 L
.46002 .34326 L
.46001 .34327 L
.46001 .34328 L
.46001 .34329 L
.46001 .34329 L
.46001 .3433 L
.46001 .34331 L
.46001 .34332 L
.46 .34332 L
.46 .34333 L
Mistroke
.46 .34334 L
.46 .34335 L
.46 .34335 L
.46 .34336 L
.46 .34337 L
.45999 .34338 L
.45999 .34338 L
.45999 .34339 L
.45999 .3434 L
.45999 .34341 L
.45999 .34341 L
.45998 .34342 L
.45998 .34343 L
.45998 .34344 L
.45998 .34344 L
.45998 .34345 L
.45998 .34346 L
.45998 .34347 L
.45997 .34347 L
.45997 .34348 L
.45997 .34349 L
.45997 .3435 L
.45997 .3435 L
.45997 .34351 L
.45996 .34352 L
.45996 .34353 L
.45996 .34353 L
.45996 .34354 L
.45996 .34355 L
.45996 .34356 L
.45995 .34356 L
.45995 .34357 L
.45995 .34358 L
.45995 .34359 L
.45995 .34359 L
.45995 .3436 L
.45994 .34361 L
.45994 .34362 L
.45994 .34362 L
.45994 .34363 L
.45994 .34364 L
.45993 .34365 L
.45993 .34365 L
.45993 .34366 L
.45993 .34367 L
.45993 .34368 L
.45993 .34368 L
.45992 .34369 L
.45992 .3437 L
.45992 .34371 L
Mistroke
.45992 .34371 L
.45992 .34372 L
.45991 .34373 L
.45991 .34374 L
.45991 .34374 L
.45991 .34375 L
.45991 .34376 L
.4599 .34377 L
.4599 .34377 L
.4599 .34378 L
.4599 .34379 L
.4599 .3438 L
.4599 .3438 L
.45989 .34381 L
.45989 .34382 L
.45989 .34383 L
.45989 .34383 L
.45989 .34384 L
.45988 .34385 L
.45988 .34386 L
.45988 .34386 L
.45988 .34387 L
.45988 .34388 L
.45987 .34388 L
.45987 .34389 L
.45987 .3439 L
.45987 .34391 L
.45987 .34391 L
.45986 .34392 L
.45986 .34393 L
.45986 .34394 L
.45986 .34394 L
.45985 .34395 L
.45985 .34396 L
.45985 .34397 L
.45985 .34397 L
.45985 .34398 L
.45984 .34399 L
.45984 .344 L
.45984 .344 L
.45984 .34401 L
.45984 .34402 L
.45983 .34403 L
.45983 .34403 L
.45983 .34404 L
.45983 .34405 L
.45983 .34405 L
.45982 .34406 L
.45982 .34407 L
.45982 .34408 L
Mistroke
.45982 .34408 L
.45981 .34409 L
.45981 .3441 L
.45981 .34411 L
.45981 .34411 L
.45981 .34412 L
.4598 .34413 L
.4598 .34414 L
.4598 .34414 L
.4598 .34415 L
.45979 .34416 L
.45979 .34417 L
.45979 .34417 L
.45979 .34418 L
.45978 .34419 L
.45978 .34419 L
.45978 .3442 L
.45978 .34421 L
.45978 .34422 L
.45977 .34422 L
.45977 .34423 L
.45977 .34424 L
.45977 .34425 L
.45976 .34425 L
.45976 .34426 L
.45976 .34427 L
.45976 .34427 L
.45975 .34428 L
.45975 .34429 L
.45975 .3443 L
.45975 .3443 L
.45974 .34431 L
.45974 .34432 L
.45974 .34433 L
.45974 .34433 L
.45973 .34434 L
.45973 .34435 L
.45973 .34436 L
.45973 .34436 L
.45972 .34437 L
.45972 .34438 L
.45972 .34438 L
.45972 .34439 L
.45971 .3444 L
.45971 .34441 L
.45971 .34441 L
.45971 .34442 L
.4597 .34443 L
.4597 .34443 L
.4597 .34444 L
Mistroke
.4597 .34445 L
.45969 .34446 L
.45969 .34446 L
.45969 .34447 L
.45969 .34448 L
.45968 .34449 L
.45968 .34449 L
.45968 .3445 L
.45968 .34451 L
.45967 .34451 L
.45967 .34452 L
.45967 .34453 L
.45967 .34454 L
.45966 .34454 L
.45966 .34455 L
.45966 .34456 L
.45966 .34457 L
.45965 .34457 L
.45965 .34458 L
.45965 .34459 L
.45964 .34459 L
.45964 .3446 L
.45964 .34461 L
.45964 .34462 L
.45963 .34462 L
.45963 .34463 L
.45963 .34464 L
.45963 .34464 L
.45962 .34465 L
.45962 .34466 L
.45962 .34467 L
.45961 .34467 L
.45961 .34468 L
.45961 .34469 L
.45961 .34469 L
.4596 .3447 L
.4596 .34471 L
.4596 .34472 L
.4596 .34472 L
.45959 .34473 L
.45959 .34474 L
.45959 .34474 L
.45958 .34475 L
.45958 .34476 L
.45958 .34477 L
.45958 .34477 L
.45957 .34478 L
.45957 .34479 L
.45957 .34479 L
.45956 .3448 L
Mistroke
.45956 .34481 L
.45956 .34482 L
.45956 .34482 L
.45955 .34483 L
.45955 .34484 L
.45955 .34484 L
.45954 .34485 L
.45954 .34486 L
.45954 .34487 L
.45954 .34487 L
.45953 .34488 L
.45953 .34489 L
.45953 .34489 L
.45952 .3449 L
.45952 .34491 L
.45952 .34492 L
.45951 .34492 L
.45951 .34493 L
.45951 .34494 L
.45951 .34494 L
.4595 .34495 L
.4595 .34496 L
.4595 .34497 L
.45949 .34497 L
.45949 .34498 L
.45949 .34499 L
.45948 .34499 L
.45948 .345 L
.45948 .34501 L
.45948 .34501 L
.45947 .34502 L
.45947 .34503 L
.45947 .34504 L
.45946 .34504 L
.45946 .34505 L
.45946 .34506 L
.45945 .34506 L
.45945 .34507 L
.45945 .34508 L
.45945 .34508 L
.45944 .34509 L
.45944 .3451 L
.45944 .34511 L
.45943 .34511 L
.45943 .34512 L
.45943 .34513 L
.45942 .34513 L
.45942 .34514 L
.45942 .34515 L
.45941 .34515 L
Mistroke
.45941 .34516 L
.45941 .34517 L
.4594 .34518 L
.4594 .34518 L
.4594 .34519 L
.4594 .3452 L
.45939 .3452 L
.45939 .34521 L
.45939 .34522 L
.45938 .34522 L
.45938 .34523 L
.45938 .34524 L
.45937 .34525 L
.45937 .34525 L
.45937 .34526 L
.45936 .34527 L
.45936 .34527 L
.45936 .34528 L
.45935 .34529 L
.45935 .34529 L
.45935 .3453 L
.45934 .34531 L
.45934 .34531 L
.45934 .34532 L
.45933 .34533 L
.45933 .34534 L
.45933 .34534 L
.45932 .34535 L
.45932 .34536 L
.45932 .34536 L
.45931 .34537 L
.45931 .34538 L
.45931 .34538 L
.4593 .34539 L
.4593 .3454 L
.4593 .3454 L
.45929 .34541 L
.45929 .34542 L
.45929 .34543 L
.45928 .34543 L
.45928 .34544 L
.45928 .34545 L
.45927 .34545 L
.45927 .34546 L
.45927 .34547 L
.45926 .34547 L
.45926 .34548 L
.45926 .34549 L
.45925 .34549 L
.45925 .3455 L
Mistroke
.45925 .34551 L
.45924 .34551 L
.45924 .34552 L
.45924 .34553 L
.45923 .34553 L
.45923 .34554 L
.45923 .34555 L
.45922 .34556 L
.45922 .34556 L
.45922 .34557 L
.45921 .34558 L
.45921 .34558 L
.45921 .34559 L
.4592 .3456 L
.4592 .3456 L
.45919 .34561 L
.45919 .34562 L
.45919 .34562 L
.45918 .34563 L
.45918 .34564 L
.45918 .34564 L
.45917 .34565 L
.45917 .34566 L
.45917 .34566 L
.45916 .34567 L
.45916 .34568 L
.45916 .34568 L
.45915 .34569 L
.45915 .3457 L
.45915 .3457 L
.45914 .34571 L
.45914 .34572 L
.45913 .34572 L
.45913 .34573 L
.45913 .34574 L
.45912 .34574 L
.45912 .34575 L
.45912 .34576 L
.45911 .34576 L
.45911 .34577 L
.45911 .34578 L
.4591 .34578 L
.4591 .34579 L
.45909 .3458 L
.45909 .34581 L
.45909 .34581 L
.45908 .34582 L
.45908 .34583 L
.45908 .34583 L
.45907 .34584 L
Mistroke
.45907 .34585 L
.45907 .34585 L
.45906 .34586 L
.45906 .34587 L
.45905 .34587 L
.45905 .34588 L
.45905 .34589 L
.45904 .34589 L
.45904 .3459 L
.45904 .3459 L
.45903 .34591 L
.45903 .34592 L
.45903 .34592 L
.45902 .34593 L
.45902 .34594 L
.45901 .34594 L
.45901 .34595 L
.45901 .34596 L
.459 .34596 L
.459 .34597 L
.459 .34598 L
.45899 .34598 L
.45899 .34599 L
.45898 .346 L
.45898 .346 L
.45898 .34601 L
.45897 .34602 L
.45897 .34602 L
.45896 .34603 L
.45896 .34604 L
.45896 .34604 L
.45895 .34605 L
.45895 .34606 L
.45895 .34606 L
.45894 .34607 L
.45894 .34608 L
.45893 .34608 L
.45893 .34609 L
.45893 .3461 L
.45892 .3461 L
.45892 .34611 L
.45892 .34612 L
.45891 .34612 L
.45891 .34613 L
.4589 .34614 L
.4589 .34614 L
.4589 .34615 L
.45889 .34615 L
.45889 .34616 L
.45888 .34617 L
Mistroke
.45888 .34617 L
.45888 .34618 L
.45887 .34619 L
.45887 .34619 L
.45886 .3462 L
.45886 .34621 L
.45886 .34621 L
.45885 .34622 L
.45885 .34623 L
.45885 .34623 L
.45884 .34624 L
.45884 .34625 L
.45883 .34625 L
.45883 .34626 L
.45883 .34626 L
.45882 .34627 L
.45882 .34628 L
.45881 .34628 L
.45881 .34629 L
.45881 .3463 L
.4588 .3463 L
.4588 .34631 L
.45879 .34632 L
.45879 .34632 L
.45879 .34633 L
.45878 .34634 L
.45878 .34634 L
.45877 .34635 L
.45877 .34635 L
.45877 .34636 L
.45876 .34637 L
.45876 .34637 L
.45875 .34638 L
.45875 .34639 L
.45875 .34639 L
.45874 .3464 L
.45874 .34641 L
.45873 .34641 L
.45873 .34642 L
.45873 .34642 L
.45872 .34643 L
.45872 .34644 L
.45871 .34644 L
.45871 .34645 L
.45871 .34646 L
.4587 .34646 L
.4587 .34647 L
.45869 .34648 L
.45869 .34648 L
.45869 .34649 L
Mistroke
.45868 .34649 L
.45868 .3465 L
.45867 .34651 L
.45867 .34651 L
.45866 .34652 L
.45866 .34653 L
.45866 .34653 L
.45865 .34654 L
.45865 .34654 L
.45864 .34655 L
.45864 .34656 L
.45864 .34656 L
.45863 .34657 L
.45863 .34658 L
.45862 .34658 L
.45862 .34659 L
.45862 .34659 L
.45861 .3466 L
.45861 .34661 L
.4586 .34661 L
.4586 .34662 L
.45859 .34663 L
.45859 .34663 L
.45859 .34664 L
.45858 .34664 L
.45858 .34665 L
.45857 .34666 L
.45857 .34666 L
.45857 .34667 L
.45856 .34668 L
.45856 .34668 L
.45855 .34669 L
.45855 .34669 L
.45854 .3467 L
.45854 .34671 L
.45854 .34671 L
.45853 .34672 L
.45853 .34672 L
.45852 .34673 L
.45852 .34674 L
.45851 .34674 L
.45851 .34675 L
.45851 .34676 L
.4585 .34676 L
.4585 .34677 L
.45849 .34677 L
.45849 .34678 L
.45849 .34679 L
.45848 .34679 L
.45848 .3468 L
Mistroke
.45847 .3468 L
.45847 .34681 L
.45846 .34682 L
.45846 .34682 L
.45846 .34683 L
.45845 .34683 L
.45845 .34684 L
.45844 .34685 L
.45844 .34685 L
.45843 .34686 L
.45843 .34687 L
.45843 .34687 L
.45842 .34688 L
.45842 .34688 L
.45841 .34689 L
.45841 .3469 L
.4584 .3469 L
.4584 .34691 L
.4584 .34691 L
.45839 .34692 L
.45839 .34693 L
.45838 .34693 L
.45838 .34694 L
.45837 .34694 L
.45837 .34695 L
.45836 .34696 L
.45836 .34696 L
.45836 .34697 L
.45835 .34697 L
.45835 .34698 L
.45834 .34699 L
.45834 .34699 L
.45833 .347 L
.45833 .347 L
.45833 .34701 L
.45832 .34702 L
.45832 .34702 L
.45831 .34703 L
.45831 .34703 L
.4583 .34704 L
.4583 .34705 L
.45829 .34705 L
.45829 .34706 L
.45829 .34706 L
.45828 .34707 L
.45828 .34707 L
.45827 .34708 L
.45827 .34709 L
.45826 .34709 L
.45826 .3471 L
Mistroke
.45826 .3471 L
.45825 .34711 L
.45825 .34712 L
.45824 .34712 L
.45824 .34713 L
.45823 .34713 L
.45823 .34714 L
.45822 .34715 L
.45822 .34715 L
.45822 .34716 L
.45821 .34716 L
.45821 .34717 L
.4582 .34718 L
.4582 .34718 L
.45819 .34719 L
.45819 .34719 L
.45818 .3472 L
.45818 .3472 L
.45818 .34721 L
.45817 .34722 L
.45817 .34722 L
.45816 .34723 L
.45816 .34723 L
.45815 .34724 L
.45815 .34724 L
.45814 .34725 L
.45814 .34726 L
.45813 .34726 L
.45813 .34727 L
.45813 .34727 L
.45812 .34728 L
.45812 .34729 L
.45811 .34729 L
.45811 .3473 L
.4581 .3473 L
.4581 .34731 L
.45809 .34731 L
.45809 .34732 L
.45809 .34733 L
.45808 .34733 L
.45808 .34734 L
.45807 .34734 L
.45807 .34735 L
.45806 .34735 L
.45806 .34736 L
.45805 .34737 L
.45805 .34737 L
.45804 .34738 L
.45804 .34738 L
.45804 .34739 L
Mistroke
.45803 .34739 L
.45803 .3474 L
.45802 .34741 L
.45802 .34741 L
.45801 .34742 L
.45801 .34742 L
.458 .34743 L
.458 .34743 L
.45799 .34744 L
.45799 .34745 L
.45799 .34745 L
.45798 .34746 L
.45798 .34746 L
.45797 .34747 L
.45797 .34747 L
.45796 .34748 L
.45796 .34748 L
.45795 .34749 L
.45795 .3475 L
.45794 .3475 L
.45794 .34751 L
.45793 .34751 L
.45793 .34752 L
.45793 .34752 L
.45792 .34753 L
.45792 .34753 L
.45791 .34754 L
.45791 .34755 L
.4579 .34755 L
.4579 .34756 L
.45789 .34756 L
.45789 .34757 L
.45788 .34757 L
.45788 .34758 L
.45787 .34758 L
.45787 .34759 L
.45787 .3476 L
.45786 .3476 L
.45786 .34761 L
.45785 .34761 L
.45785 .34762 L
.45784 .34762 L
.45784 .34763 L
.45783 .34763 L
.45783 .34764 L
.45782 .34765 L
.45782 .34765 L
.45781 .34766 L
.45781 .34766 L
.4578 .34767 L
Mistroke
.4578 .34767 L
.4578 .34768 L
.45779 .34768 L
.45779 .34769 L
.45778 .34769 L
.45778 .3477 L
.45777 .34771 L
.45777 .34771 L
.45776 .34772 L
.45776 .34772 L
.45775 .34773 L
.45775 .34773 L
.45774 .34774 L
.45774 .34774 L
.45773 .34775 L
.45773 .34775 L
.45773 .34776 L
.45772 .34777 L
.45772 .34777 L
.45771 .34778 L
.45771 .34778 L
.4577 .34779 L
.4577 .34779 L
.45769 .3478 L
.45769 .3478 L
.45768 .34781 L
.45768 .34781 L
.45767 .34782 L
.45767 .34782 L
.45766 .34783 L
.45766 .34783 L
.45765 .34784 L
.45765 .34785 L
.45764 .34785 L
.45764 .34786 L
.45764 .34786 L
.45763 .34787 L
.45763 .34787 L
.45762 .34788 L
.45762 .34788 L
.45761 .34789 L
.45761 .34789 L
.4576 .3479 L
.4576 .3479 L
.45759 .34791 L
.45759 .34791 L
.45758 .34792 L
.45758 .34792 L
.45757 .34793 L
.45757 .34794 L
Mistroke
.45756 .34794 L
.45756 .34795 L
.45755 .34795 L
.45755 .34796 L
.45754 .34796 L
.45754 .34797 L
.45754 .34797 L
.45753 .34798 L
.45753 .34798 L
.45752 .34799 L
.45752 .34799 L
.45751 .348 L
.45751 .348 L
.4575 .34801 L
.4575 .34801 L
.45749 .34802 L
.45749 .34802 L
.45748 .34803 L
.45748 .34803 L
.45747 .34804 L
.45747 .34804 L
.45746 .34805 L
.45746 .34805 L
.45745 .34806 L
.45745 .34806 L
.45744 .34807 L
.45744 .34808 L
.45743 .34808 L
.45743 .34809 L
.45742 .34809 L
.45742 .3481 L
.45742 .3481 L
.45741 .34811 L
.45741 .34811 L
.4574 .34812 L
.4574 .34812 L
.45739 .34813 L
.45739 .34813 L
.45738 .34814 L
.45738 .34814 L
.45737 .34815 L
.45737 .34815 L
.45736 .34816 L
.45736 .34816 L
.45735 .34817 L
.45735 .34817 L
.45734 .34818 L
.45734 .34818 L
.45733 .34819 L
.45733 .34819 L
Mistroke
.45732 .3482 L
.45732 .3482 L
.45731 .34821 L
.45731 .34821 L
.4573 .34822 L
.4573 .34822 L
.45729 .34823 L
.45729 .34823 L
.45728 .34824 L
.45728 .34824 L
.45727 .34825 L
.45727 .34825 L
.45727 .34826 L
.45726 .34826 L
.45726 .34827 L
.45725 .34827 L
.45725 .34828 L
.45724 .34828 L
.45724 .34829 L
.45723 .34829 L
.45723 .3483 L
.45722 .3483 L
.45722 .34831 L
.45721 .34831 L
.45721 .34832 L
.4572 .34832 L
.4572 .34833 L
.45719 .34833 L
.45719 .34834 L
.45718 .34834 L
.45718 .34834 L
.45717 .34835 L
.45717 .34835 L
.45716 .34836 L
.45716 .34836 L
.45715 .34837 L
.45715 .34837 L
.45714 .34838 L
.45714 .34838 L
.45713 .34839 L
.45713 .34839 L
.45712 .3484 L
.45712 .3484 L
.45711 .34841 L
.45711 .34841 L
.4571 .34842 L
.4571 .34842 L
.45709 .34843 L
.45709 .34843 L
.45708 .34844 L
Mistroke
.45708 .34844 L
.45707 .34845 L
.45707 .34845 L
.45706 .34846 L
.45706 .34846 L
.45705 .34846 L
.45705 .34847 L
.45705 .34847 L
.45704 .34848 L
.45704 .34848 L
.45703 .34849 L
.45703 .34849 L
.45702 .3485 L
.45702 .3485 L
.45701 .34851 L
.45701 .34851 L
.457 .34852 L
.457 .34852 L
.45699 .34853 L
.45699 .34853 L
.45698 .34854 L
.45698 .34854 L
.45697 .34854 L
.45697 .34855 L
.45696 .34855 L
.45696 .34856 L
.45695 .34856 L
.45695 .34857 L
.45694 .34857 L
.45694 .34858 L
.45693 .34858 L
.45693 .34859 L
.45692 .34859 L
.45692 .3486 L
.45691 .3486 L
.45691 .34861 L
.4569 .34861 L
.4569 .34861 L
.45689 .34862 L
.45689 .34862 L
.45688 .34863 L
.45688 .34863 L
.45687 .34864 L
.45687 .34864 L
.45686 .34865 L
.45686 .34865 L
.45685 .34866 L
.45685 .34866 L
.45684 .34866 L
.45684 .34867 L
Mistroke
.45683 .34867 L
.45683 .34868 L
.45682 .34868 L
.45682 .34869 L
.45681 .34869 L
.45681 .3487 L
.4568 .3487 L
.4568 .34871 L
.45679 .34871 L
.45679 .34871 L
.45678 .34872 L
.45678 .34872 L
.45677 .34873 L
.45677 .34873 L
.45676 .34874 L
.45676 .34874 L
.45675 .34875 L
.45675 .34875 L
.45674 .34875 L
.45674 .34876 L
.45673 .34876 L
.45673 .34877 L
.45672 .34877 L
.45672 .34878 L
.45671 .34878 L
.45671 .34879 L
.4567 .34879 L
.4567 .34879 L
.45669 .3488 L
.45669 .3488 L
.45668 .34881 L
.45668 .34881 L
.45667 .34882 L
.45667 .34882 L
.45666 .34883 L
.45666 .34883 L
.45665 .34883 L
.45665 .34884 L
.45664 .34884 L
.45664 .34885 L
.45663 .34885 L
.45663 .34886 L
.45662 .34886 L
.45662 .34886 L
.45661 .34887 L
.45661 .34887 L
.4566 .34888 L
.4566 .34888 L
.45659 .34889 L
.45659 .34889 L
Mistroke
.45658 .34889 L
.45658 .3489 L
.45657 .3489 L
.45657 .34891 L
.45656 .34891 L
.45656 .34892 L
.45655 .34892 L
.45655 .34892 L
.45654 .34893 L
.45654 .34893 L
.45653 .34894 L
.45653 .34894 L
.45653 .34895 L
.45652 .34895 L
.45652 .34895 L
.45651 .34896 L
.45651 .34896 L
.4565 .34897 L
.4565 .34897 L
.45649 .34898 L
.45649 .34898 L
.45648 .34898 L
.45648 .34899 L
.45647 .34899 L
.45647 .349 L
.45646 .349 L
.45646 .349 L
.45645 .34901 L
.45645 .34901 L
.45644 .34902 L
.45644 .34902 L
.45643 .34903 L
.45643 .34903 L
.45642 .34903 L
.45642 .34904 L
.45641 .34904 L
.45641 .34905 L
.4564 .34905 L
.4564 .34905 L
.45639 .34906 L
.45639 .34906 L
.45638 .34907 L
.45638 .34907 L
.45637 .34907 L
.45637 .34908 L
.45636 .34908 L
.45636 .34909 L
.45635 .34909 L
.45635 .34909 L
.45634 .3491 L
Mistroke
.45634 .3491 L
.45633 .34911 L
.45633 .34911 L
.45632 .34912 L
.45632 .34912 L
.45631 .34912 L
.45631 .34913 L
.4563 .34913 L
.4563 .34914 L
.45629 .34914 L
.45629 .34914 L
.45628 .34915 L
.45628 .34915 L
.45627 .34916 L
.45627 .34916 L
.45626 .34916 L
.45626 .34917 L
.45625 .34917 L
.45625 .34918 L
.45624 .34918 L
.45624 .34918 L
.45623 .34919 L
.45623 .34919 L
.45622 .34919 L
.45622 .3492 L
.45621 .3492 L
.45621 .34921 L
.4562 .34921 L
.4562 .34921 L
.45619 .34922 L
.45619 .34922 L
.45618 .34923 L
.45618 .34923 L
.45617 .34923 L
.45617 .34924 L
.45616 .34924 L
.45616 .34925 L
.45615 .34925 L
.45615 .34925 L
.45614 .34926 L
.45614 .34926 L
.45613 .34927 L
.45613 .34927 L
.45612 .34927 L
.45612 .34928 L
.45611 .34928 L
.45611 .34928 L
.4561 .34929 L
.4561 .34929 L
.45609 .3493 L
Mistroke
.45609 .3493 L
.45608 .3493 L
.45608 .34931 L
.45607 .34931 L
.45607 .34931 L
.45606 .34932 L
.45606 .34932 L
.45605 .34933 L
.45605 .34933 L
.45604 .34933 L
.45604 .34934 L
.45603 .34934 L
.45603 .34934 L
.45602 .34935 L
.45602 .34935 L
.45601 .34936 L
.45601 .34936 L
.456 .34936 L
.456 .34937 L
.45599 .34937 L
.45599 .34937 L
.45598 .34938 L
.45598 .34938 L
.45597 .34939 L
.45597 .34939 L
.45596 .34939 L
.45596 .3494 L
.45595 .3494 L
.45595 .3494 L
.45594 .34941 L
.45594 .34941 L
.45593 .34942 L
.45593 .34942 L
.45592 .34942 L
.45592 .34943 L
.45591 .34943 L
.45591 .34943 L
.4559 .34944 L
.4559 .34944 L
.45589 .34944 L
.45589 .34945 L
.45588 .34945 L
.45588 .34946 L
.45587 .34946 L
.45587 .34946 L
.45586 .34947 L
.45586 .34947 L
.45585 .34947 L
.45585 .34948 L
.45584 .34948 L
Mistroke
.45584 .34948 L
.45583 .34949 L
.45583 .34949 L
.45582 .34949 L
.45582 .3495 L
.45581 .3495 L
.45581 .34951 L
.4558 .34951 L
.4558 .34951 L
.45579 .34952 L
.45579 .34952 L
.45578 .34952 L
.45578 .34953 L
.45577 .34953 L
.45577 .34953 L
.45576 .34954 L
.45576 .34954 L
.45575 .34954 L
.45575 .34955 L
.45574 .34955 L
.45574 .34955 L
.45573 .34956 L
.45573 .34956 L
.45572 .34956 L
.45572 .34957 L
.45571 .34957 L
.45571 .34958 L
.4557 .34958 L
.4557 .34958 L
.45569 .34959 L
.45569 .34959 L
.45568 .34959 L
.45568 .3496 L
.45567 .3496 L
.45567 .3496 L
.45566 .34961 L
.45566 .34961 L
.45565 .34961 L
.45565 .34962 L
.45564 .34962 L
.45564 .34962 L
.45563 .34963 L
.45563 .34963 L
.45562 .34963 L
.45562 .34964 L
.45561 .34964 L
.45561 .34964 L
.45561 .34965 L
.4556 .34965 L
.4556 .34965 L
Mistroke
.45559 .34966 L
.45559 .34966 L
.45558 .34966 L
.45558 .34967 L
.45557 .34967 L
.45557 .34967 L
.45556 .34968 L
.45556 .34968 L
.45555 .34968 L
.45555 .34969 L
.45554 .34969 L
.45554 .34969 L
.45553 .3497 L
.45553 .3497 L
.45552 .3497 L
.45552 .34971 L
.45551 .34971 L
.45551 .34971 L
.4555 .34972 L
.4555 .34972 L
.45549 .34972 L
.45549 .34973 L
.45548 .34973 L
.45548 .34973 L
.45547 .34973 L
.45547 .34974 L
.45546 .34974 L
.45546 .34974 L
.45545 .34975 L
.45545 .34975 L
.45544 .34975 L
.45544 .34976 L
.45543 .34976 L
.45543 .34976 L
.45542 .34977 L
.45542 .34977 L
.45541 .34977 L
.45541 .34978 L
.4554 .34978 L
.4554 .34978 L
.45539 .34979 L
.45539 .34979 L
.45538 .34979 L
.45538 .34979 L
.45537 .3498 L
.45537 .3498 L
.45536 .3498 L
.45536 .34981 L
.45535 .34981 L
.45535 .34981 L
Mistroke
.45535 .34982 L
.45534 .34982 L
.45534 .34982 L
.45533 .34983 L
.45533 .34983 L
.45532 .34983 L
.45532 .34984 L
.45531 .34984 L
.45531 .34984 L
.4553 .34984 L
.4553 .34985 L
.45529 .34985 L
.45529 .34985 L
.45528 .34986 L
.45528 .34986 L
.45527 .34986 L
.45527 .34987 L
.45526 .34987 L
.45526 .34987 L
.45525 .34987 L
.45525 .34988 L
.45524 .34988 L
.45524 .34988 L
.45523 .34989 L
.45523 .34989 L
.45522 .34989 L
.45522 .3499 L
.45521 .3499 L
.45521 .3499 L
.4552 .3499 L
.4552 .34991 L
.45519 .34991 L
.45519 .34991 L
.45518 .34992 L
.45518 .34992 L
.45517 .34992 L
.45517 .34992 L
.45517 .34993 L
.45516 .34993 L
.45516 .34993 L
.45515 .34994 L
.45515 .34994 L
.45514 .34994 L
.45514 .34995 L
.45513 .34995 L
.45513 .34995 L
.45512 .34995 L
.45512 .34996 L
.45511 .34996 L
.45511 .34996 L
Mistroke
.4551 .34997 L
.4551 .34997 L
.45509 .34997 L
.45509 .34997 L
.45508 .34998 L
.45508 .34998 L
.45507 .34998 L
.45507 .34998 L
.45506 .34999 L
.45506 .34999 L
.45505 .34999 L
.45505 .35 L
.45504 .35 L
.45504 .35 L
.45503 .35 L
.45503 .35001 L
.45503 .35001 L
.45502 .35001 L
.45502 .35002 L
.45501 .35002 L
.45501 .35002 L
.455 .35002 L
.455 .35003 L
.45499 .35003 L
.45499 .35003 L
.45498 .35003 L
.45498 .35004 L
.45497 .35004 L
.45497 .35004 L
.45496 .35005 L
.45496 .35005 L
.45495 .35005 L
.45495 .35005 L
.45494 .35006 L
.45494 .35006 L
.45493 .35006 L
.45493 .35006 L
.45492 .35007 L
.45492 .35007 L
.45492 .35007 L
.45491 .35008 L
.45491 .35008 L
.4549 .35008 L
.4549 .35008 L
.45489 .35009 L
.45489 .35009 L
.45488 .35009 L
.45488 .35009 L
.45487 .3501 L
.45487 .3501 L
Mistroke
.45486 .3501 L
.45486 .3501 L
.45485 .35011 L
.45485 .35011 L
.45484 .35011 L
.45484 .35011 L
.45483 .35012 L
.45483 .35012 L
.45482 .35012 L
.45482 .35013 L
.45482 .35013 L
.45481 .35013 L
.45481 .35013 L
.4548 .35014 L
.4548 .35014 L
.45479 .35014 L
.45479 .35014 L
.45478 .35015 L
.45478 .35015 L
.45477 .35015 L
.45477 .35015 L
.45476 .35016 L
.45476 .35016 L
.45475 .35016 L
.45475 .35016 L
.45474 .35017 L
.45474 .35017 L
.45473 .35017 L
.45473 .35017 L
.45473 .35018 L
.45472 .35018 L
.45472 .35018 L
.45471 .35018 L
.45471 .35019 L
.4547 .35019 L
.4547 .35019 L
.45469 .35019 L
.45469 .3502 L
.45468 .3502 L
.45468 .3502 L
.45467 .3502 L
.45467 .35021 L
.45466 .35021 L
.45466 .35021 L
.45466 .35021 L
.45465 .35021 L
.45465 .35022 L
.45464 .35022 L
.45464 .35022 L
.45463 .35022 L
Mistroke
.45463 .35023 L
.45462 .35023 L
.45462 .35023 L
.45461 .35023 L
.45461 .35024 L
.4546 .35024 L
.4546 .35024 L
.45459 .35024 L
.45459 .35025 L
.45459 .35025 L
.45458 .35025 L
.45458 .35025 L
.45457 .35026 L
.45457 .35026 L
.45456 .35026 L
.45456 .35026 L
.45455 .35026 L
.45455 .35027 L
.45454 .35027 L
.45454 .35027 L
.45453 .35027 L
.45453 .35028 L
.45452 .35028 L
.45452 .35028 L
.45452 .35028 L
.45451 .35029 L
.45451 .35029 L
.4545 .35029 L
.4545 .35029 L
.45449 .35029 L
.45449 .3503 L
.45448 .3503 L
.45448 .3503 L
.45447 .3503 L
.45447 .35031 L
.45446 .35031 L
.45446 .35031 L
.45446 .35031 L
.45445 .35031 L
.45445 .35032 L
.45444 .35032 L
.45444 .35032 L
.45443 .35032 L
.45443 .35033 L
.45442 .35033 L
.45442 .35033 L
.45441 .35033 L
.45441 .35033 L
.4544 .35034 L
.4544 .35034 L
Mistroke
.4544 .35034 L
.45439 .35034 L
.45439 .35034 L
.45438 .35035 L
.45438 .35035 L
.45437 .35035 L
.45437 .35035 L
.45436 .35036 L
.45436 .35036 L
.45435 .35036 L
.45435 .35036 L
.45435 .35036 L
.45434 .35037 L
.45434 .35037 L
.45433 .35037 L
.45433 .35037 L
.45432 .35037 L
.45432 .35038 L
.45431 .35038 L
.45431 .35038 L
.4543 .35038 L
.4543 .35038 L
.4543 .35039 L
.45429 .35039 L
.45429 .35039 L
.45428 .35039 L
.45428 .35039 L
.45427 .3504 L
.45427 .3504 L
.45426 .3504 L
.45426 .3504 L
.45425 .35041 L
.45425 .35041 L
.45425 .35041 L
.45424 .35041 L
.45424 .35041 L
.45423 .35042 L
.45423 .35042 L
.45422 .35042 L
.45422 .35042 L
.45421 .35042 L
.45421 .35043 L
.4542 .35043 L
.4542 .35043 L
.4542 .35043 L
.45419 .35043 L
.45419 .35043 L
.45418 .35044 L
.45418 .35044 L
.45417 .35044 L
Mistroke
.45417 .35044 L
.45416 .35044 L
.45416 .35045 L
.45416 .35045 L
.45415 .35045 L
.45415 .35045 L
.45414 .35045 L
.45414 .35046 L
.45413 .35046 L
.45413 .35046 L
.45412 .35046 L
.45412 .35046 L
.45412 .35047 L
.45411 .35047 L
.45411 .35047 L
.4541 .35047 L
.4541 .35047 L
.45409 .35048 L
.45409 .35048 L
.45408 .35048 L
.45408 .35048 L
.45408 .35048 L
.45407 .35048 L
.45407 .35049 L
.45406 .35049 L
.45406 .35049 L
.45405 .35049 L
.45405 .35049 L
.45404 .3505 L
.45404 .3505 L
.45404 .3505 L
.45403 .3505 L
.45403 .3505 L
.45402 .3505 L
.45402 .35051 L
.45401 .35051 L
.45401 .35051 L
.454 .35051 L
.454 .35051 L
.454 .35051 L
.45399 .35052 L
.45399 .35052 L
.45398 .35052 L
.45398 .35052 L
.45397 .35052 L
.45397 .35053 L
.45396 .35053 L
.45396 .35053 L
.45396 .35053 L
.45395 .35053 L
Mistroke
.45395 .35053 L
.45394 .35054 L
.45394 .35054 L
.45393 .35054 L
.45393 .35054 L
.45393 .35054 L
.45392 .35054 L
.45392 .35055 L
.45391 .35055 L
.45391 .35055 L
.4539 .35055 L
.4539 .35055 L
.4539 .35055 L
.45389 .35056 L
.45389 .35056 L
.45388 .35056 L
.45388 .35056 L
.45387 .35056 L
.45387 .35056 L
.45386 .35057 L
.45386 .35057 L
.45386 .35057 L
.45385 .35057 L
.45385 .35057 L
.45384 .35057 L
.45384 .35058 L
.45383 .35058 L
.45383 .35058 L
.45383 .35058 L
.45382 .35058 L
.45382 .35058 L
.45381 .35059 L
.45381 .35059 L
.4538 .35059 L
.4538 .35059 L
.4538 .35059 L
.45379 .35059 L
.45379 .35059 L
.45378 .3506 L
.45378 .3506 L
.45377 .3506 L
.45377 .3506 L
.45377 .3506 L
.45376 .3506 L
.45376 .35061 L
.45375 .35061 L
.45375 .35061 L
.45374 .35061 L
.45374 .35061 L
.45374 .35061 L
Mistroke
.45373 .35061 L
.45373 .35062 L
.45372 .35062 L
.45372 .35062 L
.45371 .35062 L
.45371 .35062 L
.45371 .35062 L
.4537 .35063 L
.4537 .35063 L
.45369 .35063 L
.45369 .35063 L
.45368 .35063 L
.45368 .35063 L
.45368 .35063 L
.45367 .35064 L
.45367 .35064 L
.45366 .35064 L
.45366 .35064 L
.45366 .35064 L
.45365 .35064 L
.45365 .35064 L
.45364 .35065 L
.45364 .35065 L
.45363 .35065 L
.45363 .35065 L
.45363 .35065 L
.45362 .35065 L
.45362 .35065 L
.45361 .35066 L
.45361 .35066 L
.4536 .35066 L
.4536 .35066 L
.4536 .35066 L
.45359 .35066 L
.45359 .35066 L
.45358 .35066 L
.45358 .35067 L
.45358 .35067 L
.45357 .35067 L
.45357 .35067 L
.45356 .35067 L
.45356 .35067 L
.45355 .35067 L
.45355 .35068 L
.45355 .35068 L
.45354 .35068 L
.45354 .35068 L
.45353 .35068 L
.45353 .35068 L
.45353 .35068 L
Mistroke
.45352 .35068 L
.45352 .35069 L
.45351 .35069 L
.45351 .35069 L
.45351 .35069 L
.4535 .35069 L
.4535 .35069 L
.45349 .35069 L
.45349 .3507 L
.45348 .3507 L
.45348 .3507 L
.45348 .3507 L
.45347 .3507 L
.45347 .3507 L
.45346 .3507 L
.45346 .3507 L
.45346 .35071 L
.45345 .35071 L
.45345 .35071 L
.45344 .35071 L
.45344 .35071 L
.45344 .35071 L
.45343 .35071 L
.45343 .35071 L
.45342 .35071 L
.45342 .35072 L
.45341 .35072 L
.45341 .35072 L
.45341 .35072 L
.4534 .35072 L
.4534 .35072 L
.45339 .35072 L
.45339 .35072 L
.45339 .35073 L
.45338 .35073 L
.45338 .35073 L
.45337 .35073 L
.45337 .35073 L
.45337 .35073 L
.45336 .35073 L
.45336 .35073 L
.45335 .35073 L
.45335 .35074 L
.45335 .35074 L
.45334 .35074 L
.45334 .35074 L
.45333 .35074 L
.45333 .35074 L
.45333 .35074 L
.45332 .35074 L
Mistroke
.45332 .35074 L
.45331 .35075 L
.45331 .35075 L
.45331 .35075 L
.4533 .35075 L
.4533 .35075 L
.45329 .35075 L
.45329 .35075 L
.45329 .35075 L
.45328 .35075 L
.45328 .35076 L
.45327 .35076 L
.45327 .35076 L
.45327 .35076 L
.45326 .35076 L
.45326 .35076 L
.45325 .35076 L
.45325 .35076 L
.45325 .35076 L
.45324 .35077 L
.45324 .35077 L
.45323 .35077 L
.45323 .35077 L
.45323 .35077 L
.45322 .35077 L
.45322 .35077 L
.45321 .35077 L
.45321 .35077 L
.45321 .35077 L
.4532 .35078 L
.4532 .35078 L
.45319 .35078 L
.45319 .35078 L
.45319 .35078 L
.45318 .35078 L
.45318 .35078 L
.45318 .35078 L
.45317 .35078 L
.45317 .35078 L
.45316 .35078 L
.45316 .35079 L
.45316 .35079 L
.45315 .35079 L
.45315 .35079 L
.45314 .35079 L
.45314 .35079 L
.45314 .35079 L
.45313 .35079 L
.45313 .35079 L
.45312 .35079 L
Mistroke
.45312 .3508 L
.45312 .3508 L
.45311 .3508 L
.45311 .3508 L
.45311 .3508 L
.4531 .3508 L
.4531 .3508 L
.45309 .3508 L
.45309 .3508 L
.45309 .3508 L
.45308 .3508 L
.45308 .3508 L
.45307 .35081 L
.45307 .35081 L
.45307 .35081 L
.45306 .35081 L
.45306 .35081 L
.45306 .35081 L
.45305 .35081 L
.45305 .35081 L
.45304 .35081 L
.45304 .35081 L
.45304 .35081 L
.45303 .35081 L
.45303 .35082 L
.45302 .35082 L
.45302 .35082 L
.45302 .35082 L
.45301 .35082 L
.45301 .35082 L
.45301 .35082 L
.453 .35082 L
.453 .35082 L
.45299 .35082 L
.45299 .35082 L
.45299 .35082 L
.45298 .35083 L
.45298 .35083 L
.45298 .35083 L
.45297 .35083 L
.45297 .35083 L
.45296 .35083 L
.45296 .35083 L
.45296 .35083 L
.45295 .35083 L
.45295 .35083 L
.45295 .35083 L
.45294 .35083 L
.45294 .35083 L
.45293 .35084 L
Mistroke
.45293 .35084 L
.45293 .35084 L
.45292 .35084 L
.45292 .35084 L
.45292 .35084 L
.45291 .35084 L
.45291 .35084 L
.4529 .35084 L
.4529 .35084 L
.4529 .35084 L
.45289 .35084 L
.45289 .35084 L
.45289 .35084 L
.45288 .35084 L
.45288 .35085 L
.45287 .35085 L
.45287 .35085 L
.45287 .35085 L
.45286 .35085 L
.45286 .35085 L
.45286 .35085 L
.45285 .35085 L
.45285 .35085 L
.45285 .35085 L
.45284 .35085 L
.45284 .35085 L
.45283 .35085 L
.45283 .35085 L
.45283 .35085 L
.45282 .35086 L
.45282 .35086 L
.45282 .35086 L
.45281 .35086 L
.45281 .35086 L
.45281 .35086 L
.4528 .35086 L
.4528 .35086 L
.45279 .35086 L
.45279 .35086 L
.45279 .35086 L
.45278 .35086 L
.45278 .35086 L
.45278 .35086 L
.45277 .35086 L
.45277 .35086 L
.45277 .35086 L
.45276 .35087 L
.45276 .35087 L
.45275 .35087 L
.45275 .35087 L
Mistroke
.45275 .35087 L
.45274 .35087 L
.45274 .35087 L
.45274 .35087 L
.45273 .35087 L
.45273 .35087 L
.45273 .35087 L
.45272 .35087 L
.45272 .35087 L
.45272 .35087 L
.45271 .35087 L
.45271 .35087 L
.4527 .35087 L
.4527 .35087 L
.4527 .35087 L
.45269 .35087 L
.45269 .35088 L
.45269 .35088 L
.45268 .35088 L
.45268 .35088 L
.45268 .35088 L
.45267 .35088 L
.45267 .35088 L
.45267 .35088 L
.45266 .35088 L
.45266 .35088 L
.45266 .35088 L
.45265 .35088 L
.45265 .35088 L
.45264 .35088 L
.45264 .35088 L
.45264 .35088 L
.45263 .35088 L
.45263 .35088 L
.45263 .35088 L
.45262 .35088 L
.45262 .35088 L
.45262 .35088 L
.45261 .35089 L
.45261 .35089 L
.45261 .35089 L
.4526 .35089 L
.4526 .35089 L
.4526 .35089 L
.45259 .35089 L
.45259 .35089 L
.45259 .35089 L
.45258 .35089 L
.45258 .35089 L
.45257 .35089 L
Mistroke
.45257 .35089 L
.45257 .35089 L
.45256 .35089 L
.45256 .35089 L
.45256 .35089 L
.45255 .35089 L
.45255 .35089 L
.45255 .35089 L
.45254 .35089 L
.45254 .35089 L
.45254 .35089 L
.45253 .35089 L
.45253 .35089 L
.45253 .35089 L
.45252 .35089 L
.45252 .35089 L
.45252 .3509 L
.45251 .3509 L
.45251 .3509 L
.45251 .3509 L
.4525 .3509 L
.4525 .3509 L
.4525 .3509 L
.45249 .3509 L
.45249 .3509 L
.45249 .3509 L
.45248 .3509 L
.45248 .3509 L
.45248 .3509 L
.45247 .3509 L
.45247 .3509 L
.45247 .3509 L
.45246 .3509 L
.45246 .3509 L
.45246 .3509 L
.45245 .3509 L
.45245 .3509 L
.45245 .3509 L
.45244 .3509 L
.45244 .3509 L
.45244 .3509 L
.45243 .3509 L
.45243 .3509 L
.45243 .3509 L
.45242 .3509 L
.45242 .3509 L
.45242 .3509 L
.45241 .3509 L
.45241 .3509 L
.45241 .3509 L
Mistroke
.4524 .3509 L
.4524 .3509 L
.4524 .3509 L
.45239 .3509 L
.45239 .3509 L
.45239 .3509 L
.45238 .35091 L
.45238 .35091 L
.45238 .35091 L
.45237 .35091 L
.45237 .35091 L
.45237 .35091 L
.45236 .35091 L
.45236 .35091 L
.45236 .35091 L
.45235 .35091 L
.45235 .35091 L
.45235 .35091 L
.45234 .35091 L
.45234 .35091 L
.45234 .35091 L
.45233 .35091 L
.45233 .35091 L
.45233 .35091 L
.45232 .35091 L
.45232 .35091 L
.45232 .35091 L
.45232 .35091 L
.45231 .35091 L
.45231 .35091 L
.45231 .35091 L
.4523 .35091 L
.4523 .35091 L
.4523 .35091 L
.45229 .35091 L
.45229 .35091 L
.45229 .35091 L
.45228 .35091 L
.45228 .35091 L
.45228 .35091 L
.45227 .35091 L
.45227 .35091 L
.45227 .35091 L
.45226 .35091 L
.45226 .35091 L
.45226 .35091 L
.45225 .35091 L
.45225 .35091 L
.45225 .35091 L
.45225 .35091 L
Mistroke
.45224 .35091 L
.45224 .35091 L
.45224 .35091 L
.45223 .35091 L
.45223 .35091 L
.45223 .35091 L
.45222 .35091 L
.45222 .35091 L
.45222 .35091 L
.45221 .35091 L
.45221 .35091 L
.45221 .35091 L
.4522 .35091 L
.4522 .35091 L
.4522 .35091 L
.4522 .35091 L
.45219 .35091 L
.45219 .35091 L
.45219 .35091 L
.45218 .35091 L
.45218 .35091 L
.45218 .35091 L
.45217 .35091 L
.45217 .35091 L
.45217 .35091 L
.45216 .35091 L
.45216 .35091 L
.45216 .35091 L
.45216 .35091 L
.45215 .35091 L
.45215 .35091 L
.45215 .35091 L
.45214 .35091 L
.45214 .35091 L
.45214 .35091 L
.45213 .35091 L
.45213 .35091 L
.45213 .35091 L
.45213 .35091 L
.45212 .35091 L
.45212 .35091 L
.45212 .35091 L
.45211 .35091 L
.45211 .35091 L
.45211 .35091 L
.4521 .35091 L
.4521 .35091 L
.4521 .35091 L
.45209 .35091 L
.45209 .35091 L
Mistroke
.45209 .35091 L
.45209 .35091 L
.45208 .35091 L
.45208 .35091 L
.45208 .35091 L
.45207 .35091 L
.45207 .35091 L
.45207 .35091 L
.45207 .35091 L
.45206 .35091 L
.45206 .35091 L
.45206 .35091 L
.45205 .35091 L
.45205 .35091 L
.45205 .35091 L
.45204 .35091 L
.45204 .35091 L
.45204 .35091 L
.45204 .35091 L
.45203 .35091 L
.45203 .35091 L
.45203 .35091 L
.45202 .35091 L
.45202 .35091 L
.45202 .3509 L
.45202 .3509 L
.45201 .3509 L
.45201 .3509 L
.45201 .3509 L
.452 .3509 L
.452 .3509 L
.452 .3509 L
.45199 .3509 L
.45199 .3509 L
.45199 .3509 L
.45199 .3509 L
.45198 .3509 L
.45198 .3509 L
.45198 .3509 L
.45197 .3509 L
.45197 .3509 L
.45197 .3509 L
.45197 .3509 L
.45196 .3509 L
.45196 .3509 L
.45196 .3509 L
.45195 .3509 L
.45195 .3509 L
.45195 .3509 L
.45195 .3509 L
Mistroke
.45194 .3509 L
.45194 .3509 L
.45194 .3509 L
.45193 .3509 L
.45193 .3509 L
.45193 .3509 L
.45193 .3509 L
.45192 .3509 L
.45192 .3509 L
.45192 .3509 L
.45192 .3509 L
.45191 .3509 L
.45191 .3509 L
.45191 .3509 L
.4519 .3509 L
.4519 .3509 L
.4519 .35089 L
.4519 .35089 L
.45189 .35089 L
.45189 .35089 L
.45189 .35089 L
.45188 .35089 L
.45188 .35089 L
.45188 .35089 L
.45188 .35089 L
.45187 .35089 L
.45187 .35089 L
.45187 .35089 L
.45187 .35089 L
.45186 .35089 L
.45186 .35089 L
.45186 .35089 L
.45185 .35089 L
.45185 .35089 L
.45185 .35089 L
.45185 .35089 L
.45184 .35089 L
.45184 .35089 L
.45184 .35089 L
.45184 .35089 L
.45183 .35089 L
.45183 .35089 L
.45183 .35089 L
.45182 .35089 L
.45182 .35089 L
.45182 .35089 L
.45182 .35088 L
.45181 .35088 L
.45181 .35088 L
.45181 .35088 L
Mistroke
.45181 .35088 L
.4518 .35088 L
.4518 .35088 L
.4518 .35088 L
.4518 .35088 L
.45179 .35088 L
.45179 .35088 L
.45179 .35088 L
.45178 .35088 L
.45178 .35088 L
.45178 .35088 L
.45178 .35088 L
.45177 .35088 L
.45177 .35088 L
.45177 .35088 L
.45177 .35088 L
.45176 .35088 L
.45176 .35088 L
.45176 .35088 L
.45176 .35088 L
.45175 .35088 L
.45175 .35087 L
.45175 .35087 L
.45175 .35087 L
.45174 .35087 L
.45174 .35087 L
.45174 .35087 L
.45173 .35087 L
.45173 .35087 L
.45173 .35087 L
.45173 .35087 L
.45172 .35087 L
.45172 .35087 L
.45172 .35087 L
.45172 .35087 L
.45171 .35087 L
.45171 .35087 L
.45171 .35087 L
.45171 .35087 L
.4517 .35087 L
.4517 .35087 L
.4517 .35087 L
.4517 .35086 L
.45169 .35086 L
.45169 .35086 L
.45169 .35086 L
.45169 .35086 L
.45168 .35086 L
.45168 .35086 L
.45168 .35086 L
Mistroke
.45168 .35086 L
.45167 .35086 L
.45167 .35086 L
.45167 .35086 L
.45167 .35086 L
.45166 .35086 L
.45166 .35086 L
.45166 .35086 L
.45166 .35086 L
.45165 .35086 L
.45165 .35086 L
.45165 .35085 L
.45165 .35085 L
.45164 .35085 L
.45164 .35085 L
.45164 .35085 L
.45164 .35085 L
.45163 .35085 L
.45163 .35085 L
.45163 .35085 L
.45163 .35085 L
.45162 .35085 L
.45162 .35085 L
.45162 .35085 L
.45162 .35085 L
.45161 .35085 L
.45161 .35085 L
.45161 .35085 L
.45161 .35085 L
.4516 .35084 L
.4516 .35084 L
.4516 .35084 L
.4516 .35084 L
.45159 .35084 L
.45159 .35084 L
.45159 .35084 L
.45159 .35084 L
.45158 .35084 L
.45158 .35084 L
.45158 .35084 L
.45158 .35084 L
.45158 .35084 L
.45157 .35084 L
.45157 .35084 L
.45157 .35084 L
.45157 .35084 L
.45156 .35083 L
.45156 .35083 L
.45156 .35083 L
.45156 .35083 L
Mistroke
.45155 .35083 L
.45155 .35083 L
.45155 .35083 L
.45155 .35083 L
.45154 .35083 L
.45154 .35083 L
.45154 .35083 L
.45154 .35083 L
.45154 .35083 L
.45153 .35083 L
.45153 .35083 L
.45153 .35082 L
.45153 .35082 L
.45152 .35082 L
.45152 .35082 L
.45152 .35082 L
.45152 .35082 L
.45151 .35082 L
.45151 .35082 L
.45151 .35082 L
.45151 .35082 L
.4515 .35082 L
.4515 .35082 L
.4515 .35082 L
.4515 .35082 L
.4515 .35082 L
.45149 .35081 L
.45149 .35081 L
.45149 .35081 L
.45149 .35081 L
.45148 .35081 L
.45148 .35081 L
.45148 .35081 L
.45148 .35081 L
.45148 .35081 L
.45147 .35081 L
.45147 .35081 L
.45147 .35081 L
.45147 .35081 L
.45146 .35081 L
.45146 .3508 L
.45146 .3508 L
.45146 .3508 L
.45146 .3508 L
.45145 .3508 L
.45145 .3508 L
.45145 .3508 L
.45145 .3508 L
.45144 .3508 L
.45144 .3508 L
Mistroke
.45144 .3508 L
.45144 .3508 L
.45144 .3508 L
.45143 .3508 L
.45143 .35079 L
.45143 .35079 L
.45143 .35079 L
.45142 .35079 L
.45142 .35079 L
.45142 .35079 L
.45142 .35079 L
.45142 .35079 L
.45141 .35079 L
.45141 .35079 L
.45141 .35079 L
.45141 .35079 L
.4514 .35079 L
.4514 .35078 L
.4514 .35078 L
.4514 .35078 L
.4514 .35078 L
.45139 .35078 L
.45139 .35078 L
.45139 .35078 L
.45139 .35078 L
.45139 .35078 L
.45138 .35078 L
.45138 .35078 L
.45138 .35078 L
.45138 .35077 L
.45137 .35077 L
.45137 .35077 L
.45137 .35077 L
.45137 .35077 L
.45137 .35077 L
.45136 .35077 L
.45136 .35077 L
.45136 .35077 L
.45136 .35077 L
.45136 .35077 L
.45135 .35077 L
.45135 .35076 L
.45135 .35076 L
.45135 .35076 L
.45135 .35076 L
.45134 .35076 L
.45134 .35076 L
.45134 .35076 L
.45134 .35076 L
.45134 .35076 L
Mistroke
.45133 .35076 L
.45133 .35076 L
.45133 .35076 L
.45133 .35075 L
.45132 .35075 L
.45132 .35075 L
.45132 .35075 L
.45132 .35075 L
.45132 .35075 L
.45131 .35075 L
.45131 .35075 L
.45131 .35075 L
.45131 .35075 L
.45131 .35075 L
.4513 .35075 L
.4513 .35074 L
.4513 .35074 L
.4513 .35074 L
.4513 .35074 L
.45129 .35074 L
.45129 .35074 L
.45129 .35074 L
.45129 .35074 L
.45129 .35074 L
.45128 .35074 L
.45128 .35074 L
.45128 .35073 L
.45128 .35073 L
.45128 .35073 L
.45127 .35073 L
.45127 .35073 L
.45127 .35073 L
.45127 .35073 L
.45127 .35073 L
.45127 .35073 L
.45126 .35073 L
.45126 .35073 L
.45126 .35072 L
.45126 .35072 L
.45126 .35072 L
.45125 .35072 L
.45125 .35072 L
.45125 .35072 L
.45125 .35072 L
.45125 .35072 L
.45124 .35072 L
.45124 .35072 L
.45124 .35072 L
.45124 .35071 L
.45124 .35071 L
Mistroke
.45123 .35071 L
.45123 .35071 L
.45123 .35071 L
.45123 .35071 L
.45123 .35071 L
.45122 .35071 L
.45122 .35071 L
.45122 .35071 L
.45122 .3507 L
.45122 .3507 L
.45122 .3507 L
.45121 .3507 L
.45121 .3507 L
.45121 .3507 L
.45121 .3507 L
.45121 .3507 L
.4512 .3507 L
.4512 .3507 L
.4512 .35069 L
.4512 .35069 L
.4512 .35069 L
.4512 .35069 L
.45119 .35069 L
.45119 .35069 L
.45119 .35069 L
.45119 .35069 L
.45119 .35069 L
.45118 .35069 L
.45118 .35068 L
.45118 .35068 L
.45118 .35068 L
.45118 .35068 L
.45117 .35068 L
.45117 .35068 L
.45117 .35068 L
.45117 .35068 L
.45117 .35068 L
.45117 .35068 L
.45116 .35067 L
.45116 .35067 L
.45116 .35067 L
.45116 .35067 L
.45116 .35067 L
.45116 .35067 L
.45115 .35067 L
.45115 .35067 L
.45115 .35067 L
.45115 .35067 L
.45115 .35066 L
.45114 .35066 L
Mistroke
.45114 .35066 L
.45114 .35066 L
.45114 .35066 L
.45114 .35066 L
.45114 .35066 L
.45113 .35066 L
.45113 .35066 L
.45113 .35066 L
.45113 .35065 L
.45113 .35065 L
.45113 .35065 L
.45112 .35065 L
.45112 .35065 L
.45112 .35065 L
.45112 .35065 L
.45112 .35065 L
.45112 .35065 L
.45111 .35064 L
.45111 .35064 L
.45111 .35064 L
.45111 .35064 L
.45111 .35064 L
.45111 .35064 L
.4511 .35064 L
.4511 .35064 L
.4511 .35064 L
.4511 .35063 L
.4511 .35063 L
.4511 .35063 L
.45109 .35063 L
.45109 .35063 L
.45109 .35063 L
.45109 .35063 L
.45109 .35063 L
.45109 .35063 L
.45108 .35062 L
.45108 .35062 L
.45108 .35062 L
.45108 .35062 L
.45108 .35062 L
.45108 .35062 L
.45107 .35062 L
.45107 .35062 L
.45107 .35062 L
.45107 .35062 L
.45107 .35061 L
.45107 .35061 L
.45106 .35061 L
.45106 .35061 L
.45106 .35061 L
Mistroke
.45106 .35061 L
.45106 .35061 L
.45106 .35061 L
.45105 .3506 L
.45105 .3506 L
.45105 .3506 L
.45105 .3506 L
.45105 .3506 L
.45105 .3506 L
.45104 .3506 L
.45104 .3506 L
.45104 .3506 L
.45104 .35059 L
.45104 .35059 L
.45104 .35059 L
.45104 .35059 L
.45103 .35059 L
.45103 .35059 L
.45103 .35059 L
.45103 .35059 L
.45103 .35059 L
.45103 .35058 L
.45102 .35058 L
.45102 .35058 L
.45102 .35058 L
.45102 .35058 L
.45102 .35058 L
.45102 .35058 L
.45102 .35058 L
.45101 .35058 L
.45101 .35057 L
.45101 .35057 L
.45101 .35057 L
.45101 .35057 L
.45101 .35057 L
.45101 .35057 L
.451 .35057 L
.451 .35057 L
.451 .35056 L
.451 .35056 L
.451 .35056 L
.451 .35056 L
.45099 .35056 L
.45099 .35056 L
.45099 .35056 L
.45099 .35056 L
.45099 .35056 L
.45099 .35055 L
.45099 .35055 L
.45098 .35055 L
Mistroke
.45098 .35055 L
.45098 .35055 L
.45098 .35055 L
.45098 .35055 L
.45098 .35055 L
.45098 .35054 L
.45097 .35054 L
.45097 .35054 L
.45097 .35054 L
.45097 .35054 L
.45097 .35054 L
.45097 .35054 L
.45097 .35054 L
.45096 .35053 L
.45096 .35053 L
.45096 .35053 L
.45096 .35053 L
.45096 .35053 L
.45096 .35053 L
.45096 .35053 L
.45095 .35053 L
.45095 .35052 L
.45095 .35052 L
.45095 .35052 L
.45095 .35052 L
.45095 .35052 L
.45095 .35052 L
.45094 .35052 L
.45094 .35052 L
.45094 .35052 L
.45094 .35051 L
.45094 .35051 L
.45094 .35051 L
.45094 .35051 L
.45094 .35051 L
.45093 .35051 L
.45093 .35051 L
.45093 .35051 L
.45093 .3505 L
.45093 .3505 L
.45093 .3505 L
.45093 .3505 L
.45092 .3505 L
.45092 .3505 L
.45092 .3505 L
.45092 .3505 L
.45092 .35049 L
.45092 .35049 L
.45092 .35049 L
.45092 .35049 L
Mistroke
.45091 .35049 L
.45091 .35049 L
.45091 .35049 L
.45091 .35049 L
.45091 .35048 L
.45091 .35048 L
.45091 .35048 L
.4509 .35048 L
.4509 .35048 L
.4509 .35048 L
.4509 .35048 L
.4509 .35047 L
.4509 .35047 L
.4509 .35047 L
.4509 .35047 L
.45089 .35047 L
.45089 .35047 L
.45089 .35047 L
.45089 .35047 L
.45089 .35046 L
.45089 .35046 L
.45089 .35046 L
.45089 .35046 L
.45088 .35046 L
.45088 .35046 L
.45088 .35046 L
.45088 .35046 L
.45088 .35045 L
.45088 .35045 L
.45088 .35045 L
.45088 .35045 L
.45087 .35045 L
.45087 .35045 L
.45087 .35045 L
.45087 .35045 L
.45087 .35044 L
.45087 .35044 L
.45087 .35044 L
.45087 .35044 L
.45086 .35044 L
.45086 .35044 L
.45086 .35044 L
.45086 .35043 L
.45086 .35043 L
.45086 .35043 L
.45086 .35043 L
.45086 .35043 L
.45086 .35043 L
.45085 .35043 L
.45085 .35043 L
Mistroke
.45085 .35042 L
.45085 .35042 L
.45085 .35042 L
.45085 .35042 L
.45085 .35042 L
.45085 .35042 L
.45084 .35042 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45084 .35041 L
.45083 .3504 L
.45083 .3504 L
.45083 .3504 L
.45083 .3504 L
.45083 .3504 L
.45083 .3504 L
.45083 .3504 L
.45083 .35039 L
.45083 .35039 L
.45082 .35039 L
.45082 .35039 L
.45082 .35039 L
.45082 .35039 L
.45082 .35039 L
.45082 .35039 L
.45082 .35038 L
.45082 .35038 L
.45082 .35038 L
.45081 .35038 L
.45081 .35038 L
.45081 .35038 L
.45081 .35038 L
.45081 .35037 L
.45081 .35037 L
.45081 .35037 L
.45081 .35037 L
.45081 .35037 L
.4508 .35037 L
.4508 .35037 L
.4508 .35036 L
.4508 .35036 L
.4508 .35036 L
.4508 .35036 L
.4508 .35036 L
.4508 .35036 L
Mistroke
.4508 .35036 L
.4508 .35036 L
.45079 .35035 L
.45079 .35035 L
.45079 .35035 L
.45079 .35035 L
.45079 .35035 L
.45079 .35035 L
.45079 .35035 L
.45079 .35034 L
.45079 .35034 L
.45079 .35034 L
.45078 .35034 L
.45078 .35034 L
.45078 .35034 L
.45078 .35034 L
.45078 .35033 L
.45078 .35033 L
.45078 .35033 L
.45078 .35033 L
.45078 .35033 L
.45078 .35033 L
.45077 .35033 L
.45077 .35032 L
.45077 .35032 L
.45077 .35032 L
.45077 .35032 L
.45077 .35032 L
.45077 .35032 L
.45077 .35032 L
.45077 .35031 L
.45077 .35031 L
.45076 .35031 L
.45076 .35031 L
.45076 .35031 L
.45076 .35031 L
.45076 .35031 L
.45076 .3503 L
.45076 .3503 L
.45076 .3503 L
.45076 .3503 L
.45076 .3503 L
.45076 .3503 L
.45075 .3503 L
.45075 .35029 L
.45075 .35029 L
.45075 .35029 L
.45075 .35029 L
.45075 .35029 L
.45075 .35029 L
Mistroke
.45075 .35029 L
.45075 .35028 L
.45075 .35028 L
.45075 .35028 L
.45074 .35028 L
.45074 .35028 L
.45074 .35028 L
.45074 .35028 L
.45074 .35027 L
.45074 .35027 L
.45074 .35027 L
.45074 .35027 L
.45074 .35027 L
.45074 .35027 L
.45074 .35027 L
.45074 .35026 L
.45073 .35026 L
.45073 .35026 L
.45073 .35026 L
.45073 .35026 L
.45073 .35026 L
.45073 .35026 L
.45073 .35025 L
.45073 .35025 L
.45073 .35025 L
.45073 .35025 L
.45073 .35025 L
.45072 .35025 L
.45072 .35025 L
.45072 .35024 L
.45072 .35024 L
.45072 .35024 L
.45072 .35024 L
.45072 .35024 L
.45072 .35024 L
.45072 .35024 L
.45072 .35023 L
.45072 .35023 L
.45072 .35023 L
.45072 .35023 L
.45071 .35023 L
.45071 .35023 L
.45071 .35023 L
.45071 .35022 L
.45071 .35022 L
.45071 .35022 L
.45071 .35022 L
.45071 .35022 L
.45071 .35022 L
.45071 .35022 L
Mistroke
.45071 .35021 L
.45071 .35021 L
.4507 .35021 L
.4507 .35021 L
.4507 .35021 L
.4507 .35021 L
.4507 .35021 L
.4507 .3502 L
.4507 .3502 L
.4507 .3502 L
.4507 .3502 L
.4507 .3502 L
.4507 .3502 L
.4507 .35019 L
.4507 .35019 L
.4507 .35019 L
.45069 .35019 L
.45069 .35019 L
.45069 .35019 L
.45069 .35019 L
.45069 .35018 L
.45069 .35018 L
.45069 .35018 L
.45069 .35018 L
.45069 .35018 L
.45069 .35018 L
.45069 .35018 L
.45069 .35017 L
.45069 .35017 L
.45069 .35017 L
.45068 .35017 L
.45068 .35017 L
.45068 .35017 L
.45068 .35017 L
.45068 .35016 L
.45068 .35016 L
.45068 .35016 L
.45068 .35016 L
.45068 .35016 L
.45068 .35016 L
.45068 .35015 L
.45068 .35015 L
.45068 .35015 L
.45068 .35015 L
.45067 .35015 L
.45067 .35015 L
.45067 .35015 L
.45067 .35014 L
.45067 .35014 L
.45067 .35014 L
Mistroke
.45067 .35014 L
.45067 .35014 L
.45067 .35014 L
.45067 .35014 L
.45067 .35013 L
.45067 .35013 L
.45067 .35013 L
.45067 .35013 L
.45067 .35013 L
.45067 .35013 L
.45066 .35012 L
.45066 .35012 L
.45066 .35012 L
.45066 .35012 L
.45066 .35012 L
.45066 .35012 L
.45066 .35012 L
.45066 .35011 L
.45066 .35011 L
.45066 .35011 L
.45066 .35011 L
.45066 .35011 L
.45066 .35011 L
.45066 .3501 L
.45066 .3501 L
.45066 .3501 L
.45065 .3501 L
.45065 .3501 L
.45065 .3501 L
.45065 .3501 L
.45065 .35009 L
.45065 .35009 L
.45065 .35009 L
.45065 .35009 L
.45065 .35009 L
.45065 .35009 L
.45065 .35009 L
.45065 .35008 L
.45065 .35008 L
.45065 .35008 L
.45065 .35008 L
.45065 .35008 L
.45065 .35008 L
.45065 .35007 L
.45064 .35007 L
.45064 .35007 L
.45064 .35007 L
.45064 .35007 L
.45064 .35007 L
.45064 .35007 L
Mistroke
.45064 .35006 L
.45064 .35006 L
.45064 .35006 L
.45064 .35006 L
.45064 .35006 L
.45064 .35006 L
.45064 .35005 L
.45064 .35005 L
.45064 .35005 L
.45064 .35005 L
.45064 .35005 L
.45064 .35005 L
.45064 .35005 L
.45064 .35004 L
.45063 .35004 L
.45063 .35004 L
.45063 .35004 L
.45063 .35004 L
.45063 .35004 L
.45063 .35003 L
.45063 .35003 L
.45063 .35003 L
.45063 .35003 L
.45063 .35003 L
.45063 .35003 L
.45063 .35003 L
.45063 .35002 L
.45063 .35002 L
.45063 .35002 L
.45063 .35002 L
.45063 .35002 L
.45063 .35002 L
.45063 .35001 L
.45063 .35001 L
.45063 .35001 L
.45062 .35001 L
.45062 .35001 L
.45062 .35001 L
.45062 .35001 L
.45062 .35 L
.45062 .35 L
.45062 .35 L
.45062 .35 L
.45062 .35 L
.45062 .35 L
.45062 .34999 L
.45062 .34999 L
.45062 .34999 L
.45062 .34999 L
.45062 .34999 L
Mistroke
.45062 .34999 L
.45062 .34999 L
.45062 .34998 L
.45062 .34998 L
.45062 .34998 L
.45062 .34998 L
.45062 .34998 L
.45062 .34998 L
.45062 .34997 L
.45061 .34997 L
.45061 .34997 L
.45061 .34997 L
.45061 .34997 L
.45061 .34997 L
.45061 .34996 L
.45061 .34996 L
.45061 .34996 L
.45061 .34996 L
.45061 .34996 L
.45061 .34996 L
.45061 .34996 L
.45061 .34995 L
.45061 .34995 L
.45061 .34995 L
.45061 .34995 L
.45061 .34995 L
.45061 .34995 L
.45061 .34994 L
.45061 .34994 L
.45061 .34994 L
.45061 .34994 L
.45061 .34994 L
.45061 .34994 L
.45061 .34994 L
.45061 .34993 L
.45061 .34993 L
.45061 .34993 L
.4506 .34993 L
.4506 .34993 L
.4506 .34993 L
.4506 .34992 L
.4506 .34992 L
.4506 .34992 L
.4506 .34992 L
.4506 .34992 L
.4506 .34992 L
.4506 .34991 L
.4506 .34991 L
.4506 .34991 L
.4506 .34991 L
Mistroke
.4506 .34991 L
.4506 .34991 L
.4506 .34991 L
.4506 .3499 L
.4506 .3499 L
.4506 .3499 L
.4506 .3499 L
.4506 .3499 L
.4506 .3499 L
.4506 .34989 L
.4506 .34989 L
.4506 .34989 L
.4506 .34989 L
.4506 .34989 L
.4506 .34989 L
.4506 .34988 L
.4506 .34988 L
.4506 .34988 L
.4506 .34988 L
.4506 .34988 L
.4506 .34988 L
.45059 .34988 L
.45059 .34987 L
.45059 .34987 L
.45059 .34987 L
.45059 .34987 L
.45059 .34987 L
.45059 .34987 L
.45059 .34986 L
.45059 .34986 L
.45059 .34986 L
.45059 .34986 L
.45059 .34986 L
.45059 .34986 L
.45059 .34986 L
.45059 .34985 L
.45059 .34985 L
.45059 .34985 L
.45059 .34985 L
.45059 .34985 L
.45059 .34985 L
.45059 .34984 L
.45059 .34984 L
.45059 .34984 L
.45059 .34984 L
.45059 .34984 L
.45059 .34984 L
.45059 .34983 L
.45059 .34983 L
.45059 .34983 L
Mistroke
.45059 .34983 L
.45059 .34983 L
.45059 .34983 L
.45059 .34982 L
.45059 .34982 L
.45059 .34982 L
.45059 .34982 L
.45059 .34982 L
.45059 .34982 L
.45059 .34982 L
.45059 .34981 L
.45059 .34981 L
.45059 .34981 L
.45059 .34981 L
.45059 .34981 L
.45059 .34981 L
.45059 .3498 L
.45059 .3498 L
.45059 .3498 L
.45059 .3498 L
.45059 .3498 L
.45059 .3498 L
.45058 .34979 L
.45058 .34979 L
.45058 .34979 L
.45058 .34979 L
.45058 .34979 L
.45058 .34979 L
.45058 .34979 L
.45058 .34978 L
.45058 .34978 L
.45058 .34978 L
.45058 .34978 L
.45058 .34978 L
.45058 .34978 L
.45058 .34977 L
.45058 .34977 L
.45058 .34977 L
.45058 .34977 L
.45058 .34977 L
.45058 .34977 L
.45058 .34976 L
.45058 .34976 L
.45058 .34976 L
.45058 .34976 L
.45058 .34976 L
.45058 .34976 L
.45058 .34976 L
.45058 .34975 L
.45058 .34975 L
Mistroke
.45058 .34975 L
.45058 .34975 L
.45058 .34975 L
.45058 .34975 L
.45058 .34974 L
.45058 .34974 L
.45058 .34974 L
.45058 .34974 L
.45058 .34974 L
.45058 .34974 L
.45058 .34973 L
.45058 .34973 L
.45058 .34973 L
.45058 .34973 L
.45058 .34973 L
.45058 .34973 L
.45058 .34973 L
.45058 .34972 L
.45058 .34972 L
.45058 .34972 L
.45058 .34972 L
.45058 .34972 L
.45058 .34972 L
.45058 .34971 L
.45058 .34971 L
.45058 .34971 L
.45058 .34971 L
.45058 .34971 L
.45058 .34971 L
.45058 .3497 L
.45058 .3497 L
.45058 .3497 L
.45058 .3497 L
.45058 .3497 L
.45058 .3497 L
.45058 .34969 L
.45058 .34969 L
.45058 .34969 L
.45058 .34969 L
.45058 .34969 L
.45058 .34969 L
.45058 .34969 L
.45058 .34968 L
.45058 .34968 L
.45058 .34968 L
.45058 .34968 L
.45058 .34968 L
.45058 .34968 L
.45058 .34967 L
.45058 .34967 L
Mistroke
.45058 .34967 L
.45058 .34967 L
.45058 .34967 L
.45058 .34967 L
.45058 .34966 L
.45058 .34966 L
.45058 .34966 L
.45058 .34966 L
.45058 .34966 L
.45058 .34966 L
.45058 .34966 L
.45058 .34965 L
.45058 .34965 L
.45058 .34965 L
.45058 .34965 L
.45058 .34965 L
.45058 .34965 L
.45058 .34964 L
.45058 .34964 L
.45058 .34964 L
.45058 .34964 L
.45058 .34964 L
.45058 .34964 L
.45058 .34963 L
.45058 .34963 L
.45058 .34963 L
.45058 .34963 L
.45058 .34963 L
.45058 .34963 L
.45058 .34962 L
.45058 .34962 L
.45058 .34962 L
.45058 .34962 L
.45058 .34962 L
.45058 .34962 L
.45058 .34962 L
.45058 .34961 L
.45058 .34961 L
.45058 .34961 L
.45058 .34961 L
.45058 .34961 L
.45058 .34961 L
.45058 .3496 L
.45058 .3496 L
.45058 .3496 L
.45058 .3496 L
.45058 .3496 L
.45058 .3496 L
.45058 .34959 L
.45058 .34959 L
Mistroke
.45058 .34959 L
.45058 .34959 L
.45058 .34959 L
.45058 .34959 L
.45058 .34959 L
.45058 .34958 L
.45058 .34958 L
.45058 .34958 L
.45058 .34958 L
.45058 .34958 L
.45058 .34958 L
.45058 .34957 L
.45058 .34957 L
.45058 .34957 L
.45058 .34957 L
.45058 .34957 L
.45058 .34957 L
.45058 .34956 L
.45058 .34956 L
.45059 .34956 L
.45059 .34956 L
.45059 .34956 L
.45059 .34956 L
.45059 .34956 L
.45059 .34955 L
.45059 .34955 L
.45059 .34955 L
.45059 .34955 L
.45059 .34955 L
.45059 .34955 L
.45059 .34954 L
.45059 .34954 L
.45059 .34954 L
.45059 .34954 L
.45059 .34954 L
.45059 .34954 L
.45059 .34953 L
.45059 .34953 L
.45059 .34953 L
.45059 .34953 L
.45059 .34953 L
.45059 .34953 L
.45059 .34953 L
.45059 .34952 L
.45059 .34952 L
.45059 .34952 L
.45059 .34952 L
.45059 .34952 L
.45059 .34952 L
.45059 .34951 L
Mistroke
.45059 .34951 L
.45059 .34951 L
.45059 .34951 L
.45059 .34951 L
.45059 .34951 L
.45059 .3495 L
.45059 .3495 L
.45059 .3495 L
.45059 .3495 L
.45059 .3495 L
.45059 .3495 L
.45059 .3495 L
.45059 .34949 L
.45059 .34949 L
.45059 .34949 L
.45059 .34949 L
.45059 .34949 L
.45059 .34949 L
.45059 .34948 L
.45059 .34948 L
.45059 .34948 L
.45059 .34948 L
.45059 .34948 L
.4506 .34948 L
.4506 .34947 L
.4506 .34947 L
.4506 .34947 L
.4506 .34947 L
.4506 .34947 L
.4506 .34947 L
.4506 .34947 L
.4506 .34946 L
.4506 .34946 L
.4506 .34946 L
.4506 .34946 L
.4506 .34946 L
.4506 .34946 L
.4506 .34945 L
.4506 .34945 L
.4506 .34945 L
.4506 .34945 L
.4506 .34945 L
.4506 .34945 L
.4506 .34944 L
.4506 .34944 L
.4506 .34944 L
.4506 .34944 L
.4506 .34944 L
.4506 .34944 L
.4506 .34944 L
Mistroke
.4506 .34943 L
.4506 .34943 L
.4506 .34943 L
.4506 .34943 L
.4506 .34943 L
.4506 .34943 L
.4506 .34942 L
.4506 .34942 L
.4506 .34942 L
.4506 .34942 L
.4506 .34942 L
.45061 .34942 L
.45061 .34941 L
.45061 .34941 L
.45061 .34941 L
.45061 .34941 L
.45061 .34941 L
.45061 .34941 L
.45061 .34941 L
.45061 .3494 L
.45061 .3494 L
.45061 .3494 L
.45061 .3494 L
.45061 .3494 L
.45061 .3494 L
.45061 .34939 L
.45061 .34939 L
.45061 .34939 L
.45061 .34939 L
.45061 .34939 L
.45061 .34939 L
.45061 .34939 L
.45061 .34938 L
.45061 .34938 L
.45061 .34938 L
.45061 .34938 L
.45061 .34938 L
.45061 .34938 L
.45061 .34937 L
.45061 .34937 L
.45061 .34937 L
.45061 .34937 L
.45062 .34937 L
.45062 .34937 L
.45062 .34937 L
.45062 .34936 L
.45062 .34936 L
.45062 .34936 L
.45062 .34936 L
.45062 .34936 L
Mistroke
.45062 .34936 L
.45062 .34935 L
.45062 .34935 L
.45062 .34935 L
.45062 .34935 L
.45062 .34935 L
.45062 .34935 L
.45062 .34934 L
.45062 .34934 L
.45062 .34934 L
.45062 .34934 L
.45062 .34934 L
.45062 .34934 L
.45062 .34934 L
.45062 .34933 L
.45062 .34933 L
.45062 .34933 L
.45062 .34933 L
.45062 .34933 L
.45063 .34933 L
.45063 .34932 L
.45063 .34932 L
.45063 .34932 L
.45063 .34932 L
.45063 .34932 L
.45063 .34932 L
.45063 .34932 L
.45063 .34931 L
.45063 .34931 L
.45063 .34931 L
.45063 .34931 L
.45063 .34931 L
.45063 .34931 L
.45063 .3493 L
.45063 .3493 L
.45063 .3493 L
.45063 .3493 L
.45063 .3493 L
.45063 .3493 L
.45063 .3493 L
.45063 .34929 L
.45063 .34929 L
.45063 .34929 L
.45063 .34929 L
.45064 .34929 L
.45064 .34929 L
.45064 .34928 L
.45064 .34928 L
.45064 .34928 L
.45064 .34928 L
Mistroke
.45064 .34928 L
.45064 .34928 L
.45064 .34928 L
.45064 .34927 L
.45064 .34927 L
.45064 .34927 L
.45064 .34927 L
.45064 .34927 L
.45064 .34927 L
.45064 .34926 L
.45064 .34926 L
.45064 .34926 L
.45064 .34926 L
.45064 .34926 L
.45064 .34926 L
.45064 .34926 L
.45064 .34925 L
.45065 .34925 L
.45065 .34925 L
.45065 .34925 L
.45065 .34925 L
.45065 .34925 L
.45065 .34925 L
.45065 .34924 L
.45065 .34924 L
.45065 .34924 L
.45065 .34924 L
.45065 .34924 L
.45065 .34924 L
.45065 .34923 L
.45065 .34923 L
.45065 .34923 L
.45065 .34923 L
.45065 .34923 L
.45065 .34923 L
.45065 .34923 L
.45065 .34922 L
.45065 .34922 L
.45066 .34922 L
.45066 .34922 L
.45066 .34922 L
.45066 .34922 L
.45066 .34921 L
.45066 .34921 L
.45066 .34921 L
.45066 .34921 L
.45066 .34921 L
.45066 .34921 L
.45066 .34921 L
.45066 .3492 L
Mistroke
.45066 .3492 L
.45066 .3492 L
.45066 .3492 L
.45066 .3492 L
.45066 .3492 L
.45066 .3492 L
.45066 .34919 L
.45066 .34919 L
.45066 .34919 L
.45067 .34919 L
.45067 .34919 L
.45067 .34919 L
.45067 .34918 L
.45067 .34918 L
.45067 .34918 L
.45067 .34918 L
.45067 .34918 L
.45067 .34918 L
.45067 .34918 L
.45067 .34917 L
.45067 .34917 L
.45067 .34917 L
.45067 .34917 L
.45067 .34917 L
.45067 .34917 L
.45067 .34917 L
.45067 .34916 L
.45067 .34916 L
.45068 .34916 L
.45068 .34916 L
.45068 .34916 L
.45068 .34916 L
.45068 .34915 L
.45068 .34915 L
.45068 .34915 L
.45068 .34915 L
.45068 .34915 L
.45068 .34915 L
.45068 .34915 L
.45068 .34914 L
.45068 .34914 L
.45068 .34914 L
.45068 .34914 L
.45068 .34914 L
.45068 .34914 L
.45068 .34914 L
.45069 .34913 L
.45069 .34913 L
.45069 .34913 L
.45069 .34913 L
Mistroke
.45069 .34913 L
.45069 .34913 L
.45069 .34912 L
.45069 .34912 L
.45069 .34912 L
.45069 .34912 L
.45069 .34912 L
.45069 .34912 L
.45069 .34912 L
.45069 .34911 L
.45069 .34911 L
.45069 .34911 L
.45069 .34911 L
.45069 .34911 L
.4507 .34911 L
.4507 .34911 L
.4507 .3491 L
.4507 .3491 L
.4507 .3491 L
.4507 .3491 L
.4507 .3491 L
.4507 .3491 L
.4507 .3491 L
.4507 .34909 L
.4507 .34909 L
.4507 .34909 L
.4507 .34909 L
.4507 .34909 L
.4507 .34909 L
.4507 .34909 L
.45071 .34908 L
.45071 .34908 L
.45071 .34908 L
.45071 .34908 L
.45071 .34908 L
.45071 .34908 L
.45071 .34907 L
.45071 .34907 L
.45071 .34907 L
.45071 .34907 L
.45071 .34907 L
.45071 .34907 L
.45071 .34907 L
.45071 .34906 L
.45071 .34906 L
.45071 .34906 L
.45071 .34906 L
.45072 .34906 L
.45072 .34906 L
.45072 .34906 L
Mistroke
.45072 .34905 L
.45072 .34905 L
.45072 .34905 L
.45072 .34905 L
.45072 .34905 L
.45072 .34905 L
.45072 .34905 L
.45072 .34904 L
.45072 .34904 L
.45072 .34904 L
.45072 .34904 L
.45072 .34904 L
.45072 .34904 L
.45073 .34904 L
.45073 .34903 L
.45073 .34903 L
.45073 .34903 L
.45073 .34903 L
.45073 .34903 L
.45073 .34903 L
.45073 .34903 L
.45073 .34902 L
.45073 .34902 L
.45073 .34902 L
.45073 .34902 L
.45073 .34902 L
.45073 .34902 L
.45073 .34902 L
.45074 .34901 L
.45074 .34901 L
.45074 .34901 L
.45074 .34901 L
.45074 .34901 L
.45074 .34901 L
.45074 .34901 L
.45074 .349 L
.45074 .349 L
.45074 .349 L
.45074 .349 L
.45074 .349 L
.45074 .349 L
.45074 .349 L
.45074 .34899 L
.45075 .34899 L
.45075 .34899 L
.45075 .34899 L
.45075 .34899 L
.45075 .34899 L
.45075 .34899 L
.45075 .34898 L
Mistroke
.45075 .34898 L
.45075 .34898 L
.45075 .34898 L
.45075 .34898 L
.45075 .34898 L
.45075 .34898 L
.45075 .34897 L
.45075 .34897 L
.45076 .34897 L
.45076 .34897 L
.45076 .34897 L
.45076 .34897 L
.45076 .34897 L
.45076 .34896 L
.45076 .34896 L
.45076 .34896 L
.45076 .34896 L
.45076 .34896 L
.45076 .34896 L
.45076 .34896 L
.45076 .34895 L
.45076 .34895 L
.45077 .34895 L
.45077 .34895 L
.45077 .34895 L
.45077 .34895 L
.45077 .34895 L
.45077 .34894 L
.45077 .34894 L
.45077 .34894 L
.45077 .34894 L
.45077 .34894 L
.45077 .34894 L
.45077 .34894 L
.45077 .34893 L
.45077 .34893 L
.45077 .34893 L
.45078 .34893 L
.45078 .34893 L
.45078 .34893 L
.45078 .34893 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34892 L
.45078 .34891 L
Mistroke
.45079 .34891 L
.45079 .34891 L
.45079 .34891 L
.45079 .34891 L
.45079 .34891 L
.45079 .34891 L
.45079 .3489 L
.45079 .3489 L
.45079 .3489 L
.45079 .3489 L
.45079 .3489 L
.45079 .3489 L
.45079 .3489 L
.45079 .34889 L
.4508 .34889 L
.4508 .34889 L
.4508 .34889 L
.4508 .34889 L
.4508 .34889 L
.4508 .34889 L
.4508 .34888 L
.4508 .34888 L
.4508 .34888 L
.4508 .34888 L
.4508 .34888 L
.4508 .34888 L
.4508 .34888 L
.45081 .34888 L
.45081 .34887 L
.45081 .34887 L
.45081 .34887 L
.45081 .34887 L
.45081 .34887 L
.45081 .34887 L
.45081 .34887 L
.45081 .34886 L
.45081 .34886 L
.45081 .34886 L
.45081 .34886 L
.45081 .34886 L
.45081 .34886 L
.45082 .34886 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
.45082 .34885 L
Mistroke
.45082 .34884 L
.45082 .34884 L
.45082 .34884 L
.45083 .34884 L
.45083 .34884 L
.45083 .34884 L
.45083 .34884 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34883 L
.45083 .34882 L
.45084 .34882 L
.45084 .34882 L
.45084 .34882 L
.45084 .34882 L
.45084 .34882 L
.45084 .34882 L
.45084 .34881 L
.45084 .34881 L
.45084 .34881 L
.45084 .34881 L
.45084 .34881 L
.45084 .34881 L
.45084 .34881 L
.45085 .34881 L
.45085 .3488 L
.45085 .3488 L
.45085 .3488 L
.45085 .3488 L
.45085 .3488 L
.45085 .3488 L
.45085 .3488 L
.45085 .34879 L
.45085 .34879 L
.45085 .34879 L
.45085 .34879 L
.45086 .34879 L
.45086 .34879 L
.45086 .34879 L
.45086 .34879 L
.45086 .34878 L
.45086 .34878 L
.45086 .34878 L
.45086 .34878 L
.45086 .34878 L
Mistroke
.45086 .34878 L
.45086 .34878 L
.45086 .34877 L
.45086 .34877 L
.45087 .34877 L
.45087 .34877 L
.45087 .34877 L
.45087 .34877 L
.45087 .34877 L
.45087 .34877 L
.45087 .34876 L
.45087 .34876 L
.45087 .34876 L
.45087 .34876 L
.45087 .34876 L
.45087 .34876 L
.45088 .34876 L
.45088 .34876 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34875 L
.45088 .34874 L
.45088 .34874 L
.45089 .34874 L
.45089 .34874 L
.45089 .34874 L
.45089 .34874 L
.45089 .34874 L
.45089 .34873 L
.45089 .34873 L
.45089 .34873 L
.45089 .34873 L
.45089 .34873 L
.45089 .34873 L
.45089 .34873 L
.4509 .34873 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34872 L
.4509 .34871 L
Mistroke
.4509 .34871 L
.45091 .34871 L
.45091 .34871 L
.45091 .34871 L
.45091 .34871 L
.45091 .34871 L
.45091 .34871 L
.45091 .3487 L
.45091 .3487 L
.45091 .3487 L
.45091 .3487 L
.45091 .3487 L
.45091 .3487 L
.45092 .3487 L
.45092 .3487 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34869 L
.45092 .34868 L
.45092 .34868 L
.45093 .34868 L
.45093 .34868 L
.45093 .34868 L
.45093 .34868 L
.45093 .34868 L
.45093 .34868 L
.45093 .34867 L
.45093 .34867 L
.45093 .34867 L
.45093 .34867 L
.45093 .34867 L
.45094 .34867 L
.45094 .34867 L
.45094 .34867 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45094 .34866 L
.45095 .34865 L
.45095 .34865 L
.45095 .34865 L
Mistroke
.45095 .34865 L
.45095 .34865 L
.45095 .34865 L
.45095 .34865 L
.45095 .34865 L
.45095 .34864 L
.45095 .34864 L
.45095 .34864 L
.45095 .34864 L
.45096 .34864 L
.45096 .34864 L
.45096 .34864 L
.45096 .34864 L
.45096 .34863 L
.45096 .34863 L
.45096 .34863 L
.45096 .34863 L
.45096 .34863 L
.45096 .34863 L
.45096 .34863 L
.45097 .34863 L
.45097 .34863 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34862 L
.45097 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .34861 L
.45098 .3486 L
.45098 .3486 L
.45098 .3486 L
.45098 .3486 L
.45099 .3486 L
.45099 .3486 L
.45099 .3486 L
.45099 .3486 L
.45099 .3486 L
.45099 .34859 L
.45099 .34859 L
.45099 .34859 L
Mistroke
.45099 .34859 L
.45099 .34859 L
.45099 .34859 L
.451 .34859 L
.451 .34859 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.451 .34858 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34857 L
.45101 .34856 L
.45101 .34856 L
.45101 .34856 L
.45102 .34856 L
.45102 .34856 L
.45102 .34856 L
.45102 .34856 L
.45102 .34856 L
.45102 .34856 L
.45102 .34855 L
.45102 .34855 L
.45102 .34855 L
.45102 .34855 L
.45103 .34855 L
.45103 .34855 L
.45103 .34855 L
.45103 .34855 L
.45103 .34855 L
.45103 .34854 L
.45103 .34854 L
.45103 .34854 L
.45103 .34854 L
.45103 .34854 L
.45103 .34854 L
.45104 .34854 L
.45104 .34854 L
.45104 .34853 L
.45104 .34853 L
Mistroke
.45104 .34853 L
.45104 .34853 L
.45104 .34853 L
.45104 .34853 L
.45104 .34853 L
.45104 .34853 L
.45104 .34853 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34852 L
.45105 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .34851 L
.45106 .3485 L
.45106 .3485 L
.45106 .3485 L
.45107 .3485 L
.45107 .3485 L
.45107 .3485 L
.45107 .3485 L
.45107 .3485 L
.45107 .3485 L
.45107 .34849 L
.45107 .34849 L
.45107 .34849 L
.45107 .34849 L
.45108 .34849 L
.45108 .34849 L
.45108 .34849 L
.45108 .34849 L
.45108 .34849 L
.45108 .34848 L
.45108 .34848 L
.45108 .34848 L
.45108 .34848 L
.45108 .34848 L
.45108 .34848 L
.45109 .34848 L
Mistroke
.45109 .34848 L
.45109 .34848 L
.45109 .34847 L
.45109 .34847 L
.45109 .34847 L
.45109 .34847 L
.45109 .34847 L
.45109 .34847 L
.45109 .34847 L
.4511 .34847 L
.4511 .34847 L
.4511 .34847 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.4511 .34846 L
.45111 .34846 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45111 .34845 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45112 .34844 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34843 L
.45113 .34842 L
Mistroke
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34842 L
.45114 .34841 L
.45114 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .34841 L
.45115 .3484 L
.45115 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .3484 L
.45116 .34839 L
.45116 .34839 L
.45116 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34839 L
.45117 .34838 L
.45117 .34838 L
.45117 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34838 L
.45118 .34837 L
.45118 .34837 L
Mistroke
.45118 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34837 L
.45119 .34836 L
.45119 .34836 L
.45119 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34836 L
.4512 .34835 L
.4512 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34835 L
.45121 .34834 L
.45121 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34834 L
.45122 .34833 L
.45122 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
.45123 .34833 L
Mistroke
.45123 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34832 L
.45124 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45125 .34831 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45126 .3483 L
.45127 .3483 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45127 .34829 L
.45128 .34829 L
.45128 .34829 L
.45128 .34828 L
.45128 .34828 L
.45128 .34828 L
.45128 .34828 L
.45128 .34828 L
.45128 .34828 L
.45128 .34828 L
Mistroke
.45128 .34828 L
.45129 .34828 L
.45129 .34828 L
.45129 .34828 L
.45129 .34827 L
.45129 .34827 L
.45129 .34827 L
.45129 .34827 L
.45129 .34827 L
.45129 .34827 L
.45129 .34827 L
.4513 .34827 L
.4513 .34827 L
.4513 .34827 L
.4513 .34827 L
.4513 .34826 L
.4513 .34826 L
.4513 .34826 L
.4513 .34826 L
.4513 .34826 L
.4513 .34826 L
.45131 .34826 L
.45131 .34826 L
.45131 .34826 L
.45131 .34826 L
.45131 .34826 L
.45131 .34826 L
.45131 .34825 L
.45131 .34825 L
.45131 .34825 L
.45131 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34825 L
.45132 .34824 L
.45132 .34824 L
.45132 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
.45133 .34824 L
Mistroke
.45133 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45134 .34823 L
.45135 .34823 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45135 .34822 L
.45136 .34822 L
.45136 .34822 L
.45136 .34822 L
.45136 .34821 L
.45136 .34821 L
.45136 .34821 L
.45136 .34821 L
.45136 .34821 L
.45136 .34821 L
.45136 .34821 L
.45137 .34821 L
.45137 .34821 L
.45137 .34821 L
.45137 .34821 L
.45137 .34821 L
.45137 .3482 L
.45137 .3482 L
.45137 .3482 L
.45137 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .3482 L
.45138 .34819 L
Mistroke
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.45139 .34819 L
.4514 .34819 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.4514 .34818 L
.45141 .34818 L
.45141 .34818 L
.45141 .34818 L
.45141 .34818 L
.45141 .34817 L
.45141 .34817 L
.45141 .34817 L
.45141 .34817 L
.45141 .34817 L
.45141 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34817 L
.45142 .34816 L
.45142 .34816 L
.45142 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
.45143 .34816 L
Mistroke
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45144 .34815 L
.45145 .34815 L
.45145 .34815 L
.45145 .34815 L
.45145 .34815 L
.45145 .34814 L
.45145 .34814 L
.45145 .34814 L
.45145 .34814 L
.45145 .34814 L
.45145 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34814 L
.45146 .34813 L
.45146 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45147 .34813 L
.45148 .34813 L
.45148 .34813 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
.45148 .34812 L
Mistroke
.45149 .34812 L
.45149 .34812 L
.45149 .34812 L
.45149 .34812 L
.45149 .34812 L
.45149 .34812 L
.45149 .34811 L
.45149 .34811 L
.45149 .34811 L
.45149 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.4515 .34811 L
.45151 .34811 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45151 .3481 L
.45152 .3481 L
.45152 .3481 L
.45152 .3481 L
.45152 .3481 L
.45152 .3481 L
.45152 .34809 L
.45152 .34809 L
.45152 .34809 L
.45152 .34809 L
.45152 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
.45153 .34809 L
Mistroke
.45154 .34809 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45154 .34808 L
.45155 .34808 L
.45155 .34808 L
.45155 .34808 L
.45155 .34808 L
.45155 .34808 L
.45155 .34808 L
.45155 .34807 L
.45155 .34807 L
.45155 .34807 L
.45155 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45156 .34807 L
.45157 .34807 L
.45157 .34807 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45157 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34806 L
.45158 .34805 L
Mistroke
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.45159 .34805 L
.4516 .34805 L
.4516 .34805 L
.4516 .34805 L
.4516 .34805 L
.4516 .34804 L
.4516 .34804 L
.4516 .34804 L
.4516 .34804 L
.4516 .34804 L
.4516 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45161 .34804 L
.45162 .34804 L
.45162 .34804 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45162 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
.45163 .34803 L
Mistroke
.45163 .34802 L
.45163 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45164 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34802 L
.45165 .34801 L
.45165 .34801 L
.45165 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45166 .34801 L
.45167 .34801 L
.45167 .34801 L
.45167 .34801 L
.45167 .34801 L
.45167 .34801 L
.45167 .348 L
.45167 .348 L
.45167 .348 L
.45167 .348 L
.45167 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
Mistroke
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45168 .348 L
.45169 .348 L
.45169 .348 L
.45169 .348 L
.45169 .34799 L
.45169 .34799 L
.45169 .34799 L
.45169 .34799 L
.45169 .34799 L
.45169 .34799 L
.45169 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.4517 .34799 L
.45171 .34799 L
.45171 .34799 L
.45171 .34799 L
.45171 .34798 L
.45171 .34798 L
.45171 .34798 L
.45171 .34798 L
.45171 .34798 L
.45171 .34798 L
.45171 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45172 .34798 L
.45173 .34798 L
.45173 .34798 L
.45173 .34798 L
.45173 .34797 L
Mistroke
.45173 .34797 L
.45173 .34797 L
.45173 .34797 L
.45173 .34797 L
.45173 .34797 L
.45173 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45174 .34797 L
.45175 .34797 L
.45175 .34797 L
.45175 .34797 L
.45175 .34797 L
.45175 .34796 L
.45175 .34796 L
.45175 .34796 L
.45175 .34796 L
.45175 .34796 L
.45175 .34796 L
.45175 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45176 .34796 L
.45177 .34796 L
.45177 .34796 L
.45177 .34796 L
.45177 .34796 L
.45177 .34796 L
.45177 .34795 L
.45177 .34795 L
.45177 .34795 L
.45177 .34795 L
.45177 .34795 L
.45177 .34795 L
Mistroke
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45178 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34795 L
.45179 .34794 L
.45179 .34794 L
.45179 .34794 L
.45179 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.4518 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45181 .34794 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
Mistroke
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45182 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45183 .34793 L
.45184 .34793 L
.45184 .34793 L
.45184 .34793 L
.45184 .34793 L
.45184 .34793 L
.45184 .34793 L
.45184 .34792 L
.45184 .34792 L
.45184 .34792 L
.45184 .34792 L
.45184 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45185 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
.45186 .34792 L
Mistroke
.45187 .34792 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45187 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45188 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .34791 L
.45189 .3479 L
.45189 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.4519 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
Mistroke
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45191 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .3479 L
.45192 .34789 L
.45192 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45193 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45194 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
Mistroke
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45195 .34789 L
.45196 .34789 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45196 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45197 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45198 .34788 L
.45199 .34788 L
.45199 .34788 L
.45199 .34788 L
.45199 .34788 L
.45199 .34788 L
.45199 .34788 L
.45199 .34788 L
Mistroke
.45199 .34788 L
.45199 .34788 L
.45199 .34787 L
.45199 .34787 L
.45199 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.452 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45201 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45202 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
Mistroke
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45203 .34787 L
.45204 .34787 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45204 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45205 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45206 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
Mistroke
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45207 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45208 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34786 L
.45209 .34785 L
.45209 .34785 L
.45209 .34785 L
.45209 .34785 L
.45209 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
.4521 .34785 L
Mistroke
.4521 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45211 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45212 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45213 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
Mistroke
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45214 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45215 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45216 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
Mistroke
.45217 .34785 L
.45217 .34785 L
.45217 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45218 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.45219 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
.4522 .34785 L
Mistroke
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45221 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45222 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45223 .34785 L
.45224 .34785 L
Mistroke
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45224 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45225 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
.45226 .34785 L
Mistroke
.45226 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45227 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45228 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
Mistroke
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.45229 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34785 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.4523 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45231 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
Mistroke
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45232 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45233 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
.45234 .34786 L
Mistroke
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45234 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45235 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
.45236 .34787 L
Mistroke
.45236 .34787 L
.45236 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34787 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45237 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
.45238 .34788 L
Mistroke
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34788 L
.45239 .34789 L
.45239 .34789 L
.45239 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
.4524 .34789 L
Mistroke
.4524 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .34789 L
.45241 .3479 L
.45241 .3479 L
.45241 .3479 L
.45241 .3479 L
.45241 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
Mistroke
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45242 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .3479 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45243 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
Mistroke
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34791 L
.45244 .34792 L
.45244 .34792 L
.45244 .34792 L
.45244 .34792 L
.45244 .34792 L
.45244 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
Mistroke
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45245 .34792 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45246 .34793 L
.45247 .34793 L
.45247 .34793 L
.45247 .34793 L
.45247 .34793 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
Mistroke
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45247 .34794 L
.45248 .34794 L
.45248 .34794 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
Mistroke
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34795 L
.45248 .34796 L
.45248 .34796 L
.45248 .34796 L
.45248 .34796 L
.45248 .34796 L
.45248 .34796 L
.45248 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
Mistroke
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34796 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.45249 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34797 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
Mistroke
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34798 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.4525 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
Mistroke
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .34799 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .348 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
Mistroke
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45251 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34801 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
Mistroke
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34802 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34803 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
Mistroke
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45252 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34804 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
.45253 .34805 L
Mistroke
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34806 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
Mistroke
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34807 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34808 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
Mistroke
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .34809 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
Mistroke
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .3481 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34811 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
Mistroke
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34812 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34813 L
.45253 .34814 L
Mistroke
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34814 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
.45253 .34815 L
Mistroke
.45253 .34815 L
.45253 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34815 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34816 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
Mistroke
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34817 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
Mistroke
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34818 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45252 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .34819 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
Mistroke
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .3482 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
Mistroke
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34821 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.45251 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34822 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
Mistroke
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34823 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.4525 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
Mistroke
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34824 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34825 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
Mistroke
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45249 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34826 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
Mistroke
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34827 L
.45248 .34828 L
.45248 .34828 L
.45248 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
Mistroke
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34828 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45247 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .34829 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
Mistroke
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .3483 L
.45246 .34831 L
.45246 .34831 L
.45246 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
Mistroke
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34831 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45245 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
Mistroke
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34832 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45244 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
Mistroke
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34833 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45243 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
Mistroke
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34834 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45242 .34835 L
.45241 .34835 L
.45241 .34835 L
.45241 .34835 L
.45241 .34835 L
.45241 .34835 L
Mistroke
.45241 .34835 L
.45241 .34835 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.45241 .34836 L
.4524 .34836 L
.4524 .34836 L
.4524 .34836 L
.4524 .34836 L
.4524 .34836 L
.4524 .34836 L
Mistroke
.4524 .34836 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.4524 .34837 L
.45239 .34837 L
.45239 .34837 L
.45239 .34837 L
.45239 .34837 L
.45239 .34837 L
.45239 .34837 L
Mistroke
.45239 .34837 L
.45239 .34837 L
.45239 .34837 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45239 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
Mistroke
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34838 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45238 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
Mistroke
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .34839 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45237 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
Mistroke
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .3484 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45236 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
Mistroke
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45235 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34841 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
Mistroke
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45234 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
Mistroke
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34842 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45233 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
Mistroke
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45232 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
Mistroke
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34843 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.45231 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
Mistroke
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.4523 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
Mistroke
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34844 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45229 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
Mistroke
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45228 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
Mistroke
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34845 L
.45227 .34846 L
.45227 .34846 L
.45227 .34846 L
.45227 .34846 L
.45227 .34846 L
.45227 .34846 L
Mistroke
.45227 .34846 L
.45227 .34846 L
.45227 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
Mistroke
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45226 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
Mistroke
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45225 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
Mistroke
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45224 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
Mistroke
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34846 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45223 .34847 L
.45222 .34847 L
.45222 .34847 L
Mistroke
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
Mistroke
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45222 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
Mistroke
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.45221 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
Mistroke
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
Mistroke
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.4522 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
Mistroke
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
Mistroke
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45219 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
Mistroke
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45218 .34847 L
.45217 .34847 L
Mistroke
.45217 .34847 L
.45217 .34847 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
Mistroke
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
Mistroke
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45217 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
Mistroke
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
Mistroke
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45216 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
Mistroke
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34846 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
Mistroke
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
Mistroke
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
Mistroke
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45215 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
Mistroke
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34845 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
Mistroke
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
Mistroke
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
Mistroke
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34844 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
Mistroke
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
Mistroke
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45214 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
Mistroke
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34843 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
Mistroke
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
Mistroke
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
Mistroke
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34842 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
Mistroke
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
Mistroke
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
Mistroke
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .34841 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
.45213 .3484 L
Mistroke
.45213 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
Mistroke
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
Mistroke
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
.45214 .3484 L
Mistroke
.45214 .3484 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
Mistroke
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
Mistroke
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
Mistroke
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34839 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
Mistroke
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
.45214 .34838 L
Mistroke
.45214 .34838 L
.45214 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
Mistroke
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
Mistroke
.45215 .34838 L
.45215 .34838 L
.45215 .34838 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
Mistroke
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
Mistroke
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
Mistroke
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45215 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
Mistroke
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34837 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
Mistroke
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
Mistroke
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
Mistroke
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
Mistroke
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45216 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
Mistroke
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
Mistroke
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
Mistroke
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
Mistroke
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
Mistroke
.45217 .34835 L
.45217 .34835 L
.45217 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45218 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
.45219 .34834 L
Mistroke
.45219 .34834 L
Mfstroke
.194 1 0 r
.40132 .25661 m
.40147 .25658 L
.40162 .25654 L
.40177 .2565 L
.40191 .25646 L
.40206 .25643 L
.40221 .25639 L
.40236 .25635 L
.40251 .25632 L
.40266 .25628 L
.40281 .25624 L
.40296 .25621 L
.40311 .25617 L
.40325 .25613 L
.4034 .2561 L
.40355 .25606 L
.4037 .25603 L
.40385 .25599 L
.404 .25596 L
.40414 .25592 L
.40429 .25589 L
.40444 .25585 L
.40459 .25581 L
.40474 .25578 L
.40488 .25575 L
.40503 .25571 L
.40518 .25568 L
.40533 .25564 L
.40547 .25561 L
.40562 .25557 L
.40577 .25554 L
.40592 .2555 L
.40606 .25547 L
.40621 .25544 L
.40636 .2554 L
.4065 .25537 L
.40665 .25534 L
.4068 .2553 L
.40695 .25527 L
.40709 .25524 L
.40724 .2552 L
.40739 .25517 L
.40753 .25514 L
.40768 .2551 L
.40782 .25507 L
.40797 .25504 L
.40812 .25501 L
.40826 .25497 L
.40841 .25494 L
.40856 .25491 L
Mistroke
.4087 .25488 L
.40885 .25485 L
.40899 .25482 L
.40914 .25478 L
.40928 .25475 L
.40943 .25472 L
.40958 .25469 L
.40972 .25466 L
.40987 .25463 L
.41001 .2546 L
.41016 .25457 L
.4103 .25453 L
.41045 .2545 L
.41059 .25447 L
.41074 .25444 L
.41088 .25441 L
.41103 .25438 L
.41117 .25435 L
.41132 .25432 L
.41146 .25429 L
.4116 .25426 L
.41175 .25423 L
.41189 .2542 L
.41204 .25417 L
.41218 .25414 L
.41233 .25412 L
.41247 .25409 L
.41261 .25406 L
.41276 .25403 L
.4129 .254 L
.41304 .25397 L
.41319 .25394 L
.41333 .25391 L
.41348 .25389 L
.41362 .25386 L
.41376 .25383 L
.41391 .2538 L
.41405 .25377 L
.41419 .25375 L
.41433 .25372 L
.41448 .25369 L
.41462 .25366 L
.41476 .25364 L
.41491 .25361 L
.41505 .25358 L
.41519 .25355 L
.41533 .25353 L
.41548 .2535 L
.41562 .25347 L
.41576 .25345 L
Mistroke
.4159 .25342 L
.41605 .25339 L
.41619 .25337 L
.41633 .25334 L
.41647 .25332 L
.41661 .25329 L
.41676 .25326 L
.4169 .25324 L
.41704 .25321 L
.41718 .25319 L
.41732 .25316 L
.41746 .25314 L
.4176 .25311 L
.41775 .25309 L
.41789 .25306 L
.41803 .25304 L
.41817 .25301 L
.41831 .25299 L
.41845 .25296 L
.41859 .25294 L
.41873 .25291 L
.41887 .25289 L
.41901 .25286 L
.41915 .25284 L
.41929 .25282 L
.41944 .25279 L
.41958 .25277 L
.41972 .25274 L
.41986 .25272 L
.42 .2527 L
.42014 .25267 L
.42028 .25265 L
.42042 .25263 L
.42056 .2526 L
.42069 .25258 L
.42083 .25256 L
.42097 .25254 L
.42111 .25251 L
.42125 .25249 L
.42139 .25247 L
.42153 .25245 L
.42167 .25242 L
.42181 .2524 L
.42195 .25238 L
.42209 .25236 L
.42223 .25234 L
.42236 .25231 L
.4225 .25229 L
.42264 .25227 L
.42278 .25225 L
Mistroke
.42292 .25223 L
.42306 .25221 L
.4232 .25219 L
.42333 .25216 L
.42347 .25214 L
.42361 .25212 L
.42375 .2521 L
.42389 .25208 L
.42402 .25206 L
.42416 .25204 L
.4243 .25202 L
.42444 .252 L
.42457 .25198 L
.42471 .25196 L
.42485 .25194 L
.42499 .25192 L
.42512 .2519 L
.42526 .25188 L
.4254 .25186 L
.42554 .25184 L
.42567 .25182 L
.42581 .2518 L
.42595 .25178 L
.42608 .25177 L
.42622 .25175 L
.42636 .25173 L
.42649 .25171 L
.42663 .25169 L
.42676 .25167 L
.4269 .25165 L
.42704 .25164 L
.42717 .25162 L
.42731 .2516 L
.42744 .25158 L
.42758 .25156 L
.42772 .25155 L
.42785 .25153 L
.42799 .25151 L
.42812 .25149 L
.42826 .25148 L
.42839 .25146 L
.42853 .25144 L
.42866 .25142 L
.4288 .25141 L
.42893 .25139 L
.42907 .25137 L
.4292 .25136 L
.42934 .25134 L
.42947 .25132 L
.42961 .25131 L
Mistroke
.42974 .25129 L
.42988 .25127 L
.43001 .25126 L
.43015 .25124 L
.43028 .25123 L
.43041 .25121 L
.43055 .25119 L
.43068 .25118 L
.43082 .25116 L
.43095 .25115 L
.43108 .25113 L
.43122 .25112 L
.43135 .2511 L
.43148 .25109 L
.43162 .25107 L
.43175 .25106 L
.43188 .25104 L
.43202 .25103 L
.43215 .25101 L
.43228 .251 L
.43242 .25098 L
.43255 .25097 L
.43268 .25096 L
.43281 .25094 L
.43295 .25093 L
.43308 .25091 L
.43321 .2509 L
.43335 .25089 L
.43348 .25087 L
.43361 .25086 L
.43374 .25085 L
.43387 .25083 L
.43401 .25082 L
.43414 .25081 L
.43427 .25079 L
.4344 .25078 L
.43453 .25077 L
.43466 .25075 L
.4348 .25074 L
.43493 .25073 L
.43506 .25072 L
.43519 .2507 L
.43532 .25069 L
.43545 .25068 L
.43558 .25067 L
.43571 .25066 L
.43585 .25064 L
.43598 .25063 L
.43611 .25062 L
.43624 .25061 L
Mistroke
.43637 .2506 L
.4365 .25059 L
.43663 .25058 L
.43676 .25056 L
.43689 .25055 L
.43702 .25054 L
.43715 .25053 L
.43728 .25052 L
.43741 .25051 L
.43754 .2505 L
.43767 .25049 L
.4378 .25048 L
.43793 .25047 L
.43806 .25046 L
.43819 .25045 L
.43832 .25044 L
.43845 .25043 L
.43857 .25042 L
.4387 .25041 L
.43883 .2504 L
.43896 .25039 L
.43909 .25038 L
.43922 .25037 L
.43935 .25036 L
.43948 .25035 L
.4396 .25034 L
.43973 .25033 L
.43986 .25032 L
.43999 .25031 L
.44012 .25031 L
.44025 .2503 L
.44037 .25029 L
.4405 .25028 L
.44063 .25027 L
.44076 .25026 L
.44088 .25025 L
.44101 .25025 L
.44114 .25024 L
.44127 .25023 L
.44139 .25022 L
.44152 .25021 L
.44165 .25021 L
.44178 .2502 L
.4419 .25019 L
.44203 .25018 L
.44216 .25018 L
.44228 .25017 L
.44241 .25016 L
.44254 .25016 L
.44266 .25015 L
Mistroke
.44279 .25014 L
.44292 .25014 L
.44304 .25013 L
.44317 .25012 L
.44329 .25012 L
.44342 .25011 L
.44355 .2501 L
.44367 .2501 L
.4438 .25009 L
.44392 .25008 L
.44405 .25008 L
.44417 .25007 L
.4443 .25007 L
.44443 .25006 L
.44455 .25006 L
.44468 .25005 L
.4448 .25004 L
.44493 .25004 L
.44505 .25003 L
.44518 .25003 L
.4453 .25002 L
.44542 .25002 L
.44555 .25001 L
.44567 .25001 L
.4458 .25 L
.44592 .25 L
.44605 .25 L
.44617 .24999 L
.44629 .24999 L
.44642 .24998 L
.44654 .24998 L
.44667 .24997 L
.44679 .24997 L
.44691 .24997 L
.44704 .24996 L
.44716 .24996 L
.44728 .24996 L
.44741 .24995 L
.44753 .24995 L
.44765 .24994 L
.44778 .24994 L
.4479 .24994 L
.44802 .24994 L
.44815 .24993 L
.44827 .24993 L
.44839 .24993 L
.44851 .24992 L
.44864 .24992 L
.44876 .24992 L
.44888 .24992 L
Mistroke
.449 .24991 L
.44912 .24991 L
.44925 .24991 L
.44937 .24991 L
.44949 .24991 L
.44961 .2499 L
.44973 .2499 L
.44986 .2499 L
.44998 .2499 L
.4501 .2499 L
.45022 .24989 L
.45034 .24989 L
.45046 .24989 L
.45058 .24989 L
.4507 .24989 L
.45082 .24989 L
.45095 .24989 L
.45107 .24989 L
.45119 .24989 L
.45131 .24988 L
.45143 .24988 L
.45155 .24988 L
.45167 .24988 L
.45179 .24988 L
.45191 .24988 L
.45203 .24988 L
.45215 .24988 L
.45227 .24988 L
.45239 .24988 L
.45251 .24988 L
.45263 .24988 L
.45275 .24988 L
.45287 .24988 L
.45299 .24988 L
.4531 .24988 L
.45322 .24989 L
.45334 .24989 L
.45346 .24989 L
.45358 .24989 L
.4537 .24989 L
.45382 .24989 L
.45394 .24989 L
.45406 .24989 L
.45417 .24989 L
.45429 .24989 L
.45441 .2499 L
.45453 .2499 L
.45465 .2499 L
.45477 .2499 L
.45488 .2499 L
Mistroke
.455 .24991 L
.45512 .24991 L
.45524 .24991 L
.45535 .24991 L
.45547 .24991 L
.45559 .24992 L
.45571 .24992 L
.45582 .24992 L
.45594 .24992 L
.45606 .24993 L
.45617 .24993 L
.45629 .24993 L
.45641 .24993 L
.45652 .24994 L
.45664 .24994 L
.45676 .24994 L
.45687 .24995 L
.45699 .24995 L
.45711 .24995 L
.45722 .24996 L
.45734 .24996 L
.45745 .24996 L
.45757 .24997 L
.45769 .24997 L
.4578 .24998 L
.45792 .24998 L
.45803 .24998 L
.45815 .24999 L
.45826 .24999 L
.45838 .25 L
.45849 .25 L
.45861 .25001 L
.45872 .25001 L
.45884 .25002 L
.45895 .25002 L
.45907 .25003 L
.45918 .25003 L
.4593 .25004 L
.45941 .25004 L
.45953 .25005 L
.45964 .25005 L
.45976 .25006 L
.45987 .25006 L
.45998 .25007 L
.4601 .25007 L
.46021 .25008 L
.46033 .25008 L
.46044 .25009 L
.46055 .2501 L
.46067 .2501 L
Mistroke
.46078 .25011 L
.46089 .25011 L
.46101 .25012 L
.46112 .25013 L
.46123 .25013 L
.46135 .25014 L
.46146 .25015 L
.46157 .25015 L
.46168 .25016 L
.4618 .25017 L
.46191 .25017 L
.46202 .25018 L
.46213 .25019 L
.46225 .25019 L
.46236 .2502 L
.46247 .25021 L
.46258 .25022 L
.46269 .25022 L
.46281 .25023 L
.46292 .25024 L
.46303 .25025 L
.46314 .25025 L
.46325 .25026 L
.46336 .25027 L
.46347 .25028 L
.46359 .25029 L
.4637 .25029 L
.46381 .2503 L
.46392 .25031 L
.46403 .25032 L
.46414 .25033 L
.46425 .25034 L
.46436 .25035 L
.46447 .25035 L
.46458 .25036 L
.46469 .25037 L
.4648 .25038 L
.46491 .25039 L
.46502 .2504 L
.46513 .25041 L
.46524 .25042 L
.46535 .25043 L
.46546 .25044 L
.46557 .25045 L
.46568 .25046 L
.46579 .25047 L
.4659 .25048 L
.46601 .25049 L
.46612 .2505 L
.46623 .25051 L
Mistroke
.46633 .25052 L
.46644 .25053 L
.46655 .25054 L
.46666 .25055 L
.46677 .25056 L
.46688 .25057 L
.46699 .25058 L
.46709 .25059 L
.4672 .2506 L
.46731 .25061 L
.46742 .25062 L
.46753 .25063 L
.46763 .25064 L
.46774 .25065 L
.46785 .25067 L
.46796 .25068 L
.46806 .25069 L
.46817 .2507 L
.46828 .25071 L
.46839 .25072 L
.46849 .25073 L
.4686 .25075 L
.46871 .25076 L
.46881 .25077 L
.46892 .25078 L
.46903 .25079 L
.46913 .25081 L
.46924 .25082 L
.46934 .25083 L
.46945 .25084 L
.46956 .25085 L
.46966 .25087 L
.46977 .25088 L
.46987 .25089 L
.46998 .25091 L
.47009 .25092 L
.47019 .25093 L
.4703 .25094 L
.4704 .25096 L
.47051 .25097 L
.47061 .25098 L
.47072 .251 L
.47082 .25101 L
.47093 .25102 L
.47103 .25104 L
.47114 .25105 L
.47124 .25106 L
.47135 .25108 L
.47145 .25109 L
.47156 .25111 L
Mistroke
.47166 .25112 L
.47176 .25113 L
.47187 .25115 L
.47197 .25116 L
.47208 .25118 L
.47218 .25119 L
.47228 .25121 L
.47239 .25122 L
.47249 .25123 L
.47259 .25125 L
.4727 .25126 L
.4728 .25128 L
.4729 .25129 L
.47301 .25131 L
.47311 .25132 L
.47321 .25134 L
.47331 .25135 L
.47342 .25137 L
.47352 .25138 L
.47362 .2514 L
.47372 .25141 L
.47383 .25143 L
.47393 .25145 L
.47403 .25146 L
.47413 .25148 L
.47423 .25149 L
.47434 .25151 L
.47444 .25153 L
.47454 .25154 L
.47464 .25156 L
.47474 .25157 L
.47484 .25159 L
.47494 .25161 L
.47505 .25162 L
.47515 .25164 L
.47525 .25166 L
.47535 .25167 L
.47545 .25169 L
.47555 .25171 L
.47565 .25172 L
.47575 .25174 L
.47585 .25176 L
.47595 .25177 L
.47605 .25179 L
.47615 .25181 L
.47625 .25183 L
.47635 .25184 L
.47645 .25186 L
.47655 .25188 L
.47665 .2519 L
Mistroke
.47675 .25191 L
.47685 .25193 L
.47695 .25195 L
.47705 .25197 L
.47715 .25199 L
.47725 .252 L
.47735 .25202 L
.47744 .25204 L
.47754 .25206 L
.47764 .25208 L
.47774 .25209 L
.47784 .25211 L
.47794 .25213 L
.47803 .25215 L
.47813 .25217 L
.47823 .25219 L
.47833 .25221 L
.47843 .25223 L
.47852 .25224 L
.47862 .25226 L
.47872 .25228 L
.47882 .2523 L
.47891 .25232 L
.47901 .25234 L
.47911 .25236 L
.47921 .25238 L
.4793 .2524 L
.4794 .25242 L
.4795 .25244 L
.47959 .25246 L
.47969 .25248 L
.47979 .2525 L
.47988 .25252 L
.47998 .25254 L
.48008 .25256 L
.48017 .25258 L
.48027 .2526 L
.48036 .25262 L
.48046 .25264 L
.48056 .25266 L
.48065 .25268 L
.48075 .2527 L
.48084 .25272 L
.48094 .25274 L
.48103 .25276 L
.48113 .25279 L
.48122 .25281 L
.48132 .25283 L
.48141 .25285 L
.48151 .25287 L
Mistroke
.4816 .25289 L
.4817 .25291 L
.48179 .25293 L
.48189 .25296 L
.48198 .25298 L
.48207 .253 L
.48217 .25302 L
.48226 .25304 L
.48236 .25306 L
.48245 .25309 L
.48254 .25311 L
.48264 .25313 L
.48273 .25315 L
.48282 .25317 L
.48292 .2532 L
.48301 .25322 L
.4831 .25324 L
.4832 .25326 L
.48329 .25329 L
.48338 .25331 L
.48348 .25333 L
.48357 .25335 L
.48366 .25338 L
.48375 .2534 L
.48385 .25342 L
.48394 .25345 L
.48403 .25347 L
.48412 .25349 L
.48421 .25352 L
.48431 .25354 L
.4844 .25356 L
.48449 .25359 L
.48458 .25361 L
.48467 .25363 L
.48476 .25366 L
.48486 .25368 L
.48495 .2537 L
.48504 .25373 L
.48513 .25375 L
.48522 .25378 L
.48531 .2538 L
.4854 .25382 L
.48549 .25385 L
.48558 .25387 L
.48567 .2539 L
.48576 .25392 L
.48585 .25395 L
.48594 .25397 L
.48603 .25399 L
.48612 .25402 L
Mistroke
.48621 .25404 L
.4863 .25407 L
.48639 .25409 L
.48648 .25412 L
.48657 .25414 L
.48666 .25417 L
.48675 .25419 L
.48684 .25422 L
.48693 .25424 L
.48702 .25427 L
.48711 .25429 L
.48719 .25432 L
.48728 .25435 L
.48737 .25437 L
.48746 .2544 L
.48755 .25442 L
.48764 .25445 L
.48772 .25447 L
.48781 .2545 L
.4879 .25453 L
.48799 .25455 L
.48808 .25458 L
.48816 .25461 L
.48825 .25463 L
.48834 .25466 L
.48843 .25468 L
.48851 .25471 L
.4886 .25474 L
.48869 .25476 L
.48877 .25479 L
.48886 .25482 L
.48895 .25484 L
.48903 .25487 L
.48912 .2549 L
.48921 .25493 L
.48929 .25495 L
.48938 .25498 L
.48947 .25501 L
.48955 .25503 L
.48964 .25506 L
.48972 .25509 L
.48981 .25512 L
.4899 .25514 L
.48998 .25517 L
.49007 .2552 L
.49015 .25523 L
.49024 .25525 L
.49032 .25528 L
.49041 .25531 L
.49049 .25534 L
Mistroke
.49058 .25537 L
.49066 .25539 L
.49075 .25542 L
.49083 .25545 L
.49092 .25548 L
.491 .25551 L
.49108 .25554 L
.49117 .25556 L
.49125 .25559 L
.49134 .25562 L
.49142 .25565 L
.4915 .25568 L
.49159 .25571 L
.49167 .25574 L
.49175 .25577 L
.49184 .25579 L
.49192 .25582 L
.492 .25585 L
.49209 .25588 L
.49217 .25591 L
.49225 .25594 L
.49234 .25597 L
.49242 .256 L
.4925 .25603 L
.49258 .25606 L
.49267 .25609 L
.49275 .25612 L
.49283 .25615 L
.49291 .25618 L
.49299 .25621 L
.49308 .25624 L
.49316 .25627 L
.49324 .2563 L
.49332 .25633 L
.4934 .25636 L
.49348 .25639 L
.49357 .25642 L
.49365 .25645 L
.49373 .25648 L
.49381 .25651 L
.49389 .25654 L
.49397 .25657 L
.49405 .2566 L
.49413 .25663 L
.49421 .25666 L
.49429 .2567 L
.49437 .25673 L
.49445 .25676 L
.49453 .25679 L
.49461 .25682 L
Mistroke
.49469 .25685 L
.49477 .25688 L
.49485 .25691 L
.49493 .25695 L
.49501 .25698 L
.49509 .25701 L
.49517 .25704 L
.49525 .25707 L
.49533 .2571 L
.49541 .25714 L
.49548 .25717 L
.49556 .2572 L
.49564 .25723 L
.49572 .25726 L
.4958 .2573 L
.49588 .25733 L
.49596 .25736 L
.49603 .25739 L
.49611 .25742 L
.49619 .25746 L
.49627 .25749 L
.49635 .25752 L
.49642 .25755 L
.4965 .25759 L
.49658 .25762 L
.49665 .25765 L
.49673 .25769 L
.49681 .25772 L
.49689 .25775 L
.49696 .25778 L
.49704 .25782 L
.49712 .25785 L
.49719 .25788 L
.49727 .25792 L
.49735 .25795 L
.49742 .25798 L
.4975 .25802 L
.49757 .25805 L
.49765 .25808 L
.49773 .25812 L
.4978 .25815 L
.49788 .25819 L
.49795 .25822 L
.49803 .25825 L
.4981 .25829 L
.49818 .25832 L
.49825 .25835 L
.49833 .25839 L
.4984 .25842 L
.49848 .25846 L
Mistroke
.49855 .25849 L
.49863 .25853 L
.4987 .25856 L
.49878 .2586 L
.49885 .25863 L
.49893 .25866 L
.499 .2587 L
.49907 .25873 L
.49915 .25877 L
.49922 .2588 L
.4993 .25884 L
.49937 .25887 L
.49944 .25891 L
.49952 .25894 L
.49959 .25898 L
.49966 .25901 L
.49974 .25905 L
.49981 .25908 L
.49988 .25912 L
.49996 .25915 L
.50003 .25919 L
.5001 .25923 L
.50017 .25926 L
.50025 .2593 L
.50032 .25933 L
.50039 .25937 L
.50046 .2594 L
.50053 .25944 L
.50061 .25948 L
.50068 .25951 L
.50075 .25955 L
.50082 .25958 L
.50089 .25962 L
.50096 .25966 L
.50104 .25969 L
.50111 .25973 L
.50118 .25977 L
.50125 .2598 L
.50132 .25984 L
.50139 .25988 L
.50146 .25991 L
.50153 .25995 L
.5016 .25999 L
.50167 .26002 L
.50174 .26006 L
.50181 .2601 L
.50188 .26013 L
.50195 .26017 L
.50202 .26021 L
.50209 .26024 L
Mistroke
.50216 .26028 L
.50223 .26032 L
.5023 .26036 L
.50237 .26039 L
.50244 .26043 L
.50251 .26047 L
.50258 .26051 L
.50265 .26054 L
.50272 .26058 L
.50278 .26062 L
.50285 .26066 L
.50292 .26069 L
.50299 .26073 L
.50306 .26077 L
.50313 .26081 L
.50319 .26085 L
.50326 .26088 L
.50333 .26092 L
.5034 .26096 L
.50347 .261 L
.50353 .26104 L
.5036 .26108 L
.50367 .26111 L
.50374 .26115 L
.5038 .26119 L
.50387 .26123 L
.50394 .26127 L
.504 .26131 L
.50407 .26135 L
.50414 .26138 L
.5042 .26142 L
.50427 .26146 L
.50434 .2615 L
.5044 .26154 L
.50447 .26158 L
.50454 .26162 L
.5046 .26166 L
.50467 .2617 L
.50473 .26174 L
.5048 .26178 L
.50486 .26182 L
.50493 .26186 L
.505 .26189 L
.50506 .26193 L
.50513 .26197 L
.50519 .26201 L
.50526 .26205 L
.50532 .26209 L
.50538 .26213 L
.50545 .26217 L
Mistroke
.50551 .26221 L
.50558 .26225 L
.50564 .26229 L
.50571 .26233 L
.50577 .26237 L
.50583 .26241 L
.5059 .26245 L
.50596 .26249 L
.50603 .26253 L
.50609 .26258 L
.50615 .26262 L
.50622 .26266 L
.50628 .2627 L
.50634 .26274 L
.50641 .26278 L
.50647 .26282 L
.50653 .26286 L
.50659 .2629 L
.50666 .26294 L
.50672 .26298 L
.50678 .26302 L
.50684 .26307 L
.50691 .26311 L
.50697 .26315 L
.50703 .26319 L
.50709 .26323 L
.50715 .26327 L
.50722 .26331 L
.50728 .26335 L
.50734 .2634 L
.5074 .26344 L
.50746 .26348 L
.50752 .26352 L
.50758 .26356 L
.50765 .2636 L
.50771 .26365 L
.50777 .26369 L
.50783 .26373 L
.50789 .26377 L
.50795 .26381 L
.50801 .26386 L
.50807 .2639 L
.50813 .26394 L
.50819 .26398 L
.50825 .26402 L
.50831 .26407 L
.50837 .26411 L
.50843 .26415 L
.50849 .26419 L
.50855 .26424 L
Mistroke
.50861 .26428 L
.50867 .26432 L
.50873 .26437 L
.50878 .26441 L
.50884 .26445 L
.5089 .26449 L
.50896 .26454 L
.50902 .26458 L
.50908 .26462 L
.50914 .26467 L
.5092 .26471 L
.50925 .26475 L
.50931 .2648 L
.50937 .26484 L
.50943 .26488 L
.50949 .26493 L
.50954 .26497 L
.5096 .26501 L
.50966 .26506 L
.50972 .2651 L
.50977 .26514 L
.50983 .26519 L
.50989 .26523 L
.50994 .26527 L
.51 .26532 L
.51006 .26536 L
.51011 .26541 L
.51017 .26545 L
.51023 .26549 L
.51028 .26554 L
.51034 .26558 L
.5104 .26563 L
.51045 .26567 L
.51051 .26571 L
.51056 .26576 L
.51062 .2658 L
.51067 .26585 L
.51073 .26589 L
.51079 .26594 L
.51084 .26598 L
.5109 .26603 L
.51095 .26607 L
.51101 .26612 L
.51106 .26616 L
.51112 .2662 L
.51117 .26625 L
.51123 .26629 L
.51128 .26634 L
.51133 .26638 L
.51139 .26643 L
Mistroke
.51144 .26647 L
.5115 .26652 L
.51155 .26656 L
.5116 .26661 L
.51166 .26666 L
.51171 .2667 L
.51177 .26675 L
.51182 .26679 L
.51187 .26684 L
.51193 .26688 L
.51198 .26693 L
.51203 .26697 L
.51208 .26702 L
.51214 .26707 L
.51219 .26711 L
.51224 .26716 L
.51229 .2672 L
.51235 .26725 L
.5124 .26729 L
.51245 .26734 L
.5125 .26739 L
.51256 .26743 L
.51261 .26748 L
.51266 .26753 L
.51271 .26757 L
.51276 .26762 L
.51281 .26766 L
.51287 .26771 L
.51292 .26776 L
.51297 .2678 L
.51302 .26785 L
.51307 .2679 L
.51312 .26794 L
.51317 .26799 L
.51322 .26804 L
.51327 .26808 L
.51332 .26813 L
.51337 .26818 L
.51342 .26822 L
.51347 .26827 L
.51352 .26832 L
.51357 .26836 L
.51362 .26841 L
.51367 .26846 L
.51372 .26851 L
.51377 .26855 L
.51382 .2686 L
.51387 .26865 L
.51392 .2687 L
.51397 .26874 L
Mistroke
.51402 .26879 L
.51407 .26884 L
.51412 .26888 L
.51416 .26893 L
.51421 .26898 L
.51426 .26903 L
.51431 .26908 L
.51436 .26912 L
.51441 .26917 L
.51445 .26922 L
.5145 .26927 L
.51455 .26931 L
.5146 .26936 L
.51465 .26941 L
.51469 .26946 L
.51474 .26951 L
.51479 .26956 L
.51484 .2696 L
.51488 .26965 L
.51493 .2697 L
.51498 .26975 L
.51502 .2698 L
.51507 .26985 L
.51512 .26989 L
.51516 .26994 L
.51521 .26999 L
.51526 .27004 L
.5153 .27009 L
.51535 .27014 L
.51539 .27019 L
.51544 .27023 L
.51549 .27028 L
.51553 .27033 L
.51558 .27038 L
.51562 .27043 L
.51567 .27048 L
.51571 .27053 L
.51576 .27058 L
.5158 .27063 L
.51585 .27068 L
.51589 .27072 L
.51594 .27077 L
.51598 .27082 L
.51603 .27087 L
.51607 .27092 L
.51612 .27097 L
.51616 .27102 L
.5162 .27107 L
.51625 .27112 L
.51629 .27117 L
Mistroke
.51634 .27122 L
.51638 .27127 L
.51642 .27132 L
.51647 .27137 L
.51651 .27142 L
.51655 .27147 L
.5166 .27152 L
.51664 .27157 L
.51668 .27162 L
.51673 .27167 L
.51677 .27172 L
.51681 .27177 L
.51685 .27182 L
.5169 .27187 L
.51694 .27192 L
.51698 .27197 L
.51702 .27202 L
.51706 .27207 L
.51711 .27212 L
.51715 .27217 L
.51719 .27222 L
.51723 .27227 L
.51727 .27232 L
.51732 .27237 L
.51736 .27242 L
.5174 .27247 L
.51744 .27252 L
.51748 .27257 L
.51752 .27263 L
.51756 .27268 L
.5176 .27273 L
.51764 .27278 L
.51768 .27283 L
.51772 .27288 L
.51776 .27293 L
.5178 .27298 L
.51784 .27303 L
.51788 .27308 L
.51792 .27314 L
.51796 .27319 L
.518 .27324 L
.51804 .27329 L
.51808 .27334 L
.51812 .27339 L
.51816 .27344 L
.5182 .2735 L
.51824 .27355 L
.51828 .2736 L
.51832 .27365 L
.51836 .2737 L
Mistroke
.5184 .27375 L
.51843 .2738 L
.51847 .27386 L
.51851 .27391 L
.51855 .27396 L
.51859 .27401 L
.51863 .27406 L
.51866 .27412 L
.5187 .27417 L
.51874 .27422 L
.51878 .27427 L
.51881 .27432 L
.51885 .27438 L
.51889 .27443 L
.51893 .27448 L
.51896 .27453 L
.519 .27459 L
.51904 .27464 L
.51907 .27469 L
.51911 .27474 L
.51915 .27479 L
.51918 .27485 L
.51922 .2749 L
.51926 .27495 L
.51929 .27501 L
.51933 .27506 L
.51937 .27511 L
.5194 .27516 L
.51944 .27522 L
.51947 .27527 L
.51951 .27532 L
.51954 .27537 L
.51958 .27543 L
.51961 .27548 L
.51965 .27553 L
.51968 .27559 L
.51972 .27564 L
.51975 .27569 L
.51979 .27575 L
.51982 .2758 L
.51986 .27585 L
.51989 .2759 L
.51993 .27596 L
.51996 .27601 L
.52 .27606 L
.52003 .27612 L
.52006 .27617 L
.5201 .27623 L
.52013 .27628 L
.52017 .27633 L
Mistroke
.5202 .27639 L
.52023 .27644 L
.52027 .27649 L
.5203 .27655 L
.52033 .2766 L
.52037 .27665 L
.5204 .27671 L
.52043 .27676 L
.52046 .27682 L
.5205 .27687 L
.52053 .27692 L
.52056 .27698 L
.52059 .27703 L
.52063 .27709 L
.52066 .27714 L
.52069 .27719 L
.52072 .27725 L
.52075 .2773 L
.52079 .27736 L
.52082 .27741 L
.52085 .27746 L
.52088 .27752 L
.52091 .27757 L
.52094 .27763 L
.52097 .27768 L
.52101 .27774 L
.52104 .27779 L
.52107 .27785 L
.5211 .2779 L
.52113 .27795 L
.52116 .27801 L
.52119 .27806 L
.52122 .27812 L
.52125 .27817 L
.52128 .27823 L
.52131 .27828 L
.52134 .27834 L
.52137 .27839 L
.5214 .27845 L
.52143 .2785 L
.52146 .27856 L
.52149 .27861 L
.52152 .27867 L
.52155 .27872 L
.52158 .27878 L
.52161 .27883 L
.52163 .27889 L
.52166 .27894 L
.52169 .279 L
.52172 .27905 L
Mistroke
.52175 .27911 L
.52178 .27916 L
.52181 .27922 L
.52183 .27927 L
.52186 .27933 L
.52189 .27939 L
.52192 .27944 L
.52195 .2795 L
.52197 .27955 L
.522 .27961 L
.52203 .27966 L
.52206 .27972 L
.52208 .27977 L
.52211 .27983 L
.52214 .27989 L
.52217 .27994 L
.52219 .28 L
.52222 .28005 L
.52225 .28011 L
.52227 .28016 L
.5223 .28022 L
.52233 .28028 L
.52235 .28033 L
.52238 .28039 L
.5224 .28044 L
.52243 .2805 L
.52246 .28056 L
.52248 .28061 L
.52251 .28067 L
.52253 .28073 L
.52256 .28078 L
.52258 .28084 L
.52261 .28089 L
.52263 .28095 L
.52266 .28101 L
.52268 .28106 L
.52271 .28112 L
.52273 .28118 L
.52276 .28123 L
.52278 .28129 L
.52281 .28135 L
.52283 .2814 L
.52286 .28146 L
.52288 .28152 L
.52291 .28157 L
.52293 .28163 L
.52295 .28169 L
.52298 .28174 L
.523 .2818 L
.52302 .28186 L
Mistroke
.52305 .28191 L
.52307 .28197 L
.5231 .28203 L
.52312 .28208 L
.52314 .28214 L
.52316 .2822 L
.52319 .28225 L
.52321 .28231 L
.52323 .28237 L
.52326 .28243 L
.52328 .28248 L
.5233 .28254 L
.52332 .2826 L
.52335 .28265 L
.52337 .28271 L
.52339 .28277 L
.52341 .28283 L
.52343 .28288 L
.52346 .28294 L
.52348 .283 L
.5235 .28306 L
.52352 .28311 L
.52354 .28317 L
.52356 .28323 L
.52358 .28329 L
.5236 .28334 L
.52363 .2834 L
.52365 .28346 L
.52367 .28352 L
.52369 .28357 L
.52371 .28363 L
.52373 .28369 L
.52375 .28375 L
.52377 .2838 L
.52379 .28386 L
.52381 .28392 L
.52383 .28398 L
.52385 .28404 L
.52387 .28409 L
.52389 .28415 L
.52391 .28421 L
.52393 .28427 L
.52395 .28433 L
.52397 .28438 L
.52399 .28444 L
.52401 .2845 L
.52403 .28456 L
.52404 .28462 L
.52406 .28467 L
.52408 .28473 L
Mistroke
.5241 .28479 L
.52412 .28485 L
.52414 .28491 L
.52416 .28497 L
.52417 .28502 L
.52419 .28508 L
.52421 .28514 L
.52423 .2852 L
.52425 .28526 L
.52426 .28532 L
.52428 .28537 L
.5243 .28543 L
.52432 .28549 L
.52433 .28555 L
.52435 .28561 L
.52437 .28567 L
.52439 .28573 L
.5244 .28578 L
.52442 .28584 L
.52444 .2859 L
.52445 .28596 L
.52447 .28602 L
.52449 .28608 L
.5245 .28614 L
.52452 .2862 L
.52453 .28625 L
.52455 .28631 L
.52457 .28637 L
.52458 .28643 L
.5246 .28649 L
.52461 .28655 L
.52463 .28661 L
.52465 .28667 L
.52466 .28673 L
.52468 .28679 L
.52469 .28684 L
.52471 .2869 L
.52472 .28696 L
.52474 .28702 L
.52475 .28708 L
.52477 .28714 L
.52478 .2872 L
.5248 .28726 L
.52481 .28732 L
.52482 .28738 L
.52484 .28744 L
.52485 .2875 L
.52487 .28756 L
.52488 .28762 L
.5249 .28767 L
Mistroke
.52491 .28773 L
.52492 .28779 L
.52494 .28785 L
.52495 .28791 L
.52496 .28797 L
.52498 .28803 L
.52499 .28809 L
.525 .28815 L
.52502 .28821 L
.52503 .28827 L
.52504 .28833 L
.52506 .28839 L
.52507 .28845 L
.52508 .28851 L
.52509 .28857 L
.52511 .28863 L
.52512 .28869 L
.52513 .28875 L
.52514 .28881 L
.52515 .28887 L
.52517 .28893 L
.52518 .28899 L
.52519 .28905 L
.5252 .28911 L
.52521 .28917 L
.52522 .28923 L
.52524 .28929 L
.52525 .28935 L
.52526 .28941 L
.52527 .28947 L
.52528 .28953 L
.52529 .28959 L
.5253 .28965 L
.52531 .28971 L
.52532 .28977 L
.52533 .28983 L
.52534 .28989 L
.52535 .28995 L
.52536 .29001 L
.52537 .29007 L
.52538 .29013 L
.52539 .29019 L
.5254 .29025 L
.52541 .29031 L
.52542 .29037 L
.52543 .29043 L
.52544 .29049 L
.52545 .29055 L
.52546 .29061 L
.52547 .29067 L
Mistroke
.52548 .29073 L
.52549 .29079 L
.5255 .29086 L
.52551 .29092 L
.52552 .29098 L
.52552 .29104 L
.52553 .2911 L
.52554 .29116 L
.52555 .29122 L
.52556 .29128 L
.52557 .29134 L
.52557 .2914 L
.52558 .29146 L
.52559 .29152 L
.5256 .29158 L
.52561 .29164 L
.52561 .2917 L
.52562 .29177 L
.52563 .29183 L
.52564 .29189 L
.52564 .29195 L
.52565 .29201 L
.52566 .29207 L
.52566 .29213 L
.52567 .29219 L
.52568 .29225 L
.52569 .29231 L
.52569 .29237 L
.5257 .29244 L
.5257 .2925 L
.52571 .29256 L
.52572 .29262 L
.52572 .29268 L
.52573 .29274 L
.52574 .2928 L
.52574 .29286 L
.52575 .29292 L
.52575 .29299 L
.52576 .29305 L
.52576 .29311 L
.52577 .29317 L
.52577 .29323 L
.52578 .29329 L
.52579 .29335 L
.52579 .29341 L
.5258 .29348 L
.5258 .29354 L
.52581 .2936 L
.52581 .29366 L
.52581 .29372 L
Mistroke
.52582 .29378 L
.52582 .29384 L
.52583 .29391 L
.52583 .29397 L
.52584 .29403 L
.52584 .29409 L
.52584 .29415 L
.52585 .29421 L
.52585 .29427 L
.52586 .29434 L
.52586 .2944 L
.52586 .29446 L
.52587 .29452 L
.52587 .29458 L
.52587 .29464 L
.52588 .2947 L
.52588 .29477 L
.52588 .29483 L
.52589 .29489 L
.52589 .29495 L
.52589 .29501 L
.52589 .29507 L
.5259 .29514 L
.5259 .2952 L
.5259 .29526 L
.5259 .29532 L
.52591 .29538 L
.52591 .29545 L
.52591 .29551 L
.52591 .29557 L
.52591 .29563 L
.52592 .29569 L
.52592 .29575 L
.52592 .29582 L
.52592 .29588 L
.52592 .29594 L
.52592 .296 L
.52592 .29606 L
.52592 .29613 L
.52593 .29619 L
.52593 .29625 L
.52593 .29631 L
.52593 .29637 L
.52593 .29644 L
.52593 .2965 L
.52593 .29656 L
.52593 .29662 L
.52593 .29668 L
.52593 .29675 L
.52593 .29681 L
Mistroke
.52593 .29687 L
.52593 .29693 L
.52593 .29699 L
.52593 .29706 L
.52593 .29712 L
.52593 .29718 L
.52593 .29724 L
.52593 .2973 L
.52593 .29737 L
.52593 .29743 L
.52593 .29749 L
.52593 .29755 L
.52593 .29762 L
.52592 .29768 L
.52592 .29774 L
.52592 .2978 L
.52592 .29786 L
.52592 .29793 L
.52592 .29799 L
.52592 .29805 L
.52591 .29811 L
.52591 .29818 L
.52591 .29824 L
.52591 .2983 L
.52591 .29836 L
.52591 .29843 L
.5259 .29849 L
.5259 .29855 L
.5259 .29861 L
.5259 .29867 L
.52589 .29874 L
.52589 .2988 L
.52589 .29886 L
.52589 .29892 L
.52588 .29899 L
.52588 .29905 L
.52588 .29911 L
.52587 .29917 L
.52587 .29924 L
.52587 .2993 L
.52586 .29936 L
.52586 .29942 L
.52586 .29949 L
.52585 .29955 L
.52585 .29961 L
.52585 .29967 L
.52584 .29974 L
.52584 .2998 L
.52583 .29986 L
.52583 .29992 L
Mistroke
.52583 .29999 L
.52582 .30005 L
.52582 .30011 L
.52581 .30017 L
.52581 .30024 L
.5258 .3003 L
.5258 .30036 L
.52579 .30043 L
.52579 .30049 L
.52578 .30055 L
.52578 .30061 L
.52577 .30068 L
.52577 .30074 L
.52576 .3008 L
.52576 .30086 L
.52575 .30093 L
.52575 .30099 L
.52574 .30105 L
.52573 .30111 L
.52573 .30118 L
.52572 .30124 L
.52572 .3013 L
.52571 .30137 L
.5257 .30143 L
.5257 .30149 L
.52569 .30155 L
.52569 .30162 L
.52568 .30168 L
.52567 .30174 L
.52567 .30181 L
.52566 .30187 L
.52565 .30193 L
.52565 .30199 L
.52564 .30206 L
.52563 .30212 L
.52562 .30218 L
.52562 .30225 L
.52561 .30231 L
.5256 .30237 L
.52559 .30243 L
.52559 .3025 L
.52558 .30256 L
.52557 .30262 L
.52556 .30269 L
.52556 .30275 L
.52555 .30281 L
.52554 .30287 L
.52553 .30294 L
.52552 .303 L
.52552 .30306 L
Mistroke
.52551 .30313 L
.5255 .30319 L
.52549 .30325 L
.52548 .30331 L
.52547 .30338 L
.52546 .30344 L
.52545 .3035 L
.52545 .30357 L
.52544 .30363 L
.52543 .30369 L
.52542 .30376 L
.52541 .30382 L
.5254 .30388 L
.52539 .30394 L
.52538 .30401 L
.52537 .30407 L
.52536 .30413 L
.52535 .3042 L
.52534 .30426 L
.52533 .30432 L
.52532 .30439 L
.52531 .30445 L
.5253 .30451 L
.52529 .30457 L
.52528 .30464 L
.52527 .3047 L
.52526 .30476 L
.52525 .30483 L
.52524 .30489 L
.52523 .30495 L
.52522 .30502 L
.52521 .30508 L
.5252 .30514 L
.52518 .3052 L
.52517 .30527 L
.52516 .30533 L
.52515 .30539 L
.52514 .30546 L
.52513 .30552 L
.52512 .30558 L
.5251 .30565 L
.52509 .30571 L
.52508 .30577 L
.52507 .30584 L
.52506 .3059 L
.52505 .30596 L
.52503 .30602 L
.52502 .30609 L
.52501 .30615 L
.525 .30621 L
Mistroke
.52498 .30628 L
.52497 .30634 L
.52496 .3064 L
.52495 .30647 L
.52493 .30653 L
.52492 .30659 L
.52491 .30666 L
.5249 .30672 L
.52488 .30678 L
.52487 .30684 L
.52486 .30691 L
.52484 .30697 L
.52483 .30703 L
.52482 .3071 L
.5248 .30716 L
.52479 .30722 L
.52478 .30729 L
.52476 .30735 L
.52475 .30741 L
.52473 .30748 L
.52472 .30754 L
.52471 .3076 L
.52469 .30766 L
.52468 .30773 L
.52466 .30779 L
.52465 .30785 L
.52464 .30792 L
.52462 .30798 L
.52461 .30804 L
.52459 .30811 L
.52458 .30817 L
.52456 .30823 L
.52455 .3083 L
.52453 .30836 L
.52452 .30842 L
.5245 .30848 L
.52449 .30855 L
.52447 .30861 L
.52446 .30867 L
.52444 .30874 L
.52443 .3088 L
.52441 .30886 L
.52439 .30893 L
.52438 .30899 L
.52436 .30905 L
.52435 .30912 L
.52433 .30918 L
.52432 .30924 L
.5243 .3093 L
.52428 .30937 L
Mistroke
.52427 .30943 L
.52425 .30949 L
.52423 .30956 L
.52422 .30962 L
.5242 .30968 L
.52419 .30975 L
.52417 .30981 L
.52415 .30987 L
.52413 .30994 L
.52412 .31 L
.5241 .31006 L
.52408 .31012 L
.52407 .31019 L
.52405 .31025 L
.52403 .31031 L
.52402 .31038 L
.524 .31044 L
.52398 .3105 L
.52396 .31057 L
.52395 .31063 L
.52393 .31069 L
.52391 .31075 L
.52389 .31082 L
.52387 .31088 L
.52386 .31094 L
.52384 .31101 L
.52382 .31107 L
.5238 .31113 L
.52378 .3112 L
.52377 .31126 L
.52375 .31132 L
.52373 .31138 L
.52371 .31145 L
.52369 .31151 L
.52367 .31157 L
.52365 .31164 L
.52363 .3117 L
.52362 .31176 L
.5236 .31183 L
.52358 .31189 L
.52356 .31195 L
.52354 .31201 L
.52352 .31208 L
.5235 .31214 L
.52348 .3122 L
.52346 .31227 L
.52344 .31233 L
.52342 .31239 L
.5234 .31245 L
.52338 .31252 L
Mistroke
.52336 .31258 L
.52334 .31264 L
.52332 .31271 L
.5233 .31277 L
.52328 .31283 L
.52326 .31289 L
.52324 .31296 L
.52322 .31302 L
.5232 .31308 L
.52318 .31315 L
.52316 .31321 L
.52314 .31327 L
.52312 .31333 L
.5231 .3134 L
.52308 .31346 L
.52306 .31352 L
.52304 .31358 L
.52302 .31365 L
.52299 .31371 L
.52297 .31377 L
.52295 .31384 L
.52293 .3139 L
.52291 .31396 L
.52289 .31402 L
.52287 .31409 L
.52285 .31415 L
.52282 .31421 L
.5228 .31427 L
.52278 .31434 L
.52276 .3144 L
.52274 .31446 L
.52271 .31453 L
.52269 .31459 L
.52267 .31465 L
.52265 .31471 L
.52263 .31478 L
.5226 .31484 L
.52258 .3149 L
.52256 .31496 L
.52254 .31503 L
.52251 .31509 L
.52249 .31515 L
.52247 .31521 L
.52245 .31528 L
.52242 .31534 L
.5224 .3154 L
.52238 .31546 L
.52235 .31553 L
.52233 .31559 L
.52231 .31565 L
Mistroke
.52228 .31571 L
.52226 .31578 L
.52224 .31584 L
.52221 .3159 L
.52219 .31596 L
.52217 .31603 L
.52214 .31609 L
.52212 .31615 L
.5221 .31621 L
.52207 .31628 L
.52205 .31634 L
.52202 .3164 L
.522 .31646 L
.52198 .31653 L
.52195 .31659 L
.52193 .31665 L
.5219 .31671 L
.52188 .31678 L
.52185 .31684 L
.52183 .3169 L
.5218 .31696 L
.52178 .31702 L
.52175 .31709 L
.52173 .31715 L
.52171 .31721 L
.52168 .31727 L
.52166 .31734 L
.52163 .3174 L
.52161 .31746 L
.52158 .31752 L
.52155 .31758 L
.52153 .31765 L
.5215 .31771 L
.52148 .31777 L
.52145 .31783 L
.52143 .3179 L
.5214 .31796 L
.52138 .31802 L
.52135 .31808 L
.52132 .31814 L
.5213 .31821 L
.52127 .31827 L
.52125 .31833 L
.52122 .31839 L
.52119 .31845 L
.52117 .31852 L
.52114 .31858 L
.52112 .31864 L
.52109 .3187 L
.52106 .31876 L
Mistroke
.52104 .31883 L
.52101 .31889 L
.52098 .31895 L
.52096 .31901 L
.52093 .31907 L
.5209 .31914 L
.52088 .3192 L
.52085 .31926 L
.52082 .31932 L
.5208 .31938 L
.52077 .31944 L
.52074 .31951 L
.52071 .31957 L
.52069 .31963 L
.52066 .31969 L
.52063 .31975 L
.5206 .31981 L
.52058 .31988 L
.52055 .31994 L
.52052 .32 L
.52049 .32006 L
.52047 .32012 L
.52044 .32018 L
.52041 .32025 L
.52038 .32031 L
.52035 .32037 L
.52033 .32043 L
.5203 .32049 L
.52027 .32055 L
.52024 .32062 L
.52021 .32068 L
.52018 .32074 L
.52016 .3208 L
.52013 .32086 L
.5201 .32092 L
.52007 .32099 L
.52004 .32105 L
.52001 .32111 L
.51998 .32117 L
.51996 .32123 L
.51993 .32129 L
.5199 .32135 L
.51987 .32141 L
.51984 .32148 L
.51981 .32154 L
.51978 .3216 L
.51975 .32166 L
.51972 .32172 L
.51969 .32178 L
.51966 .32184 L
Mistroke
.51963 .32191 L
.5196 .32197 L
.51957 .32203 L
.51954 .32209 L
.51951 .32215 L
.51948 .32221 L
.51946 .32227 L
.51943 .32233 L
.5194 .32239 L
.51937 .32246 L
.51933 .32252 L
.5193 .32258 L
.51927 .32264 L
.51924 .3227 L
.51921 .32276 L
.51918 .32282 L
.51915 .32288 L
.51912 .32294 L
.51909 .323 L
.51906 .32307 L
.51903 .32313 L
.519 .32319 L
.51897 .32325 L
.51894 .32331 L
.51891 .32337 L
.51888 .32343 L
.51885 .32349 L
.51881 .32355 L
.51878 .32361 L
.51875 .32367 L
.51872 .32373 L
.51869 .3238 L
.51866 .32386 L
.51863 .32392 L
.5186 .32398 L
.51856 .32404 L
.51853 .3241 L
.5185 .32416 L
.51847 .32422 L
.51844 .32428 L
.51841 .32434 L
.51837 .3244 L
.51834 .32446 L
.51831 .32452 L
.51828 .32458 L
.51825 .32464 L
.51821 .3247 L
.51818 .32476 L
.51815 .32482 L
.51812 .32488 L
Mistroke
.51808 .32495 L
.51805 .32501 L
.51802 .32507 L
.51799 .32513 L
.51795 .32519 L
.51792 .32525 L
.51789 .32531 L
.51786 .32537 L
.51782 .32543 L
.51779 .32549 L
.51776 .32555 L
.51772 .32561 L
.51769 .32567 L
.51766 .32573 L
.51763 .32579 L
.51759 .32585 L
.51756 .32591 L
.51753 .32597 L
.51749 .32603 L
.51746 .32609 L
.51743 .32615 L
.51739 .32621 L
.51736 .32627 L
.51733 .32633 L
.51729 .32639 L
.51726 .32645 L
.51722 .32651 L
.51719 .32657 L
.51716 .32663 L
.51712 .32669 L
.51709 .32675 L
.51706 .32681 L
.51702 .32687 L
.51699 .32693 L
.51695 .32699 L
.51692 .32704 L
.51688 .3271 L
.51685 .32716 L
.51682 .32722 L
.51678 .32728 L
.51675 .32734 L
.51671 .3274 L
.51668 .32746 L
.51664 .32752 L
.51661 .32758 L
.51657 .32764 L
.51654 .3277 L
.5165 .32776 L
.51647 .32782 L
.51643 .32788 L
Mistroke
.5164 .32794 L
.51636 .328 L
.51633 .32806 L
.51629 .32811 L
.51626 .32817 L
.51622 .32823 L
.51619 .32829 L
.51615 .32835 L
.51612 .32841 L
.51608 .32847 L
.51605 .32853 L
.51601 .32859 L
.51598 .32865 L
.51594 .32871 L
.51591 .32877 L
.51587 .32882 L
.51583 .32888 L
.5158 .32894 L
.51576 .329 L
.51573 .32906 L
.51569 .32912 L
.51565 .32918 L
.51562 .32924 L
.51558 .3293 L
.51555 .32935 L
.51551 .32941 L
.51547 .32947 L
.51544 .32953 L
.5154 .32959 L
.51537 .32965 L
.51533 .32971 L
.51529 .32976 L
.51526 .32982 L
.51522 .32988 L
.51518 .32994 L
.51515 .33 L
.51511 .33006 L
.51507 .33012 L
.51504 .33017 L
.515 .33023 L
.51496 .33029 L
.51493 .33035 L
.51489 .33041 L
.51485 .33047 L
.51481 .33052 L
.51478 .33058 L
.51474 .33064 L
.5147 .3307 L
.51467 .33076 L
.51463 .33082 L
Mistroke
.51459 .33087 L
.51455 .33093 L
.51452 .33099 L
.51448 .33105 L
.51444 .33111 L
.5144 .33116 L
.51437 .33122 L
.51433 .33128 L
.51429 .33134 L
.51425 .3314 L
.51422 .33145 L
.51418 .33151 L
.51414 .33157 L
.5141 .33163 L
.51406 .33168 L
.51403 .33174 L
.51399 .3318 L
.51395 .33186 L
.51391 .33192 L
.51387 .33197 L
.51384 .33203 L
.5138 .33209 L
.51376 .33215 L
.51372 .3322 L
.51368 .33226 L
.51364 .33232 L
.51361 .33238 L
.51357 .33243 L
.51353 .33249 L
.51349 .33255 L
.51345 .33261 L
.51341 .33266 L
.51337 .33272 L
.51333 .33278 L
.5133 .33283 L
.51326 .33289 L
.51322 .33295 L
.51318 .33301 L
.51314 .33306 L
.5131 .33312 L
.51306 .33318 L
.51302 .33323 L
.51298 .33329 L
.51294 .33335 L
.51291 .33341 L
.51287 .33346 L
.51283 .33352 L
.51279 .33358 L
.51275 .33363 L
.51271 .33369 L
Mistroke
.51267 .33375 L
.51263 .3338 L
.51259 .33386 L
.51255 .33392 L
.51251 .33397 L
.51247 .33403 L
.51243 .33409 L
.51239 .33414 L
.51235 .3342 L
.51231 .33426 L
.51227 .33431 L
.51223 .33437 L
.51219 .33443 L
.51215 .33448 L
.51211 .33454 L
.51207 .3346 L
.51203 .33465 L
.51199 .33471 L
.51195 .33476 L
.51191 .33482 L
.51187 .33488 L
.51183 .33493 L
.51179 .33499 L
.51175 .33505 L
.51171 .3351 L
.51167 .33516 L
.51163 .33521 L
.51159 .33527 L
.51155 .33533 L
.51151 .33538 L
.51147 .33544 L
.51143 .33549 L
.51139 .33555 L
.51134 .33561 L
.5113 .33566 L
.51126 .33572 L
.51122 .33577 L
.51118 .33583 L
.51114 .33588 L
.5111 .33594 L
.51106 .336 L
.51102 .33605 L
.51098 .33611 L
.51093 .33616 L
.51089 .33622 L
.51085 .33627 L
.51081 .33633 L
.51077 .33638 L
.51073 .33644 L
.51069 .33649 L
Mistroke
.51065 .33655 L
.5106 .33661 L
.51056 .33666 L
.51052 .33672 L
.51048 .33677 L
.51044 .33683 L
.5104 .33688 L
.51035 .33694 L
.51031 .33699 L
.51027 .33705 L
.51023 .3371 L
.51019 .33716 L
.51015 .33721 L
.5101 .33727 L
.51006 .33732 L
.51002 .33738 L
.50998 .33743 L
.50994 .33749 L
.50989 .33754 L
.50985 .3376 L
.50981 .33765 L
.50977 .3377 L
.50973 .33776 L
.50968 .33781 L
.50964 .33787 L
.5096 .33792 L
.50956 .33798 L
.50951 .33803 L
.50947 .33809 L
.50943 .33814 L
.50939 .3382 L
.50934 .33825 L
.5093 .3383 L
.50926 .33836 L
.50922 .33841 L
.50917 .33847 L
.50913 .33852 L
.50909 .33858 L
.50905 .33863 L
.509 .33868 L
.50896 .33874 L
.50892 .33879 L
.50887 .33885 L
.50883 .3389 L
.50879 .33895 L
.50875 .33901 L
.5087 .33906 L
.50866 .33912 L
.50862 .33917 L
.50857 .33922 L
Mistroke
.50853 .33928 L
.50849 .33933 L
.50844 .33938 L
.5084 .33944 L
.50836 .33949 L
.50831 .33954 L
.50827 .3396 L
.50823 .33965 L
.50818 .33971 L
.50814 .33976 L
.5081 .33981 L
.50805 .33987 L
.50801 .33992 L
.50797 .33997 L
.50792 .34003 L
.50788 .34008 L
.50784 .34013 L
.50779 .34019 L
.50775 .34024 L
.50771 .34029 L
.50766 .34034 L
.50762 .3404 L
.50757 .34045 L
.50753 .3405 L
.50749 .34056 L
.50744 .34061 L
.5074 .34066 L
.50735 .34071 L
.50731 .34077 L
.50727 .34082 L
.50722 .34087 L
.50718 .34093 L
.50713 .34098 L
.50709 .34103 L
.50705 .34108 L
.507 .34114 L
.50696 .34119 L
.50691 .34124 L
.50687 .34129 L
.50683 .34135 L
.50678 .3414 L
.50674 .34145 L
.50669 .3415 L
.50665 .34156 L
.5066 .34161 L
.50656 .34166 L
.50651 .34171 L
.50647 .34176 L
.50643 .34182 L
.50638 .34187 L
Mistroke
.50634 .34192 L
.50629 .34197 L
.50625 .34202 L
.5062 .34208 L
.50616 .34213 L
.50611 .34218 L
.50607 .34223 L
.50602 .34228 L
.50598 .34234 L
.50593 .34239 L
.50589 .34244 L
.50584 .34249 L
.5058 .34254 L
.50575 .34259 L
.50571 .34265 L
.50566 .3427 L
.50562 .34275 L
.50557 .3428 L
.50553 .34285 L
.50548 .3429 L
.50544 .34295 L
.50539 .343 L
.50535 .34306 L
.5053 .34311 L
.50526 .34316 L
.50521 .34321 L
.50517 .34326 L
.50512 .34331 L
.50508 .34336 L
.50503 .34341 L
.50499 .34346 L
.50494 .34352 L
.50489 .34357 L
.50485 .34362 L
.5048 .34367 L
.50476 .34372 L
.50471 .34377 L
.50467 .34382 L
.50462 .34387 L
.50458 .34392 L
.50453 .34397 L
.50448 .34402 L
.50444 .34407 L
.50439 .34412 L
.50435 .34417 L
.5043 .34422 L
.50426 .34427 L
.50421 .34432 L
.50416 .34438 L
.50412 .34443 L
Mistroke
.50407 .34448 L
.50403 .34453 L
.50398 .34458 L
.50393 .34463 L
.50389 .34468 L
.50384 .34473 L
.5038 .34478 L
.50375 .34483 L
.5037 .34488 L
.50366 .34493 L
.50361 .34498 L
.50357 .34503 L
.50352 .34508 L
.50347 .34512 L
.50343 .34517 L
.50338 .34522 L
.50334 .34527 L
.50329 .34532 L
.50324 .34537 L
.5032 .34542 L
.50315 .34547 L
.5031 .34552 L
.50306 .34557 L
.50301 .34562 L
.50296 .34567 L
.50292 .34572 L
.50287 .34577 L
.50283 .34582 L
.50278 .34587 L
.50273 .34592 L
.50269 .34596 L
.50264 .34601 L
.50259 .34606 L
.50255 .34611 L
.5025 .34616 L
.50245 .34621 L
.50241 .34626 L
.50236 .34631 L
.50231 .34636 L
.50227 .3464 L
.50222 .34645 L
.50217 .3465 L
.50213 .34655 L
.50208 .3466 L
.50203 .34665 L
.50199 .3467 L
.50194 .34674 L
.50189 .34679 L
.50184 .34684 L
.5018 .34689 L
Mistroke
.50175 .34694 L
.5017 .34699 L
.50166 .34703 L
.50161 .34708 L
.50156 .34713 L
.50152 .34718 L
.50147 .34723 L
.50142 .34727 L
.50137 .34732 L
.50133 .34737 L
.50128 .34742 L
.50123 .34747 L
.50119 .34751 L
.50114 .34756 L
.50109 .34761 L
.50104 .34766 L
.501 .3477 L
.50095 .34775 L
.5009 .3478 L
.50086 .34785 L
.50081 .34789 L
.50076 .34794 L
.50071 .34799 L
.50067 .34804 L
.50062 .34808 L
.50057 .34813 L
.50052 .34818 L
.50048 .34823 L
.50043 .34827 L
.50038 .34832 L
.50033 .34837 L
.50029 .34841 L
.50024 .34846 L
.50019 .34851 L
.50014 .34855 L
.5001 .3486 L
.50005 .34865 L
.5 .3487 L
.49995 .34874 L
.49991 .34879 L
.49986 .34884 L
.49981 .34888 L
.49976 .34893 L
.49972 .34898 L
.49967 .34902 L
.49962 .34907 L
.49957 .34911 L
.49953 .34916 L
.49948 .34921 L
.49943 .34925 L
Mistroke
.49938 .3493 L
.49933 .34935 L
.49929 .34939 L
.49924 .34944 L
.49919 .34948 L
.49914 .34953 L
.49909 .34958 L
.49905 .34962 L
.499 .34967 L
.49895 .34971 L
.4989 .34976 L
.49886 .34981 L
.49881 .34985 L
.49876 .3499 L
.49871 .34994 L
.49866 .34999 L
.49862 .35003 L
.49857 .35008 L
.49852 .35013 L
.49847 .35017 L
.49842 .35022 L
.49838 .35026 L
.49833 .35031 L
.49828 .35035 L
.49823 .3504 L
.49818 .35044 L
.49813 .35049 L
.49809 .35053 L
.49804 .35058 L
.49799 .35062 L
.49794 .35067 L
.49789 .35071 L
.49785 .35076 L
.4978 .3508 L
.49775 .35085 L
.4977 .35089 L
.49765 .35094 L
.4976 .35098 L
.49756 .35103 L
.49751 .35107 L
.49746 .35112 L
.49741 .35116 L
.49736 .35121 L
.49731 .35125 L
.49727 .35129 L
.49722 .35134 L
.49717 .35138 L
.49712 .35143 L
.49707 .35147 L
.49702 .35152 L
Mistroke
.49698 .35156 L
.49693 .3516 L
.49688 .35165 L
.49683 .35169 L
.49678 .35174 L
.49673 .35178 L
.49669 .35182 L
.49664 .35187 L
.49659 .35191 L
.49654 .35196 L
.49649 .352 L
.49644 .35204 L
.49639 .35209 L
.49635 .35213 L
.4963 .35217 L
.49625 .35222 L
.4962 .35226 L
.49615 .35231 L
.4961 .35235 L
.49605 .35239 L
.49601 .35244 L
.49596 .35248 L
.49591 .35252 L
.49586 .35256 L
.49581 .35261 L
.49576 .35265 L
.49571 .35269 L
.49566 .35274 L
.49562 .35278 L
.49557 .35282 L
.49552 .35287 L
.49547 .35291 L
.49542 .35295 L
.49537 .35299 L
.49532 .35304 L
.49527 .35308 L
.49523 .35312 L
.49518 .35317 L
.49513 .35321 L
.49508 .35325 L
.49503 .35329 L
.49498 .35334 L
.49493 .35338 L
.49488 .35342 L
.49484 .35346 L
.49479 .3535 L
.49474 .35355 L
.49469 .35359 L
.49464 .35363 L
.49459 .35367 L
Mistroke
.49454 .35371 L
.49449 .35376 L
.49444 .3538 L
.4944 .35384 L
.49435 .35388 L
.4943 .35392 L
.49425 .35397 L
.4942 .35401 L
.49415 .35405 L
.4941 .35409 L
.49405 .35413 L
.494 .35417 L
.49396 .35422 L
.49391 .35426 L
.49386 .3543 L
.49381 .35434 L
.49376 .35438 L
.49371 .35442 L
.49366 .35446 L
.49361 .3545 L
.49356 .35455 L
.49351 .35459 L
.49347 .35463 L
.49342 .35467 L
.49337 .35471 L
.49332 .35475 L
.49327 .35479 L
.49322 .35483 L
.49317 .35487 L
.49312 .35491 L
.49307 .35495 L
.49302 .355 L
.49298 .35504 L
.49293 .35508 L
.49288 .35512 L
.49283 .35516 L
.49278 .3552 L
.49273 .35524 L
.49268 .35528 L
.49263 .35532 L
.49258 .35536 L
.49253 .3554 L
.49248 .35544 L
.49244 .35548 L
.49239 .35552 L
.49234 .35556 L
.49229 .3556 L
.49224 .35564 L
.49219 .35568 L
.49214 .35572 L
Mistroke
.49209 .35576 L
.49204 .3558 L
.49199 .35584 L
.49194 .35588 L
.4919 .35592 L
.49185 .35596 L
.4918 .356 L
.49175 .35604 L
.4917 .35608 L
.49165 .35612 L
.4916 .35616 L
.49155 .35619 L
.4915 .35623 L
.49145 .35627 L
.4914 .35631 L
.49135 .35635 L
.49131 .35639 L
.49126 .35643 L
.49121 .35647 L
.49116 .35651 L
.49111 .35655 L
.49106 .35659 L
.49101 .35662 L
.49096 .35666 L
.49091 .3567 L
.49086 .35674 L
.49081 .35678 L
.49076 .35682 L
.49072 .35686 L
.49067 .35689 L
.49062 .35693 L
.49057 .35697 L
.49052 .35701 L
.49047 .35705 L
.49042 .35709 L
.49037 .35712 L
.49032 .35716 L
.49027 .3572 L
.49022 .35724 L
.49017 .35728 L
.49013 .35731 L
.49008 .35735 L
.49003 .35739 L
.48998 .35743 L
.48993 .35747 L
.48988 .3575 L
.48983 .35754 L
.48978 .35758 L
.48973 .35762 L
.48968 .35765 L
Mistroke
.48963 .35769 L
.48958 .35773 L
.48953 .35777 L
.48949 .3578 L
.48944 .35784 L
.48939 .35788 L
.48934 .35792 L
.48929 .35795 L
.48924 .35799 L
.48919 .35803 L
.48914 .35807 L
.48909 .3581 L
.48904 .35814 L
.48899 .35818 L
.48894 .35821 L
.4889 .35825 L
.48885 .35829 L
.4888 .35832 L
.48875 .35836 L
.4887 .3584 L
.48865 .35843 L
.4886 .35847 L
.48855 .35851 L
.4885 .35854 L
.48845 .35858 L
.4884 .35862 L
.48835 .35865 L
.48831 .35869 L
.48826 .35873 L
.48821 .35876 L
.48816 .3588 L
.48811 .35883 L
.48806 .35887 L
.48801 .35891 L
.48796 .35894 L
.48791 .35898 L
.48786 .35901 L
.48781 .35905 L
.48776 .35909 L
.48772 .35912 L
.48767 .35916 L
.48762 .35919 L
.48757 .35923 L
.48752 .35926 L
.48747 .3593 L
.48742 .35933 L
.48737 .35937 L
.48732 .35941 L
.48727 .35944 L
.48722 .35948 L
Mistroke
.48718 .35951 L
.48713 .35955 L
.48708 .35958 L
.48703 .35962 L
.48698 .35965 L
.48693 .35969 L
.48688 .35972 L
.48683 .35976 L
.48678 .35979 L
.48673 .35983 L
.48668 .35986 L
.48664 .3599 L
.48659 .35993 L
.48654 .35997 L
.48649 .36 L
.48644 .36003 L
.48639 .36007 L
.48634 .3601 L
.48629 .36014 L
.48624 .36017 L
.48619 .36021 L
.48615 .36024 L
.4861 .36028 L
.48605 .36031 L
.486 .36034 L
.48595 .36038 L
.4859 .36041 L
.48585 .36045 L
.4858 .36048 L
.48575 .36051 L
.4857 .36055 L
.48566 .36058 L
.48561 .36062 L
.48556 .36065 L
.48551 .36068 L
.48546 .36072 L
.48541 .36075 L
.48536 .36078 L
.48531 .36082 L
.48526 .36085 L
.48522 .36088 L
.48517 .36092 L
.48512 .36095 L
.48507 .36098 L
.48502 .36102 L
.48497 .36105 L
.48492 .36108 L
.48487 .36112 L
.48482 .36115 L
.48478 .36118 L
Mistroke
.48473 .36121 L
.48468 .36125 L
.48463 .36128 L
.48458 .36131 L
.48453 .36135 L
.48448 .36138 L
.48443 .36141 L
.48438 .36144 L
.48434 .36148 L
.48429 .36151 L
.48424 .36154 L
.48419 .36157 L
.48414 .36161 L
.48409 .36164 L
.48404 .36167 L
.48399 .3617 L
.48395 .36174 L
.4839 .36177 L
.48385 .3618 L
.4838 .36183 L
.48375 .36186 L
.4837 .3619 L
.48365 .36193 L
.48361 .36196 L
.48356 .36199 L
.48351 .36202 L
.48346 .36205 L
.48341 .36209 L
.48336 .36212 L
.48331 .36215 L
.48327 .36218 L
.48322 .36221 L
.48317 .36224 L
.48312 .36228 L
.48307 .36231 L
.48302 .36234 L
.48297 .36237 L
.48293 .3624 L
.48288 .36243 L
.48283 .36246 L
.48278 .36249 L
.48273 .36253 L
.48268 .36256 L
.48263 .36259 L
.48259 .36262 L
.48254 .36265 L
.48249 .36268 L
.48244 .36271 L
.48239 .36274 L
.48234 .36277 L
Mistroke
.4823 .3628 L
.48225 .36283 L
.4822 .36286 L
.48215 .36289 L
.4821 .36292 L
.48205 .36295 L
.482 .36298 L
.48196 .36302 L
.48191 .36305 L
.48186 .36308 L
.48181 .36311 L
.48176 .36314 L
.48171 .36317 L
.48167 .3632 L
.48162 .36323 L
.48157 .36326 L
.48152 .36329 L
.48147 .36332 L
.48143 .36334 L
.48138 .36337 L
.48133 .3634 L
.48128 .36343 L
.48123 .36346 L
.48118 .36349 L
.48114 .36352 L
.48109 .36355 L
.48104 .36358 L
.48099 .36361 L
.48094 .36364 L
.4809 .36367 L
.48085 .3637 L
.4808 .36373 L
.48075 .36376 L
.4807 .36379 L
.48066 .36381 L
.48061 .36384 L
.48056 .36387 L
.48051 .3639 L
.48046 .36393 L
.48042 .36396 L
.48037 .36399 L
.48032 .36402 L
.48027 .36405 L
.48022 .36407 L
.48018 .3641 L
.48013 .36413 L
.48008 .36416 L
.48003 .36419 L
.47998 .36422 L
.47994 .36424 L
Mistroke
.47989 .36427 L
.47984 .3643 L
.47979 .36433 L
.47974 .36436 L
.4797 .36439 L
.47965 .36441 L
.4796 .36444 L
.47955 .36447 L
.47951 .3645 L
.47946 .36452 L
.47941 .36455 L
.47936 .36458 L
.47932 .36461 L
.47927 .36464 L
.47922 .36466 L
.47917 .36469 L
.47912 .36472 L
.47908 .36475 L
.47903 .36477 L
.47898 .3648 L
.47893 .36483 L
.47889 .36486 L
.47884 .36488 L
.47879 .36491 L
.47874 .36494 L
.4787 .36496 L
.47865 .36499 L
.4786 .36502 L
.47855 .36505 L
.47851 .36507 L
.47846 .3651 L
.47841 .36513 L
.47836 .36515 L
.47832 .36518 L
.47827 .36521 L
.47822 .36523 L
.47817 .36526 L
.47813 .36529 L
.47808 .36531 L
.47803 .36534 L
.47799 .36536 L
.47794 .36539 L
.47789 .36542 L
.47784 .36544 L
.4778 .36547 L
.47775 .3655 L
.4777 .36552 L
.47765 .36555 L
.47761 .36557 L
.47756 .3656 L
Mistroke
.47751 .36563 L
.47747 .36565 L
.47742 .36568 L
.47737 .3657 L
.47733 .36573 L
.47728 .36576 L
.47723 .36578 L
.47718 .36581 L
.47714 .36583 L
.47709 .36586 L
.47704 .36588 L
.477 .36591 L
.47695 .36593 L
.4769 .36596 L
.47686 .36598 L
.47681 .36601 L
.47676 .36603 L
.47671 .36606 L
.47667 .36609 L
.47662 .36611 L
.47657 .36614 L
.47653 .36616 L
.47648 .36619 L
.47643 .36621 L
.47639 .36623 L
.47634 .36626 L
.47629 .36628 L
.47625 .36631 L
.4762 .36633 L
.47615 .36636 L
.47611 .36638 L
.47606 .36641 L
.47601 .36643 L
.47597 .36646 L
.47592 .36648 L
.47587 .3665 L
.47583 .36653 L
.47578 .36655 L
.47573 .36658 L
.47569 .3666 L
.47564 .36663 L
.47559 .36665 L
.47555 .36667 L
.4755 .3667 L
.47546 .36672 L
.47541 .36675 L
.47536 .36677 L
.47532 .36679 L
.47527 .36682 L
.47522 .36684 L
Mistroke
.47518 .36686 L
.47513 .36689 L
.47508 .36691 L
.47504 .36693 L
.47499 .36696 L
.47495 .36698 L
.4749 .367 L
.47485 .36703 L
.47481 .36705 L
.47476 .36707 L
.47471 .3671 L
.47467 .36712 L
.47462 .36714 L
.47458 .36717 L
.47453 .36719 L
.47448 .36721 L
.47444 .36724 L
.47439 .36726 L
.47435 .36728 L
.4743 .3673 L
.47425 .36733 L
.47421 .36735 L
.47416 .36737 L
.47412 .36739 L
.47407 .36742 L
.47403 .36744 L
.47398 .36746 L
.47393 .36748 L
.47389 .36751 L
.47384 .36753 L
.4738 .36755 L
.47375 .36757 L
.4737 .3676 L
.47366 .36762 L
.47361 .36764 L
.47357 .36766 L
.47352 .36768 L
.47348 .36771 L
.47343 .36773 L
.47339 .36775 L
.47334 .36777 L
.47329 .36779 L
.47325 .36781 L
.4732 .36784 L
.47316 .36786 L
.47311 .36788 L
.47307 .3679 L
.47302 .36792 L
.47298 .36794 L
.47293 .36796 L
Mistroke
.47288 .36799 L
.47284 .36801 L
.47279 .36803 L
.47275 .36805 L
.4727 .36807 L
.47266 .36809 L
.47261 .36811 L
.47257 .36813 L
.47252 .36816 L
.47248 .36818 L
.47243 .3682 L
.47239 .36822 L
.47234 .36824 L
.4723 .36826 L
.47225 .36828 L
.47221 .3683 L
.47216 .36832 L
.47212 .36834 L
.47207 .36836 L
.47203 .36838 L
.47198 .3684 L
.47194 .36842 L
.47189 .36844 L
.47185 .36846 L
.4718 .36848 L
.47176 .3685 L
.47171 .36852 L
.47167 .36854 L
.47162 .36857 L
.47158 .36859 L
.47153 .3686 L
.47149 .36862 L
.47144 .36864 L
.4714 .36866 L
.47135 .36868 L
.47131 .3687 L
.47127 .36872 L
.47122 .36874 L
.47118 .36876 L
.47113 .36878 L
.47109 .3688 L
.47104 .36882 L
.471 .36884 L
.47095 .36886 L
.47091 .36888 L
.47086 .3689 L
.47082 .36892 L
.47078 .36894 L
.47073 .36896 L
.47069 .36898 L
Mistroke
.47064 .36899 L
.4706 .36901 L
.47055 .36903 L
.47051 .36905 L
.47047 .36907 L
.47042 .36909 L
.47038 .36911 L
.47033 .36913 L
.47029 .36915 L
.47024 .36916 L
.4702 .36918 L
.47016 .3692 L
.47011 .36922 L
.47007 .36924 L
.47002 .36926 L
.46998 .36928 L
.46994 .36929 L
.46989 .36931 L
.46985 .36933 L
.4698 .36935 L
.46976 .36937 L
.46972 .36938 L
.46967 .3694 L
.46963 .36942 L
.46959 .36944 L
.46954 .36946 L
.4695 .36947 L
.46945 .36949 L
.46941 .36951 L
.46937 .36953 L
.46932 .36955 L
.46928 .36956 L
.46924 .36958 L
.46919 .3696 L
.46915 .36962 L
.46911 .36963 L
.46906 .36965 L
.46902 .36967 L
.46898 .36969 L
.46893 .3697 L
.46889 .36972 L
.46884 .36974 L
.4688 .36976 L
.46876 .36977 L
.46871 .36979 L
.46867 .36981 L
.46863 .36982 L
.46859 .36984 L
.46854 .36986 L
.4685 .36987 L
Mistroke
.46846 .36989 L
.46841 .36991 L
.46837 .36993 L
.46833 .36994 L
.46828 .36996 L
.46824 .36998 L
.4682 .36999 L
.46815 .37001 L
.46811 .37002 L
.46807 .37004 L
.46803 .37006 L
.46798 .37007 L
.46794 .37009 L
.4679 .37011 L
.46785 .37012 L
.46781 .37014 L
.46777 .37016 L
.46773 .37017 L
.46768 .37019 L
.46764 .3702 L
.4676 .37022 L
.46755 .37024 L
.46751 .37025 L
.46747 .37027 L
.46743 .37028 L
.46738 .3703 L
.46734 .37031 L
.4673 .37033 L
.46726 .37035 L
.46721 .37036 L
.46717 .37038 L
.46713 .37039 L
.46709 .37041 L
.46704 .37042 L
.467 .37044 L
.46696 .37045 L
.46692 .37047 L
.46688 .37048 L
.46683 .3705 L
.46679 .37051 L
.46675 .37053 L
.46671 .37054 L
.46666 .37056 L
.46662 .37057 L
.46658 .37059 L
.46654 .3706 L
.4665 .37062 L
.46645 .37063 L
.46641 .37065 L
.46637 .37066 L
Mistroke
.46633 .37068 L
.46629 .37069 L
.46624 .37071 L
.4662 .37072 L
.46616 .37074 L
.46612 .37075 L
.46608 .37077 L
.46603 .37078 L
.46599 .37079 L
.46595 .37081 L
.46591 .37082 L
.46587 .37084 L
.46583 .37085 L
.46578 .37087 L
.46574 .37088 L
.4657 .37089 L
.46566 .37091 L
.46562 .37092 L
.46558 .37094 L
.46554 .37095 L
.46549 .37096 L
.46545 .37098 L
.46541 .37099 L
.46537 .371 L
.46533 .37102 L
.46529 .37103 L
.46525 .37105 L
.46521 .37106 L
.46516 .37107 L
.46512 .37109 L
.46508 .3711 L
.46504 .37111 L
.465 .37113 L
.46496 .37114 L
.46492 .37115 L
.46488 .37117 L
.46484 .37118 L
.46479 .37119 L
.46475 .3712 L
.46471 .37122 L
.46467 .37123 L
.46463 .37124 L
.46459 .37126 L
.46455 .37127 L
.46451 .37128 L
.46447 .37129 L
.46443 .37131 L
.46439 .37132 L
.46435 .37133 L
.4643 .37135 L
Mistroke
.46426 .37136 L
.46422 .37137 L
.46418 .37138 L
.46414 .3714 L
.4641 .37141 L
.46406 .37142 L
.46402 .37143 L
.46398 .37144 L
.46394 .37146 L
.4639 .37147 L
.46386 .37148 L
.46382 .37149 L
.46378 .37151 L
.46374 .37152 L
.4637 .37153 L
.46366 .37154 L
.46362 .37155 L
.46358 .37157 L
.46354 .37158 L
.4635 .37159 L
.46346 .3716 L
.46342 .37161 L
.46338 .37162 L
.46334 .37164 L
.4633 .37165 L
.46326 .37166 L
.46322 .37167 L
.46318 .37168 L
.46314 .37169 L
.4631 .3717 L
.46306 .37172 L
.46302 .37173 L
.46298 .37174 L
.46294 .37175 L
.4629 .37176 L
.46286 .37177 L
.46282 .37178 L
.46278 .37179 L
.46274 .3718 L
.4627 .37182 L
.46266 .37183 L
.46262 .37184 L
.46258 .37185 L
.46254 .37186 L
.4625 .37187 L
.46246 .37188 L
.46242 .37189 L
.46238 .3719 L
.46235 .37191 L
.46231 .37192 L
Mistroke
.46227 .37193 L
.46223 .37194 L
.46219 .37195 L
.46215 .37196 L
.46211 .37197 L
.46207 .37199 L
.46203 .372 L
.46199 .37201 L
.46195 .37202 L
.46191 .37203 L
.46188 .37204 L
.46184 .37205 L
.4618 .37206 L
.46176 .37207 L
.46172 .37208 L
.46168 .37209 L
.46164 .3721 L
.4616 .37211 L
.46156 .37212 L
.46153 .37213 L
.46149 .37213 L
.46145 .37214 L
.46141 .37215 L
.46137 .37216 L
.46133 .37217 L
.46129 .37218 L
.46126 .37219 L
.46122 .3722 L
.46118 .37221 L
.46114 .37222 L
.4611 .37223 L
.46106 .37224 L
.46103 .37225 L
.46099 .37226 L
.46095 .37227 L
.46091 .37228 L
.46087 .37228 L
.46083 .37229 L
.4608 .3723 L
.46076 .37231 L
.46072 .37232 L
.46068 .37233 L
.46064 .37234 L
.46061 .37235 L
.46057 .37236 L
.46053 .37236 L
.46049 .37237 L
.46045 .37238 L
.46042 .37239 L
.46038 .3724 L
Mistroke
.46034 .37241 L
.4603 .37242 L
.46026 .37242 L
.46023 .37243 L
.46019 .37244 L
.46015 .37245 L
.46011 .37246 L
.46008 .37247 L
.46004 .37247 L
.46 .37248 L
.45996 .37249 L
.45993 .3725 L
.45989 .37251 L
.45985 .37251 L
.45981 .37252 L
.45978 .37253 L
.45974 .37254 L
.4597 .37255 L
.45966 .37255 L
.45963 .37256 L
.45959 .37257 L
.45955 .37258 L
.45952 .37258 L
.45948 .37259 L
.45944 .3726 L
.4594 .37261 L
.45937 .37261 L
.45933 .37262 L
.45929 .37263 L
.45926 .37264 L
.45922 .37264 L
.45918 .37265 L
.45915 .37266 L
.45911 .37267 L
.45907 .37267 L
.45903 .37268 L
.459 .37269 L
.45896 .37269 L
.45892 .3727 L
.45889 .37271 L
.45885 .37272 L
.45881 .37272 L
.45878 .37273 L
.45874 .37274 L
.4587 .37274 L
.45867 .37275 L
.45863 .37276 L
.4586 .37276 L
.45856 .37277 L
.45852 .37278 L
Mistroke
.45849 .37278 L
.45845 .37279 L
.45841 .3728 L
.45838 .3728 L
.45834 .37281 L
.45831 .37282 L
.45827 .37282 L
.45823 .37283 L
.4582 .37283 L
.45816 .37284 L
.45812 .37285 L
.45809 .37285 L
.45805 .37286 L
.45802 .37287 L
.45798 .37287 L
.45794 .37288 L
.45791 .37288 L
.45787 .37289 L
.45784 .3729 L
.4578 .3729 L
.45777 .37291 L
.45773 .37291 L
.45769 .37292 L
.45766 .37292 L
.45762 .37293 L
.45759 .37294 L
.45755 .37294 L
.45752 .37295 L
.45748 .37295 L
.45745 .37296 L
.45741 .37296 L
.45737 .37297 L
.45734 .37297 L
.4573 .37298 L
.45727 .37298 L
.45723 .37299 L
.4572 .373 L
.45716 .373 L
.45713 .37301 L
.45709 .37301 L
.45706 .37302 L
.45702 .37302 L
.45699 .37303 L
.45695 .37303 L
.45692 .37304 L
.45688 .37304 L
.45685 .37305 L
.45681 .37305 L
.45678 .37306 L
.45674 .37306 L
Mistroke
.45671 .37307 L
.45667 .37307 L
.45664 .37307 L
.4566 .37308 L
.45657 .37308 L
.45653 .37309 L
.4565 .37309 L
.45646 .3731 L
.45643 .3731 L
.4564 .37311 L
.45636 .37311 L
.45633 .37311 L
.45629 .37312 L
.45626 .37312 L
.45622 .37313 L
.45619 .37313 L
.45615 .37314 L
.45612 .37314 L
.45609 .37314 L
.45605 .37315 L
.45602 .37315 L
.45598 .37316 L
.45595 .37316 L
.45592 .37316 L
.45588 .37317 L
.45585 .37317 L
.45581 .37318 L
.45578 .37318 L
.45575 .37318 L
.45571 .37319 L
.45568 .37319 L
.45564 .37319 L
.45561 .3732 L
.45558 .3732 L
.45554 .3732 L
.45551 .37321 L
.45547 .37321 L
.45544 .37322 L
.45541 .37322 L
.45537 .37322 L
.45534 .37323 L
.45531 .37323 L
.45527 .37323 L
.45524 .37323 L
.45521 .37324 L
.45517 .37324 L
.45514 .37324 L
.45511 .37325 L
.45507 .37325 L
.45504 .37325 L
Mistroke
.45501 .37326 L
.45497 .37326 L
.45494 .37326 L
.45491 .37326 L
.45487 .37327 L
.45484 .37327 L
.45481 .37327 L
.45477 .37328 L
.45474 .37328 L
.45471 .37328 L
.45468 .37328 L
.45464 .37329 L
.45461 .37329 L
.45458 .37329 L
.45454 .37329 L
.45451 .3733 L
.45448 .3733 L
.45445 .3733 L
.45441 .3733 L
.45438 .37331 L
.45435 .37331 L
.45431 .37331 L
.45428 .37331 L
.45425 .37331 L
.45422 .37332 L
.45418 .37332 L
.45415 .37332 L
.45412 .37332 L
.45409 .37333 L
.45406 .37333 L
.45402 .37333 L
.45399 .37333 L
.45396 .37333 L
.45393 .37333 L
.45389 .37334 L
.45386 .37334 L
.45383 .37334 L
.4538 .37334 L
.45377 .37334 L
.45373 .37334 L
.4537 .37335 L
.45367 .37335 L
.45364 .37335 L
.45361 .37335 L
.45357 .37335 L
.45354 .37335 L
.45351 .37336 L
.45348 .37336 L
.45345 .37336 L
.45341 .37336 L
Mistroke
.45338 .37336 L
.45335 .37336 L
.45332 .37336 L
.45329 .37336 L
.45326 .37337 L
.45322 .37337 L
.45319 .37337 L
.45316 .37337 L
.45313 .37337 L
.4531 .37337 L
.45307 .37337 L
.45304 .37337 L
.45301 .37337 L
.45297 .37337 L
.45294 .37337 L
.45291 .37338 L
.45288 .37338 L
.45285 .37338 L
.45282 .37338 L
.45279 .37338 L
.45276 .37338 L
.45272 .37338 L
.45269 .37338 L
.45266 .37338 L
.45263 .37338 L
.4526 .37338 L
.45257 .37338 L
.45254 .37338 L
.45251 .37338 L
.45248 .37338 L
.45245 .37338 L
.45242 .37338 L
.45239 .37338 L
.45236 .37338 L
.45232 .37338 L
.45229 .37338 L
.45226 .37338 L
.45223 .37338 L
.4522 .37338 L
.45217 .37338 L
.45214 .37338 L
.45211 .37338 L
.45208 .37338 L
.45205 .37338 L
.45202 .37338 L
.45199 .37338 L
.45196 .37338 L
.45193 .37338 L
.4519 .37338 L
.45187 .37338 L
Mistroke
.45184 .37338 L
.45181 .37338 L
.45178 .37338 L
.45175 .37338 L
.45172 .37338 L
.45169 .37338 L
.45166 .37338 L
.45163 .37338 L
.4516 .37338 L
.45157 .37338 L
.45154 .37338 L
.45151 .37338 L
.45148 .37338 L
.45145 .37338 L
.45142 .37337 L
.45139 .37337 L
.45136 .37337 L
.45133 .37337 L
.4513 .37337 L
.45127 .37337 L
.45124 .37337 L
.45121 .37337 L
.45119 .37337 L
.45116 .37337 L
.45113 .37336 L
.4511 .37336 L
.45107 .37336 L
.45104 .37336 L
.45101 .37336 L
.45098 .37336 L
.45095 .37336 L
.45092 .37336 L
.45089 .37336 L
.45086 .37335 L
.45084 .37335 L
.45081 .37335 L
.45078 .37335 L
.45075 .37335 L
.45072 .37335 L
.45069 .37334 L
.45066 .37334 L
.45063 .37334 L
.4506 .37334 L
.45058 .37334 L
.45055 .37334 L
.45052 .37333 L
.45049 .37333 L
.45046 .37333 L
.45043 .37333 L
.4504 .37333 L
Mistroke
.45038 .37333 L
.45035 .37332 L
.45032 .37332 L
.45029 .37332 L
.45026 .37332 L
.45023 .37332 L
.45021 .37331 L
.45018 .37331 L
.45015 .37331 L
.45012 .37331 L
.45009 .37331 L
.45006 .3733 L
.45004 .3733 L
.45001 .3733 L
.44998 .3733 L
.44995 .37329 L
.44992 .37329 L
.4499 .37329 L
.44987 .37329 L
.44984 .37328 L
.44981 .37328 L
.44979 .37328 L
.44976 .37328 L
.44973 .37327 L
.4497 .37327 L
.44967 .37327 L
.44965 .37327 L
.44962 .37326 L
.44959 .37326 L
.44956 .37326 L
.44954 .37326 L
.44951 .37325 L
.44948 .37325 L
.44945 .37325 L
.44943 .37324 L
.4494 .37324 L
.44937 .37324 L
.44934 .37324 L
.44932 .37323 L
.44929 .37323 L
.44926 .37323 L
.44924 .37322 L
.44921 .37322 L
.44918 .37322 L
.44915 .37321 L
.44913 .37321 L
.4491 .37321 L
.44907 .3732 L
.44905 .3732 L
.44902 .3732 L
Mistroke
.44899 .3732 L
.44897 .37319 L
.44894 .37319 L
.44891 .37318 L
.44889 .37318 L
.44886 .37318 L
.44883 .37317 L
.44881 .37317 L
.44878 .37317 L
.44875 .37316 L
.44873 .37316 L
.4487 .37316 L
.44867 .37315 L
.44865 .37315 L
.44862 .37315 L
.44859 .37314 L
.44857 .37314 L
.44854 .37313 L
.44851 .37313 L
.44849 .37313 L
.44846 .37312 L
.44844 .37312 L
.44841 .37312 L
.44838 .37311 L
.44836 .37311 L
.44833 .3731 L
.44831 .3731 L
.44828 .3731 L
.44825 .37309 L
.44823 .37309 L
.4482 .37308 L
.44818 .37308 L
.44815 .37307 L
.44812 .37307 L
.4481 .37307 L
.44807 .37306 L
.44805 .37306 L
.44802 .37305 L
.448 .37305 L
.44797 .37304 L
.44794 .37304 L
.44792 .37304 L
.44789 .37303 L
.44787 .37303 L
.44784 .37302 L
.44782 .37302 L
.44779 .37301 L
.44777 .37301 L
.44774 .373 L
.44772 .373 L
Mistroke
.44769 .37299 L
.44767 .37299 L
.44764 .37298 L
.44762 .37298 L
.44759 .37298 L
.44756 .37297 L
.44754 .37297 L
.44751 .37296 L
.44749 .37296 L
.44746 .37295 L
.44744 .37295 L
.44741 .37294 L
.44739 .37294 L
.44737 .37293 L
.44734 .37293 L
.44732 .37292 L
.44729 .37292 L
.44727 .37291 L
.44724 .37291 L
.44722 .3729 L
.44719 .3729 L
.44717 .37289 L
.44714 .37288 L
.44712 .37288 L
.44709 .37287 L
.44707 .37287 L
.44705 .37286 L
.44702 .37286 L
.447 .37285 L
.44697 .37285 L
.44695 .37284 L
.44692 .37284 L
.4469 .37283 L
.44688 .37283 L
.44685 .37282 L
.44683 .37281 L
.4468 .37281 L
.44678 .3728 L
.44675 .3728 L
.44673 .37279 L
.44671 .37279 L
.44668 .37278 L
.44666 .37277 L
.44664 .37277 L
.44661 .37276 L
.44659 .37276 L
.44656 .37275 L
.44654 .37275 L
.44652 .37274 L
.44649 .37273 L
Mistroke
.44647 .37273 L
.44645 .37272 L
.44642 .37272 L
.4464 .37271 L
.44637 .3727 L
.44635 .3727 L
.44633 .37269 L
.4463 .37269 L
.44628 .37268 L
.44626 .37267 L
.44623 .37267 L
.44621 .37266 L
.44619 .37265 L
.44616 .37265 L
.44614 .37264 L
.44612 .37264 L
.44609 .37263 L
.44607 .37262 L
.44605 .37262 L
.44603 .37261 L
.446 .3726 L
.44598 .3726 L
.44596 .37259 L
.44593 .37258 L
.44591 .37258 L
.44589 .37257 L
.44587 .37256 L
.44584 .37256 L
.44582 .37255 L
.4458 .37254 L
.44577 .37254 L
.44575 .37253 L
.44573 .37252 L
.44571 .37252 L
.44568 .37251 L
.44566 .3725 L
.44564 .3725 L
.44562 .37249 L
.44559 .37248 L
.44557 .37248 L
.44555 .37247 L
.44553 .37246 L
.4455 .37246 L
.44548 .37245 L
.44546 .37244 L
.44544 .37244 L
.44542 .37243 L
.44539 .37242 L
.44537 .37241 L
.44535 .37241 L
Mistroke
.44533 .3724 L
.44531 .37239 L
.44528 .37239 L
.44526 .37238 L
.44524 .37237 L
.44522 .37236 L
.4452 .37236 L
.44517 .37235 L
.44515 .37234 L
.44513 .37233 L
.44511 .37233 L
.44509 .37232 L
.44506 .37231 L
.44504 .37231 L
.44502 .3723 L
.445 .37229 L
.44498 .37228 L
.44496 .37228 L
.44494 .37227 L
.44491 .37226 L
.44489 .37225 L
.44487 .37225 L
.44485 .37224 L
.44483 .37223 L
.44481 .37222 L
.44479 .37221 L
.44476 .37221 L
.44474 .3722 L
.44472 .37219 L
.4447 .37218 L
.44468 .37218 L
.44466 .37217 L
.44464 .37216 L
.44462 .37215 L
.4446 .37214 L
.44458 .37214 L
.44455 .37213 L
.44453 .37212 L
.44451 .37211 L
.44449 .3721 L
.44447 .3721 L
.44445 .37209 L
.44443 .37208 L
.44441 .37207 L
.44439 .37206 L
.44437 .37206 L
.44435 .37205 L
.44433 .37204 L
.44431 .37203 L
.44429 .37202 L
Mistroke
.44426 .37202 L
.44424 .37201 L
.44422 .372 L
.4442 .37199 L
.44418 .37198 L
.44416 .37197 L
.44414 .37197 L
.44412 .37196 L
.4441 .37195 L
.44408 .37194 L
.44406 .37193 L
.44404 .37192 L
.44402 .37191 L
.444 .37191 L
.44398 .3719 L
.44396 .37189 L
.44394 .37188 L
.44392 .37187 L
.4439 .37186 L
.44388 .37185 L
.44386 .37185 L
.44384 .37184 L
.44382 .37183 L
.4438 .37182 L
.44378 .37181 L
.44376 .3718 L
.44374 .37179 L
.44372 .37179 L
.4437 .37178 L
.44368 .37177 L
.44366 .37176 L
.44365 .37175 L
.44363 .37174 L
.44361 .37173 L
.44359 .37172 L
.44357 .37171 L
.44355 .37171 L
.44353 .3717 L
.44351 .37169 L
.44349 .37168 L
.44347 .37167 L
.44345 .37166 L
.44343 .37165 L
.44341 .37164 L
.44339 .37163 L
.44338 .37162 L
.44336 .37161 L
.44334 .37161 L
.44332 .3716 L
.4433 .37159 L
Mistroke
.44328 .37158 L
.44326 .37157 L
.44324 .37156 L
.44322 .37155 L
.4432 .37154 L
.44319 .37153 L
.44317 .37152 L
.44315 .37151 L
.44313 .3715 L
.44311 .37149 L
.44309 .37148 L
.44307 .37147 L
.44306 .37147 L
.44304 .37146 L
.44302 .37145 L
.443 .37144 L
.44298 .37143 L
.44296 .37142 L
.44294 .37141 L
.44293 .3714 L
.44291 .37139 L
.44289 .37138 L
.44287 .37137 L
.44285 .37136 L
.44284 .37135 L
.44282 .37134 L
.4428 .37133 L
.44278 .37132 L
.44276 .37131 L
.44274 .3713 L
.44273 .37129 L
.44271 .37128 L
.44269 .37127 L
.44267 .37126 L
.44266 .37125 L
.44264 .37124 L
.44262 .37123 L
.4426 .37122 L
.44258 .37121 L
.44257 .3712 L
.44255 .37119 L
.44253 .37118 L
.44251 .37117 L
.4425 .37116 L
.44248 .37115 L
.44246 .37114 L
.44244 .37113 L
.44243 .37112 L
.44241 .37111 L
.44239 .3711 L
Mistroke
.44237 .37109 L
.44236 .37108 L
.44234 .37107 L
.44232 .37106 L
.4423 .37105 L
.44229 .37104 L
.44227 .37103 L
.44225 .37102 L
.44224 .37101 L
.44222 .371 L
.4422 .37099 L
.44218 .37098 L
.44217 .37097 L
.44215 .37096 L
.44213 .37095 L
.44212 .37094 L
.4421 .37093 L
.44208 .37092 L
.44207 .37091 L
.44205 .37089 L
.44203 .37088 L
.44201 .37087 L
.442 .37086 L
.44198 .37085 L
.44196 .37084 L
.44195 .37083 L
.44193 .37082 L
.44191 .37081 L
.4419 .3708 L
.44188 .37079 L
.44187 .37078 L
.44185 .37077 L
.44183 .37076 L
.44182 .37075 L
.4418 .37074 L
.44178 .37072 L
.44177 .37071 L
.44175 .3707 L
.44173 .37069 L
.44172 .37068 L
.4417 .37067 L
.44169 .37066 L
.44167 .37065 L
.44165 .37064 L
.44164 .37063 L
.44162 .37062 L
.44161 .3706 L
.44159 .37059 L
.44157 .37058 L
.44156 .37057 L
Mistroke
.44154 .37056 L
.44153 .37055 L
.44151 .37054 L
.44149 .37053 L
.44148 .37052 L
.44146 .37051 L
.44145 .37049 L
.44143 .37048 L
.44142 .37047 L
.4414 .37046 L
.44138 .37045 L
.44137 .37044 L
.44135 .37043 L
.44134 .37042 L
.44132 .3704 L
.44131 .37039 L
.44129 .37038 L
.44128 .37037 L
.44126 .37036 L
.44125 .37035 L
.44123 .37034 L
.44121 .37033 L
.4412 .37031 L
.44118 .3703 L
.44117 .37029 L
.44115 .37028 L
.44114 .37027 L
.44112 .37026 L
.44111 .37025 L
.44109 .37023 L
.44108 .37022 L
.44106 .37021 L
.44105 .3702 L
.44103 .37019 L
.44102 .37018 L
.441 .37016 L
.44099 .37015 L
.44097 .37014 L
.44096 .37013 L
.44094 .37012 L
.44093 .37011 L
.44092 .3701 L
.4409 .37008 L
.44089 .37007 L
.44087 .37006 L
.44086 .37005 L
.44084 .37004 L
.44083 .37002 L
.44081 .37001 L
.4408 .37 L
Mistroke
.44078 .36999 L
.44077 .36998 L
.44076 .36997 L
.44074 .36995 L
.44073 .36994 L
.44071 .36993 L
.4407 .36992 L
.44068 .36991 L
.44067 .36989 L
.44066 .36988 L
.44064 .36987 L
.44063 .36986 L
.44061 .36985 L
.4406 .36983 L
.44059 .36982 L
.44057 .36981 L
.44056 .3698 L
.44054 .36979 L
.44053 .36977 L
.44052 .36976 L
.4405 .36975 L
.44049 .36974 L
.44047 .36973 L
.44046 .36971 L
.44045 .3697 L
.44043 .36969 L
.44042 .36968 L
.44041 .36967 L
.44039 .36965 L
.44038 .36964 L
.44037 .36963 L
.44035 .36962 L
.44034 .3696 L
.44032 .36959 L
.44031 .36958 L
.4403 .36957 L
.44028 .36956 L
.44027 .36954 L
.44026 .36953 L
.44024 .36952 L
.44023 .36951 L
.44022 .36949 L
.4402 .36948 L
.44019 .36947 L
.44018 .36946 L
.44017 .36944 L
.44015 .36943 L
.44014 .36942 L
.44013 .36941 L
.44011 .36939 L
Mistroke
.4401 .36938 L
.44009 .36937 L
.44007 .36936 L
.44006 .36934 L
.44005 .36933 L
.44004 .36932 L
.44002 .36931 L
.44001 .36929 L
.44 .36928 L
.43998 .36927 L
.43997 .36926 L
.43996 .36924 L
.43995 .36923 L
.43993 .36922 L
.43992 .36921 L
.43991 .36919 L
.4399 .36918 L
.43988 .36917 L
.43987 .36916 L
.43986 .36914 L
.43985 .36913 L
.43983 .36912 L
.43982 .3691 L
.43981 .36909 L
.4398 .36908 L
.43978 .36907 L
.43977 .36905 L
.43976 .36904 L
.43975 .36903 L
.43974 .36901 L
.43972 .369 L
.43971 .36899 L
.4397 .36898 L
.43969 .36896 L
.43968 .36895 L
.43966 .36894 L
.43965 .36892 L
.43964 .36891 L
.43963 .3689 L
.43962 .36889 L
.4396 .36887 L
.43959 .36886 L
.43958 .36885 L
.43957 .36883 L
.43956 .36882 L
.43954 .36881 L
.43953 .36879 L
.43952 .36878 L
.43951 .36877 L
.4395 .36876 L
Mistroke
.43949 .36874 L
.43947 .36873 L
.43946 .36872 L
.43945 .3687 L
.43944 .36869 L
.43943 .36868 L
.43942 .36866 L
.43941 .36865 L
.43939 .36864 L
.43938 .36862 L
.43937 .36861 L
.43936 .3686 L
.43935 .36858 L
.43934 .36857 L
.43933 .36856 L
.43932 .36854 L
.4393 .36853 L
.43929 .36852 L
.43928 .3685 L
.43927 .36849 L
.43926 .36848 L
.43925 .36846 L
.43924 .36845 L
.43923 .36844 L
.43922 .36842 L
.43921 .36841 L
.43919 .3684 L
.43918 .36838 L
.43917 .36837 L
.43916 .36836 L
.43915 .36834 L
.43914 .36833 L
.43913 .36832 L
.43912 .3683 L
.43911 .36829 L
.4391 .36828 L
.43909 .36826 L
.43908 .36825 L
.43907 .36824 L
.43906 .36822 L
.43905 .36821 L
.43903 .3682 L
.43902 .36818 L
.43901 .36817 L
.439 .36815 L
.43899 .36814 L
.43898 .36813 L
.43897 .36811 L
.43896 .3681 L
.43895 .36809 L
Mistroke
.43894 .36807 L
.43893 .36806 L
.43892 .36805 L
.43891 .36803 L
.4389 .36802 L
.43889 .368 L
.43888 .36799 L
.43887 .36798 L
.43886 .36796 L
.43885 .36795 L
.43884 .36794 L
.43883 .36792 L
.43882 .36791 L
.43881 .3679 L
.4388 .36788 L
.43879 .36787 L
.43878 .36785 L
.43877 .36784 L
.43876 .36783 L
.43875 .36781 L
.43874 .3678 L
.43873 .36778 L
.43872 .36777 L
.43871 .36776 L
.4387 .36774 L
.43869 .36773 L
.43868 .36772 L
.43868 .3677 L
.43867 .36769 L
.43866 .36767 L
.43865 .36766 L
.43864 .36765 L
.43863 .36763 L
.43862 .36762 L
.43861 .3676 L
.4386 .36759 L
.43859 .36758 L
.43858 .36756 L
.43857 .36755 L
.43856 .36753 L
.43855 .36752 L
.43854 .36751 L
.43854 .36749 L
.43853 .36748 L
.43852 .36746 L
.43851 .36745 L
.4385 .36744 L
.43849 .36742 L
.43848 .36741 L
.43847 .36739 L
Mistroke
.43846 .36738 L
.43845 .36737 L
.43845 .36735 L
.43844 .36734 L
.43843 .36732 L
.43842 .36731 L
.43841 .36729 L
.4384 .36728 L
.43839 .36727 L
.43838 .36725 L
.43838 .36724 L
.43837 .36722 L
.43836 .36721 L
.43835 .3672 L
.43834 .36718 L
.43833 .36717 L
.43832 .36715 L
.43832 .36714 L
.43831 .36712 L
.4383 .36711 L
.43829 .3671 L
.43828 .36708 L
.43827 .36707 L
.43827 .36705 L
.43826 .36704 L
.43825 .36702 L
.43824 .36701 L
.43823 .367 L
.43822 .36698 L
.43822 .36697 L
.43821 .36695 L
.4382 .36694 L
.43819 .36692 L
.43818 .36691 L
.43818 .36689 L
.43817 .36688 L
.43816 .36687 L
.43815 .36685 L
.43814 .36684 L
.43814 .36682 L
.43813 .36681 L
.43812 .36679 L
.43811 .36678 L
.4381 .36676 L
.4381 .36675 L
.43809 .36674 L
.43808 .36672 L
.43807 .36671 L
.43807 .36669 L
.43806 .36668 L
Mistroke
.43805 .36666 L
.43804 .36665 L
.43804 .36663 L
.43803 .36662 L
.43802 .36661 L
.43801 .36659 L
.438 .36658 L
.438 .36656 L
.43799 .36655 L
.43798 .36653 L
.43798 .36652 L
.43797 .3665 L
.43796 .36649 L
.43795 .36647 L
.43795 .36646 L
.43794 .36645 L
.43793 .36643 L
.43792 .36642 L
.43792 .3664 L
.43791 .36639 L
.4379 .36637 L
.4379 .36636 L
.43789 .36634 L
.43788 .36633 L
.43787 .36631 L
.43787 .3663 L
.43786 .36628 L
.43785 .36627 L
.43785 .36625 L
.43784 .36624 L
.43783 .36623 L
.43783 .36621 L
.43782 .3662 L
.43781 .36618 L
.43781 .36617 L
.4378 .36615 L
.43779 .36614 L
.43778 .36612 L
.43778 .36611 L
.43777 .36609 L
.43776 .36608 L
.43776 .36606 L
.43775 .36605 L
.43774 .36603 L
.43774 .36602 L
.43773 .366 L
.43773 .36599 L
.43772 .36597 L
.43771 .36596 L
.43771 .36594 L
Mistroke
.4377 .36593 L
.43769 .36591 L
.43769 .3659 L
.43768 .36589 L
.43767 .36587 L
.43767 .36586 L
.43766 .36584 L
.43766 .36583 L
.43765 .36581 L
.43764 .3658 L
.43764 .36578 L
.43763 .36577 L
.43762 .36575 L
.43762 .36574 L
.43761 .36572 L
.43761 .36571 L
.4376 .36569 L
.43759 .36568 L
.43759 .36566 L
.43758 .36565 L
.43758 .36563 L
.43757 .36562 L
.43756 .3656 L
.43756 .36559 L
.43755 .36557 L
.43755 .36556 L
.43754 .36554 L
.43754 .36553 L
.43753 .36551 L
.43752 .3655 L
.43752 .36548 L
.43751 .36547 L
.43751 .36545 L
.4375 .36544 L
.4375 .36542 L
.43749 .36541 L
.43748 .36539 L
.43748 .36538 L
.43747 .36536 L
.43747 .36535 L
.43746 .36533 L
.43746 .36532 L
.43745 .3653 L
.43745 .36529 L
.43744 .36527 L
.43744 .36526 L
.43743 .36524 L
.43742 .36523 L
.43742 .36521 L
.43741 .3652 L
Mistroke
.43741 .36518 L
.4374 .36517 L
.4374 .36515 L
.43739 .36514 L
.43739 .36512 L
.43738 .36511 L
.43738 .36509 L
.43737 .36507 L
.43737 .36506 L
.43736 .36504 L
.43736 .36503 L
.43735 .36501 L
.43735 .365 L
.43734 .36498 L
.43734 .36497 L
.43733 .36495 L
.43733 .36494 L
.43732 .36492 L
.43732 .36491 L
.43731 .36489 L
.43731 .36488 L
.4373 .36486 L
.4373 .36485 L
.4373 .36483 L
.43729 .36482 L
.43729 .3648 L
.43728 .36479 L
.43728 .36477 L
.43727 .36476 L
.43727 .36474 L
.43726 .36473 L
.43726 .36471 L
.43725 .3647 L
.43725 .36468 L
.43724 .36466 L
.43724 .36465 L
.43724 .36463 L
.43723 .36462 L
.43723 .3646 L
.43722 .36459 L
.43722 .36457 L
.43721 .36456 L
.43721 .36454 L
.43721 .36453 L
.4372 .36451 L
.4372 .3645 L
.43719 .36448 L
.43719 .36447 L
.43718 .36445 L
.43718 .36444 L
Mistroke
.43718 .36442 L
.43717 .3644 L
.43717 .36439 L
.43716 .36437 L
.43716 .36436 L
.43716 .36434 L
.43715 .36433 L
.43715 .36431 L
.43714 .3643 L
.43714 .36428 L
.43714 .36427 L
.43713 .36425 L
.43713 .36424 L
.43713 .36422 L
.43712 .36421 L
.43712 .36419 L
.43711 .36417 L
.43711 .36416 L
.43711 .36414 L
.4371 .36413 L
.4371 .36411 L
.4371 .3641 L
.43709 .36408 L
.43709 .36407 L
.43708 .36405 L
.43708 .36404 L
.43708 .36402 L
.43707 .36401 L
.43707 .36399 L
.43707 .36397 L
.43706 .36396 L
.43706 .36394 L
.43706 .36393 L
.43705 .36391 L
.43705 .3639 L
.43705 .36388 L
.43704 .36387 L
.43704 .36385 L
.43704 .36384 L
.43703 .36382 L
.43703 .3638 L
.43703 .36379 L
.43702 .36377 L
.43702 .36376 L
.43702 .36374 L
.43701 .36373 L
.43701 .36371 L
.43701 .3637 L
.43701 .36368 L
.437 .36367 L
Mistroke
.437 .36365 L
.437 .36363 L
.43699 .36362 L
.43699 .3636 L
.43699 .36359 L
.43698 .36357 L
.43698 .36356 L
.43698 .36354 L
.43698 .36353 L
.43697 .36351 L
.43697 .3635 L
.43697 .36348 L
.43697 .36346 L
.43696 .36345 L
.43696 .36343 L
.43696 .36342 L
.43695 .3634 L
.43695 .36339 L
.43695 .36337 L
.43695 .36336 L
.43694 .36334 L
.43694 .36332 L
.43694 .36331 L
.43694 .36329 L
.43693 .36328 L
.43693 .36326 L
.43693 .36325 L
.43693 .36323 L
.43692 .36322 L
.43692 .3632 L
.43692 .36319 L
.43692 .36317 L
.43691 .36315 L
.43691 .36314 L
.43691 .36312 L
.43691 .36311 L
.43691 .36309 L
.4369 .36308 L
.4369 .36306 L
.4369 .36305 L
.4369 .36303 L
.43689 .36301 L
.43689 .363 L
.43689 .36298 L
.43689 .36297 L
.43689 .36295 L
.43688 .36294 L
.43688 .36292 L
.43688 .36291 L
.43688 .36289 L
Mistroke
.43688 .36287 L
.43687 .36286 L
.43687 .36284 L
.43687 .36283 L
.43687 .36281 L
.43687 .3628 L
.43686 .36278 L
.43686 .36277 L
.43686 .36275 L
.43686 .36273 L
.43686 .36272 L
.43686 .3627 L
.43685 .36269 L
.43685 .36267 L
.43685 .36266 L
.43685 .36264 L
.43685 .36263 L
.43685 .36261 L
.43684 .36259 L
.43684 .36258 L
.43684 .36256 L
.43684 .36255 L
.43684 .36253 L
.43684 .36252 L
.43683 .3625 L
.43683 .36248 L
.43683 .36247 L
.43683 .36245 L
.43683 .36244 L
.43683 .36242 L
.43683 .36241 L
.43682 .36239 L
.43682 .36238 L
.43682 .36236 L
.43682 .36234 L
.43682 .36233 L
.43682 .36231 L
.43682 .3623 L
.43682 .36228 L
.43681 .36227 L
.43681 .36225 L
.43681 .36224 L
.43681 .36222 L
.43681 .3622 L
.43681 .36219 L
.43681 .36217 L
.43681 .36216 L
.43681 .36214 L
.4368 .36213 L
.4368 .36211 L
Mistroke
.4368 .36209 L
.4368 .36208 L
.4368 .36206 L
.4368 .36205 L
.4368 .36203 L
.4368 .36202 L
.4368 .362 L
.4368 .36199 L
.4368 .36197 L
.43679 .36195 L
.43679 .36194 L
.43679 .36192 L
.43679 .36191 L
.43679 .36189 L
.43679 .36188 L
.43679 .36186 L
.43679 .36185 L
.43679 .36183 L
.43679 .36181 L
.43679 .3618 L
.43679 .36178 L
.43679 .36177 L
.43679 .36175 L
.43679 .36174 L
.43679 .36172 L
.43678 .3617 L
.43678 .36169 L
.43678 .36167 L
.43678 .36166 L
.43678 .36164 L
.43678 .36163 L
.43678 .36161 L
.43678 .3616 L
.43678 .36158 L
.43678 .36156 L
.43678 .36155 L
.43678 .36153 L
.43678 .36152 L
.43678 .3615 L
.43678 .36149 L
.43678 .36147 L
.43678 .36146 L
.43678 .36144 L
.43678 .36142 L
.43678 .36141 L
.43678 .36139 L
.43678 .36138 L
.43678 .36136 L
.43678 .36135 L
.43678 .36133 L
Mistroke
.43678 .36131 L
.43678 .3613 L
.43678 .36128 L
.43678 .36127 L
.43678 .36125 L
.43678 .36124 L
.43678 .36122 L
.43678 .36121 L
.43678 .36119 L
.43678 .36117 L
.43678 .36116 L
.43678 .36114 L
.43678 .36113 L
.43678 .36111 L
.43678 .3611 L
.43678 .36108 L
.43678 .36107 L
.43678 .36105 L
.43678 .36103 L
.43678 .36102 L
.43678 .361 L
.43678 .36099 L
.43678 .36097 L
.43678 .36096 L
.43678 .36094 L
.43678 .36092 L
.43678 .36091 L
.43678 .36089 L
.43678 .36088 L
.43679 .36086 L
.43679 .36085 L
.43679 .36083 L
.43679 .36082 L
.43679 .3608 L
.43679 .36078 L
.43679 .36077 L
.43679 .36075 L
.43679 .36074 L
.43679 .36072 L
.43679 .36071 L
.43679 .36069 L
.43679 .36068 L
.43679 .36066 L
.43679 .36064 L
.43679 .36063 L
.4368 .36061 L
.4368 .3606 L
.4368 .36058 L
.4368 .36057 L
.4368 .36055 L
Mistroke
.4368 .36054 L
.4368 .36052 L
.4368 .3605 L
.4368 .36049 L
.4368 .36047 L
.4368 .36046 L
.43681 .36044 L
.43681 .36043 L
.43681 .36041 L
.43681 .3604 L
.43681 .36038 L
.43681 .36036 L
.43681 .36035 L
.43681 .36033 L
.43681 .36032 L
.43681 .3603 L
.43682 .36029 L
.43682 .36027 L
.43682 .36026 L
.43682 .36024 L
.43682 .36023 L
.43682 .36021 L
.43682 .36019 L
.43682 .36018 L
.43683 .36016 L
.43683 .36015 L
.43683 .36013 L
.43683 .36012 L
.43683 .3601 L
.43683 .36009 L
.43683 .36007 L
.43683 .36005 L
.43684 .36004 L
.43684 .36002 L
.43684 .36001 L
.43684 .35999 L
.43684 .35998 L
.43684 .35996 L
.43684 .35995 L
.43685 .35993 L
.43685 .35992 L
.43685 .3599 L
.43685 .35988 L
.43685 .35987 L
.43685 .35985 L
.43686 .35984 L
.43686 .35982 L
.43686 .35981 L
.43686 .35979 L
.43686 .35978 L
Mistroke
.43686 .35976 L
.43687 .35975 L
.43687 .35973 L
.43687 .35971 L
.43687 .3597 L
.43687 .35968 L
.43687 .35967 L
.43688 .35965 L
.43688 .35964 L
.43688 .35962 L
.43688 .35961 L
.43688 .35959 L
.43689 .35958 L
.43689 .35956 L
.43689 .35954 L
.43689 .35953 L
.43689 .35951 L
.4369 .3595 L
.4369 .35948 L
.4369 .35947 L
.4369 .35945 L
.4369 .35944 L
.43691 .35942 L
.43691 .35941 L
.43691 .35939 L
.43691 .35938 L
.43691 .35936 L
.43692 .35934 L
.43692 .35933 L
.43692 .35931 L
.43692 .3593 L
.43693 .35928 L
.43693 .35927 L
.43693 .35925 L
.43693 .35924 L
.43693 .35922 L
.43694 .35921 L
.43694 .35919 L
.43694 .35918 L
.43694 .35916 L
.43695 .35914 L
.43695 .35913 L
.43695 .35911 L
.43695 .3591 L
.43696 .35908 L
.43696 .35907 L
.43696 .35905 L
.43696 .35904 L
.43697 .35902 L
.43697 .35901 L
Mistroke
.43697 .35899 L
.43697 .35898 L
.43698 .35896 L
.43698 .35895 L
.43698 .35893 L
.43698 .35892 L
.43699 .3589 L
.43699 .35888 L
.43699 .35887 L
.43699 .35885 L
.437 .35884 L
.437 .35882 L
.437 .35881 L
.437 .35879 L
.43701 .35878 L
.43701 .35876 L
.43701 .35875 L
.43702 .35873 L
.43702 .35872 L
.43702 .3587 L
.43702 .35869 L
.43703 .35867 L
.43703 .35866 L
.43703 .35864 L
.43703 .35863 L
.43704 .35861 L
.43704 .35859 L
.43704 .35858 L
.43705 .35856 L
.43705 .35855 L
.43705 .35853 L
.43706 .35852 L
.43706 .3585 L
.43706 .35849 L
.43706 .35847 L
.43707 .35846 L
.43707 .35844 L
.43707 .35843 L
.43708 .35841 L
.43708 .3584 L
.43708 .35838 L
.43709 .35837 L
.43709 .35835 L
.43709 .35834 L
.4371 .35832 L
.4371 .35831 L
.4371 .35829 L
.43711 .35828 L
.43711 .35826 L
.43711 .35825 L
Mistroke
.43711 .35823 L
.43712 .35822 L
.43712 .3582 L
.43712 .35818 L
.43713 .35817 L
.43713 .35815 L
.43713 .35814 L
.43714 .35812 L
.43714 .35811 L
.43714 .35809 L
.43715 .35808 L
.43715 .35806 L
.43716 .35805 L
.43716 .35803 L
.43716 .35802 L
.43717 .358 L
.43717 .35799 L
.43717 .35797 L
.43718 .35796 L
.43718 .35794 L
.43718 .35793 L
.43719 .35791 L
.43719 .3579 L
.43719 .35788 L
.4372 .35787 L
.4372 .35785 L
.4372 .35784 L
.43721 .35782 L
.43721 .35781 L
.43722 .35779 L
.43722 .35778 L
.43722 .35776 L
.43723 .35775 L
.43723 .35773 L
.43723 .35772 L
.43724 .3577 L
.43724 .35769 L
.43725 .35767 L
.43725 .35766 L
.43725 .35764 L
.43726 .35763 L
.43726 .35761 L
.43726 .3576 L
.43727 .35758 L
.43727 .35757 L
.43728 .35755 L
.43728 .35754 L
.43728 .35752 L
.43729 .35751 L
.43729 .35749 L
Mistroke
.4373 .35748 L
.4373 .35746 L
.4373 .35745 L
.43731 .35743 L
.43731 .35742 L
.43732 .3574 L
.43732 .35739 L
.43732 .35737 L
.43733 .35736 L
.43733 .35734 L
.43734 .35733 L
.43734 .35731 L
.43734 .3573 L
.43735 .35728 L
.43735 .35727 L
.43736 .35726 L
.43736 .35724 L
.43737 .35723 L
.43737 .35721 L
.43737 .3572 L
.43738 .35718 L
.43738 .35717 L
.43739 .35715 L
.43739 .35714 L
.43739 .35712 L
.4374 .35711 L
.4374 .35709 L
.43741 .35708 L
.43741 .35706 L
.43742 .35705 L
.43742 .35703 L
.43743 .35702 L
.43743 .357 L
.43743 .35699 L
.43744 .35697 L
.43744 .35696 L
.43745 .35694 L
.43745 .35693 L
.43746 .35691 L
.43746 .3569 L
.43746 .35689 L
.43747 .35687 L
.43747 .35686 L
.43748 .35684 L
.43748 .35683 L
.43749 .35681 L
.43749 .3568 L
.4375 .35678 L
.4375 .35677 L
.43751 .35675 L
Mistroke
.43751 .35674 L
.43752 .35672 L
.43752 .35671 L
.43752 .35669 L
.43753 .35668 L
.43753 .35666 L
.43754 .35665 L
.43754 .35664 L
.43755 .35662 L
.43755 .35661 L
.43756 .35659 L
.43756 .35658 L
.43757 .35656 L
.43757 .35655 L
.43758 .35653 L
.43758 .35652 L
.43759 .3565 L
.43759 .35649 L
.4376 .35647 L
.4376 .35646 L
.43761 .35645 L
.43761 .35643 L
.43762 .35642 L
.43762 .3564 L
.43762 .35639 L
.43763 .35637 L
.43763 .35636 L
.43764 .35634 L
.43764 .35633 L
.43765 .35631 L
.43765 .3563 L
.43766 .35629 L
.43766 .35627 L
.43767 .35626 L
.43767 .35624 L
.43768 .35623 L
.43768 .35621 L
.43769 .3562 L
.4377 .35618 L
.4377 .35617 L
.43771 .35616 L
.43771 .35614 L
.43772 .35613 L
.43772 .35611 L
.43773 .3561 L
.43773 .35608 L
.43774 .35607 L
.43774 .35605 L
.43775 .35604 L
.43775 .35603 L
Mistroke
.43776 .35601 L
.43776 .356 L
.43777 .35598 L
.43777 .35597 L
.43778 .35595 L
.43778 .35594 L
.43779 .35592 L
.43779 .35591 L
.4378 .3559 L
.4378 .35588 L
.43781 .35587 L
.43782 .35585 L
.43782 .35584 L
.43783 .35582 L
.43783 .35581 L
.43784 .3558 L
.43784 .35578 L
.43785 .35577 L
.43785 .35575 L
.43786 .35574 L
.43786 .35572 L
.43787 .35571 L
.43787 .3557 L
.43788 .35568 L
.43789 .35567 L
.43789 .35565 L
.4379 .35564 L
.4379 .35562 L
.43791 .35561 L
.43791 .3556 L
.43792 .35558 L
.43792 .35557 L
.43793 .35555 L
.43794 .35554 L
.43794 .35552 L
.43795 .35551 L
.43795 .3555 L
.43796 .35548 L
.43796 .35547 L
.43797 .35545 L
.43798 .35544 L
.43798 .35542 L
.43799 .35541 L
.43799 .3554 L
.438 .35538 L
.438 .35537 L
.43801 .35535 L
.43802 .35534 L
.43802 .35533 L
.43803 .35531 L
Mistroke
.43803 .3553 L
.43804 .35528 L
.43804 .35527 L
.43805 .35526 L
.43806 .35524 L
.43806 .35523 L
.43807 .35521 L
.43807 .3552 L
.43808 .35519 L
.43809 .35517 L
.43809 .35516 L
.4381 .35514 L
.4381 .35513 L
.43811 .35511 L
.43811 .3551 L
.43812 .35509 L
.43813 .35507 L
.43813 .35506 L
.43814 .35504 L
.43814 .35503 L
.43815 .35502 L
.43816 .355 L
.43816 .35499 L
.43817 .35497 L
.43817 .35496 L
.43818 .35495 L
.43819 .35493 L
.43819 .35492 L
.4382 .35491 L
.43821 .35489 L
.43821 .35488 L
.43822 .35486 L
.43822 .35485 L
.43823 .35484 L
.43824 .35482 L
.43824 .35481 L
.43825 .35479 L
.43825 .35478 L
.43826 .35477 L
.43827 .35475 L
.43827 .35474 L
.43828 .35472 L
.43829 .35471 L
.43829 .3547 L
.4383 .35468 L
.4383 .35467 L
.43831 .35466 L
.43832 .35464 L
.43832 .35463 L
.43833 .35461 L
Mistroke
.43834 .3546 L
.43834 .35459 L
.43835 .35457 L
.43835 .35456 L
.43836 .35455 L
.43837 .35453 L
.43837 .35452 L
.43838 .3545 L
.43839 .35449 L
.43839 .35448 L
.4384 .35446 L
.43841 .35445 L
.43841 .35444 L
.43842 .35442 L
.43842 .35441 L
.43843 .35439 L
.43844 .35438 L
.43844 .35437 L
.43845 .35435 L
.43846 .35434 L
.43846 .35433 L
.43847 .35431 L
.43848 .3543 L
.43848 .35429 L
.43849 .35427 L
.4385 .35426 L
.4385 .35424 L
.43851 .35423 L
.43852 .35422 L
.43852 .3542 L
.43853 .35419 L
.43854 .35418 L
.43854 .35416 L
.43855 .35415 L
.43856 .35414 L
.43856 .35412 L
.43857 .35411 L
.43858 .3541 L
.43858 .35408 L
.43859 .35407 L
.4386 .35405 L
.4386 .35404 L
.43861 .35403 L
.43862 .35401 L
.43862 .354 L
.43863 .35399 L
.43864 .35397 L
.43864 .35396 L
.43865 .35395 L
.43866 .35393 L
Mistroke
.43866 .35392 L
.43867 .35391 L
.43868 .35389 L
.43868 .35388 L
.43869 .35387 L
.4387 .35385 L
.4387 .35384 L
.43871 .35383 L
.43872 .35381 L
.43872 .3538 L
.43873 .35379 L
.43874 .35377 L
.43875 .35376 L
.43875 .35375 L
.43876 .35373 L
.43877 .35372 L
.43877 .35371 L
.43878 .35369 L
.43879 .35368 L
.43879 .35367 L
.4388 .35365 L
.43881 .35364 L
.43881 .35363 L
.43882 .35361 L
.43883 .3536 L
.43884 .35359 L
.43884 .35357 L
.43885 .35356 L
.43886 .35355 L
.43886 .35353 L
.43887 .35352 L
.43888 .35351 L
.43888 .35349 L
.43889 .35348 L
.4389 .35347 L
.43891 .35345 L
.43891 .35344 L
.43892 .35343 L
.43893 .35341 L
.43893 .3534 L
.43894 .35339 L
.43895 .35338 L
.43896 .35336 L
.43896 .35335 L
.43897 .35334 L
.43898 .35332 L
.43898 .35331 L
.43899 .3533 L
.439 .35328 L
.43901 .35327 L
Mistroke
.43901 .35326 L
.43902 .35324 L
.43903 .35323 L
.43904 .35322 L
.43904 .35321 L
.43905 .35319 L
.43906 .35318 L
.43906 .35317 L
.43907 .35315 L
.43908 .35314 L
.43909 .35313 L
.43909 .35311 L
.4391 .3531 L
.43911 .35309 L
.43912 .35308 L
.43912 .35306 L
.43913 .35305 L
.43914 .35304 L
.43914 .35302 L
.43915 .35301 L
.43916 .353 L
.43917 .35298 L
.43917 .35297 L
.43918 .35296 L
.43919 .35295 L
.4392 .35293 L
.4392 .35292 L
.43921 .35291 L
.43922 .35289 L
.43923 .35288 L
.43923 .35287 L
.43924 .35286 L
.43925 .35284 L
.43926 .35283 L
.43926 .35282 L
.43927 .35281 L
.43928 .35279 L
.43929 .35278 L
.43929 .35277 L
.4393 .35275 L
.43931 .35274 L
.43932 .35273 L
.43932 .35272 L
.43933 .3527 L
.43934 .35269 L
.43935 .35268 L
.43935 .35266 L
.43936 .35265 L
.43937 .35264 L
.43938 .35263 L
Mistroke
.43938 .35261 L
.43939 .3526 L
.4394 .35259 L
.43941 .35258 L
.43941 .35256 L
.43942 .35255 L
.43943 .35254 L
.43944 .35253 L
.43945 .35251 L
.43945 .3525 L
.43946 .35249 L
.43947 .35248 L
.43948 .35246 L
.43948 .35245 L
.43949 .35244 L
.4395 .35242 L
.43951 .35241 L
.43951 .3524 L
.43952 .35239 L
.43953 .35237 L
.43954 .35236 L
.43955 .35235 L
.43955 .35234 L
.43956 .35232 L
.43957 .35231 L
.43958 .3523 L
.43958 .35229 L
.43959 .35227 L
.4396 .35226 L
.43961 .35225 L
.43962 .35224 L
.43962 .35223 L
.43963 .35221 L
.43964 .3522 L
.43965 .35219 L
.43966 .35218 L
.43966 .35216 L
.43967 .35215 L
.43968 .35214 L
.43969 .35213 L
.43969 .35211 L
.4397 .3521 L
.43971 .35209 L
.43972 .35208 L
.43973 .35206 L
.43973 .35205 L
.43974 .35204 L
.43975 .35203 L
.43976 .35201 L
.43977 .352 L
Mistroke
.43977 .35199 L
.43978 .35198 L
.43979 .35197 L
.4398 .35195 L
.43981 .35194 L
.43981 .35193 L
.43982 .35192 L
.43983 .3519 L
.43984 .35189 L
.43985 .35188 L
.43985 .35187 L
.43986 .35186 L
.43987 .35184 L
.43988 .35183 L
.43989 .35182 L
.43989 .35181 L
.4399 .3518 L
.43991 .35178 L
.43992 .35177 L
.43993 .35176 L
.43993 .35175 L
.43994 .35173 L
.43995 .35172 L
.43996 .35171 L
.43997 .3517 L
.43997 .35169 L
.43998 .35167 L
.43999 .35166 L
.44 .35165 L
.44001 .35164 L
.44002 .35163 L
.44002 .35161 L
.44003 .3516 L
.44004 .35159 L
.44005 .35158 L
.44006 .35157 L
.44006 .35155 L
.44007 .35154 L
.44008 .35153 L
.44009 .35152 L
.4401 .35151 L
.44011 .35149 L
.44011 .35148 L
.44012 .35147 L
.44013 .35146 L
.44014 .35145 L
.44015 .35143 L
.44015 .35142 L
.44016 .35141 L
.44017 .3514 L
Mistroke
.44018 .35139 L
.44019 .35138 L
.4402 .35136 L
.4402 .35135 L
.44021 .35134 L
.44022 .35133 L
.44023 .35132 L
.44024 .3513 L
.44025 .35129 L
.44025 .35128 L
.44026 .35127 L
.44027 .35126 L
.44028 .35125 L
.44029 .35123 L
.4403 .35122 L
.4403 .35121 L
.44031 .3512 L
.44032 .35119 L
.44033 .35118 L
.44034 .35116 L
.44035 .35115 L
.44035 .35114 L
.44036 .35113 L
.44037 .35112 L
.44038 .35111 L
.44039 .35109 L
.4404 .35108 L
.4404 .35107 L
.44041 .35106 L
.44042 .35105 L
.44043 .35104 L
.44044 .35102 L
.44045 .35101 L
.44046 .351 L
.44046 .35099 L
.44047 .35098 L
.44048 .35097 L
.44049 .35095 L
.4405 .35094 L
.44051 .35093 L
.44051 .35092 L
.44052 .35091 L
.44053 .3509 L
.44054 .35089 L
.44055 .35087 L
.44056 .35086 L
.44057 .35085 L
.44057 .35084 L
.44058 .35083 L
.44059 .35082 L
Mistroke
.4406 .35081 L
.44061 .35079 L
.44062 .35078 L
.44063 .35077 L
.44063 .35076 L
.44064 .35075 L
.44065 .35074 L
.44066 .35073 L
.44067 .35071 L
.44068 .3507 L
.44069 .35069 L
.44069 .35068 L
.4407 .35067 L
.44071 .35066 L
.44072 .35065 L
.44073 .35064 L
.44074 .35062 L
.44075 .35061 L
.44075 .3506 L
.44076 .35059 L
.44077 .35058 L
.44078 .35057 L
.44079 .35056 L
.4408 .35055 L
.44081 .35053 L
.44082 .35052 L
.44082 .35051 L
.44083 .3505 L
.44084 .35049 L
.44085 .35048 L
.44086 .35047 L
.44087 .35046 L
.44088 .35044 L
.44088 .35043 L
.44089 .35042 L
.4409 .35041 L
.44091 .3504 L
.44092 .35039 L
.44093 .35038 L
.44094 .35037 L
.44095 .35036 L
.44095 .35035 L
.44096 .35033 L
.44097 .35032 L
.44098 .35031 L
.44099 .3503 L
.441 .35029 L
.44101 .35028 L
.44102 .35027 L
.44102 .35026 L
Mistroke
.44103 .35025 L
.44104 .35024 L
.44105 .35022 L
.44106 .35021 L
.44107 .3502 L
.44108 .35019 L
.44109 .35018 L
.44109 .35017 L
.4411 .35016 L
.44111 .35015 L
.44112 .35014 L
.44113 .35013 L
.44114 .35011 L
.44115 .3501 L
.44116 .35009 L
.44117 .35008 L
.44117 .35007 L
.44118 .35006 L
.44119 .35005 L
.4412 .35004 L
.44121 .35003 L
.44122 .35002 L
.44123 .35001 L
.44124 .35 L
.44125 .34999 L
.44125 .34997 L
.44126 .34996 L
.44127 .34995 L
.44128 .34994 L
.44129 .34993 L
.4413 .34992 L
.44131 .34991 L
.44132 .3499 L
.44133 .34989 L
.44133 .34988 L
.44134 .34987 L
.44135 .34986 L
.44136 .34985 L
.44137 .34984 L
.44138 .34982 L
.44139 .34981 L
.4414 .3498 L
.44141 .34979 L
.44141 .34978 L
.44142 .34977 L
.44143 .34976 L
.44144 .34975 L
.44145 .34974 L
.44146 .34973 L
.44147 .34972 L
Mistroke
.44148 .34971 L
.44149 .3497 L
.4415 .34969 L
.4415 .34968 L
.44151 .34967 L
.44152 .34966 L
.44153 .34965 L
.44154 .34964 L
.44155 .34962 L
.44156 .34961 L
.44157 .3496 L
.44158 .34959 L
.44159 .34958 L
.44159 .34957 L
.4416 .34956 L
.44161 .34955 L
.44162 .34954 L
.44163 .34953 L
.44164 .34952 L
.44165 .34951 L
.44166 .3495 L
.44167 .34949 L
.44168 .34948 L
.44168 .34947 L
.44169 .34946 L
.4417 .34945 L
.44171 .34944 L
.44172 .34943 L
.44173 .34942 L
.44174 .34941 L
.44175 .3494 L
.44176 .34939 L
.44177 .34938 L
.44178 .34937 L
.44178 .34936 L
.44179 .34935 L
.4418 .34934 L
.44181 .34933 L
.44182 .34932 L
.44183 .34931 L
.44184 .34929 L
.44185 .34928 L
.44186 .34927 L
.44187 .34926 L
.44188 .34925 L
.44188 .34924 L
.44189 .34923 L
.4419 .34922 L
.44191 .34921 L
.44192 .3492 L
Mistroke
.44193 .34919 L
.44194 .34918 L
.44195 .34917 L
.44196 .34916 L
.44197 .34915 L
.44198 .34914 L
.44199 .34913 L
.44199 .34912 L
.442 .34911 L
.44201 .3491 L
.44202 .34909 L
.44203 .34908 L
.44204 .34907 L
.44205 .34906 L
.44206 .34905 L
.44207 .34904 L
.44208 .34903 L
.44209 .34902 L
.4421 .34901 L
.4421 .349 L
.44211 .34899 L
.44212 .34898 L
.44213 .34897 L
.44214 .34896 L
.44215 .34895 L
.44216 .34895 L
.44217 .34894 L
.44218 .34893 L
.44219 .34892 L
.4422 .34891 L
.44221 .3489 L
.44221 .34889 L
.44222 .34888 L
.44223 .34887 L
.44224 .34886 L
.44225 .34885 L
.44226 .34884 L
.44227 .34883 L
.44228 .34882 L
.44229 .34881 L
.4423 .3488 L
.44231 .34879 L
.44232 .34878 L
.44233 .34877 L
.44234 .34876 L
.44234 .34875 L
.44235 .34874 L
.44236 .34873 L
.44237 .34872 L
.44238 .34871 L
Mistroke
.44239 .3487 L
.4424 .34869 L
.44241 .34868 L
.44242 .34867 L
.44243 .34866 L
.44244 .34865 L
.44245 .34864 L
.44246 .34864 L
.44246 .34863 L
.44247 .34862 L
.44248 .34861 L
.44249 .3486 L
.4425 .34859 L
.44251 .34858 L
.44252 .34857 L
.44253 .34856 L
.44254 .34855 L
.44255 .34854 L
.44256 .34853 L
.44257 .34852 L
.44258 .34851 L
.44259 .3485 L
.4426 .34849 L
.4426 .34848 L
.44261 .34847 L
.44262 .34847 L
.44263 .34846 L
.44264 .34845 L
.44265 .34844 L
.44266 .34843 L
.44267 .34842 L
.44268 .34841 L
.44269 .3484 L
.4427 .34839 L
.44271 .34838 L
.44272 .34837 L
.44273 .34836 L
.44274 .34835 L
.44274 .34834 L
.44275 .34833 L
.44276 .34833 L
.44277 .34832 L
.44278 .34831 L
.44279 .3483 L
.4428 .34829 L
.44281 .34828 L
.44282 .34827 L
.44283 .34826 L
.44284 .34825 L
.44285 .34824 L
Mistroke
.44286 .34823 L
.44287 .34822 L
.44288 .34822 L
.44288 .34821 L
.44289 .3482 L
.4429 .34819 L
.44291 .34818 L
.44292 .34817 L
.44293 .34816 L
.44294 .34815 L
.44295 .34814 L
.44296 .34813 L
.44297 .34812 L
.44298 .34812 L
.44299 .34811 L
.443 .3481 L
.44301 .34809 L
.44302 .34808 L
.44303 .34807 L
.44304 .34806 L
.44304 .34805 L
.44305 .34804 L
.44306 .34804 L
.44307 .34803 L
.44308 .34802 L
.44309 .34801 L
.4431 .348 L
.44311 .34799 L
.44312 .34798 L
.44313 .34797 L
.44314 .34796 L
.44315 .34796 L
.44316 .34795 L
.44317 .34794 L
.44318 .34793 L
.44319 .34792 L
.4432 .34791 L
.4432 .3479 L
.44321 .34789 L
.44322 .34788 L
.44323 .34788 L
.44324 .34787 L
.44325 .34786 L
.44326 .34785 L
.44327 .34784 L
.44328 .34783 L
.44329 .34782 L
.4433 .34781 L
.44331 .34781 L
.44332 .3478 L
Mistroke
.44333 .34779 L
.44334 .34778 L
.44335 .34777 L
.44336 .34776 L
.44336 .34775 L
.44337 .34775 L
.44338 .34774 L
.44339 .34773 L
.4434 .34772 L
.44341 .34771 L
.44342 .3477 L
.44343 .34769 L
.44344 .34769 L
.44345 .34768 L
.44346 .34767 L
.44347 .34766 L
.44348 .34765 L
.44349 .34764 L
.4435 .34763 L
.44351 .34763 L
.44352 .34762 L
.44353 .34761 L
.44353 .3476 L
.44354 .34759 L
.44355 .34758 L
.44356 .34758 L
.44357 .34757 L
.44358 .34756 L
.44359 .34755 L
.4436 .34754 L
.44361 .34753 L
.44362 .34752 L
.44363 .34752 L
.44364 .34751 L
.44365 .3475 L
.44366 .34749 L
.44367 .34748 L
.44368 .34747 L
.44369 .34747 L
.4437 .34746 L
.44371 .34745 L
.44371 .34744 L
.44372 .34743 L
.44373 .34743 L
.44374 .34742 L
.44375 .34741 L
.44376 .3474 L
.44377 .34739 L
.44378 .34738 L
.44379 .34738 L
Mistroke
.4438 .34737 L
.44381 .34736 L
.44382 .34735 L
.44383 .34734 L
.44384 .34733 L
.44385 .34733 L
.44386 .34732 L
.44387 .34731 L
.44388 .3473 L
.44389 .34729 L
.44389 .34729 L
.4439 .34728 L
.44391 .34727 L
.44392 .34726 L
.44393 .34725 L
.44394 .34725 L
.44395 .34724 L
.44396 .34723 L
.44397 .34722 L
.44398 .34721 L
.44399 .34721 L
.444 .3472 L
.44401 .34719 L
.44402 .34718 L
.44403 .34717 L
.44404 .34717 L
.44405 .34716 L
.44406 .34715 L
.44407 .34714 L
.44407 .34713 L
.44408 .34713 L
.44409 .34712 L
.4441 .34711 L
.44411 .3471 L
.44412 .34709 L
.44413 .34709 L
.44414 .34708 L
.44415 .34707 L
.44416 .34706 L
.44417 .34706 L
.44418 .34705 L
.44419 .34704 L
.4442 .34703 L
.44421 .34702 L
.44422 .34702 L
.44423 .34701 L
.44424 .347 L
.44425 .34699 L
.44425 .34699 L
.44426 .34698 L
Mistroke
.44427 .34697 L
.44428 .34696 L
.44429 .34695 L
.4443 .34695 L
.44431 .34694 L
.44432 .34693 L
.44433 .34692 L
.44434 .34692 L
.44435 .34691 L
.44436 .3469 L
.44437 .34689 L
.44438 .34689 L
.44439 .34688 L
.4444 .34687 L
.44441 .34686 L
.44442 .34685 L
.44443 .34685 L
.44444 .34684 L
.44444 .34683 L
.44445 .34682 L
.44446 .34682 L
.44447 .34681 L
.44448 .3468 L
.44449 .34679 L
.4445 .34679 L
.44451 .34678 L
.44452 .34677 L
.44453 .34676 L
.44454 .34676 L
.44455 .34675 L
.44456 .34674 L
.44457 .34673 L
.44458 .34673 L
.44459 .34672 L
.4446 .34671 L
.44461 .3467 L
.44462 .3467 L
.44462 .34669 L
.44463 .34668 L
.44464 .34668 L
.44465 .34667 L
.44466 .34666 L
.44467 .34665 L
.44468 .34665 L
.44469 .34664 L
.4447 .34663 L
.44471 .34662 L
.44472 .34662 L
.44473 .34661 L
.44474 .3466 L
Mistroke
.44475 .3466 L
.44476 .34659 L
.44477 .34658 L
.44478 .34657 L
.44479 .34657 L
.4448 .34656 L
.4448 .34655 L
.44481 .34654 L
.44482 .34654 L
.44483 .34653 L
.44484 .34652 L
.44485 .34652 L
.44486 .34651 L
.44487 .3465 L
.44488 .34649 L
.44489 .34649 L
.4449 .34648 L
.44491 .34647 L
.44492 .34647 L
.44493 .34646 L
.44494 .34645 L
.44495 .34644 L
.44496 .34644 L
.44497 .34643 L
.44497 .34642 L
.44498 .34642 L
.44499 .34641 L
.445 .3464 L
.44501 .3464 L
.44502 .34639 L
.44503 .34638 L
.44504 .34637 L
.44505 .34637 L
.44506 .34636 L
.44507 .34635 L
.44508 .34635 L
.44509 .34634 L
.4451 .34633 L
.44511 .34633 L
.44512 .34632 L
.44513 .34631 L
.44514 .34631 L
.44514 .3463 L
.44515 .34629 L
.44516 .34628 L
.44517 .34628 L
.44518 .34627 L
.44519 .34626 L
.4452 .34626 L
.44521 .34625 L
Mistroke
.44522 .34624 L
.44523 .34624 L
.44524 .34623 L
.44525 .34622 L
.44526 .34622 L
.44527 .34621 L
.44528 .3462 L
.44529 .3462 L
.4453 .34619 L
.4453 .34618 L
.44531 .34618 L
.44532 .34617 L
.44533 .34616 L
.44534 .34616 L
.44535 .34615 L
.44536 .34614 L
.44537 .34614 L
.44538 .34613 L
.44539 .34612 L
.4454 .34612 L
.44541 .34611 L
.44542 .3461 L
.44543 .3461 L
.44544 .34609 L
.44545 .34608 L
.44546 .34608 L
.44546 .34607 L
.44547 .34606 L
.44548 .34606 L
.44549 .34605 L
.4455 .34604 L
.44551 .34604 L
.44552 .34603 L
.44553 .34603 L
.44554 .34602 L
.44555 .34601 L
.44556 .34601 L
.44557 .346 L
.44558 .34599 L
.44559 .34599 L
.4456 .34598 L
.44561 .34597 L
.44561 .34597 L
.44562 .34596 L
.44563 .34595 L
.44564 .34595 L
.44565 .34594 L
.44566 .34594 L
.44567 .34593 L
.44568 .34592 L
Mistroke
.44569 .34592 L
.4457 .34591 L
.44571 .3459 L
.44572 .3459 L
.44573 .34589 L
.44574 .34588 L
.44575 .34588 L
.44576 .34587 L
.44576 .34587 L
.44577 .34586 L
.44578 .34585 L
.44579 .34585 L
.4458 .34584 L
.44581 .34583 L
.44582 .34583 L
.44583 .34582 L
.44584 .34582 L
.44585 .34581 L
.44586 .3458 L
.44587 .3458 L
.44588 .34579 L
.44589 .34579 L
.4459 .34578 L
.4459 .34577 L
.44591 .34577 L
.44592 .34576 L
.44593 .34575 L
.44594 .34575 L
.44595 .34574 L
.44596 .34574 L
.44597 .34573 L
.44598 .34572 L
.44599 .34572 L
.446 .34571 L
.44601 .34571 L
.44602 .3457 L
.44603 .34569 L
.44603 .34569 L
.44604 .34568 L
.44605 .34568 L
.44606 .34567 L
.44607 .34566 L
.44608 .34566 L
.44609 .34565 L
.4461 .34565 L
.44611 .34564 L
.44612 .34563 L
.44613 .34563 L
.44614 .34562 L
.44615 .34562 L
Mistroke
.44616 .34561 L
.44616 .34561 L
.44617 .3456 L
.44618 .34559 L
.44619 .34559 L
.4462 .34558 L
.44621 .34558 L
.44622 .34557 L
.44623 .34556 L
.44624 .34556 L
.44625 .34555 L
.44626 .34555 L
.44627 .34554 L
.44628 .34554 L
.44629 .34553 L
.44629 .34552 L
.4463 .34552 L
.44631 .34551 L
.44632 .34551 L
.44633 .3455 L
.44634 .3455 L
.44635 .34549 L
.44636 .34548 L
.44637 .34548 L
.44638 .34547 L
.44639 .34547 L
.4464 .34546 L
.4464 .34546 L
.44641 .34545 L
.44642 .34545 L
.44643 .34544 L
.44644 .34543 L
.44645 .34543 L
.44646 .34542 L
.44647 .34542 L
.44648 .34541 L
.44649 .34541 L
.4465 .3454 L
.44651 .34539 L
.44652 .34539 L
.44652 .34538 L
.44653 .34538 L
.44654 .34537 L
.44655 .34537 L
.44656 .34536 L
.44657 .34536 L
.44658 .34535 L
.44659 .34535 L
.4466 .34534 L
.44661 .34533 L
Mistroke
.44662 .34533 L
.44663 .34532 L
.44663 .34532 L
.44664 .34531 L
.44665 .34531 L
.44666 .3453 L
.44667 .3453 L
.44668 .34529 L
.44669 .34529 L
.4467 .34528 L
.44671 .34528 L
.44672 .34527 L
.44673 .34526 L
.44673 .34526 L
.44674 .34525 L
.44675 .34525 L
.44676 .34524 L
.44677 .34524 L
.44678 .34523 L
.44679 .34523 L
.4468 .34522 L
.44681 .34522 L
.44682 .34521 L
.44683 .34521 L
.44684 .3452 L
.44684 .3452 L
.44685 .34519 L
.44686 .34519 L
.44687 .34518 L
.44688 .34518 L
.44689 .34517 L
.4469 .34517 L
.44691 .34516 L
.44692 .34516 L
.44693 .34515 L
.44693 .34515 L
.44694 .34514 L
.44695 .34513 L
.44696 .34513 L
.44697 .34512 L
.44698 .34512 L
.44699 .34511 L
.447 .34511 L
.44701 .3451 L
.44702 .3451 L
.44703 .34509 L
.44703 .34509 L
.44704 .34508 L
.44705 .34508 L
.44706 .34507 L
Mistroke
.44707 .34507 L
.44708 .34506 L
.44709 .34506 L
.4471 .34505 L
.44711 .34505 L
.44712 .34504 L
.44712 .34504 L
.44713 .34503 L
.44714 .34503 L
.44715 .34503 L
.44716 .34502 L
.44717 .34502 L
.44718 .34501 L
.44719 .34501 L
.4472 .345 L
.44721 .345 L
.44721 .34499 L
.44722 .34499 L
.44723 .34498 L
.44724 .34498 L
.44725 .34497 L
.44726 .34497 L
.44727 .34496 L
.44728 .34496 L
.44729 .34495 L
.4473 .34495 L
.4473 .34494 L
.44731 .34494 L
.44732 .34493 L
.44733 .34493 L
.44734 .34492 L
.44735 .34492 L
.44736 .34491 L
.44737 .34491 L
.44738 .34491 L
.44738 .3449 L
.44739 .3449 L
.4474 .34489 L
.44741 .34489 L
.44742 .34488 L
.44743 .34488 L
.44744 .34487 L
.44745 .34487 L
.44746 .34486 L
.44746 .34486 L
.44747 .34485 L
.44748 .34485 L
.44749 .34485 L
.4475 .34484 L
.44751 .34484 L
Mistroke
.44752 .34483 L
.44753 .34483 L
.44754 .34482 L
.44754 .34482 L
.44755 .34481 L
.44756 .34481 L
.44757 .3448 L
.44758 .3448 L
.44759 .3448 L
.4476 .34479 L
.44761 .34479 L
.44762 .34478 L
.44762 .34478 L
.44763 .34477 L
.44764 .34477 L
.44765 .34476 L
.44766 .34476 L
.44767 .34476 L
.44768 .34475 L
.44769 .34475 L
.44769 .34474 L
.4477 .34474 L
.44771 .34473 L
.44772 .34473 L
.44773 .34473 L
.44774 .34472 L
.44775 .34472 L
.44776 .34471 L
.44777 .34471 L
.44777 .3447 L
.44778 .3447 L
.44779 .3447 L
.4478 .34469 L
.44781 .34469 L
.44782 .34468 L
.44783 .34468 L
.44784 .34467 L
.44784 .34467 L
.44785 .34467 L
.44786 .34466 L
.44787 .34466 L
.44788 .34465 L
.44789 .34465 L
.4479 .34464 L
.44791 .34464 L
.44791 .34464 L
.44792 .34463 L
.44793 .34463 L
.44794 .34462 L
.44795 .34462 L
Mistroke
.44796 .34462 L
.44797 .34461 L
.44797 .34461 L
.44798 .3446 L
.44799 .3446 L
.448 .3446 L
.44801 .34459 L
.44802 .34459 L
.44803 .34458 L
.44804 .34458 L
.44804 .34457 L
.44805 .34457 L
.44806 .34457 L
.44807 .34456 L
.44808 .34456 L
.44809 .34455 L
.4481 .34455 L
.4481 .34455 L
.44811 .34454 L
.44812 .34454 L
.44813 .34454 L
.44814 .34453 L
.44815 .34453 L
.44816 .34452 L
.44817 .34452 L
.44817 .34452 L
.44818 .34451 L
.44819 .34451 L
.4482 .3445 L
.44821 .3445 L
.44822 .3445 L
.44823 .34449 L
.44823 .34449 L
.44824 .34448 L
.44825 .34448 L
.44826 .34448 L
.44827 .34447 L
.44828 .34447 L
.44829 .34447 L
.44829 .34446 L
.4483 .34446 L
.44831 .34445 L
.44832 .34445 L
.44833 .34445 L
.44834 .34444 L
.44835 .34444 L
.44835 .34444 L
.44836 .34443 L
.44837 .34443 L
.44838 .34442 L
Mistroke
.44839 .34442 L
.4484 .34442 L
.44841 .34441 L
.44841 .34441 L
.44842 .34441 L
.44843 .3444 L
.44844 .3444 L
.44845 .3444 L
.44846 .34439 L
.44846 .34439 L
.44847 .34438 L
.44848 .34438 L
.44849 .34438 L
.4485 .34437 L
.44851 .34437 L
.44852 .34437 L
.44852 .34436 L
.44853 .34436 L
.44854 .34436 L
.44855 .34435 L
.44856 .34435 L
.44857 .34434 L
.44857 .34434 L
.44858 .34434 L
.44859 .34433 L
.4486 .34433 L
.44861 .34433 L
.44862 .34432 L
.44863 .34432 L
.44863 .34432 L
.44864 .34431 L
.44865 .34431 L
.44866 .34431 L
.44867 .3443 L
.44868 .3443 L
.44868 .3443 L
.44869 .34429 L
.4487 .34429 L
.44871 .34429 L
.44872 .34428 L
.44873 .34428 L
.44873 .34428 L
.44874 .34427 L
.44875 .34427 L
.44876 .34427 L
.44877 .34426 L
.44878 .34426 L
.44878 .34426 L
.44879 .34425 L
.4488 .34425 L
Mistroke
.44881 .34425 L
.44882 .34424 L
.44883 .34424 L
.44883 .34424 L
.44884 .34423 L
.44885 .34423 L
.44886 .34423 L
.44887 .34422 L
.44888 .34422 L
.44888 .34422 L
.44889 .34421 L
.4489 .34421 L
.44891 .34421 L
.44892 .3442 L
.44893 .3442 L
.44893 .3442 L
.44894 .34419 L
.44895 .34419 L
.44896 .34419 L
.44897 .34419 L
.44897 .34418 L
.44898 .34418 L
.44899 .34418 L
.449 .34417 L
.44901 .34417 L
.44902 .34417 L
.44902 .34416 L
.44903 .34416 L
.44904 .34416 L
.44905 .34415 L
.44906 .34415 L
.44906 .34415 L
.44907 .34415 L
.44908 .34414 L
.44909 .34414 L
.4491 .34414 L
.44911 .34413 L
.44911 .34413 L
.44912 .34413 L
.44913 .34412 L
.44914 .34412 L
.44915 .34412 L
.44915 .34412 L
.44916 .34411 L
.44917 .34411 L
.44918 .34411 L
.44919 .3441 L
.4492 .3441 L
.4492 .3441 L
.44921 .3441 L
Mistroke
.44922 .34409 L
.44923 .34409 L
.44924 .34409 L
.44924 .34408 L
.44925 .34408 L
.44926 .34408 L
.44927 .34408 L
.44928 .34407 L
.44928 .34407 L
.44929 .34407 L
.4493 .34406 L
.44931 .34406 L
.44932 .34406 L
.44932 .34406 L
.44933 .34405 L
.44934 .34405 L
.44935 .34405 L
.44936 .34404 L
.44936 .34404 L
.44937 .34404 L
.44938 .34404 L
.44939 .34403 L
.4494 .34403 L
.4494 .34403 L
.44941 .34403 L
.44942 .34402 L
.44943 .34402 L
.44944 .34402 L
.44944 .34401 L
.44945 .34401 L
.44946 .34401 L
.44947 .34401 L
.44948 .344 L
.44948 .344 L
.44949 .344 L
.4495 .344 L
.44951 .34399 L
.44952 .34399 L
.44952 .34399 L
.44953 .34399 L
.44954 .34398 L
.44955 .34398 L
.44956 .34398 L
.44956 .34398 L
.44957 .34397 L
.44958 .34397 L
.44959 .34397 L
.4496 .34397 L
.4496 .34396 L
.44961 .34396 L
Mistroke
.44962 .34396 L
.44963 .34396 L
.44964 .34395 L
.44964 .34395 L
.44965 .34395 L
.44966 .34395 L
.44967 .34394 L
.44967 .34394 L
.44968 .34394 L
.44969 .34394 L
.4497 .34393 L
.44971 .34393 L
.44971 .34393 L
.44972 .34393 L
.44973 .34392 L
.44974 .34392 L
.44974 .34392 L
.44975 .34392 L
.44976 .34391 L
.44977 .34391 L
.44978 .34391 L
.44978 .34391 L
.44979 .3439 L
.4498 .3439 L
.44981 .3439 L
.44981 .3439 L
.44982 .3439 L
.44983 .34389 L
.44984 .34389 L
.44985 .34389 L
.44985 .34389 L
.44986 .34388 L
.44987 .34388 L
.44988 .34388 L
.44988 .34388 L
.44989 .34388 L
.4499 .34387 L
.44991 .34387 L
.44992 .34387 L
.44992 .34387 L
.44993 .34386 L
.44994 .34386 L
.44995 .34386 L
.44995 .34386 L
.44996 .34386 L
.44997 .34385 L
.44998 .34385 L
.44998 .34385 L
.44999 .34385 L
.45 .34384 L
Mistroke
.45001 .34384 L
.45001 .34384 L
.45002 .34384 L
.45003 .34384 L
.45004 .34383 L
.45005 .34383 L
.45005 .34383 L
.45006 .34383 L
.45007 .34383 L
.45008 .34382 L
.45008 .34382 L
.45009 .34382 L
.4501 .34382 L
.45011 .34382 L
.45011 .34381 L
.45012 .34381 L
.45013 .34381 L
.45014 .34381 L
.45014 .34381 L
.45015 .3438 L
.45016 .3438 L
.45017 .3438 L
.45017 .3438 L
.45018 .3438 L
.45019 .34379 L
.4502 .34379 L
.4502 .34379 L
.45021 .34379 L
.45022 .34379 L
.45023 .34378 L
.45023 .34378 L
.45024 .34378 L
.45025 .34378 L
.45026 .34378 L
.45026 .34377 L
.45027 .34377 L
.45028 .34377 L
.45029 .34377 L
.45029 .34377 L
.4503 .34377 L
.45031 .34376 L
.45032 .34376 L
.45032 .34376 L
.45033 .34376 L
.45034 .34376 L
.45035 .34375 L
.45035 .34375 L
.45036 .34375 L
.45037 .34375 L
.45038 .34375 L
Mistroke
.45038 .34375 L
.45039 .34374 L
.4504 .34374 L
.45041 .34374 L
.45041 .34374 L
.45042 .34374 L
.45043 .34374 L
.45043 .34373 L
.45044 .34373 L
.45045 .34373 L
.45046 .34373 L
.45046 .34373 L
.45047 .34372 L
.45048 .34372 L
.45049 .34372 L
.45049 .34372 L
.4505 .34372 L
.45051 .34372 L
.45052 .34371 L
.45052 .34371 L
.45053 .34371 L
.45054 .34371 L
.45054 .34371 L
.45055 .34371 L
.45056 .34371 L
.45057 .3437 L
.45057 .3437 L
.45058 .3437 L
.45059 .3437 L
.4506 .3437 L
.4506 .3437 L
.45061 .34369 L
.45062 .34369 L
.45062 .34369 L
.45063 .34369 L
.45064 .34369 L
.45065 .34369 L
.45065 .34369 L
.45066 .34368 L
.45067 .34368 L
.45067 .34368 L
.45068 .34368 L
.45069 .34368 L
.4507 .34368 L
.4507 .34367 L
.45071 .34367 L
.45072 .34367 L
.45072 .34367 L
.45073 .34367 L
.45074 .34367 L
Mistroke
.45075 .34367 L
.45075 .34366 L
.45076 .34366 L
.45077 .34366 L
.45077 .34366 L
.45078 .34366 L
.45079 .34366 L
.4508 .34366 L
.4508 .34366 L
.45081 .34365 L
.45082 .34365 L
.45082 .34365 L
.45083 .34365 L
.45084 .34365 L
.45085 .34365 L
.45085 .34365 L
.45086 .34364 L
.45087 .34364 L
.45087 .34364 L
.45088 .34364 L
.45089 .34364 L
.45089 .34364 L
.4509 .34364 L
.45091 .34364 L
.45092 .34363 L
.45092 .34363 L
.45093 .34363 L
.45094 .34363 L
.45094 .34363 L
.45095 .34363 L
.45096 .34363 L
.45096 .34363 L
.45097 .34362 L
.45098 .34362 L
.45099 .34362 L
.45099 .34362 L
.451 .34362 L
.45101 .34362 L
.45101 .34362 L
.45102 .34362 L
.45103 .34362 L
.45103 .34361 L
.45104 .34361 L
.45105 .34361 L
.45105 .34361 L
.45106 .34361 L
.45107 .34361 L
.45108 .34361 L
.45108 .34361 L
.45109 .34361 L
Mistroke
.4511 .3436 L
.4511 .3436 L
.45111 .3436 L
.45112 .3436 L
.45112 .3436 L
.45113 .3436 L
.45114 .3436 L
.45114 .3436 L
.45115 .3436 L
.45116 .3436 L
.45116 .34359 L
.45117 .34359 L
.45118 .34359 L
.45118 .34359 L
.45119 .34359 L
.4512 .34359 L
.45121 .34359 L
.45121 .34359 L
.45122 .34359 L
.45123 .34359 L
.45123 .34358 L
.45124 .34358 L
.45125 .34358 L
.45125 .34358 L
.45126 .34358 L
.45127 .34358 L
.45127 .34358 L
.45128 .34358 L
.45129 .34358 L
.45129 .34358 L
.4513 .34358 L
.45131 .34357 L
.45131 .34357 L
.45132 .34357 L
.45133 .34357 L
.45133 .34357 L
.45134 .34357 L
.45135 .34357 L
.45135 .34357 L
.45136 .34357 L
.45137 .34357 L
.45137 .34357 L
.45138 .34357 L
.45139 .34356 L
.45139 .34356 L
.4514 .34356 L
.45141 .34356 L
.45141 .34356 L
.45142 .34356 L
.45143 .34356 L
Mistroke
.45143 .34356 L
.45144 .34356 L
.45145 .34356 L
.45145 .34356 L
.45146 .34356 L
.45147 .34356 L
.45147 .34355 L
.45148 .34355 L
.45149 .34355 L
.45149 .34355 L
.4515 .34355 L
.4515 .34355 L
.45151 .34355 L
.45152 .34355 L
.45152 .34355 L
.45153 .34355 L
.45154 .34355 L
.45154 .34355 L
.45155 .34355 L
.45156 .34355 L
.45156 .34355 L
.45157 .34355 L
.45158 .34354 L
.45158 .34354 L
.45159 .34354 L
.4516 .34354 L
.4516 .34354 L
.45161 .34354 L
.45162 .34354 L
.45162 .34354 L
.45163 .34354 L
.45163 .34354 L
.45164 .34354 L
.45165 .34354 L
.45165 .34354 L
.45166 .34354 L
.45167 .34354 L
.45167 .34354 L
.45168 .34354 L
.45169 .34354 L
.45169 .34353 L
.4517 .34353 L
.4517 .34353 L
.45171 .34353 L
.45172 .34353 L
.45172 .34353 L
.45173 .34353 L
.45174 .34353 L
.45174 .34353 L
.45175 .34353 L
Mistroke
.45176 .34353 L
.45176 .34353 L
.45177 .34353 L
.45177 .34353 L
.45178 .34353 L
.45179 .34353 L
.45179 .34353 L
.4518 .34353 L
.45181 .34353 L
.45181 .34353 L
.45182 .34353 L
.45182 .34353 L
.45183 .34353 L
.45184 .34352 L
.45184 .34352 L
.45185 .34352 L
.45186 .34352 L
.45186 .34352 L
.45187 .34352 L
.45187 .34352 L
.45188 .34352 L
.45189 .34352 L
.45189 .34352 L
.4519 .34352 L
.45191 .34352 L
.45191 .34352 L
.45192 .34352 L
.45192 .34352 L
.45193 .34352 L
.45194 .34352 L
.45194 .34352 L
.45195 .34352 L
.45195 .34352 L
.45196 .34352 L
.45197 .34352 L
.45197 .34352 L
.45198 .34352 L
.45199 .34352 L
.45199 .34352 L
.452 .34352 L
.452 .34352 L
.45201 .34352 L
.45202 .34352 L
.45202 .34352 L
.45203 .34352 L
.45203 .34352 L
.45204 .34352 L
.45205 .34352 L
.45205 .34352 L
.45206 .34352 L
Mistroke
.45206 .34352 L
.45207 .34352 L
.45208 .34352 L
.45208 .34352 L
.45209 .34352 L
.45209 .34352 L
.4521 .34352 L
.45211 .34351 L
.45211 .34351 L
.45212 .34351 L
.45212 .34351 L
.45213 .34351 L
.45214 .34351 L
.45214 .34351 L
.45215 .34351 L
.45215 .34351 L
.45216 .34351 L
.45217 .34351 L
.45217 .34351 L
.45218 .34351 L
.45218 .34351 L
.45219 .34351 L
.4522 .34351 L
.4522 .34351 L
.45221 .34351 L
.45221 .34351 L
.45222 .34351 L
.45223 .34351 L
.45223 .34351 L
.45224 .34351 L
.45224 .34351 L
.45225 .34351 L
.45225 .34351 L
.45226 .34351 L
.45227 .34351 L
.45227 .34351 L
.45228 .34351 L
.45228 .34351 L
.45229 .34351 L
.4523 .34351 L
.4523 .34351 L
.45231 .34352 L
.45231 .34352 L
.45232 .34352 L
.45232 .34352 L
.45233 .34352 L
.45234 .34352 L
.45234 .34352 L
.45235 .34352 L
.45235 .34352 L
Mistroke
.45236 .34352 L
.45236 .34352 L
.45237 .34352 L
.45238 .34352 L
.45238 .34352 L
.45239 .34352 L
.45239 .34352 L
.4524 .34352 L
.4524 .34352 L
.45241 .34352 L
.45242 .34352 L
.45242 .34352 L
.45243 .34352 L
.45243 .34352 L
.45244 .34352 L
.45244 .34352 L
.45245 .34352 L
.45246 .34352 L
.45246 .34352 L
.45247 .34352 L
.45247 .34352 L
.45248 .34352 L
.45248 .34352 L
.45249 .34352 L
.45249 .34352 L
.4525 .34352 L
.45251 .34352 L
.45251 .34352 L
.45252 .34352 L
.45252 .34352 L
.45253 .34352 L
.45253 .34352 L
.45254 .34352 L
.45255 .34352 L
.45255 .34352 L
.45256 .34352 L
.45256 .34353 L
.45257 .34353 L
.45257 .34353 L
.45258 .34353 L
.45258 .34353 L
.45259 .34353 L
.45259 .34353 L
.4526 .34353 L
.45261 .34353 L
.45261 .34353 L
.45262 .34353 L
.45262 .34353 L
.45263 .34353 L
.45263 .34353 L
Mistroke
.45264 .34353 L
.45264 .34353 L
.45265 .34353 L
.45266 .34353 L
.45266 .34353 L
.45267 .34353 L
.45267 .34353 L
.45268 .34353 L
.45268 .34353 L
.45269 .34353 L
.45269 .34353 L
.4527 .34354 L
.4527 .34354 L
.45271 .34354 L
.45271 .34354 L
.45272 .34354 L
.45273 .34354 L
.45273 .34354 L
.45274 .34354 L
.45274 .34354 L
.45275 .34354 L
.45275 .34354 L
.45276 .34354 L
.45276 .34354 L
.45277 .34354 L
.45277 .34354 L
.45278 .34354 L
.45278 .34354 L
.45279 .34354 L
.45279 .34354 L
.4528 .34355 L
.45281 .34355 L
.45281 .34355 L
.45282 .34355 L
.45282 .34355 L
.45283 .34355 L
.45283 .34355 L
.45284 .34355 L
.45284 .34355 L
.45285 .34355 L
.45285 .34355 L
.45286 .34355 L
.45286 .34355 L
.45287 .34355 L
.45287 .34355 L
.45288 .34355 L
.45288 .34356 L
.45289 .34356 L
.45289 .34356 L
.4529 .34356 L
Mistroke
.4529 .34356 L
.45291 .34356 L
.45291 .34356 L
.45292 .34356 L
.45292 .34356 L
.45293 .34356 L
.45294 .34356 L
.45294 .34356 L
.45295 .34356 L
.45295 .34356 L
.45296 .34356 L
.45296 .34357 L
.45297 .34357 L
.45297 .34357 L
.45298 .34357 L
.45298 .34357 L
.45299 .34357 L
.45299 .34357 L
.453 .34357 L
.453 .34357 L
.45301 .34357 L
.45301 .34357 L
.45302 .34357 L
.45302 .34357 L
.45303 .34358 L
.45303 .34358 L
.45304 .34358 L
.45304 .34358 L
.45305 .34358 L
.45305 .34358 L
.45306 .34358 L
.45306 .34358 L
.45307 .34358 L
.45307 .34358 L
.45308 .34358 L
.45308 .34358 L
.45309 .34359 L
.45309 .34359 L
.4531 .34359 L
.4531 .34359 L
.45311 .34359 L
.45311 .34359 L
.45312 .34359 L
.45312 .34359 L
.45313 .34359 L
.45313 .34359 L
.45314 .34359 L
.45314 .3436 L
.45315 .3436 L
.45315 .3436 L
Mistroke
.45316 .3436 L
.45316 .3436 L
.45316 .3436 L
.45317 .3436 L
.45317 .3436 L
.45318 .3436 L
.45318 .3436 L
.45319 .3436 L
.45319 .34361 L
.4532 .34361 L
.4532 .34361 L
.45321 .34361 L
.45321 .34361 L
.45322 .34361 L
.45322 .34361 L
.45323 .34361 L
.45323 .34361 L
.45324 .34361 L
.45324 .34362 L
.45325 .34362 L
.45325 .34362 L
.45326 .34362 L
.45326 .34362 L
.45327 .34362 L
.45327 .34362 L
.45327 .34362 L
.45328 .34362 L
.45328 .34362 L
.45329 .34363 L
.45329 .34363 L
.4533 .34363 L
.4533 .34363 L
.45331 .34363 L
.45331 .34363 L
.45332 .34363 L
.45332 .34363 L
.45333 .34363 L
.45333 .34364 L
.45334 .34364 L
.45334 .34364 L
.45335 .34364 L
.45335 .34364 L
.45335 .34364 L
.45336 .34364 L
.45336 .34364 L
.45337 .34364 L
.45337 .34364 L
.45338 .34365 L
.45338 .34365 L
.45339 .34365 L
Mistroke
.45339 .34365 L
.4534 .34365 L
.4534 .34365 L
.4534 .34365 L
.45341 .34365 L
.45341 .34366 L
.45342 .34366 L
.45342 .34366 L
.45343 .34366 L
.45343 .34366 L
.45344 .34366 L
.45344 .34366 L
.45345 .34366 L
.45345 .34366 L
.45345 .34367 L
.45346 .34367 L
.45346 .34367 L
.45347 .34367 L
.45347 .34367 L
.45348 .34367 L
.45348 .34367 L
.45349 .34367 L
.45349 .34368 L
.45349 .34368 L
.4535 .34368 L
.4535 .34368 L
.45351 .34368 L
.45351 .34368 L
.45352 .34368 L
.45352 .34368 L
.45353 .34369 L
.45353 .34369 L
.45353 .34369 L
.45354 .34369 L
.45354 .34369 L
.45355 .34369 L
.45355 .34369 L
.45356 .34369 L
.45356 .3437 L
.45357 .3437 L
.45357 .3437 L
.45357 .3437 L
.45358 .3437 L
.45358 .3437 L
.45359 .3437 L
.45359 .34371 L
.4536 .34371 L
.4536 .34371 L
.4536 .34371 L
.45361 .34371 L
Mistroke
.45361 .34371 L
.45362 .34371 L
.45362 .34372 L
.45363 .34372 L
.45363 .34372 L
.45363 .34372 L
.45364 .34372 L
.45364 .34372 L
.45365 .34372 L
.45365 .34372 L
.45366 .34373 L
.45366 .34373 L
.45366 .34373 L
.45367 .34373 L
.45367 .34373 L
.45368 .34373 L
.45368 .34373 L
.45368 .34374 L
.45369 .34374 L
.45369 .34374 L
.4537 .34374 L
.4537 .34374 L
.45371 .34374 L
.45371 .34374 L
.45371 .34375 L
.45372 .34375 L
.45372 .34375 L
.45373 .34375 L
.45373 .34375 L
.45373 .34375 L
.45374 .34375 L
.45374 .34376 L
.45375 .34376 L
.45375 .34376 L
.45376 .34376 L
.45376 .34376 L
.45376 .34376 L
.45377 .34377 L
.45377 .34377 L
.45378 .34377 L
.45378 .34377 L
.45378 .34377 L
.45379 .34377 L
.45379 .34377 L
.4538 .34378 L
.4538 .34378 L
.4538 .34378 L
.45381 .34378 L
.45381 .34378 L
.45382 .34378 L
Mistroke
.45382 .34379 L
.45382 .34379 L
.45383 .34379 L
.45383 .34379 L
.45384 .34379 L
.45384 .34379 L
.45384 .34379 L
.45385 .3438 L
.45385 .3438 L
.45386 .3438 L
.45386 .3438 L
.45386 .3438 L
.45387 .3438 L
.45387 .34381 L
.45388 .34381 L
.45388 .34381 L
.45388 .34381 L
.45389 .34381 L
.45389 .34381 L
.45389 .34382 L
.4539 .34382 L
.4539 .34382 L
.45391 .34382 L
.45391 .34382 L
.45391 .34382 L
.45392 .34383 L
.45392 .34383 L
.45393 .34383 L
.45393 .34383 L
.45393 .34383 L
.45394 .34383 L
.45394 .34384 L
.45394 .34384 L
.45395 .34384 L
.45395 .34384 L
.45396 .34384 L
.45396 .34384 L
.45396 .34385 L
.45397 .34385 L
.45397 .34385 L
.45397 .34385 L
.45398 .34385 L
.45398 .34385 L
.45399 .34386 L
.45399 .34386 L
.45399 .34386 L
.454 .34386 L
.454 .34386 L
.454 .34386 L
.45401 .34387 L
Mistroke
.45401 .34387 L
.45402 .34387 L
.45402 .34387 L
.45402 .34387 L
.45403 .34388 L
.45403 .34388 L
.45403 .34388 L
.45404 .34388 L
.45404 .34388 L
.45405 .34388 L
.45405 .34389 L
.45405 .34389 L
.45406 .34389 L
.45406 .34389 L
.45406 .34389 L
.45407 .34389 L
.45407 .3439 L
.45407 .3439 L
.45408 .3439 L
.45408 .3439 L
.45409 .3439 L
.45409 .34391 L
.45409 .34391 L
.4541 .34391 L
.4541 .34391 L
.4541 .34391 L
.45411 .34391 L
.45411 .34392 L
.45411 .34392 L
.45412 .34392 L
.45412 .34392 L
.45412 .34392 L
.45413 .34393 L
.45413 .34393 L
.45413 .34393 L
.45414 .34393 L
.45414 .34393 L
.45415 .34394 L
.45415 .34394 L
.45415 .34394 L
.45416 .34394 L
.45416 .34394 L
.45416 .34394 L
.45417 .34395 L
.45417 .34395 L
.45417 .34395 L
.45418 .34395 L
.45418 .34395 L
.45418 .34396 L
.45419 .34396 L
Mistroke
.45419 .34396 L
.45419 .34396 L
.4542 .34396 L
.4542 .34397 L
.4542 .34397 L
.45421 .34397 L
.45421 .34397 L
.45421 .34397 L
.45422 .34398 L
.45422 .34398 L
.45422 .34398 L
.45423 .34398 L
.45423 .34398 L
.45423 .34399 L
.45424 .34399 L
.45424 .34399 L
.45424 .34399 L
.45425 .34399 L
.45425 .34399 L
.45425 .344 L
.45426 .344 L
.45426 .344 L
.45426 .344 L
.45427 .344 L
.45427 .34401 L
.45427 .34401 L
.45428 .34401 L
.45428 .34401 L
.45428 .34401 L
.45429 .34402 L
.45429 .34402 L
.45429 .34402 L
.4543 .34402 L
.4543 .34402 L
.4543 .34403 L
.45431 .34403 L
.45431 .34403 L
.45431 .34403 L
.45432 .34404 L
.45432 .34404 L
.45432 .34404 L
.45433 .34404 L
.45433 .34404 L
.45433 .34405 L
.45434 .34405 L
.45434 .34405 L
.45434 .34405 L
.45434 .34405 L
.45435 .34406 L
.45435 .34406 L
Mistroke
.45435 .34406 L
.45436 .34406 L
.45436 .34406 L
.45436 .34407 L
.45437 .34407 L
.45437 .34407 L
.45437 .34407 L
.45438 .34407 L
.45438 .34408 L
.45438 .34408 L
.45439 .34408 L
.45439 .34408 L
.45439 .34409 L
.45439 .34409 L
.4544 .34409 L
.4544 .34409 L
.4544 .34409 L
.45441 .3441 L
.45441 .3441 L
.45441 .3441 L
.45442 .3441 L
.45442 .3441 L
.45442 .34411 L
.45443 .34411 L
.45443 .34411 L
.45443 .34411 L
.45443 .34411 L
.45444 .34412 L
.45444 .34412 L
.45444 .34412 L
.45445 .34412 L
.45445 .34413 L
.45445 .34413 L
.45445 .34413 L
.45446 .34413 L
.45446 .34413 L
.45446 .34414 L
.45447 .34414 L
.45447 .34414 L
.45447 .34414 L
.45448 .34415 L
.45448 .34415 L
.45448 .34415 L
.45448 .34415 L
.45449 .34415 L
.45449 .34416 L
.45449 .34416 L
.4545 .34416 L
.4545 .34416 L
.4545 .34417 L
Mistroke
.4545 .34417 L
.45451 .34417 L
.45451 .34417 L
.45451 .34417 L
.45452 .34418 L
.45452 .34418 L
.45452 .34418 L
.45452 .34418 L
.45453 .34419 L
.45453 .34419 L
.45453 .34419 L
.45454 .34419 L
.45454 .34419 L
.45454 .3442 L
.45454 .3442 L
.45455 .3442 L
.45455 .3442 L
.45455 .34421 L
.45455 .34421 L
.45456 .34421 L
.45456 .34421 L
.45456 .34421 L
.45457 .34422 L
.45457 .34422 L
.45457 .34422 L
.45457 .34422 L
.45458 .34423 L
.45458 .34423 L
.45458 .34423 L
.45458 .34423 L
.45459 .34424 L
.45459 .34424 L
.45459 .34424 L
.4546 .34424 L
.4546 .34424 L
.4546 .34425 L
.4546 .34425 L
.45461 .34425 L
.45461 .34425 L
.45461 .34426 L
.45461 .34426 L
.45462 .34426 L
.45462 .34426 L
.45462 .34427 L
.45462 .34427 L
.45463 .34427 L
.45463 .34427 L
.45463 .34428 L
.45464 .34428 L
.45464 .34428 L
Mistroke
.45464 .34428 L
.45464 .34428 L
.45465 .34429 L
.45465 .34429 L
.45465 .34429 L
.45465 .34429 L
.45466 .3443 L
.45466 .3443 L
.45466 .3443 L
.45466 .3443 L
.45467 .34431 L
.45467 .34431 L
.45467 .34431 L
.45467 .34431 L
.45468 .34432 L
.45468 .34432 L
.45468 .34432 L
.45468 .34432 L
.45469 .34432 L
.45469 .34433 L
.45469 .34433 L
.45469 .34433 L
.4547 .34433 L
.4547 .34434 L
.4547 .34434 L
.4547 .34434 L
.45471 .34434 L
.45471 .34435 L
.45471 .34435 L
.45471 .34435 L
.45472 .34435 L
.45472 .34436 L
.45472 .34436 L
.45472 .34436 L
.45473 .34436 L
.45473 .34437 L
.45473 .34437 L
.45473 .34437 L
.45473 .34437 L
.45474 .34438 L
.45474 .34438 L
.45474 .34438 L
.45474 .34438 L
.45475 .34439 L
.45475 .34439 L
.45475 .34439 L
.45475 .34439 L
.45476 .3444 L
.45476 .3444 L
.45476 .3444 L
Mistroke
.45476 .3444 L
.45477 .34441 L
.45477 .34441 L
.45477 .34441 L
.45477 .34441 L
.45477 .34442 L
.45478 .34442 L
.45478 .34442 L
.45478 .34442 L
.45478 .34443 L
.45479 .34443 L
.45479 .34443 L
.45479 .34443 L
.45479 .34444 L
.4548 .34444 L
.4548 .34444 L
.4548 .34444 L
.4548 .34445 L
.4548 .34445 L
.45481 .34445 L
.45481 .34445 L
.45481 .34446 L
.45481 .34446 L
.45482 .34446 L
.45482 .34446 L
.45482 .34447 L
.45482 .34447 L
.45482 .34447 L
.45483 .34447 L
.45483 .34448 L
.45483 .34448 L
.45483 .34448 L
.45483 .34448 L
.45484 .34449 L
.45484 .34449 L
.45484 .34449 L
.45484 .34449 L
.45485 .3445 L
.45485 .3445 L
.45485 .3445 L
.45485 .3445 L
.45485 .34451 L
.45486 .34451 L
.45486 .34451 L
.45486 .34451 L
.45486 .34452 L
.45486 .34452 L
.45487 .34452 L
.45487 .34452 L
.45487 .34453 L
Mistroke
.45487 .34453 L
.45487 .34453 L
.45488 .34453 L
.45488 .34454 L
.45488 .34454 L
.45488 .34454 L
.45488 .34455 L
.45489 .34455 L
.45489 .34455 L
.45489 .34455 L
.45489 .34456 L
.45489 .34456 L
.4549 .34456 L
.4549 .34456 L
.4549 .34457 L
.4549 .34457 L
.4549 .34457 L
.45491 .34457 L
.45491 .34458 L
.45491 .34458 L
.45491 .34458 L
.45491 .34458 L
.45492 .34459 L
.45492 .34459 L
.45492 .34459 L
.45492 .34459 L
.45492 .3446 L
.45493 .3446 L
.45493 .3446 L
.45493 .34461 L
.45493 .34461 L
.45493 .34461 L
.45494 .34461 L
.45494 .34462 L
.45494 .34462 L
.45494 .34462 L
.45494 .34462 L
.45495 .34463 L
.45495 .34463 L
.45495 .34463 L
.45495 .34463 L
.45495 .34464 L
.45495 .34464 L
.45496 .34464 L
.45496 .34465 L
.45496 .34465 L
.45496 .34465 L
.45496 .34465 L
.45497 .34466 L
.45497 .34466 L
Mistroke
.45497 .34466 L
.45497 .34466 L
.45497 .34467 L
.45497 .34467 L
.45498 .34467 L
.45498 .34467 L
.45498 .34468 L
.45498 .34468 L
.45498 .34468 L
.45499 .34469 L
.45499 .34469 L
.45499 .34469 L
.45499 .34469 L
.45499 .3447 L
.45499 .3447 L
.455 .3447 L
.455 .3447 L
.455 .34471 L
.455 .34471 L
.455 .34471 L
.455 .34472 L
.45501 .34472 L
.45501 .34472 L
.45501 .34472 L
.45501 .34473 L
.45501 .34473 L
.45501 .34473 L
.45502 .34473 L
.45502 .34474 L
.45502 .34474 L
.45502 .34474 L
.45502 .34474 L
.45502 .34475 L
.45503 .34475 L
.45503 .34475 L
.45503 .34476 L
.45503 .34476 L
.45503 .34476 L
.45503 .34476 L
.45504 .34477 L
.45504 .34477 L
.45504 .34477 L
.45504 .34478 L
.45504 .34478 L
.45504 .34478 L
.45505 .34478 L
.45505 .34479 L
.45505 .34479 L
.45505 .34479 L
.45505 .34479 L
Mistroke
.45505 .3448 L
.45505 .3448 L
.45506 .3448 L
.45506 .34481 L
.45506 .34481 L
.45506 .34481 L
.45506 .34481 L
.45506 .34482 L
.45507 .34482 L
.45507 .34482 L
.45507 .34482 L
.45507 .34483 L
.45507 .34483 L
.45507 .34483 L
.45507 .34484 L
.45508 .34484 L
.45508 .34484 L
.45508 .34484 L
.45508 .34485 L
.45508 .34485 L
.45508 .34485 L
.45508 .34486 L
.45509 .34486 L
.45509 .34486 L
.45509 .34486 L
.45509 .34487 L
.45509 .34487 L
.45509 .34487 L
.45509 .34487 L
.4551 .34488 L
.4551 .34488 L
.4551 .34488 L
.4551 .34489 L
.4551 .34489 L
.4551 .34489 L
.4551 .34489 L
.45511 .3449 L
.45511 .3449 L
.45511 .3449 L
.45511 .34491 L
.45511 .34491 L
.45511 .34491 L
.45511 .34491 L
.45512 .34492 L
.45512 .34492 L
.45512 .34492 L
.45512 .34493 L
.45512 .34493 L
.45512 .34493 L
.45512 .34493 L
Mistroke
.45512 .34494 L
.45513 .34494 L
.45513 .34494 L
.45513 .34495 L
.45513 .34495 L
.45513 .34495 L
.45513 .34495 L
.45513 .34496 L
.45513 .34496 L
.45514 .34496 L
.45514 .34497 L
.45514 .34497 L
.45514 .34497 L
.45514 .34497 L
.45514 .34498 L
.45514 .34498 L
.45514 .34498 L
.45515 .34499 L
.45515 .34499 L
.45515 .34499 L
.45515 .34499 L
.45515 .345 L
.45515 .345 L
.45515 .345 L
.45515 .34501 L
.45516 .34501 L
.45516 .34501 L
.45516 .34501 L
.45516 .34502 L
.45516 .34502 L
.45516 .34502 L
.45516 .34503 L
.45516 .34503 L
.45517 .34503 L
.45517 .34503 L
.45517 .34504 L
.45517 .34504 L
.45517 .34504 L
.45517 .34505 L
.45517 .34505 L
.45517 .34505 L
.45517 .34505 L
.45518 .34506 L
.45518 .34506 L
.45518 .34506 L
.45518 .34507 L
.45518 .34507 L
.45518 .34507 L
.45518 .34507 L
.45518 .34508 L
Mistroke
.45518 .34508 L
.45519 .34508 L
.45519 .34509 L
.45519 .34509 L
.45519 .34509 L
.45519 .34509 L
.45519 .3451 L
.45519 .3451 L
.45519 .3451 L
.45519 .34511 L
.45519 .34511 L
.4552 .34511 L
.4552 .34511 L
.4552 .34512 L
.4552 .34512 L
.4552 .34512 L
.4552 .34513 L
.4552 .34513 L
.4552 .34513 L
.4552 .34514 L
.4552 .34514 L
.45521 .34514 L
.45521 .34514 L
.45521 .34515 L
.45521 .34515 L
.45521 .34515 L
.45521 .34516 L
.45521 .34516 L
.45521 .34516 L
.45521 .34516 L
.45521 .34517 L
.45522 .34517 L
.45522 .34517 L
.45522 .34518 L
.45522 .34518 L
.45522 .34518 L
.45522 .34518 L
.45522 .34519 L
.45522 .34519 L
.45522 .34519 L
.45522 .3452 L
.45522 .3452 L
.45523 .3452 L
.45523 .34521 L
.45523 .34521 L
.45523 .34521 L
.45523 .34521 L
.45523 .34522 L
.45523 .34522 L
.45523 .34522 L
Mistroke
.45523 .34523 L
.45523 .34523 L
.45523 .34523 L
.45524 .34523 L
.45524 .34524 L
.45524 .34524 L
.45524 .34524 L
.45524 .34525 L
.45524 .34525 L
.45524 .34525 L
.45524 .34526 L
.45524 .34526 L
.45524 .34526 L
.45524 .34526 L
.45524 .34527 L
.45524 .34527 L
.45525 .34527 L
.45525 .34528 L
.45525 .34528 L
.45525 .34528 L
.45525 .34528 L
.45525 .34529 L
.45525 .34529 L
.45525 .34529 L
.45525 .3453 L
.45525 .3453 L
.45525 .3453 L
.45525 .34531 L
.45525 .34531 L
.45526 .34531 L
.45526 .34531 L
.45526 .34532 L
.45526 .34532 L
.45526 .34532 L
.45526 .34533 L
.45526 .34533 L
.45526 .34533 L
.45526 .34533 L
.45526 .34534 L
.45526 .34534 L
.45526 .34534 L
.45526 .34535 L
.45526 .34535 L
.45527 .34535 L
.45527 .34536 L
.45527 .34536 L
.45527 .34536 L
.45527 .34536 L
.45527 .34537 L
.45527 .34537 L
Mistroke
.45527 .34537 L
.45527 .34538 L
.45527 .34538 L
.45527 .34538 L
.45527 .34539 L
.45527 .34539 L
.45527 .34539 L
.45527 .34539 L
.45527 .3454 L
.45528 .3454 L
.45528 .3454 L
.45528 .34541 L
.45528 .34541 L
.45528 .34541 L
.45528 .34542 L
.45528 .34542 L
.45528 .34542 L
.45528 .34542 L
.45528 .34543 L
.45528 .34543 L
.45528 .34543 L
.45528 .34544 L
.45528 .34544 L
.45528 .34544 L
.45528 .34545 L
.45528 .34545 L
.45528 .34545 L
.45529 .34545 L
.45529 .34546 L
.45529 .34546 L
.45529 .34546 L
.45529 .34547 L
.45529 .34547 L
.45529 .34547 L
.45529 .34548 L
.45529 .34548 L
.45529 .34548 L
.45529 .34548 L
.45529 .34549 L
.45529 .34549 L
.45529 .34549 L
.45529 .3455 L
.45529 .3455 L
.45529 .3455 L
.45529 .34551 L
.45529 .34551 L
.45529 .34551 L
.4553 .34551 L
.4553 .34552 L
.4553 .34552 L
Mistroke
.4553 .34552 L
.4553 .34553 L
.4553 .34553 L
.4553 .34553 L
.4553 .34554 L
.4553 .34554 L
.4553 .34554 L
.4553 .34554 L
.4553 .34555 L
.4553 .34555 L
.4553 .34555 L
.4553 .34556 L
.4553 .34556 L
.4553 .34556 L
.4553 .34557 L
.4553 .34557 L
.4553 .34557 L
.4553 .34557 L
.4553 .34558 L
.4553 .34558 L
.4553 .34558 L
.4553 .34559 L
.4553 .34559 L
.45531 .34559 L
.45531 .3456 L
.45531 .3456 L
.45531 .3456 L
.45531 .3456 L
.45531 .34561 L
.45531 .34561 L
.45531 .34561 L
.45531 .34562 L
.45531 .34562 L
.45531 .34562 L
.45531 .34563 L
.45531 .34563 L
.45531 .34563 L
.45531 .34563 L
.45531 .34564 L
.45531 .34564 L
.45531 .34564 L
.45531 .34565 L
.45531 .34565 L
.45531 .34565 L
.45531 .34566 L
.45531 .34566 L
.45531 .34566 L
.45531 .34566 L
.45531 .34567 L
.45531 .34567 L
Mistroke
.45531 .34567 L
.45531 .34568 L
.45531 .34568 L
.45531 .34568 L
.45531 .34569 L
.45531 .34569 L
.45531 .34569 L
.45531 .34569 L
.45531 .3457 L
.45531 .3457 L
.45531 .3457 L
.45531 .34571 L
.45532 .34571 L
.45532 .34571 L
.45532 .34572 L
.45532 .34572 L
.45532 .34572 L
.45532 .34572 L
.45532 .34573 L
.45532 .34573 L
.45532 .34573 L
.45532 .34574 L
.45532 .34574 L
.45532 .34574 L
.45532 .34575 L
.45532 .34575 L
.45532 .34575 L
.45532 .34576 L
.45532 .34576 L
.45532 .34576 L
.45532 .34576 L
.45532 .34577 L
.45532 .34577 L
.45532 .34577 L
.45532 .34578 L
.45532 .34578 L
.45532 .34578 L
.45532 .34579 L
.45532 .34579 L
.45532 .34579 L
.45532 .34579 L
.45532 .3458 L
.45532 .3458 L
.45532 .3458 L
.45532 .34581 L
.45532 .34581 L
.45532 .34581 L
.45532 .34582 L
.45532 .34582 L
.45532 .34582 L
Mistroke
.45532 .34582 L
.45532 .34583 L
.45532 .34583 L
.45532 .34583 L
.45532 .34584 L
.45532 .34584 L
.45532 .34584 L
.45532 .34585 L
.45532 .34585 L
.45532 .34585 L
.45532 .34586 L
.45532 .34586 L
.45532 .34586 L
.45532 .34586 L
.45532 .34587 L
.45532 .34587 L
.45532 .34587 L
.45532 .34588 L
.45532 .34588 L
.45532 .34588 L
.45532 .34589 L
.45532 .34589 L
.45532 .34589 L
.45532 .34589 L
.45532 .3459 L
.45532 .3459 L
.45532 .3459 L
.45532 .34591 L
.45532 .34591 L
.45532 .34591 L
.45532 .34592 L
.45532 .34592 L
.45532 .34592 L
.45532 .34592 L
.45532 .34593 L
.45532 .34593 L
.45532 .34593 L
.45532 .34594 L
.45532 .34594 L
.45532 .34594 L
.45532 .34595 L
.45532 .34595 L
.45532 .34595 L
.45532 .34595 L
.45532 .34596 L
.45532 .34596 L
.45532 .34596 L
.45532 .34597 L
.45532 .34597 L
.45532 .34597 L
Mistroke
.45532 .34598 L
.45532 .34598 L
.45532 .34598 L
.45532 .34599 L
.45532 .34599 L
.45532 .34599 L
.45532 .34599 L
.45532 .346 L
.45531 .346 L
.45531 .346 L
.45531 .34601 L
.45531 .34601 L
.45531 .34601 L
.45531 .34602 L
.45531 .34602 L
.45531 .34602 L
.45531 .34602 L
.45531 .34603 L
.45531 .34603 L
.45531 .34603 L
.45531 .34604 L
.45531 .34604 L
.45531 .34604 L
.45531 .34605 L
.45531 .34605 L
.45531 .34605 L
.45531 .34605 L
.45531 .34606 L
.45531 .34606 L
.45531 .34606 L
.45531 .34607 L
.45531 .34607 L
.45531 .34607 L
.45531 .34608 L
.45531 .34608 L
.45531 .34608 L
.45531 .34608 L
.45531 .34609 L
.45531 .34609 L
.45531 .34609 L
.45531 .3461 L
.45531 .3461 L
.45531 .3461 L
.45531 .34611 L
.45531 .34611 L
.45531 .34611 L
.45531 .34612 L
.45531 .34612 L
.45531 .34612 L
.4553 .34612 L
Mistroke
.4553 .34613 L
.4553 .34613 L
.4553 .34613 L
.4553 .34614 L
.4553 .34614 L
.4553 .34614 L
.4553 .34615 L
.4553 .34615 L
.4553 .34615 L
.4553 .34615 L
.4553 .34616 L
.4553 .34616 L
.4553 .34616 L
.4553 .34617 L
.4553 .34617 L
.4553 .34617 L
.4553 .34618 L
.4553 .34618 L
.4553 .34618 L
.4553 .34618 L
.4553 .34619 L
.4553 .34619 L
.4553 .34619 L
.4553 .3462 L
.4553 .3462 L
.4553 .3462 L
.4553 .34621 L
.45529 .34621 L
.45529 .34621 L
.45529 .34621 L
.45529 .34622 L
.45529 .34622 L
.45529 .34622 L
.45529 .34623 L
.45529 .34623 L
.45529 .34623 L
.45529 .34624 L
.45529 .34624 L
.45529 .34624 L
.45529 .34624 L
.45529 .34625 L
.45529 .34625 L
.45529 .34625 L
.45529 .34626 L
.45529 .34626 L
.45529 .34626 L
.45529 .34627 L
.45529 .34627 L
.45529 .34627 L
.45528 .34627 L
Mistroke
.45528 .34628 L
.45528 .34628 L
.45528 .34628 L
.45528 .34629 L
.45528 .34629 L
.45528 .34629 L
.45528 .3463 L
.45528 .3463 L
.45528 .3463 L
.45528 .3463 L
.45528 .34631 L
.45528 .34631 L
.45528 .34631 L
.45528 .34632 L
.45528 .34632 L
.45528 .34632 L
.45528 .34633 L
.45528 .34633 L
.45528 .34633 L
.45527 .34633 L
.45527 .34634 L
.45527 .34634 L
.45527 .34634 L
.45527 .34635 L
.45527 .34635 L
.45527 .34635 L
.45527 .34636 L
.45527 .34636 L
.45527 .34636 L
.45527 .34636 L
.45527 .34637 L
.45527 .34637 L
.45527 .34637 L
.45527 .34638 L
.45527 .34638 L
.45527 .34638 L
.45526 .34639 L
.45526 .34639 L
.45526 .34639 L
.45526 .34639 L
.45526 .3464 L
.45526 .3464 L
.45526 .3464 L
.45526 .34641 L
.45526 .34641 L
.45526 .34641 L
.45526 .34641 L
.45526 .34642 L
.45526 .34642 L
.45526 .34642 L
Mistroke
.45526 .34643 L
.45526 .34643 L
.45525 .34643 L
.45525 .34644 L
.45525 .34644 L
.45525 .34644 L
.45525 .34644 L
.45525 .34645 L
.45525 .34645 L
.45525 .34645 L
.45525 .34646 L
.45525 .34646 L
.45525 .34646 L
.45525 .34647 L
.45525 .34647 L
.45525 .34647 L
.45525 .34647 L
.45524 .34648 L
.45524 .34648 L
.45524 .34648 L
.45524 .34649 L
.45524 .34649 L
.45524 .34649 L
.45524 .34649 L
.45524 .3465 L
.45524 .3465 L
.45524 .3465 L
.45524 .34651 L
.45524 .34651 L
.45524 .34651 L
.45524 .34652 L
.45523 .34652 L
.45523 .34652 L
.45523 .34652 L
.45523 .34653 L
.45523 .34653 L
.45523 .34653 L
.45523 .34654 L
.45523 .34654 L
.45523 .34654 L
.45523 .34655 L
.45523 .34655 L
.45523 .34655 L
.45523 .34655 L
.45523 .34656 L
.45522 .34656 L
.45522 .34656 L
.45522 .34657 L
.45522 .34657 L
.45522 .34657 L
Mistroke
.45522 .34657 L
.45522 .34658 L
.45522 .34658 L
.45522 .34658 L
.45522 .34659 L
.45522 .34659 L
.45522 .34659 L
.45521 .3466 L
.45521 .3466 L
.45521 .3466 L
.45521 .3466 L
.45521 .34661 L
.45521 .34661 L
.45521 .34661 L
.45521 .34662 L
.45521 .34662 L
.45521 .34662 L
.45521 .34662 L
.45521 .34663 L
.4552 .34663 L
.4552 .34663 L
.4552 .34664 L
.4552 .34664 L
.4552 .34664 L
.4552 .34664 L
.4552 .34665 L
.4552 .34665 L
.4552 .34665 L
.4552 .34666 L
.4552 .34666 L
.4552 .34666 L
.45519 .34667 L
.45519 .34667 L
.45519 .34667 L
.45519 .34667 L
.45519 .34668 L
.45519 .34668 L
.45519 .34668 L
.45519 .34669 L
.45519 .34669 L
.45519 .34669 L
.45519 .34669 L
.45518 .3467 L
.45518 .3467 L
.45518 .3467 L
.45518 .34671 L
.45518 .34671 L
.45518 .34671 L
.45518 .34671 L
.45518 .34672 L
Mistroke
.45518 .34672 L
.45518 .34672 L
.45518 .34673 L
.45517 .34673 L
.45517 .34673 L
.45517 .34673 L
.45517 .34674 L
.45517 .34674 L
.45517 .34674 L
.45517 .34675 L
.45517 .34675 L
.45517 .34675 L
.45517 .34676 L
.45517 .34676 L
.45516 .34676 L
.45516 .34676 L
.45516 .34677 L
.45516 .34677 L
.45516 .34677 L
.45516 .34678 L
.45516 .34678 L
.45516 .34678 L
.45516 .34678 L
.45516 .34679 L
.45515 .34679 L
.45515 .34679 L
.45515 .3468 L
.45515 .3468 L
.45515 .3468 L
.45515 .3468 L
.45515 .34681 L
.45515 .34681 L
.45515 .34681 L
.45515 .34682 L
.45514 .34682 L
.45514 .34682 L
.45514 .34682 L
.45514 .34683 L
.45514 .34683 L
.45514 .34683 L
.45514 .34684 L
.45514 .34684 L
.45514 .34684 L
.45514 .34684 L
.45513 .34685 L
.45513 .34685 L
.45513 .34685 L
.45513 .34686 L
.45513 .34686 L
.45513 .34686 L
Mistroke
.45513 .34686 L
.45513 .34687 L
.45513 .34687 L
.45512 .34687 L
.45512 .34688 L
.45512 .34688 L
.45512 .34688 L
.45512 .34688 L
.45512 .34689 L
.45512 .34689 L
.45512 .34689 L
.45512 .3469 L
.45512 .3469 L
.45511 .3469 L
.45511 .3469 L
.45511 .34691 L
.45511 .34691 L
.45511 .34691 L
.45511 .34692 L
.45511 .34692 L
.45511 .34692 L
.45511 .34692 L
.4551 .34693 L
.4551 .34693 L
.4551 .34693 L
.4551 .34693 L
.4551 .34694 L
.4551 .34694 L
.4551 .34694 L
.4551 .34695 L
.4551 .34695 L
.45509 .34695 L
.45509 .34695 L
.45509 .34696 L
.45509 .34696 L
.45509 .34696 L
.45509 .34697 L
.45509 .34697 L
.45509 .34697 L
.45509 .34697 L
.45508 .34698 L
.45508 .34698 L
.45508 .34698 L
.45508 .34699 L
.45508 .34699 L
.45508 .34699 L
.45508 .34699 L
.45508 .347 L
.45507 .347 L
.45507 .347 L
Mistroke
.45507 .34701 L
.45507 .34701 L
.45507 .34701 L
.45507 .34701 L
.45507 .34702 L
.45507 .34702 L
.45507 .34702 L
.45506 .34702 L
.45506 .34703 L
.45506 .34703 L
.45506 .34703 L
.45506 .34704 L
.45506 .34704 L
.45506 .34704 L
.45506 .34704 L
.45505 .34705 L
.45505 .34705 L
.45505 .34705 L
.45505 .34706 L
.45505 .34706 L
.45505 .34706 L
.45505 .34706 L
.45505 .34707 L
.45505 .34707 L
.45504 .34707 L
.45504 .34707 L
.45504 .34708 L
.45504 .34708 L
.45504 .34708 L
.45504 .34709 L
.45504 .34709 L
.45504 .34709 L
.45503 .34709 L
.45503 .3471 L
.45503 .3471 L
.45503 .3471 L
.45503 .34711 L
.45503 .34711 L
.45503 .34711 L
.45503 .34711 L
.45502 .34712 L
.45502 .34712 L
.45502 .34712 L
.45502 .34712 L
.45502 .34713 L
.45502 .34713 L
.45502 .34713 L
.45502 .34714 L
.45501 .34714 L
.45501 .34714 L
Mistroke
.45501 .34714 L
.45501 .34715 L
.45501 .34715 L
.45501 .34715 L
.45501 .34715 L
.455 .34716 L
.455 .34716 L
.455 .34716 L
.455 .34717 L
.455 .34717 L
.455 .34717 L
.455 .34717 L
.455 .34718 L
.45499 .34718 L
.45499 .34718 L
.45499 .34718 L
.45499 .34719 L
.45499 .34719 L
.45499 .34719 L
.45499 .3472 L
.45499 .3472 L
.45498 .3472 L
.45498 .3472 L
.45498 .34721 L
.45498 .34721 L
.45498 .34721 L
.45498 .34721 L
.45498 .34722 L
.45497 .34722 L
.45497 .34722 L
.45497 .34723 L
.45497 .34723 L
.45497 .34723 L
.45497 .34723 L
.45497 .34724 L
.45497 .34724 L
.45496 .34724 L
.45496 .34724 L
.45496 .34725 L
.45496 .34725 L
.45496 .34725 L
.45496 .34725 L
.45496 .34726 L
.45495 .34726 L
.45495 .34726 L
.45495 .34727 L
.45495 .34727 L
.45495 .34727 L
.45495 .34727 L
.45495 .34728 L
Mistroke
.45494 .34728 L
.45494 .34728 L
.45494 .34728 L
.45494 .34729 L
.45494 .34729 L
.45494 .34729 L
.45494 .3473 L
.45494 .3473 L
.45493 .3473 L
.45493 .3473 L
.45493 .34731 L
.45493 .34731 L
.45493 .34731 L
.45493 .34731 L
.45493 .34732 L
.45492 .34732 L
.45492 .34732 L
.45492 .34732 L
.45492 .34733 L
.45492 .34733 L
.45492 .34733 L
.45492 .34733 L
.45491 .34734 L
.45491 .34734 L
.45491 .34734 L
.45491 .34735 L
.45491 .34735 L
.45491 .34735 L
.45491 .34735 L
.4549 .34736 L
.4549 .34736 L
.4549 .34736 L
.4549 .34736 L
.4549 .34737 L
.4549 .34737 L
.4549 .34737 L
.45489 .34737 L
.45489 .34738 L
.45489 .34738 L
.45489 .34738 L
.45489 .34738 L
.45489 .34739 L
.45489 .34739 L
.45488 .34739 L
.45488 .3474 L
.45488 .3474 L
.45488 .3474 L
.45488 .3474 L
.45488 .34741 L
.45488 .34741 L
Mistroke
.45487 .34741 L
.45487 .34741 L
.45487 .34742 L
.45487 .34742 L
.45487 .34742 L
.45487 .34742 L
.45486 .34743 L
.45486 .34743 L
.45486 .34743 L
.45486 .34743 L
.45486 .34744 L
.45486 .34744 L
.45486 .34744 L
.45485 .34744 L
.45485 .34745 L
.45485 .34745 L
.45485 .34745 L
.45485 .34746 L
.45485 .34746 L
.45485 .34746 L
.45484 .34746 L
.45484 .34747 L
.45484 .34747 L
.45484 .34747 L
.45484 .34747 L
.45484 .34748 L
.45483 .34748 L
.45483 .34748 L
.45483 .34748 L
.45483 .34749 L
.45483 .34749 L
.45483 .34749 L
.45483 .34749 L
.45482 .3475 L
.45482 .3475 L
.45482 .3475 L
.45482 .3475 L
.45482 .34751 L
.45482 .34751 L
.45481 .34751 L
.45481 .34751 L
.45481 .34752 L
.45481 .34752 L
.45481 .34752 L
.45481 .34752 L
.45481 .34753 L
.4548 .34753 L
.4548 .34753 L
.4548 .34753 L
.4548 .34754 L
Mistroke
.4548 .34754 L
.4548 .34754 L
.45479 .34754 L
.45479 .34755 L
.45479 .34755 L
.45479 .34755 L
.45479 .34755 L
.45479 .34756 L
.45479 .34756 L
.45478 .34756 L
.45478 .34756 L
.45478 .34757 L
.45478 .34757 L
.45478 .34757 L
.45478 .34757 L
.45477 .34758 L
.45477 .34758 L
.45477 .34758 L
.45477 .34758 L
.45477 .34759 L
.45477 .34759 L
.45476 .34759 L
.45476 .34759 L
.45476 .3476 L
.45476 .3476 L
.45476 .3476 L
.45476 .3476 L
.45476 .34761 L
.45475 .34761 L
.45475 .34761 L
.45475 .34761 L
.45475 .34762 L
.45475 .34762 L
.45475 .34762 L
.45474 .34762 L
.45474 .34763 L
.45474 .34763 L
.45474 .34763 L
.45474 .34763 L
.45474 .34764 L
.45473 .34764 L
.45473 .34764 L
.45473 .34764 L
.45473 .34765 L
.45473 .34765 L
.45473 .34765 L
.45472 .34765 L
.45472 .34766 L
.45472 .34766 L
.45472 .34766 L
Mistroke
.45472 .34766 L
.45472 .34767 L
.45472 .34767 L
.45471 .34767 L
.45471 .34767 L
.45471 .34768 L
.45471 .34768 L
.45471 .34768 L
.45471 .34768 L
.4547 .34769 L
.4547 .34769 L
.4547 .34769 L
.4547 .34769 L
.4547 .3477 L
.4547 .3477 L
.45469 .3477 L
.45469 .3477 L
.45469 .34771 L
.45469 .34771 L
.45469 .34771 L
.45469 .34771 L
.45468 .34772 L
.45468 .34772 L
.45468 .34772 L
.45468 .34772 L
.45468 .34773 L
.45468 .34773 L
.45467 .34773 L
.45467 .34773 L
.45467 .34773 L
.45467 .34774 L
.45467 .34774 L
.45467 .34774 L
.45466 .34774 L
.45466 .34775 L
.45466 .34775 L
.45466 .34775 L
.45466 .34775 L
.45466 .34776 L
.45465 .34776 L
.45465 .34776 L
.45465 .34776 L
.45465 .34777 L
.45465 .34777 L
.45465 .34777 L
.45464 .34777 L
.45464 .34778 L
.45464 .34778 L
.45464 .34778 L
.45464 .34778 L
Mistroke
.45464 .34779 L
.45463 .34779 L
.45463 .34779 L
.45463 .34779 L
.45463 .34779 L
.45463 .3478 L
.45463 .3478 L
.45462 .3478 L
.45462 .3478 L
.45462 .34781 L
.45462 .34781 L
.45462 .34781 L
.45461 .34781 L
.45461 .34782 L
.45461 .34782 L
.45461 .34782 L
.45461 .34782 L
.45461 .34783 L
.4546 .34783 L
.4546 .34783 L
.4546 .34783 L
.4546 .34783 L
.4546 .34784 L
.4546 .34784 L
.45459 .34784 L
.45459 .34784 L
.45459 .34785 L
.45459 .34785 L
.45459 .34785 L
.45459 .34785 L
.45458 .34786 L
.45458 .34786 L
.45458 .34786 L
.45458 .34786 L
.45458 .34786 L
.45458 .34787 L
.45457 .34787 L
.45457 .34787 L
.45457 .34787 L
.45457 .34788 L
.45457 .34788 L
.45456 .34788 L
.45456 .34788 L
.45456 .34789 L
.45456 .34789 L
.45456 .34789 L
.45456 .34789 L
.45455 .3479 L
.45455 .3479 L
.45455 .3479 L
Mistroke
.45455 .3479 L
.45455 .3479 L
.45455 .34791 L
.45454 .34791 L
.45454 .34791 L
.45454 .34791 L
.45454 .34792 L
.45454 .34792 L
.45454 .34792 L
.45453 .34792 L
.45453 .34792 L
.45453 .34793 L
.45453 .34793 L
.45453 .34793 L
.45452 .34793 L
.45452 .34794 L
.45452 .34794 L
.45452 .34794 L
.45452 .34794 L
.45452 .34795 L
.45451 .34795 L
.45451 .34795 L
.45451 .34795 L
.45451 .34795 L
.45451 .34796 L
.4545 .34796 L
.4545 .34796 L
.4545 .34796 L
.4545 .34797 L
.4545 .34797 L
.4545 .34797 L
.45449 .34797 L
.45449 .34797 L
.45449 .34798 L
.45449 .34798 L
.45449 .34798 L
.45449 .34798 L
.45448 .34799 L
.45448 .34799 L
.45448 .34799 L
.45448 .34799 L
.45448 .34799 L
.45447 .348 L
.45447 .348 L
.45447 .348 L
.45447 .348 L
.45447 .34801 L
.45447 .34801 L
.45446 .34801 L
.45446 .34801 L
Mistroke
.45446 .34801 L
.45446 .34802 L
.45446 .34802 L
.45445 .34802 L
.45445 .34802 L
.45445 .34803 L
.45445 .34803 L
.45445 .34803 L
.45445 .34803 L
.45444 .34803 L
.45444 .34804 L
.45444 .34804 L
.45444 .34804 L
.45444 .34804 L
.45443 .34805 L
.45443 .34805 L
.45443 .34805 L
.45443 .34805 L
.45443 .34805 L
.45443 .34806 L
.45442 .34806 L
.45442 .34806 L
.45442 .34806 L
.45442 .34806 L
.45442 .34807 L
.45441 .34807 L
.45441 .34807 L
.45441 .34807 L
.45441 .34808 L
.45441 .34808 L
.45441 .34808 L
.4544 .34808 L
.4544 .34808 L
.4544 .34809 L
.4544 .34809 L
.4544 .34809 L
.45439 .34809 L
.45439 .34809 L
.45439 .3481 L
.45439 .3481 L
.45439 .3481 L
.45439 .3481 L
.45438 .34811 L
.45438 .34811 L
.45438 .34811 L
.45438 .34811 L
.45438 .34811 L
.45437 .34812 L
.45437 .34812 L
.45437 .34812 L
Mistroke
.45437 .34812 L
.45437 .34812 L
.45437 .34813 L
.45436 .34813 L
.45436 .34813 L
.45436 .34813 L
.45436 .34814 L
.45436 .34814 L
.45435 .34814 L
.45435 .34814 L
.45435 .34814 L
.45435 .34815 L
.45435 .34815 L
.45434 .34815 L
.45434 .34815 L
.45434 .34815 L
.45434 .34816 L
.45434 .34816 L
.45434 .34816 L
.45433 .34816 L
.45433 .34816 L
.45433 .34817 L
.45433 .34817 L
.45433 .34817 L
.45432 .34817 L
.45432 .34817 L
.45432 .34818 L
.45432 .34818 L
.45432 .34818 L
.45432 .34818 L
.45431 .34819 L
.45431 .34819 L
.45431 .34819 L
.45431 .34819 L
.45431 .34819 L
.4543 .3482 L
.4543 .3482 L
.4543 .3482 L
.4543 .3482 L
.4543 .3482 L
.45429 .34821 L
.45429 .34821 L
.45429 .34821 L
.45429 .34821 L
.45429 .34821 L
.45429 .34822 L
.45428 .34822 L
.45428 .34822 L
.45428 .34822 L
.45428 .34822 L
Mistroke
.45428 .34823 L
.45427 .34823 L
.45427 .34823 L
.45427 .34823 L
.45427 .34823 L
.45427 .34824 L
.45426 .34824 L
.45426 .34824 L
.45426 .34824 L
.45426 .34824 L
.45426 .34825 L
.45426 .34825 L
.45425 .34825 L
.45425 .34825 L
.45425 .34825 L
.45425 .34826 L
.45425 .34826 L
.45424 .34826 L
.45424 .34826 L
.45424 .34826 L
.45424 .34827 L
.45424 .34827 L
.45423 .34827 L
.45423 .34827 L
.45423 .34827 L
.45423 .34828 L
.45423 .34828 L
.45422 .34828 L
.45422 .34828 L
.45422 .34828 L
.45422 .34829 L
.45422 .34829 L
.45422 .34829 L
.45421 .34829 L
.45421 .34829 L
.45421 .3483 L
.45421 .3483 L
.45421 .3483 L
.4542 .3483 L
.4542 .3483 L
.4542 .34831 L
.4542 .34831 L
.4542 .34831 L
.45419 .34831 L
.45419 .34831 L
.45419 .34832 L
.45419 .34832 L
.45419 .34832 L
.45418 .34832 L
.45418 .34832 L
Mistroke
.45418 .34833 L
.45418 .34833 L
.45418 .34833 L
.45418 .34833 L
.45417 .34833 L
.45417 .34834 L
.45417 .34834 L
.45417 .34834 L
.45417 .34834 L
.45416 .34834 L
.45416 .34834 L
.45416 .34835 L
.45416 .34835 L
.45416 .34835 L
.45415 .34835 L
.45415 .34835 L
.45415 .34836 L
.45415 .34836 L
.45415 .34836 L
.45414 .34836 L
.45414 .34836 L
.45414 .34837 L
.45414 .34837 L
.45414 .34837 L
.45414 .34837 L
.45413 .34837 L
.45413 .34838 L
.45413 .34838 L
.45413 .34838 L
.45413 .34838 L
.45412 .34838 L
.45412 .34838 L
.45412 .34839 L
.45412 .34839 L
.45412 .34839 L
.45411 .34839 L
.45411 .34839 L
.45411 .3484 L
.45411 .3484 L
.45411 .3484 L
.4541 .3484 L
.4541 .3484 L
.4541 .34841 L
.4541 .34841 L
.4541 .34841 L
.45409 .34841 L
.45409 .34841 L
.45409 .34841 L
.45409 .34842 L
.45409 .34842 L
Mistroke
.45409 .34842 L
.45408 .34842 L
.45408 .34842 L
.45408 .34843 L
.45408 .34843 L
.45408 .34843 L
.45407 .34843 L
.45407 .34843 L
.45407 .34843 L
.45407 .34844 L
.45407 .34844 L
.45406 .34844 L
.45406 .34844 L
.45406 .34844 L
.45406 .34845 L
.45406 .34845 L
.45405 .34845 L
.45405 .34845 L
.45405 .34845 L
.45405 .34845 L
.45405 .34846 L
.45404 .34846 L
.45404 .34846 L
.45404 .34846 L
.45404 .34846 L
.45404 .34847 L
.45404 .34847 L
.45403 .34847 L
.45403 .34847 L
.45403 .34847 L
.45403 .34847 L
.45403 .34848 L
.45402 .34848 L
.45402 .34848 L
.45402 .34848 L
.45402 .34848 L
.45402 .34848 L
.45401 .34849 L
.45401 .34849 L
.45401 .34849 L
.45401 .34849 L
.45401 .34849 L
.454 .3485 L
.454 .3485 L
.454 .3485 L
.454 .3485 L
.454 .3485 L
.45399 .3485 L
.45399 .34851 L
.45399 .34851 L
Mistroke
.45399 .34851 L
.45399 .34851 L
.45398 .34851 L
.45398 .34851 L
.45398 .34852 L
.45398 .34852 L
.45398 .34852 L
.45397 .34852 L
.45397 .34852 L
.45397 .34853 L
.45397 .34853 L
.45397 .34853 L
.45397 .34853 L
.45396 .34853 L
.45396 .34853 L
.45396 .34854 L
.45396 .34854 L
.45396 .34854 L
.45395 .34854 L
.45395 .34854 L
.45395 .34854 L
.45395 .34855 L
.45395 .34855 L
.45394 .34855 L
.45394 .34855 L
.45394 .34855 L
.45394 .34855 L
.45394 .34856 L
.45393 .34856 L
.45393 .34856 L
.45393 .34856 L
.45393 .34856 L
.45393 .34856 L
.45392 .34857 L
.45392 .34857 L
.45392 .34857 L
.45392 .34857 L
.45392 .34857 L
.45391 .34857 L
.45391 .34858 L
.45391 .34858 L
.45391 .34858 L
.45391 .34858 L
.4539 .34858 L
.4539 .34858 L
.4539 .34859 L
.4539 .34859 L
.4539 .34859 L
.4539 .34859 L
.45389 .34859 L
Mistroke
.45389 .34859 L
.45389 .3486 L
.45389 .3486 L
.45389 .3486 L
.45388 .3486 L
.45388 .3486 L
.45388 .3486 L
.45388 .34861 L
.45388 .34861 L
.45387 .34861 L
.45387 .34861 L
.45387 .34861 L
.45387 .34861 L
.45387 .34862 L
.45386 .34862 L
.45386 .34862 L
.45386 .34862 L
.45386 .34862 L
.45386 .34862 L
.45385 .34863 L
.45385 .34863 L
.45385 .34863 L
.45385 .34863 L
.45385 .34863 L
.45384 .34863 L
.45384 .34864 L
.45384 .34864 L
.45384 .34864 L
.45384 .34864 L
.45383 .34864 L
.45383 .34864 L
.45383 .34865 L
.45383 .34865 L
.45383 .34865 L
.45382 .34865 L
.45382 .34865 L
.45382 .34865 L
.45382 .34865 L
.45382 .34866 L
.45382 .34866 L
.45381 .34866 L
.45381 .34866 L
.45381 .34866 L
.45381 .34866 L
.45381 .34867 L
.4538 .34867 L
.4538 .34867 L
.4538 .34867 L
.4538 .34867 L
.4538 .34867 L
Mistroke
.45379 .34868 L
.45379 .34868 L
.45379 .34868 L
.45379 .34868 L
.45379 .34868 L
.45378 .34868 L
.45378 .34868 L
.45378 .34869 L
.45378 .34869 L
.45378 .34869 L
.45377 .34869 L
.45377 .34869 L
.45377 .34869 L
.45377 .3487 L
.45377 .3487 L
.45376 .3487 L
.45376 .3487 L
.45376 .3487 L
.45376 .3487 L
.45376 .3487 L
.45375 .34871 L
.45375 .34871 L
.45375 .34871 L
.45375 .34871 L
.45375 .34871 L
.45374 .34871 L
.45374 .34871 L
.45374 .34872 L
.45374 .34872 L
.45374 .34872 L
.45373 .34872 L
.45373 .34872 L
.45373 .34872 L
.45373 .34873 L
.45373 .34873 L
.45373 .34873 L
.45372 .34873 L
.45372 .34873 L
.45372 .34873 L
.45372 .34873 L
.45372 .34874 L
.45371 .34874 L
.45371 .34874 L
.45371 .34874 L
.45371 .34874 L
.45371 .34874 L
.4537 .34874 L
.4537 .34875 L
.4537 .34875 L
.4537 .34875 L
Mistroke
.4537 .34875 L
.45369 .34875 L
.45369 .34875 L
.45369 .34875 L
.45369 .34876 L
.45369 .34876 L
.45368 .34876 L
.45368 .34876 L
.45368 .34876 L
.45368 .34876 L
.45368 .34877 L
.45367 .34877 L
.45367 .34877 L
.45367 .34877 L
.45367 .34877 L
.45367 .34877 L
.45366 .34877 L
.45366 .34878 L
.45366 .34878 L
.45366 .34878 L
.45366 .34878 L
.45366 .34878 L
.45365 .34878 L
.45365 .34878 L
.45365 .34879 L
.45365 .34879 L
.45365 .34879 L
.45364 .34879 L
.45364 .34879 L
.45364 .34879 L
.45364 .34879 L
.45364 .3488 L
.45363 .3488 L
.45363 .3488 L
.45363 .3488 L
.45363 .3488 L
.45363 .3488 L
.45362 .3488 L
.45362 .3488 L
.45362 .34881 L
.45362 .34881 L
.45362 .34881 L
.45361 .34881 L
.45361 .34881 L
.45361 .34881 L
.45361 .34881 L
.45361 .34882 L
.4536 .34882 L
.4536 .34882 L
.4536 .34882 L
Mistroke
.4536 .34882 L
.4536 .34882 L
.45359 .34882 L
.45359 .34883 L
.45359 .34883 L
.45359 .34883 L
.45359 .34883 L
.45359 .34883 L
.45358 .34883 L
.45358 .34883 L
.45358 .34884 L
.45358 .34884 L
.45358 .34884 L
.45357 .34884 L
.45357 .34884 L
.45357 .34884 L
.45357 .34884 L
.45357 .34884 L
.45356 .34885 L
.45356 .34885 L
.45356 .34885 L
.45356 .34885 L
.45356 .34885 L
.45355 .34885 L
.45355 .34885 L
.45355 .34886 L
.45355 .34886 L
.45355 .34886 L
.45354 .34886 L
.45354 .34886 L
.45354 .34886 L
.45354 .34886 L
.45354 .34886 L
.45353 .34887 L
.45353 .34887 L
.45353 .34887 L
.45353 .34887 L
.45353 .34887 L
.45353 .34887 L
.45352 .34887 L
.45352 .34887 L
.45352 .34888 L
.45352 .34888 L
.45352 .34888 L
.45351 .34888 L
.45351 .34888 L
.45351 .34888 L
.45351 .34888 L
.45351 .34888 L
.4535 .34889 L
Mistroke
.4535 .34889 L
.4535 .34889 L
.4535 .34889 L
.4535 .34889 L
.45349 .34889 L
.45349 .34889 L
.45349 .3489 L
.45349 .3489 L
.45349 .3489 L
.45348 .3489 L
.45348 .3489 L
.45348 .3489 L
.45348 .3489 L
.45348 .3489 L
.45348 .34891 L
.45347 .34891 L
.45347 .34891 L
.45347 .34891 L
.45347 .34891 L
.45347 .34891 L
.45346 .34891 L
.45346 .34891 L
.45346 .34892 L
.45346 .34892 L
.45346 .34892 L
.45345 .34892 L
.45345 .34892 L
.45345 .34892 L
.45345 .34892 L
.45345 .34892 L
.45344 .34892 L
.45344 .34893 L
.45344 .34893 L
.45344 .34893 L
.45344 .34893 L
.45344 .34893 L
.45343 .34893 L
.45343 .34893 L
.45343 .34893 L
.45343 .34894 L
.45343 .34894 L
.45342 .34894 L
.45342 .34894 L
.45342 .34894 L
.45342 .34894 L
.45342 .34894 L
.45341 .34894 L
.45341 .34895 L
.45341 .34895 L
.45341 .34895 L
Mistroke
.45341 .34895 L
.4534 .34895 L
.4534 .34895 L
.4534 .34895 L
.4534 .34895 L
.4534 .34895 L
.4534 .34896 L
.45339 .34896 L
.45339 .34896 L
.45339 .34896 L
.45339 .34896 L
.45339 .34896 L
.45338 .34896 L
.45338 .34896 L
.45338 .34897 L
.45338 .34897 L
.45338 .34897 L
.45337 .34897 L
.45337 .34897 L
.45337 .34897 L
.45337 .34897 L
.45337 .34897 L
.45336 .34897 L
.45336 .34898 L
.45336 .34898 L
.45336 .34898 L
.45336 .34898 L
.45336 .34898 L
.45335 .34898 L
.45335 .34898 L
.45335 .34898 L
.45335 .34898 L
.45335 .34899 L
.45334 .34899 L
.45334 .34899 L
.45334 .34899 L
.45334 .34899 L
.45334 .34899 L
.45333 .34899 L
.45333 .34899 L
.45333 .34899 L
.45333 .349 L
.45333 .349 L
.45333 .349 L
.45332 .349 L
.45332 .349 L
.45332 .349 L
.45332 .349 L
.45332 .349 L
.45331 .349 L
Mistroke
.45331 .34901 L
.45331 .34901 L
.45331 .34901 L
.45331 .34901 L
.4533 .34901 L
.4533 .34901 L
.4533 .34901 L
.4533 .34901 L
.4533 .34901 L
.45329 .34902 L
.45329 .34902 L
.45329 .34902 L
.45329 .34902 L
.45329 .34902 L
.45329 .34902 L
.45328 .34902 L
.45328 .34902 L
.45328 .34902 L
.45328 .34902 L
.45328 .34903 L
.45327 .34903 L
.45327 .34903 L
.45327 .34903 L
.45327 .34903 L
.45327 .34903 L
.45327 .34903 L
.45326 .34903 L
.45326 .34903 L
.45326 .34904 L
.45326 .34904 L
.45326 .34904 L
.45325 .34904 L
.45325 .34904 L
.45325 .34904 L
.45325 .34904 L
.45325 .34904 L
.45324 .34904 L
.45324 .34904 L
.45324 .34905 L
.45324 .34905 L
.45324 .34905 L
.45324 .34905 L
.45323 .34905 L
.45323 .34905 L
.45323 .34905 L
.45323 .34905 L
.45323 .34905 L
.45322 .34905 L
.45322 .34906 L
.45322 .34906 L
Mistroke
.45322 .34906 L
.45322 .34906 L
.45321 .34906 L
.45321 .34906 L
.45321 .34906 L
.45321 .34906 L
.45321 .34906 L
.45321 .34906 L
.4532 .34907 L
.4532 .34907 L
.4532 .34907 L
.4532 .34907 L
.4532 .34907 L
.45319 .34907 L
.45319 .34907 L
.45319 .34907 L
.45319 .34907 L
.45319 .34907 L
.45319 .34908 L
.45318 .34908 L
.45318 .34908 L
.45318 .34908 L
.45318 .34908 L
.45318 .34908 L
.45317 .34908 L
.45317 .34908 L
.45317 .34908 L
.45317 .34908 L
.45317 .34909 L
.45317 .34909 L
.45316 .34909 L
.45316 .34909 L
.45316 .34909 L
.45316 .34909 L
.45316 .34909 L
.45315 .34909 L
.45315 .34909 L
.45315 .34909 L
.45315 .34909 L
.45315 .3491 L
.45315 .3491 L
.45314 .3491 L
.45314 .3491 L
.45314 .3491 L
.45314 .3491 L
.45314 .3491 L
.45313 .3491 L
.45313 .3491 L
.45313 .3491 L
.45313 .3491 L
Mistroke
.45313 .34911 L
.45312 .34911 L
.45312 .34911 L
.45312 .34911 L
.45312 .34911 L
.45312 .34911 L
.45312 .34911 L
.45311 .34911 L
.45311 .34911 L
.45311 .34911 L
.45311 .34911 L
.45311 .34912 L
.4531 .34912 L
.4531 .34912 L
.4531 .34912 L
.4531 .34912 L
.4531 .34912 L
.4531 .34912 L
.45309 .34912 L
.45309 .34912 L
.45309 .34912 L
.45309 .34912 L
.45309 .34912 L
.45309 .34913 L
.45308 .34913 L
.45308 .34913 L
.45308 .34913 L
.45308 .34913 L
.45308 .34913 L
.45307 .34913 L
.45307 .34913 L
.45307 .34913 L
.45307 .34913 L
.45307 .34913 L
.45307 .34914 L
.45306 .34914 L
.45306 .34914 L
.45306 .34914 L
.45306 .34914 L
.45306 .34914 L
.45305 .34914 L
.45305 .34914 L
.45305 .34914 L
.45305 .34914 L
.45305 .34914 L
.45305 .34914 L
.45304 .34915 L
.45304 .34915 L
.45304 .34915 L
.45304 .34915 L
Mistroke
.45304 .34915 L
.45303 .34915 L
.45303 .34915 L
.45303 .34915 L
.45303 .34915 L
.45303 .34915 L
.45303 .34915 L
.45302 .34915 L
.45302 .34916 L
.45302 .34916 L
.45302 .34916 L
.45302 .34916 L
.45302 .34916 L
.45301 .34916 L
.45301 .34916 L
.45301 .34916 L
.45301 .34916 L
.45301 .34916 L
.453 .34916 L
.453 .34916 L
.453 .34916 L
.453 .34917 L
.453 .34917 L
.453 .34917 L
.45299 .34917 L
.45299 .34917 L
.45299 .34917 L
.45299 .34917 L
.45299 .34917 L
.45299 .34917 L
.45298 .34917 L
.45298 .34917 L
.45298 .34917 L
.45298 .34917 L
.45298 .34918 L
.45297 .34918 L
.45297 .34918 L
.45297 .34918 L
.45297 .34918 L
.45297 .34918 L
.45297 .34918 L
.45296 .34918 L
.45296 .34918 L
.45296 .34918 L
.45296 .34918 L
.45296 .34918 L
.45296 .34918 L
.45295 .34919 L
.45295 .34919 L
.45295 .34919 L
Mistroke
.45295 .34919 L
.45295 .34919 L
.45295 .34919 L
.45294 .34919 L
.45294 .34919 L
.45294 .34919 L
.45294 .34919 L
.45294 .34919 L
.45293 .34919 L
.45293 .34919 L
.45293 .34919 L
.45293 .3492 L
.45293 .3492 L
.45293 .3492 L
.45292 .3492 L
.45292 .3492 L
.45292 .3492 L
.45292 .3492 L
.45292 .3492 L
.45292 .3492 L
.45291 .3492 L
.45291 .3492 L
.45291 .3492 L
.45291 .3492 L
.45291 .3492 L
.45291 .34921 L
.4529 .34921 L
.4529 .34921 L
.4529 .34921 L
.4529 .34921 L
.4529 .34921 L
.45289 .34921 L
.45289 .34921 L
.45289 .34921 L
.45289 .34921 L
.45289 .34921 L
.45289 .34921 L
.45288 .34921 L
.45288 .34921 L
.45288 .34921 L
.45288 .34922 L
.45288 .34922 L
.45288 .34922 L
.45287 .34922 L
.45287 .34922 L
.45287 .34922 L
.45287 .34922 L
.45287 .34922 L
.45287 .34922 L
.45286 .34922 L
Mistroke
.45286 .34922 L
.45286 .34922 L
.45286 .34922 L
.45286 .34922 L
.45286 .34922 L
.45285 .34923 L
.45285 .34923 L
.45285 .34923 L
.45285 .34923 L
.45285 .34923 L
.45285 .34923 L
.45284 .34923 L
.45284 .34923 L
.45284 .34923 L
.45284 .34923 L
.45284 .34923 L
.45284 .34923 L
.45283 .34923 L
.45283 .34923 L
.45283 .34923 L
.45283 .34923 L
.45283 .34924 L
.45283 .34924 L
.45282 .34924 L
.45282 .34924 L
.45282 .34924 L
.45282 .34924 L
.45282 .34924 L
.45282 .34924 L
.45281 .34924 L
.45281 .34924 L
.45281 .34924 L
.45281 .34924 L
.45281 .34924 L
.45281 .34924 L
.4528 .34924 L
.4528 .34924 L
.4528 .34924 L
.4528 .34925 L
.4528 .34925 L
.4528 .34925 L
.45279 .34925 L
.45279 .34925 L
.45279 .34925 L
.45279 .34925 L
.45279 .34925 L
.45279 .34925 L
.45278 .34925 L
.45278 .34925 L
.45278 .34925 L
Mistroke
.45278 .34925 L
.45278 .34925 L
.45278 .34925 L
.45277 .34925 L
.45277 .34925 L
.45277 .34926 L
.45277 .34926 L
.45277 .34926 L
.45277 .34926 L
.45276 .34926 L
.45276 .34926 L
.45276 .34926 L
.45276 .34926 L
.45276 .34926 L
.45276 .34926 L
.45275 .34926 L
.45275 .34926 L
.45275 .34926 L
.45275 .34926 L
.45275 .34926 L
.45275 .34926 L
.45274 .34926 L
.45274 .34926 L
.45274 .34926 L
.45274 .34927 L
.45274 .34927 L
.45274 .34927 L
.45273 .34927 L
.45273 .34927 L
.45273 .34927 L
.45273 .34927 L
.45273 .34927 L
.45273 .34927 L
.45272 .34927 L
.45272 .34927 L
.45272 .34927 L
.45272 .34927 L
.45272 .34927 L
.45272 .34927 L
.45271 .34927 L
.45271 .34927 L
.45271 .34927 L
.45271 .34927 L
.45271 .34928 L
.45271 .34928 L
.45271 .34928 L
.4527 .34928 L
.4527 .34928 L
.4527 .34928 L
.4527 .34928 L
Mistroke
.4527 .34928 L
.4527 .34928 L
.45269 .34928 L
.45269 .34928 L
.45269 .34928 L
.45269 .34928 L
.45269 .34928 L
.45269 .34928 L
.45268 .34928 L
.45268 .34928 L
.45268 .34928 L
.45268 .34928 L
.45268 .34928 L
.45268 .34928 L
.45267 .34929 L
.45267 .34929 L
.45267 .34929 L
.45267 .34929 L
.45267 .34929 L
.45267 .34929 L
.45267 .34929 L
.45266 .34929 L
.45266 .34929 L
.45266 .34929 L
.45266 .34929 L
.45266 .34929 L
.45266 .34929 L
.45265 .34929 L
.45265 .34929 L
.45265 .34929 L
.45265 .34929 L
.45265 .34929 L
.45265 .34929 L
.45264 .34929 L
.45264 .34929 L
.45264 .34929 L
.45264 .3493 L
.45264 .3493 L
.45264 .3493 L
.45264 .3493 L
.45263 .3493 L
.45263 .3493 L
.45263 .3493 L
.45263 .3493 L
.45263 .3493 L
.45263 .3493 L
.45262 .3493 L
.45262 .3493 L
.45262 .3493 L
.45262 .3493 L
Mistroke
.45262 .3493 L
.45262 .3493 L
.45262 .3493 L
.45261 .3493 L
.45261 .3493 L
.45261 .3493 L
.45261 .3493 L
.45261 .3493 L
.45261 .3493 L
.4526 .3493 L
.4526 .34931 L
.4526 .34931 L
.4526 .34931 L
.4526 .34931 L
.4526 .34931 L
.45259 .34931 L
.45259 .34931 L
.45259 .34931 L
.45259 .34931 L
.45259 .34931 L
.45259 .34931 L
.45259 .34931 L
.45258 .34931 L
.45258 .34931 L
.45258 .34931 L
.45258 .34931 L
.45258 .34931 L
.45258 .34931 L
.45258 .34931 L
.45257 .34931 L
.45257 .34931 L
.45257 .34931 L
.45257 .34931 L
.45257 .34931 L
.45257 .34931 L
.45256 .34931 L
.45256 .34931 L
.45256 .34932 L
.45256 .34932 L
.45256 .34932 L
.45256 .34932 L
.45256 .34932 L
.45255 .34932 L
.45255 .34932 L
.45255 .34932 L
.45255 .34932 L
.45255 .34932 L
.45255 .34932 L
.45254 .34932 L
.45254 .34932 L
Mistroke
.45254 .34932 L
.45254 .34932 L
.45254 .34932 L
.45254 .34932 L
.45254 .34932 L
.45253 .34932 L
.45253 .34932 L
.45253 .34932 L
.45253 .34932 L
.45253 .34932 L
.45253 .34932 L
.45253 .34932 L
.45252 .34932 L
.45252 .34932 L
.45252 .34932 L
.45252 .34932 L
.45252 .34932 L
.45252 .34933 L
.45251 .34933 L
.45251 .34933 L
.45251 .34933 L
.45251 .34933 L
.45251 .34933 L
.45251 .34933 L
.45251 .34933 L
.4525 .34933 L
.4525 .34933 L
.4525 .34933 L
.4525 .34933 L
.4525 .34933 L
.4525 .34933 L
.4525 .34933 L
.45249 .34933 L
.45249 .34933 L
.45249 .34933 L
.45249 .34933 L
.45249 .34933 L
.45249 .34933 L
.45249 .34933 L
.45248 .34933 L
.45248 .34933 L
.45248 .34933 L
.45248 .34933 L
.45248 .34933 L
.45248 .34933 L
.45248 .34933 L
.45247 .34933 L
.45247 .34933 L
.45247 .34933 L
.45247 .34933 L
Mistroke
.45247 .34933 L
.45247 .34933 L
.45247 .34934 L
.45246 .34934 L
.45246 .34934 L
.45246 .34934 L
.45246 .34934 L
.45246 .34934 L
.45246 .34934 L
.45246 .34934 L
.45245 .34934 L
.45245 .34934 L
.45245 .34934 L
.45245 .34934 L
.45245 .34934 L
.45245 .34934 L
.45244 .34934 L
.45244 .34934 L
.45244 .34934 L
.45244 .34934 L
.45244 .34934 L
.45244 .34934 L
.45244 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45243 .34934 L
.45242 .34934 L
.45242 .34934 L
.45242 .34934 L
.45242 .34934 L
.45242 .34934 L
.45242 .34934 L
.45242 .34934 L
.45241 .34934 L
.45241 .34934 L
.45241 .34934 L
.45241 .34934 L
.45241 .34934 L
.45241 .34934 L
.45241 .34934 L
.4524 .34935 L
.4524 .34935 L
.4524 .34935 L
.4524 .34935 L
.4524 .34935 L
Mistroke
.4524 .34935 L
.4524 .34935 L
.45239 .34935 L
.45239 .34935 L
.45239 .34935 L
.45239 .34935 L
.45239 .34935 L
.45239 .34935 L
.45239 .34935 L
.45238 .34935 L
.45238 .34935 L
.45238 .34935 L
.45238 .34935 L
.45238 .34935 L
.45238 .34935 L
.45238 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45237 .34935 L
.45236 .34935 L
.45236 .34935 L
.45236 .34935 L
.45236 .34935 L
.45236 .34935 L
.45236 .34935 L
.45236 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45235 .34935 L
.45234 .34935 L
.45234 .34935 L
.45234 .34935 L
.45234 .34935 L
.45234 .34935 L
.45234 .34935 L
.45234 .34935 L
.45233 .34935 L
.45233 .34935 L
.45233 .34935 L
.45233 .34935 L
Mistroke
.45233 .34935 L
.45233 .34935 L
.45233 .34935 L
.45232 .34935 L
.45232 .34935 L
.45232 .34935 L
.45232 .34935 L
.45232 .34935 L
.45232 .34935 L
.45232 .34936 L
.45232 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.45231 .34936 L
.4523 .34936 L
.4523 .34936 L
.4523 .34936 L
.4523 .34936 L
.4523 .34936 L
.4523 .34936 L
.4523 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45229 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45228 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
.45227 .34936 L
Mistroke
.45226 .34936 L
.45226 .34936 L
.45226 .34936 L
.45226 .34936 L
.45226 .34936 L
.45226 .34936 L
.45226 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45225 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45224 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45223 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45222 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.45221 .34936 L
.4522 .34936 L
.4522 .34936 L
Mistroke
.4522 .34936 L
.4522 .34936 L
.4522 .34936 L
.4522 .34936 L
.4522 .34936 L
.4522 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45219 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45218 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45217 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45216 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45215 .34936 L
.45214 .34936 L
.45214 .34936 L
Mistroke
.45214 .34936 L
.45214 .34936 L
.45214 .34936 L
.45214 .34936 L
.45214 .34936 L
.45214 .34936 L
.45214 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45213 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45212 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.45211 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.4521 .34936 L
.45209 .34936 L
.45209 .34936 L
.45209 .34936 L
.45209 .34936 L
.45209 .34936 L
.45209 .34935 L
.45209 .34935 L
.45209 .34935 L
Mistroke
.45209 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45208 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45207 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45206 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45205 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45204 .34935 L
.45203 .34935 L
.45203 .34935 L
Mistroke
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45203 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34935 L
.45202 .34934 L
.45202 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.45201 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.452 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45199 .34934 L
.45198 .34934 L
.45198 .34934 L
Mistroke
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45198 .34934 L
.45197 .34934 L
.45197 .34934 L
.45197 .34934 L
.45197 .34934 L
.45197 .34934 L
.45197 .34934 L
.45197 .34933 L
.45197 .34933 L
.45197 .34933 L
.45197 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45196 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45195 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
.45194 .34933 L
Mistroke
.45194 .34933 L
.45193 .34933 L
.45193 .34933 L
.45193 .34933 L
.45193 .34933 L
.45193 .34933 L
.45193 .34932 L
.45193 .34932 L
.45193 .34932 L
.45193 .34932 L
.45193 .34932 L
.45193 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45192 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.45191 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34932 L
.4519 .34931 L
.4519 .34931 L
.4519 .34931 L
.4519 .34931 L
.4519 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
Mistroke
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45189 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45188 .34931 L
.45187 .34931 L
.45187 .34931 L
.45187 .34931 L
.45187 .34931 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45187 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45186 .3493 L
.45185 .3493 L
.45185 .3493 L
.45185 .3493 L
.45185 .3493 L
.45185 .3493 L
Mistroke
.45185 .3493 L
.45185 .3493 L
.45185 .3493 L
.45185 .3493 L
.45185 .34929 L
.45185 .34929 L
.45185 .34929 L
.45185 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45184 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34929 L
.45183 .34928 L
.45183 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45182 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
Mistroke
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34928 L
.45181 .34927 L
.45181 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.4518 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34927 L
.45179 .34926 L
.45179 .34926 L
.45179 .34926 L
.45179 .34926 L
.45179 .34926 L
.45179 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
Mistroke
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45178 .34926 L
.45177 .34926 L
.45177 .34926 L
.45177 .34926 L
.45177 .34926 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45177 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34925 L
.45176 .34924 L
.45176 .34924 L
.45176 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
.45175 .34924 L
Mistroke
.45175 .34924 L
.45174 .34924 L
.45174 .34924 L
.45174 .34924 L
.45174 .34924 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45174 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34923 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45173 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34922 L
.45172 .34921 L
.45172 .34921 L
Mistroke
.45172 .34921 L
.45172 .34921 L
.45172 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .34921 L
.45171 .3492 L
.45171 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .3492 L
.4517 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
Mistroke
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34919 L
.45169 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34918 L
.45168 .34917 L
.45168 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34917 L
.45167 .34916 L
.45167 .34916 L
Mistroke
.45167 .34916 L
.45167 .34916 L
.45167 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34916 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45166 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34915 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
.45165 .34914 L
Mistroke
.45165 .34914 L
.45164 .34914 L
.45164 .34914 L
.45164 .34914 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34913 L
.45164 .34912 L
.45164 .34912 L
.45164 .34912 L
.45164 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34912 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
Mistroke
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45163 .34911 L
.45162 .34911 L
.45162 .34911 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .3491 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45162 .34909 L
.45161 .34909 L
.45161 .34909 L
.45161 .34909 L
.45161 .34909 L
.45161 .34909 L
.45161 .34909 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
Mistroke
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34908 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.45161 .34907 L
.4516 .34907 L
.4516 .34907 L
.4516 .34907 L
.4516 .34907 L
.4516 .34907 L
.4516 .34907 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34906 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
Mistroke
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.4516 .34905 L
.45159 .34905 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34904 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34903 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
Mistroke
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45159 .34902 L
.45158 .34902 L
.45158 .34902 L
.45158 .34902 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .34901 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .349 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
Mistroke
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34899 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45158 .34898 L
.45157 .34898 L
.45157 .34898 L
.45157 .34898 L
.45157 .34898 L
.45157 .34898 L
.45157 .34898 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34897 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
Mistroke
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34896 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34895 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34894 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
Mistroke
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34893 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34892 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .34891 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
Mistroke
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45157 .3489 L
.45156 .3489 L
.45156 .3489 L
.45156 .3489 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34889 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34888 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
Mistroke
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34887 L
.45156 .34886 L
.45156 .34886 L
.45156 .34886 L
.45156 .34886 L
.45156 .34886 L
.45156 .34886 L
.45156 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34886 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34885 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
Mistroke
.45157 .34884 L
.45157 .34884 L
.45157 .34884 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34883 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34882 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
.45157 .34881 L
Mistroke
.45157 .34881 L
.45157 .34881 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .3488 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34879 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
.45157 .34878 L
Mistroke
.45157 .34878 L
.45157 .34877 L
.45157 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34877 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34876 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
.45158 .34875 L
Mistroke
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34874 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45158 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34873 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
.45159 .34872 L
Mistroke
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .34871 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.45159 .3487 L
.4516 .3487 L
.4516 .3487 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
.4516 .34869 L
Mistroke
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34868 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.4516 .34867 L
.45161 .34867 L
.45161 .34867 L
.45161 .34867 L
.45161 .34867 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
.45161 .34866 L
Mistroke
.45161 .34866 L
.45161 .34866 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34865 L
.45161 .34864 L
.45161 .34864 L
.45161 .34864 L
.45161 .34864 L
.45161 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34864 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
Mistroke
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34863 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45162 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34862 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .34861 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
.45163 .3486 L
Mistroke
.45163 .3486 L
.45163 .3486 L
.45164 .3486 L
.45164 .3486 L
.45164 .3486 L
.45164 .3486 L
.45164 .3486 L
.45164 .3486 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34859 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45164 .34858 L
.45165 .34858 L
.45165 .34858 L
.45165 .34858 L
.45165 .34858 L
.45165 .34858 L
.45165 .34858 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
Mistroke
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34857 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45165 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34856 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
.45166 .34855 L
Mistroke
.45166 .34855 L
.45166 .34854 L
.45166 .34854 L
.45166 .34854 L
.45166 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34854 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45167 .34853 L
.45168 .34853 L
.45168 .34853 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
Mistroke
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34852 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45168 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .34851 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.45169 .3485 L
.4517 .3485 L
.4517 .34849 L
Mistroke
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34849 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.4517 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34848 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
Mistroke
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45171 .34847 L
.45172 .34847 L
.45172 .34847 L
.45172 .34847 L
.45172 .34847 L
.45172 .34847 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34846 L
.45172 .34845 L
.45172 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
Mistroke
.45173 .34845 L
.45173 .34845 L
.45173 .34845 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45173 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34844 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45174 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34843 L
.45175 .34842 L
.45175 .34842 L
Mistroke
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45175 .34842 L
.45176 .34842 L
.45176 .34842 L
.45176 .34842 L
.45176 .34842 L
.45176 .34842 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45176 .34841 L
.45177 .34841 L
.45177 .34841 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
Mistroke
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .3484 L
.45177 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34839 L
.45178 .34838 L
.45178 .34838 L
.45178 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
Mistroke
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34838 L
.45179 .34837 L
.45179 .34837 L
.45179 .34837 L
.45179 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34837 L
.4518 .34836 L
.4518 .34836 L
.4518 .34836 L
.4518 .34836 L
.4518 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
Mistroke
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34836 L
.45181 .34835 L
.45181 .34835 L
.45181 .34835 L
.45181 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34835 L
.45182 .34834 L
.45182 .34834 L
.45182 .34834 L
.45183 .34834 L
.45183 .34834 L
Mistroke
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45183 .34834 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45184 .34833 L
.45185 .34833 L
.45185 .34833 L
Mistroke
.45185 .34833 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45185 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34832 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45186 .34831 L
.45187 .34831 L
Mistroke
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .34831 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45187 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .3483 L
.45188 .34829 L
.45188 .34829 L
.45188 .34829 L
.45188 .34829 L
.45188 .34829 L
.45188 .34829 L
.45188 .34829 L
.45189 .34829 L
Mistroke
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.45189 .34829 L
.4519 .34829 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
.4519 .34828 L
Mistroke
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34828 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45191 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34827 L
.45192 .34826 L
.45192 .34826 L
.45192 .34826 L
.45192 .34826 L
.45192 .34826 L
Mistroke
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45193 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34826 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
.45194 .34825 L
Mistroke
.45194 .34825 L
.45194 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34825 L
.45195 .34824 L
.45195 .34824 L
.45195 .34824 L
.45195 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
Mistroke
.45196 .34824 L
.45196 .34824 L
.45196 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34824 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45197 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
Mistroke
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45198 .34823 L
.45199 .34823 L
.45199 .34823 L
.45199 .34823 L
.45199 .34823 L
.45199 .34823 L
.45199 .34823 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.45199 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
Mistroke
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.452 .34822 L
.45201 .34822 L
.45201 .34822 L
.45201 .34822 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45201 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
Mistroke
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45202 .34821 L
.45203 .34821 L
.45203 .34821 L
.45203 .34821 L
.45203 .34821 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45203 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
Mistroke
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45204 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .3482 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45205 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
Mistroke
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45206 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
Mistroke
.45207 .34819 L
.45207 .34819 L
.45207 .34819 L
.45207 .34818 L
.45207 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45208 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
Mistroke
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.45209 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.4521 .34818 L
.45211 .34818 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
Mistroke
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45211 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
Mistroke
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45212 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45213 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
Mistroke
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45214 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34817 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
Mistroke
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45215 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45216 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
Mistroke
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45217 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
Mistroke
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45218 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
Mistroke
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.45219 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.4522 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
Mistroke
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45221 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
Mistroke
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45222 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
Mistroke
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45223 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
Mistroke
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45224 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34816 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
Mistroke
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45225 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
Mistroke
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45226 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
Mistroke
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45227 .34817 L
.45228 .34817 L
Mistroke
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34817 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
Mistroke
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45228 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
Mistroke
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34818 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.45229 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
Mistroke
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
Mistroke
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.4523 .34819 L
.45231 .34819 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
Mistroke
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
Mistroke
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .3482 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45231 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
Mistroke
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
Mistroke
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34821 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
Mistroke
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34822 L
.45232 .34823 L
Mistroke
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45232 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
Mistroke
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34823 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
Mistroke
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
Mistroke
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34824 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
Mistroke
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34825 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
Mistroke
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
Mistroke
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34826 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
Mistroke
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34827 L
.45233 .34828 L
Mistroke
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
Mistroke
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34828 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
Mistroke
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45233 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
Mistroke
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .34829 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
Mistroke
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .3483 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
Mistroke
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
Mistroke
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34831 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
Mistroke
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
Mistroke
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34832 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
Mistroke
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
Mistroke
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.45231 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34833 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
Mistroke
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
Mistroke
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34834 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
Mistroke
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
Mistroke
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34835 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
Mistroke
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
Mistroke
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
Mistroke
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34836 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
Mistroke
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
Mistroke
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34837 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
Mistroke
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
Mistroke
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
Mistroke
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
Mistroke
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45226 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
Mistroke
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
Mistroke
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
Mistroke
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
Mistroke
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .34839 L
.45224 .3484 L
.45224 .3484 L
Mistroke
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
Mistroke
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
Mistroke
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
Mistroke
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
Mistroke
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
Mistroke
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
Mistroke
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45222 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
Mistroke
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
Mistroke
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
Mistroke
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
Mistroke
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
Mistroke
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
Mistroke
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
Mistroke
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
Mistroke
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45219 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
Mfstroke
1 0 .162 r
.02381 .60332 m
.02421 .60261 L
.02461 .60191 L
.02501 .60121 L
.02541 .6005 L
.02581 .5998 L
.02621 .59911 L
.02661 .59841 L
.02701 .59771 L
.02741 .59702 L
.0278 .59633 L
.0282 .59564 L
.02859 .59495 L
.02899 .59426 L
.02938 .59357 L
.02978 .59288 L
.03017 .5922 L
.03056 .59152 L
.03095 .59084 L
.03135 .59016 L
.03174 .58948 L
.03213 .5888 L
.03252 .58812 L
.03291 .58745 L
.03329 .58678 L
.03368 .5861 L
.03407 .58543 L
.03446 .58476 L
.03484 .5841 L
.03523 .58343 L
.03561 .58277 L
.036 .5821 L
.03638 .58144 L
.03677 .58078 L
.03715 .58012 L
.03753 .57946 L
.03791 .5788 L
.03829 .57815 L
.03868 .57749 L
.03906 .57684 L
.03944 .57619 L
.03982 .57554 L
.04019 .57489 L
.04057 .57424 L
.04095 .57359 L
.04133 .57295 L
.0417 .5723 L
.04208 .57166 L
.04246 .57102 L
.04283 .57038 L
Mistroke
.04321 .56974 L
.04358 .5691 L
.04395 .56847 L
.04433 .56783 L
.0447 .5672 L
.04507 .56656 L
.04544 .56593 L
.04581 .5653 L
.04619 .56467 L
.04656 .56405 L
.04693 .56342 L
.04729 .5628 L
.04766 .56217 L
.04803 .56155 L
.0484 .56093 L
.04877 .56031 L
.04913 .55969 L
.0495 .55907 L
.04987 .55845 L
.05023 .55784 L
.0506 .55722 L
.05096 .55661 L
.05132 .556 L
.05169 .55539 L
.05205 .55478 L
.05241 .55417 L
.05278 .55357 L
.05314 .55296 L
.0535 .55235 L
.05386 .55175 L
.05422 .55115 L
.05458 .55055 L
.05494 .54995 L
.0553 .54935 L
.05566 .54875 L
.05601 .54816 L
.05637 .54756 L
.05673 .54697 L
.05709 .54637 L
.05744 .54578 L
.0578 .54519 L
.05815 .5446 L
.05851 .54401 L
.05886 .54343 L
.05922 .54284 L
.05957 .54226 L
.05992 .54167 L
.06028 .54109 L
.06063 .54051 L
.06098 .53993 L
Mistroke
.06133 .53935 L
.06168 .53877 L
.06204 .53819 L
.06239 .53762 L
.06274 .53704 L
.06308 .53647 L
.06343 .5359 L
.06378 .53532 L
.06413 .53475 L
.06448 .53418 L
.06483 .53362 L
.06517 .53305 L
.06552 .53248 L
.06587 .53192 L
.06621 .53135 L
.06656 .53079 L
.0669 .53023 L
.06725 .52967 L
.06759 .52911 L
.06793 .52855 L
.06828 .52799 L
.06862 .52744 L
.06896 .52688 L
.06931 .52633 L
.06965 .52577 L
.06999 .52522 L
.07033 .52467 L
.07067 .52412 L
.07101 .52357 L
.07135 .52302 L
.07169 .52248 L
.07203 .52193 L
.07237 .52138 L
.07271 .52084 L
.07305 .5203 L
.07338 .51976 L
.07372 .51921 L
.07406 .51867 L
.07439 .51814 L
.07473 .5176 L
.07507 .51706 L
.0754 .51653 L
.07574 .51599 L
.07607 .51546 L
.07641 .51492 L
.07674 .51439 L
.07707 .51386 L
.07741 .51333 L
.07774 .5128 L
.07807 .51228 L
Mistroke
.0784 .51175 L
.07874 .51122 L
.07907 .5107 L
.0794 .51017 L
.07973 .50965 L
.08006 .50913 L
.08039 .50861 L
.08072 .50809 L
.08105 .50757 L
.08138 .50705 L
.08171 .50653 L
.08204 .50602 L
.08236 .5055 L
.08269 .50499 L
.08302 .50448 L
.08335 .50396 L
.08367 .50345 L
.084 .50294 L
.08433 .50243 L
.08465 .50192 L
.08498 .50142 L
.0853 .50091 L
.08563 .5004 L
.08595 .4999 L
.08627 .4994 L
.0866 .49889 L
.08692 .49839 L
.08724 .49789 L
.08757 .49739 L
.08789 .49689 L
.08821 .49639 L
.08853 .4959 L
.08886 .4954 L
.08918 .4949 L
.0895 .49441 L
.08982 .49392 L
.09014 .49342 L
.09046 .49293 L
.09078 .49244 L
.0911 .49195 L
.09142 .49146 L
.09173 .49097 L
.09205 .49048 L
.09237 .49 L
.09269 .48951 L
.09301 .48903 L
.09332 .48854 L
.09364 .48806 L
.09396 .48758 L
.09427 .4871 L
Mistroke
.09459 .48662 L
.0949 .48614 L
.09522 .48566 L
.09553 .48518 L
.09585 .48471 L
.09616 .48423 L
.09648 .48375 L
.09679 .48328 L
.09711 .48281 L
.09742 .48233 L
.09773 .48186 L
.09804 .48139 L
.09836 .48092 L
.09867 .48045 L
.09898 .47998 L
.09929 .47952 L
.0996 .47905 L
.09991 .47858 L
.10023 .47812 L
.10054 .47766 L
.10085 .47719 L
.10116 .47673 L
.10147 .47627 L
.10177 .47581 L
.10208 .47535 L
.10239 .47489 L
.1027 .47443 L
.10301 .47397 L
.10332 .47352 L
.10362 .47306 L
.10393 .47261 L
.10424 .47215 L
.10455 .4717 L
.10485 .47125 L
.10516 .4708 L
.10546 .47034 L
.10577 .46989 L
.10608 .46945 L
.10638 .469 L
.10669 .46855 L
.10699 .4681 L
.1073 .46766 L
.1076 .46721 L
.1079 .46677 L
.10821 .46632 L
.10851 .46588 L
.10881 .46544 L
.10912 .465 L
.10942 .46456 L
.10972 .46412 L
Mistroke
.11002 .46368 L
.11033 .46324 L
.11063 .4628 L
.11093 .46237 L
.11123 .46193 L
.11153 .4615 L
.11183 .46106 L
.11213 .46063 L
.11243 .46019 L
.11273 .45976 L
.11303 .45933 L
.11333 .4589 L
.11363 .45847 L
.11393 .45804 L
.11423 .45761 L
.11453 .45719 L
.11482 .45676 L
.11512 .45634 L
.11542 .45591 L
.11572 .45549 L
.11601 .45506 L
.11631 .45464 L
.11661 .45422 L
.1169 .4538 L
.1172 .45338 L
.1175 .45296 L
.11779 .45254 L
.11809 .45212 L
.11838 .4517 L
.11868 .45128 L
.11897 .45087 L
.11927 .45045 L
.11956 .45004 L
.11985 .44962 L
.12015 .44921 L
.12044 .4488 L
.12074 .44839 L
.12103 .44797 L
.12132 .44756 L
.12161 .44715 L
.12191 .44675 L
.1222 .44634 L
.12249 .44593 L
.12278 .44552 L
.12307 .44512 L
.12337 .44471 L
.12366 .44431 L
.12395 .4439 L
.12424 .4435 L
.12453 .4431 L
Mistroke
.12482 .4427 L
.12511 .44229 L
.1254 .44189 L
.12569 .44149 L
.12598 .4411 L
.12627 .4407 L
.12656 .4403 L
.12684 .4399 L
.12713 .43951 L
.12742 .43911 L
.12771 .43872 L
.128 .43832 L
.12829 .43793 L
.12857 .43754 L
.12886 .43714 L
.12915 .43675 L
.12943 .43636 L
.12972 .43597 L
.13001 .43558 L
.13029 .43519 L
.13058 .4348 L
.13086 .43442 L
.13115 .43403 L
.13144 .43364 L
.13172 .43326 L
.13201 .43287 L
.13229 .43249 L
.13258 .43211 L
.13286 .43172 L
.13314 .43134 L
.13343 .43096 L
.13371 .43058 L
.134 .4302 L
.13428 .42982 L
.13456 .42944 L
.13484 .42906 L
.13513 .42869 L
.13541 .42831 L
.13569 .42793 L
.13597 .42756 L
.13626 .42718 L
.13654 .42681 L
.13682 .42644 L
.1371 .42606 L
.13738 .42569 L
.13766 .42532 L
.13794 .42495 L
.13822 .42458 L
.13851 .42421 L
.13879 .42384 L
Mistroke
.13907 .42347 L
.13935 .4231 L
.13962 .42273 L
.1399 .42237 L
.14018 .422 L
.14046 .42164 L
.14074 .42127 L
.14102 .42091 L
.1413 .42054 L
.14158 .42018 L
.14186 .41982 L
.14213 .41946 L
.14241 .4191 L
.14269 .41874 L
.14297 .41838 L
.14324 .41802 L
.14352 .41766 L
.1438 .4173 L
.14407 .41694 L
.14435 .41659 L
.14463 .41623 L
.1449 .41588 L
.14518 .41552 L
.14545 .41517 L
.14573 .41481 L
.14601 .41446 L
.14628 .41411 L
.14656 .41376 L
.14683 .4134 L
.14711 .41305 L
.14738 .4127 L
.14765 .41235 L
.14793 .41201 L
.1482 .41166 L
.14848 .41131 L
.14875 .41096 L
.14902 .41062 L
.1493 .41027 L
.14957 .40992 L
.14984 .40958 L
.15012 .40924 L
.15039 .40889 L
.15066 .40855 L
.15093 .40821 L
.15121 .40787 L
.15148 .40752 L
.15175 .40718 L
.15202 .40684 L
.15229 .4065 L
.15256 .40616 L
Mistroke
.15284 .40583 L
.15311 .40549 L
.15338 .40515 L
.15365 .40481 L
.15392 .40448 L
.15419 .40414 L
.15446 .40381 L
.15473 .40347 L
.155 .40314 L
.15527 .40281 L
.15554 .40247 L
.15581 .40214 L
.15608 .40181 L
.15635 .40148 L
.15661 .40115 L
.15688 .40082 L
.15715 .40049 L
.15742 .40016 L
.15769 .39983 L
.15796 .39951 L
.15822 .39918 L
.15849 .39885 L
.15876 .39853 L
.15903 .3982 L
.15929 .39788 L
.15956 .39755 L
.15983 .39723 L
.16009 .3969 L
.16036 .39658 L
.16063 .39626 L
.16089 .39594 L
.16116 .39562 L
.16143 .3953 L
.16169 .39498 L
.16196 .39466 L
.16222 .39434 L
.16249 .39402 L
.16275 .3937 L
.16302 .39338 L
.16328 .39307 L
.16355 .39275 L
.16381 .39243 L
.16408 .39212 L
.16434 .3918 L
.16461 .39149 L
.16487 .39118 L
.16514 .39086 L
.1654 .39055 L
.16566 .39024 L
.16593 .38993 L
Mistroke
.16619 .38962 L
.16645 .38931 L
.16672 .389 L
.16698 .38869 L
.16724 .38838 L
.1675 .38807 L
.16777 .38776 L
.16803 .38745 L
.16829 .38715 L
.16855 .38684 L
.16881 .38653 L
.16908 .38623 L
.16934 .38592 L
.1696 .38562 L
.16986 .38532 L
.17012 .38501 L
.17038 .38471 L
.17064 .38441 L
.1709 .38411 L
.17117 .3838 L
.17143 .3835 L
.17169 .3832 L
.17195 .3829 L
.17221 .3826 L
.17247 .3823 L
.17273 .38201 L
.17299 .38171 L
.17325 .38141 L
.1735 .38111 L
.17376 .38082 L
.17402 .38052 L
.17428 .38023 L
.17454 .37993 L
.1748 .37964 L
.17506 .37934 L
.17532 .37905 L
.17558 .37876 L
.17583 .37846 L
.17609 .37817 L
.17635 .37788 L
.17661 .37759 L
.17686 .3773 L
.17712 .37701 L
.17738 .37672 L
.17764 .37643 L
.17789 .37614 L
.17815 .37585 L
.17841 .37557 L
.17866 .37528 L
.17892 .37499 L
Mistroke
.17918 .37471 L
.17943 .37442 L
.17969 .37414 L
.17995 .37385 L
.1802 .37357 L
.18046 .37328 L
.18071 .373 L
.18097 .37272 L
.18122 .37243 L
.18148 .37215 L
.18173 .37187 L
.18199 .37159 L
.18224 .37131 L
.1825 .37103 L
.18275 .37075 L
.18301 .37047 L
.18326 .37019 L
.18352 .36991 L
.18377 .36964 L
.18403 .36936 L
.18428 .36908 L
.18453 .3688 L
.18479 .36853 L
.18504 .36825 L
.18529 .36798 L
.18555 .3677 L
.1858 .36743 L
.18605 .36716 L
.18631 .36688 L
.18656 .36661 L
.18681 .36634 L
.18706 .36607 L
.18732 .36579 L
.18757 .36552 L
.18782 .36525 L
.18807 .36498 L
.18832 .36471 L
.18858 .36444 L
.18883 .36417 L
.18908 .36391 L
.18933 .36364 L
.18958 .36337 L
.18983 .3631 L
.19008 .36284 L
.19034 .36257 L
.19059 .36231 L
.19084 .36204 L
.19109 .36178 L
.19134 .36151 L
.19159 .36125 L
Mistroke
.19184 .36098 L
.19209 .36072 L
.19234 .36046 L
.19259 .3602 L
.19284 .35993 L
.19309 .35967 L
.19334 .35941 L
.19359 .35915 L
.19384 .35889 L
.19409 .35863 L
.19434 .35837 L
.19458 .35811 L
.19483 .35785 L
.19508 .3576 L
.19533 .35734 L
.19558 .35708 L
.19583 .35683 L
.19608 .35657 L
.19632 .35631 L
.19657 .35606 L
.19682 .3558 L
.19707 .35555 L
.19732 .35529 L
.19756 .35504 L
.19781 .35479 L
.19806 .35453 L
.19831 .35428 L
.19855 .35403 L
.1988 .35378 L
.19905 .35353 L
.19929 .35328 L
.19954 .35303 L
.19979 .35278 L
.20003 .35253 L
.20028 .35228 L
.20053 .35203 L
.20077 .35178 L
.20102 .35153 L
.20127 .35128 L
.20151 .35104 L
.20176 .35079 L
.202 .35054 L
.20225 .3503 L
.20249 .35005 L
.20274 .34981 L
.20298 .34956 L
.20323 .34932 L
.20347 .34907 L
.20372 .34883 L
.20396 .34859 L
Mistroke
.20421 .34834 L
.20445 .3481 L
.2047 .34786 L
.20494 .34762 L
.20519 .34738 L
.20543 .34714 L
.20567 .3469 L
.20592 .34666 L
.20616 .34642 L
.20641 .34618 L
.20665 .34594 L
.20689 .3457 L
.20714 .34546 L
.20738 .34522 L
.20762 .34499 L
.20787 .34475 L
.20811 .34451 L
.20835 .34428 L
.2086 .34404 L
.20884 .34381 L
.20908 .34357 L
.20932 .34334 L
.20957 .3431 L
.20981 .34287 L
.21005 .34264 L
.21029 .3424 L
.21053 .34217 L
.21078 .34194 L
.21102 .34171 L
.21126 .34147 L
.2115 .34124 L
.21174 .34101 L
.21198 .34078 L
.21223 .34055 L
.21247 .34032 L
.21271 .34009 L
.21295 .33986 L
.21319 .33964 L
.21343 .33941 L
.21367 .33918 L
.21391 .33895 L
.21415 .33873 L
.21439 .3385 L
.21463 .33827 L
.21487 .33805 L
.21511 .33782 L
.21535 .3376 L
.21559 .33737 L
.21583 .33715 L
.21607 .33692 L
Mistroke
.21631 .3367 L
.21655 .33648 L
.21679 .33625 L
.21703 .33603 L
.21727 .33581 L
.21751 .33559 L
.21775 .33537 L
.21799 .33514 L
.21823 .33492 L
.21847 .3347 L
.2187 .33448 L
.21894 .33426 L
.21918 .33404 L
.21942 .33382 L
.21966 .33361 L
.2199 .33339 L
.22013 .33317 L
.22037 .33295 L
.22061 .33274 L
.22085 .33252 L
.22109 .3323 L
.22132 .33209 L
.22156 .33187 L
.2218 .33165 L
.22204 .33144 L
.22227 .33122 L
.22251 .33101 L
.22275 .3308 L
.22298 .33058 L
.22322 .33037 L
.22346 .33016 L
.22369 .32994 L
.22393 .32973 L
.22417 .32952 L
.2244 .32931 L
.22464 .3291 L
.22488 .32889 L
.22511 .32868 L
.22535 .32847 L
.22559 .32826 L
.22582 .32805 L
.22606 .32784 L
.22629 .32763 L
.22653 .32742 L
.22676 .32721 L
.227 .327 L
.22723 .3268 L
.22747 .32659 L
.22771 .32638 L
.22794 .32618 L
Mistroke
.22818 .32597 L
.22841 .32576 L
.22864 .32556 L
.22888 .32535 L
.22911 .32515 L
.22935 .32494 L
.22958 .32474 L
.22982 .32454 L
.23005 .32433 L
.23029 .32413 L
.23052 .32393 L
.23075 .32372 L
.23099 .32352 L
.23122 .32332 L
.23146 .32312 L
.23169 .32292 L
.23192 .32272 L
.23216 .32252 L
.23239 .32232 L
.23262 .32212 L
.23286 .32192 L
.23309 .32172 L
.23332 .32152 L
.23356 .32132 L
.23379 .32112 L
.23402 .32093 L
.23425 .32073 L
.23449 .32053 L
.23472 .32033 L
.23495 .32014 L
.23518 .31994 L
.23542 .31975 L
.23565 .31955 L
.23588 .31935 L
.23611 .31916 L
.23634 .31897 L
.23658 .31877 L
.23681 .31858 L
.23704 .31838 L
.23727 .31819 L
.2375 .318 L
.23773 .3178 L
.23797 .31761 L
.2382 .31742 L
.23843 .31723 L
.23866 .31704 L
.23889 .31685 L
.23912 .31665 L
.23935 .31646 L
.23958 .31627 L
Mistroke
.23981 .31608 L
.24004 .31589 L
.24027 .31571 L
.2405 .31552 L
.24073 .31533 L
.24096 .31514 L
.24119 .31495 L
.24142 .31476 L
.24165 .31458 L
.24188 .31439 L
.24211 .3142 L
.24234 .31402 L
.24257 .31383 L
.2428 .31364 L
.24303 .31346 L
.24326 .31327 L
.24349 .31309 L
.24372 .3129 L
.24395 .31272 L
.24418 .31254 L
.24441 .31235 L
.24464 .31217 L
.24487 .31199 L
.24509 .3118 L
.24532 .31162 L
.24555 .31144 L
.24578 .31126 L
.24601 .31107 L
.24624 .31089 L
.24647 .31071 L
.24669 .31053 L
.24692 .31035 L
.24715 .31017 L
.24738 .30999 L
.24761 .30981 L
.24783 .30963 L
.24806 .30945 L
.24829 .30927 L
.24852 .3091 L
.24874 .30892 L
.24897 .30874 L
.2492 .30856 L
.24943 .30839 L
.24965 .30821 L
.24988 .30803 L
.25011 .30786 L
.25033 .30768 L
.25056 .3075 L
.25079 .30733 L
.25101 .30715 L
Mistroke
.25124 .30698 L
.25147 .3068 L
.25169 .30663 L
.25192 .30646 L
.25215 .30628 L
.25237 .30611 L
.2526 .30594 L
.25282 .30576 L
.25305 .30559 L
.25328 .30542 L
.2535 .30525 L
.25373 .30507 L
.25395 .3049 L
.25418 .30473 L
.2544 .30456 L
.25463 .30439 L
.25485 .30422 L
.25508 .30405 L
.25531 .30388 L
.25553 .30371 L
.25576 .30354 L
.25598 .30337 L
.25621 .3032 L
.25643 .30304 L
.25665 .30287 L
.25688 .3027 L
.2571 .30253 L
.25733 .30237 L
.25755 .3022 L
.25778 .30203 L
.258 .30187 L
.25823 .3017 L
.25845 .30153 L
.25867 .30137 L
.2589 .3012 L
.25912 .30104 L
.25934 .30087 L
.25957 .30071 L
.25979 .30055 L
.26002 .30038 L
.26024 .30022 L
.26046 .30005 L
.26069 .29989 L
.26091 .29973 L
.26113 .29957 L
.26136 .2994 L
.26158 .29924 L
.2618 .29908 L
.26202 .29892 L
.26225 .29876 L
Mistroke
.26247 .2986 L
.26269 .29844 L
.26292 .29828 L
.26314 .29812 L
.26336 .29796 L
.26358 .2978 L
.2638 .29764 L
.26403 .29748 L
.26425 .29732 L
.26447 .29716 L
.26469 .297 L
.26491 .29684 L
.26514 .29669 L
.26536 .29653 L
.26558 .29637 L
.2658 .29622 L
.26602 .29606 L
.26624 .2959 L
.26647 .29575 L
.26669 .29559 L
.26691 .29544 L
.26713 .29528 L
.26735 .29512 L
.26757 .29497 L
.26779 .29482 L
.26801 .29466 L
.26823 .29451 L
.26845 .29435 L
.26868 .2942 L
.2689 .29405 L
.26912 .29389 L
.26934 .29374 L
.26956 .29359 L
.26978 .29344 L
.27 .29328 L
.27022 .29313 L
.27044 .29298 L
.27066 .29283 L
.27088 .29268 L
.2711 .29253 L
.27132 .29238 L
.27154 .29223 L
.27176 .29208 L
.27198 .29193 L
.2722 .29178 L
.27241 .29163 L
.27263 .29148 L
.27285 .29133 L
.27307 .29118 L
.27329 .29104 L
Mistroke
.27351 .29089 L
.27373 .29074 L
.27395 .29059 L
.27417 .29045 L
.27439 .2903 L
.2746 .29015 L
.27482 .29001 L
.27504 .28986 L
.27526 .28971 L
.27548 .28957 L
.2757 .28942 L
.27591 .28928 L
.27613 .28913 L
.27635 .28899 L
.27657 .28884 L
.27679 .2887 L
.277 .28855 L
.27722 .28841 L
.27744 .28827 L
.27766 .28812 L
.27787 .28798 L
.27809 .28784 L
.27831 .2877 L
.27853 .28755 L
.27874 .28741 L
.27896 .28727 L
.27918 .28713 L
.2794 .28699 L
.27961 .28685 L
.27983 .28671 L
.28005 .28657 L
.28026 .28643 L
.28048 .28629 L
.2807 .28615 L
.28091 .28601 L
.28113 .28587 L
.28135 .28573 L
.28156 .28559 L
.28178 .28545 L
.28199 .28531 L
.28221 .28517 L
.28243 .28504 L
.28264 .2849 L
.28286 .28476 L
.28307 .28462 L
.28329 .28449 L
.28351 .28435 L
.28372 .28421 L
.28394 .28408 L
.28415 .28394 L
Mistroke
.28437 .2838 L
.28458 .28367 L
.2848 .28353 L
.28501 .2834 L
.28523 .28326 L
.28544 .28313 L
.28566 .283 L
.28587 .28286 L
.28609 .28273 L
.2863 .28259 L
.28652 .28246 L
.28673 .28233 L
.28695 .28219 L
.28716 .28206 L
.28738 .28193 L
.28759 .2818 L
.28781 .28166 L
.28802 .28153 L
.28823 .2814 L
.28845 .28127 L
.28866 .28114 L
.28888 .28101 L
.28909 .28088 L
.2893 .28075 L
.28952 .28062 L
.28973 .28049 L
.28994 .28036 L
.29016 .28023 L
.29037 .2801 L
.29058 .27997 L
.2908 .27984 L
.29101 .27971 L
.29122 .27958 L
.29144 .27945 L
.29165 .27933 L
.29186 .2792 L
.29208 .27907 L
.29229 .27894 L
.2925 .27882 L
.29271 .27869 L
.29293 .27856 L
.29314 .27844 L
.29335 .27831 L
.29356 .27818 L
.29378 .27806 L
.29399 .27793 L
.2942 .27781 L
.29441 .27768 L
.29462 .27756 L
.29484 .27743 L
Mistroke
.29505 .27731 L
.29526 .27718 L
.29547 .27706 L
.29568 .27694 L
.2959 .27681 L
.29611 .27669 L
.29632 .27657 L
.29653 .27644 L
.29674 .27632 L
.29695 .2762 L
.29716 .27607 L
.29738 .27595 L
.29759 .27583 L
.2978 .27571 L
.29801 .27559 L
.29822 .27547 L
.29843 .27535 L
.29864 .27522 L
.29885 .2751 L
.29906 .27498 L
.29927 .27486 L
.29948 .27474 L
.29969 .27462 L
.2999 .2745 L
.30011 .27439 L
.30032 .27427 L
.30053 .27415 L
.30074 .27403 L
.30095 .27391 L
.30116 .27379 L
.30137 .27367 L
.30158 .27356 L
.30179 .27344 L
.302 .27332 L
.30221 .2732 L
.30242 .27309 L
.30263 .27297 L
.30284 .27285 L
.30305 .27274 L
.30326 .27262 L
.30347 .27251 L
.30368 .27239 L
.30389 .27227 L
.30409 .27216 L
.3043 .27204 L
.30451 .27193 L
.30472 .27181 L
.30493 .2717 L
.30514 .27159 L
.30535 .27147 L
Mistroke
.30556 .27136 L
.30576 .27124 L
.30597 .27113 L
.30618 .27102 L
.30639 .2709 L
.3066 .27079 L
.3068 .27068 L
.30701 .27057 L
.30722 .27045 L
.30743 .27034 L
.30764 .27023 L
.30784 .27012 L
.30805 .27001 L
.30826 .2699 L
.30847 .26979 L
.30867 .26967 L
.30888 .26956 L
.30909 .26945 L
.3093 .26934 L
.3095 .26923 L
.30971 .26912 L
.30992 .26901 L
.31012 .2689 L
.31033 .2688 L
.31054 .26869 L
.31074 .26858 L
.31095 .26847 L
.31116 .26836 L
.31136 .26825 L
.31157 .26814 L
.31178 .26804 L
.31198 .26793 L
.31219 .26782 L
.3124 .26771 L
.3126 .26761 L
.31281 .2675 L
.31301 .26739 L
.31322 .26729 L
.31343 .26718 L
.31363 .26708 L
.31384 .26697 L
.31404 .26686 L
.31425 .26676 L
.31445 .26665 L
.31466 .26655 L
.31486 .26644 L
.31507 .26634 L
.31527 .26623 L
.31548 .26613 L
.31568 .26603 L
Mistroke
.31589 .26592 L
.31609 .26582 L
.3163 .26571 L
.3165 .26561 L
.31671 .26551 L
.31691 .26541 L
.31712 .2653 L
.31732 .2652 L
.31753 .2651 L
.31773 .265 L
.31794 .26489 L
.31814 .26479 L
.31834 .26469 L
.31855 .26459 L
.31875 .26449 L
.31896 .26439 L
.31916 .26429 L
.31936 .26419 L
.31957 .26408 L
.31977 .26398 L
.31998 .26388 L
.32018 .26378 L
.32038 .26368 L
.32059 .26359 L
.32079 .26349 L
.32099 .26339 L
.3212 .26329 L
.3214 .26319 L
.3216 .26309 L
.3218 .26299 L
.32201 .26289 L
.32221 .2628 L
.32241 .2627 L
.32262 .2626 L
.32282 .2625 L
.32302 .26241 L
.32322 .26231 L
.32343 .26221 L
.32363 .26212 L
.32383 .26202 L
.32403 .26192 L
.32424 .26183 L
.32444 .26173 L
.32464 .26163 L
.32484 .26154 L
.32504 .26144 L
.32525 .26135 L
.32545 .26125 L
.32565 .26116 L
.32585 .26106 L
Mistroke
.32605 .26097 L
.32625 .26088 L
.32646 .26078 L
.32666 .26069 L
.32686 .26059 L
.32706 .2605 L
.32726 .26041 L
.32746 .26031 L
.32766 .26022 L
.32786 .26013 L
.32806 .26003 L
.32827 .25994 L
.32847 .25985 L
.32867 .25976 L
.32887 .25967 L
.32907 .25957 L
.32927 .25948 L
.32947 .25939 L
.32967 .2593 L
.32987 .25921 L
.33007 .25912 L
.33027 .25903 L
.33047 .25894 L
.33067 .25885 L
.33087 .25876 L
.33107 .25867 L
.33127 .25858 L
.33147 .25849 L
.33167 .2584 L
.33187 .25831 L
.33207 .25822 L
.33227 .25813 L
.33247 .25804 L
.33267 .25795 L
.33286 .25786 L
.33306 .25778 L
.33326 .25769 L
.33346 .2576 L
.33366 .25751 L
.33386 .25742 L
.33406 .25734 L
.33426 .25725 L
.33446 .25716 L
.33465 .25708 L
.33485 .25699 L
.33505 .2569 L
.33525 .25682 L
.33545 .25673 L
.33565 .25664 L
.33584 .25656 L
Mistroke
.33604 .25647 L
.33624 .25639 L
.33644 .2563 L
.33664 .25622 L
.33683 .25613 L
.33703 .25605 L
.33723 .25596 L
.33743 .25588 L
.33763 .25579 L
.33782 .25571 L
.33802 .25563 L
.33822 .25554 L
.33842 .25546 L
.33861 .25537 L
.33881 .25529 L
.33901 .25521 L
.3392 .25513 L
.3394 .25504 L
.3396 .25496 L
.33979 .25488 L
.33999 .2548 L
.34019 .25471 L
.34038 .25463 L
.34058 .25455 L
.34078 .25447 L
.34097 .25439 L
.34117 .25431 L
.34137 .25422 L
.34156 .25414 L
.34176 .25406 L
.34195 .25398 L
.34215 .2539 L
.34235 .25382 L
.34254 .25374 L
.34274 .25366 L
.34293 .25358 L
.34313 .2535 L
.34332 .25342 L
.34352 .25334 L
.34372 .25326 L
.34391 .25319 L
.34411 .25311 L
.3443 .25303 L
.3445 .25295 L
.34469 .25287 L
.34489 .25279 L
.34508 .25272 L
.34528 .25264 L
.34547 .25256 L
.34567 .25248 L
Mistroke
.34586 .25241 L
.34605 .25233 L
.34625 .25225 L
.34644 .25217 L
.34664 .2521 L
.34683 .25202 L
.34703 .25195 L
.34722 .25187 L
.34741 .25179 L
.34761 .25172 L
.3478 .25164 L
.348 .25157 L
.34819 .25149 L
.34838 .25142 L
.34858 .25134 L
.34877 .25127 L
.34896 .25119 L
.34916 .25112 L
.34935 .25104 L
.34954 .25097 L
.34974 .25089 L
.34993 .25082 L
.35012 .25075 L
.35032 .25067 L
.35051 .2506 L
.3507 .25053 L
.3509 .25045 L
.35109 .25038 L
.35128 .25031 L
.35147 .25023 L
.35167 .25016 L
.35186 .25009 L
.35205 .25002 L
.35224 .24995 L
.35244 .24987 L
.35263 .2498 L
.35282 .24973 L
.35301 .24966 L
.3532 .24959 L
.3534 .24952 L
.35359 .24945 L
.35378 .24938 L
.35397 .2493 L
.35416 .24923 L
.35435 .24916 L
.35455 .24909 L
.35474 .24902 L
.35493 .24895 L
.35512 .24888 L
.35531 .24881 L
Mistroke
.3555 .24875 L
.35569 .24868 L
.35588 .24861 L
.35607 .24854 L
.35627 .24847 L
.35646 .2484 L
.35665 .24833 L
.35684 .24826 L
.35703 .2482 L
.35722 .24813 L
.35741 .24806 L
.3576 .24799 L
.35779 .24793 L
.35798 .24786 L
.35817 .24779 L
.35836 .24772 L
.35855 .24766 L
.35874 .24759 L
.35893 .24752 L
.35912 .24746 L
.35931 .24739 L
.3595 .24732 L
.35969 .24726 L
.35988 .24719 L
.36007 .24713 L
.36026 .24706 L
.36044 .247 L
.36063 .24693 L
.36082 .24687 L
.36101 .2468 L
.3612 .24674 L
.36139 .24667 L
.36158 .24661 L
.36177 .24654 L
.36196 .24648 L
.36214 .24641 L
.36233 .24635 L
.36252 .24629 L
.36271 .24622 L
.3629 .24616 L
.36309 .2461 L
.36327 .24603 L
.36346 .24597 L
.36365 .24591 L
.36384 .24584 L
.36403 .24578 L
.36421 .24572 L
.3644 .24566 L
.36459 .2456 L
.36478 .24553 L
Mistroke
.36496 .24547 L
.36515 .24541 L
.36534 .24535 L
.36553 .24529 L
.36571 .24523 L
.3659 .24516 L
.36609 .2451 L
.36627 .24504 L
.36646 .24498 L
.36665 .24492 L
.36684 .24486 L
.36702 .2448 L
.36721 .24474 L
.3674 .24468 L
.36758 .24462 L
.36777 .24456 L
.36795 .2445 L
.36814 .24444 L
.36833 .24438 L
.36851 .24432 L
.3687 .24427 L
.36888 .24421 L
.36907 .24415 L
.36926 .24409 L
.36944 .24403 L
.36963 .24397 L
.36981 .24392 L
.37 .24386 L
.37018 .2438 L
.37037 .24374 L
.37055 .24368 L
.37074 .24363 L
.37093 .24357 L
.37111 .24351 L
.3713 .24346 L
.37148 .2434 L
.37167 .24334 L
.37185 .24329 L
.37203 .24323 L
.37222 .24317 L
.3724 .24312 L
.37259 .24306 L
.37277 .24301 L
.37296 .24295 L
.37314 .24289 L
.37333 .24284 L
.37351 .24278 L
.37369 .24273 L
.37388 .24267 L
.37406 .24262 L
Mistroke
.37425 .24256 L
.37443 .24251 L
.37461 .24246 L
.3748 .2424 L
.37498 .24235 L
.37516 .24229 L
.37535 .24224 L
.37553 .24219 L
.37571 .24213 L
.3759 .24208 L
.37608 .24203 L
.37626 .24197 L
.37644 .24192 L
.37663 .24187 L
.37681 .24181 L
.37699 .24176 L
.37718 .24171 L
.37736 .24166 L
.37754 .2416 L
.37772 .24155 L
.37791 .2415 L
.37809 .24145 L
.37827 .2414 L
.37845 .24135 L
.37863 .24129 L
.37882 .24124 L
.379 .24119 L
.37918 .24114 L
.37936 .24109 L
.37954 .24104 L
.37972 .24099 L
.37991 .24094 L
.38009 .24089 L
.38027 .24084 L
.38045 .24079 L
.38063 .24074 L
.38081 .24069 L
.38099 .24064 L
.38117 .24059 L
.38135 .24054 L
.38154 .24049 L
.38172 .24044 L
.3819 .24039 L
.38208 .24035 L
.38226 .2403 L
.38244 .24025 L
.38262 .2402 L
.3828 .24015 L
.38298 .2401 L
.38316 .24006 L
Mistroke
.38334 .24001 L
.38352 .23996 L
.3837 .23991 L
.38388 .23986 L
.38406 .23982 L
.38424 .23977 L
.38442 .23972 L
.3846 .23968 L
.38478 .23963 L
.38496 .23958 L
.38514 .23954 L
.38531 .23949 L
.38549 .23944 L
.38567 .2394 L
.38585 .23935 L
.38603 .23931 L
.38621 .23926 L
.38639 .23921 L
.38657 .23917 L
.38675 .23912 L
.38692 .23908 L
.3871 .23903 L
.38728 .23899 L
.38746 .23894 L
.38764 .2389 L
.38781 .23886 L
.38799 .23881 L
.38817 .23877 L
.38835 .23872 L
.38853 .23868 L
.3887 .23863 L
.38888 .23859 L
.38906 .23855 L
.38924 .2385 L
.38941 .23846 L
.38959 .23842 L
.38977 .23837 L
.38995 .23833 L
.39012 .23829 L
.3903 .23825 L
.39048 .2382 L
.39065 .23816 L
.39083 .23812 L
.39101 .23808 L
.39118 .23803 L
.39136 .23799 L
.39154 .23795 L
.39171 .23791 L
.39189 .23787 L
.39207 .23783 L
Mistroke
.39224 .23778 L
.39242 .23774 L
.39259 .2377 L
.39277 .23766 L
.39295 .23762 L
.39312 .23758 L
.3933 .23754 L
.39347 .2375 L
.39365 .23746 L
.39382 .23742 L
.394 .23738 L
.39417 .23734 L
.39435 .2373 L
.39453 .23726 L
.3947 .23722 L
.39488 .23718 L
.39505 .23714 L
.39522 .2371 L
.3954 .23706 L
.39557 .23702 L
.39575 .23698 L
.39592 .23695 L
.3961 .23691 L
.39627 .23687 L
.39645 .23683 L
.39662 .23679 L
.39679 .23675 L
.39697 .23672 L
.39714 .23668 L
.39732 .23664 L
.39749 .2366 L
.39766 .23657 L
.39784 .23653 L
.39801 .23649 L
.39818 .23645 L
.39836 .23642 L
.39853 .23638 L
.3987 .23634 L
.39888 .23631 L
.39905 .23627 L
.39922 .23624 L
.3994 .2362 L
.39957 .23616 L
.39974 .23613 L
.39991 .23609 L
.40009 .23606 L
.40026 .23602 L
.40043 .23598 L
.4006 .23595 L
.40078 .23591 L
Mistroke
.40095 .23588 L
.40112 .23584 L
.40129 .23581 L
.40147 .23577 L
.40164 .23574 L
.40181 .23571 L
.40198 .23567 L
.40215 .23564 L
.40232 .2356 L
.4025 .23557 L
.40267 .23554 L
.40284 .2355 L
.40301 .23547 L
.40318 .23543 L
.40335 .2354 L
.40352 .23537 L
.40369 .23533 L
.40386 .2353 L
.40403 .23527 L
.40421 .23524 L
.40438 .2352 L
.40455 .23517 L
.40472 .23514 L
.40489 .23511 L
.40506 .23507 L
.40523 .23504 L
.4054 .23501 L
.40557 .23498 L
.40574 .23495 L
.40591 .23491 L
.40608 .23488 L
.40625 .23485 L
.40642 .23482 L
.40659 .23479 L
.40676 .23476 L
.40692 .23473 L
.40709 .2347 L
.40726 .23467 L
.40743 .23464 L
.4076 .23461 L
.40777 .23458 L
.40794 .23455 L
.40811 .23452 L
.40828 .23449 L
.40844 .23446 L
.40861 .23443 L
.40878 .2344 L
.40895 .23437 L
.40912 .23434 L
.40929 .23431 L
Mistroke
.40945 .23428 L
.40962 .23425 L
.40979 .23422 L
.40996 .23419 L
.41013 .23416 L
.41029 .23414 L
.41046 .23411 L
.41063 .23408 L
.4108 .23405 L
.41096 .23402 L
.41113 .234 L
.4113 .23397 L
.41147 .23394 L
.41163 .23391 L
.4118 .23388 L
.41197 .23386 L
.41213 .23383 L
.4123 .2338 L
.41247 .23378 L
.41263 .23375 L
.4128 .23372 L
.41297 .2337 L
.41313 .23367 L
.4133 .23364 L
.41346 .23362 L
.41363 .23359 L
.4138 .23356 L
.41396 .23354 L
.41413 .23351 L
.41429 .23349 L
.41446 .23346 L
.41462 .23344 L
.41479 .23341 L
.41496 .23339 L
.41512 .23336 L
.41529 .23333 L
.41545 .23331 L
.41562 .23329 L
.41578 .23326 L
.41595 .23324 L
.41611 .23321 L
.41627 .23319 L
.41644 .23316 L
.4166 .23314 L
.41677 .23311 L
.41693 .23309 L
.4171 .23307 L
.41726 .23304 L
.41743 .23302 L
.41759 .233 L
Mistroke
.41775 .23297 L
.41792 .23295 L
.41808 .23293 L
.41824 .2329 L
.41841 .23288 L
.41857 .23286 L
.41873 .23284 L
.4189 .23281 L
.41906 .23279 L
.41922 .23277 L
.41939 .23275 L
.41955 .23272 L
.41971 .2327 L
.41988 .23268 L
.42004 .23266 L
.4202 .23264 L
.42036 .23261 L
.42053 .23259 L
.42069 .23257 L
.42085 .23255 L
.42101 .23253 L
.42118 .23251 L
.42134 .23249 L
.4215 .23247 L
.42166 .23245 L
.42182 .23243 L
.42198 .23241 L
.42215 .23239 L
.42231 .23237 L
.42247 .23234 L
.42263 .23232 L
.42279 .23231 L
.42295 .23229 L
.42311 .23227 L
.42327 .23225 L
.42344 .23223 L
.4236 .23221 L
.42376 .23219 L
.42392 .23217 L
.42408 .23215 L
.42424 .23213 L
.4244 .23211 L
.42456 .23209 L
.42472 .23208 L
.42488 .23206 L
.42504 .23204 L
.4252 .23202 L
.42536 .232 L
.42552 .23198 L
.42568 .23197 L
Mistroke
.42584 .23195 L
.426 .23193 L
.42616 .23191 L
.42632 .2319 L
.42648 .23188 L
.42663 .23186 L
.42679 .23184 L
.42695 .23183 L
.42711 .23181 L
.42727 .23179 L
.42743 .23178 L
.42759 .23176 L
.42775 .23174 L
.4279 .23173 L
.42806 .23171 L
.42822 .23169 L
.42838 .23168 L
.42854 .23166 L
.4287 .23165 L
.42885 .23163 L
.42901 .23161 L
.42917 .2316 L
.42933 .23158 L
.42948 .23157 L
.42964 .23155 L
.4298 .23154 L
.42996 .23152 L
.43011 .23151 L
.43027 .23149 L
.43043 .23148 L
.43058 .23146 L
.43074 .23145 L
.4309 .23144 L
.43105 .23142 L
.43121 .23141 L
.43137 .23139 L
.43152 .23138 L
.43168 .23136 L
.43184 .23135 L
.43199 .23134 L
.43215 .23132 L
.4323 .23131 L
.43246 .2313 L
.43262 .23128 L
.43277 .23127 L
.43293 .23126 L
.43308 .23124 L
.43324 .23123 L
.43339 .23122 L
.43355 .23121 L
Mistroke
.4337 .23119 L
.43386 .23118 L
.43401 .23117 L
.43417 .23116 L
.43432 .23115 L
.43448 .23113 L
.43463 .23112 L
.43479 .23111 L
.43494 .2311 L
.4351 .23109 L
.43525 .23108 L
.4354 .23106 L
.43556 .23105 L
.43571 .23104 L
.43587 .23103 L
.43602 .23102 L
.43617 .23101 L
.43633 .231 L
.43648 .23099 L
.43663 .23098 L
.43679 .23097 L
.43694 .23096 L
.43709 .23095 L
.43725 .23094 L
.4374 .23093 L
.43755 .23092 L
.43771 .23091 L
.43786 .2309 L
.43801 .23089 L
.43816 .23088 L
.43832 .23087 L
.43847 .23086 L
.43862 .23085 L
.43877 .23084 L
.43892 .23083 L
.43908 .23082 L
.43923 .23081 L
.43938 .23081 L
.43953 .2308 L
.43968 .23079 L
.43983 .23078 L
.43999 .23077 L
.44014 .23076 L
.44029 .23076 L
.44044 .23075 L
.44059 .23074 L
.44074 .23073 L
.44089 .23072 L
.44104 .23072 L
.44119 .23071 L
Mistroke
.44134 .2307 L
.44149 .23069 L
.44165 .23069 L
.4418 .23068 L
.44195 .23067 L
.4421 .23067 L
.44225 .23066 L
.4424 .23065 L
.44255 .23065 L
.4427 .23064 L
.44284 .23063 L
.44299 .23063 L
.44314 .23062 L
.44329 .23062 L
.44344 .23061 L
.44359 .2306 L
.44374 .2306 L
.44389 .23059 L
.44404 .23059 L
.44419 .23058 L
.44434 .23058 L
.44448 .23057 L
.44463 .23057 L
.44478 .23056 L
.44493 .23056 L
.44508 .23055 L
.44523 .23055 L
.44537 .23054 L
.44552 .23054 L
.44567 .23053 L
.44582 .23053 L
.44597 .23052 L
.44611 .23052 L
.44626 .23051 L
.44641 .23051 L
.44656 .23051 L
.4467 .2305 L
.44685 .2305 L
.447 .2305 L
.44714 .23049 L
.44729 .23049 L
.44744 .23049 L
.44758 .23048 L
.44773 .23048 L
.44788 .23048 L
.44802 .23047 L
.44817 .23047 L
.44831 .23047 L
.44846 .23047 L
.44861 .23046 L
Mistroke
.44875 .23046 L
.4489 .23046 L
.44904 .23046 L
.44919 .23045 L
.44934 .23045 L
.44948 .23045 L
.44963 .23045 L
.44977 .23045 L
.44992 .23045 L
.45006 .23044 L
.45021 .23044 L
.45035 .23044 L
.4505 .23044 L
.45064 .23044 L
.45078 .23044 L
.45093 .23044 L
.45107 .23044 L
.45122 .23043 L
.45136 .23043 L
.45151 .23043 L
.45165 .23043 L
.45179 .23043 L
.45194 .23043 L
.45208 .23043 L
.45222 .23043 L
.45237 .23043 L
.45251 .23043 L
.45265 .23043 L
.4528 .23043 L
.45294 .23043 L
.45308 .23043 L
.45323 .23043 L
.45337 .23044 L
.45351 .23044 L
.45365 .23044 L
.4538 .23044 L
.45394 .23044 L
.45408 .23044 L
.45422 .23044 L
.45437 .23044 L
.45451 .23044 L
.45465 .23045 L
.45479 .23045 L
.45493 .23045 L
.45508 .23045 L
.45522 .23045 L
.45536 .23045 L
.4555 .23046 L
.45564 .23046 L
.45578 .23046 L
Mistroke
.45592 .23046 L
.45606 .23047 L
.4562 .23047 L
.45635 .23047 L
.45649 .23047 L
.45663 .23048 L
.45677 .23048 L
.45691 .23048 L
.45705 .23049 L
.45719 .23049 L
.45733 .23049 L
.45747 .2305 L
.45761 .2305 L
.45775 .2305 L
.45789 .23051 L
.45803 .23051 L
.45817 .23051 L
.45831 .23052 L
.45844 .23052 L
.45858 .23053 L
.45872 .23053 L
.45886 .23054 L
.459 .23054 L
.45914 .23054 L
.45928 .23055 L
.45942 .23055 L
.45955 .23056 L
.45969 .23056 L
.45983 .23057 L
.45997 .23057 L
.46011 .23058 L
.46025 .23058 L
.46038 .23059 L
.46052 .2306 L
.46066 .2306 L
.4608 .23061 L
.46093 .23061 L
.46107 .23062 L
.46121 .23062 L
.46135 .23063 L
.46148 .23064 L
.46162 .23064 L
.46176 .23065 L
.46189 .23065 L
.46203 .23066 L
.46217 .23067 L
.4623 .23067 L
.46244 .23068 L
.46258 .23069 L
.46271 .23069 L
Mistroke
.46285 .2307 L
.46298 .23071 L
.46312 .23072 L
.46326 .23072 L
.46339 .23073 L
.46353 .23074 L
.46366 .23075 L
.4638 .23075 L
.46393 .23076 L
.46407 .23077 L
.4642 .23078 L
.46434 .23079 L
.46447 .23079 L
.46461 .2308 L
.46474 .23081 L
.46488 .23082 L
.46501 .23083 L
.46515 .23084 L
.46528 .23084 L
.46541 .23085 L
.46555 .23086 L
.46568 .23087 L
.46582 .23088 L
.46595 .23089 L
.46608 .2309 L
.46622 .23091 L
.46635 .23092 L
.46648 .23093 L
.46662 .23094 L
.46675 .23095 L
.46688 .23095 L
.46702 .23096 L
.46715 .23097 L
.46728 .23098 L
.46741 .23099 L
.46755 .231 L
.46768 .23102 L
.46781 .23103 L
.46794 .23104 L
.46808 .23105 L
.46821 .23106 L
.46834 .23107 L
.46847 .23108 L
.4686 .23109 L
.46873 .2311 L
.46887 .23111 L
.469 .23112 L
.46913 .23113 L
.46926 .23115 L
.46939 .23116 L
Mistroke
.46952 .23117 L
.46965 .23118 L
.46978 .23119 L
.46991 .2312 L
.47004 .23121 L
.47018 .23123 L
.47031 .23124 L
.47044 .23125 L
.47057 .23126 L
.4707 .23128 L
.47083 .23129 L
.47096 .2313 L
.47109 .23131 L
.47122 .23133 L
.47134 .23134 L
.47147 .23135 L
.4716 .23136 L
.47173 .23138 L
.47186 .23139 L
.47199 .2314 L
.47212 .23142 L
.47225 .23143 L
.47238 .23144 L
.47251 .23146 L
.47263 .23147 L
.47276 .23148 L
.47289 .2315 L
.47302 .23151 L
.47315 .23153 L
.47328 .23154 L
.4734 .23155 L
.47353 .23157 L
.47366 .23158 L
.47379 .2316 L
.47391 .23161 L
.47404 .23163 L
.47417 .23164 L
.4743 .23166 L
.47442 .23167 L
.47455 .23169 L
.47468 .2317 L
.4748 .23172 L
.47493 .23173 L
.47506 .23175 L
.47518 .23176 L
.47531 .23178 L
.47543 .23179 L
.47556 .23181 L
.47569 .23182 L
.47581 .23184 L
Mistroke
.47594 .23185 L
.47606 .23187 L
.47619 .23189 L
.47631 .2319 L
.47644 .23192 L
.47657 .23194 L
.47669 .23195 L
.47682 .23197 L
.47694 .23198 L
.47707 .232 L
.47719 .23202 L
.47731 .23203 L
.47744 .23205 L
.47756 .23207 L
.47769 .23209 L
.47781 .2321 L
.47794 .23212 L
.47806 .23214 L
.47818 .23215 L
.47831 .23217 L
.47843 .23219 L
.47855 .23221 L
.47868 .23222 L
.4788 .23224 L
.47892 .23226 L
.47905 .23228 L
.47917 .2323 L
.47929 .23231 L
.47942 .23233 L
.47954 .23235 L
.47966 .23237 L
.47978 .23239 L
.47991 .23241 L
.48003 .23243 L
.48015 .23244 L
.48027 .23246 L
.4804 .23248 L
.48052 .2325 L
.48064 .23252 L
.48076 .23254 L
.48088 .23256 L
.481 .23258 L
.48112 .2326 L
.48125 .23262 L
.48137 .23264 L
.48149 .23266 L
.48161 .23267 L
.48173 .23269 L
.48185 .23271 L
.48197 .23273 L
Mistroke
.48209 .23275 L
.48221 .23277 L
.48233 .2328 L
.48245 .23282 L
.48257 .23284 L
.48269 .23286 L
.48281 .23288 L
.48293 .2329 L
.48305 .23292 L
.48317 .23294 L
.48329 .23296 L
.48341 .23298 L
.48353 .233 L
.48365 .23302 L
.48377 .23304 L
.48388 .23307 L
.484 .23309 L
.48412 .23311 L
.48424 .23313 L
.48436 .23315 L
.48448 .23317 L
.4846 .23319 L
.48471 .23322 L
.48483 .23324 L
.48495 .23326 L
.48507 .23328 L
.48518 .2333 L
.4853 .23333 L
.48542 .23335 L
.48554 .23337 L
.48565 .23339 L
.48577 .23342 L
.48589 .23344 L
.486 .23346 L
.48612 .23349 L
.48624 .23351 L
.48635 .23353 L
.48647 .23355 L
.48659 .23358 L
.4867 .2336 L
.48682 .23362 L
.48694 .23365 L
.48705 .23367 L
.48717 .23369 L
.48728 .23372 L
.4874 .23374 L
.48751 .23377 L
.48763 .23379 L
.48774 .23381 L
.48786 .23384 L
Mistroke
.48797 .23386 L
.48809 .23389 L
.4882 .23391 L
.48832 .23393 L
.48843 .23396 L
.48855 .23398 L
.48866 .23401 L
.48878 .23403 L
.48889 .23406 L
.489 .23408 L
.48912 .23411 L
.48923 .23413 L
.48935 .23416 L
.48946 .23418 L
.48957 .23421 L
.48969 .23423 L
.4898 .23426 L
.48991 .23428 L
.49003 .23431 L
.49014 .23433 L
.49025 .23436 L
.49036 .23439 L
.49048 .23441 L
.49059 .23444 L
.4907 .23446 L
.49081 .23449 L
.49093 .23452 L
.49104 .23454 L
.49115 .23457 L
.49126 .2346 L
.49137 .23462 L
.49148 .23465 L
.4916 .23468 L
.49171 .2347 L
.49182 .23473 L
.49193 .23476 L
.49204 .23478 L
.49215 .23481 L
.49226 .23484 L
.49237 .23486 L
.49248 .23489 L
.49259 .23492 L
.4927 .23495 L
.49281 .23497 L
.49292 .235 L
.49303 .23503 L
.49314 .23506 L
.49325 .23508 L
.49336 .23511 L
.49347 .23514 L
Mistroke
.49358 .23517 L
.49369 .2352 L
.4938 .23522 L
.49391 .23525 L
.49402 .23528 L
.49413 .23531 L
.49424 .23534 L
.49435 .23537 L
.49445 .2354 L
.49456 .23542 L
.49467 .23545 L
.49478 .23548 L
.49489 .23551 L
.49499 .23554 L
.4951 .23557 L
.49521 .2356 L
.49532 .23563 L
.49543 .23566 L
.49553 .23569 L
.49564 .23572 L
.49575 .23575 L
.49585 .23578 L
.49596 .23581 L
.49607 .23583 L
.49617 .23586 L
.49628 .23589 L
.49639 .23592 L
.49649 .23595 L
.4966 .23599 L
.49671 .23602 L
.49681 .23605 L
.49692 .23608 L
.49702 .23611 L
.49713 .23614 L
.49724 .23617 L
.49734 .2362 L
.49745 .23623 L
.49755 .23626 L
.49766 .23629 L
.49776 .23632 L
.49787 .23635 L
.49797 .23638 L
.49808 .23642 L
.49818 .23645 L
.49829 .23648 L
.49839 .23651 L
.49849 .23654 L
.4986 .23657 L
.4987 .23661 L
.49881 .23664 L
Mistroke
.49891 .23667 L
.49901 .2367 L
.49912 .23673 L
.49922 .23676 L
.49932 .2368 L
.49943 .23683 L
.49953 .23686 L
.49963 .23689 L
.49974 .23693 L
.49984 .23696 L
.49994 .23699 L
.50004 .23702 L
.50015 .23706 L
.50025 .23709 L
.50035 .23712 L
.50045 .23716 L
.50055 .23719 L
.50066 .23722 L
.50076 .23726 L
.50086 .23729 L
.50096 .23732 L
.50106 .23736 L
.50116 .23739 L
.50126 .23742 L
.50137 .23746 L
.50147 .23749 L
.50157 .23752 L
.50167 .23756 L
.50177 .23759 L
.50187 .23763 L
.50197 .23766 L
.50207 .23769 L
.50217 .23773 L
.50227 .23776 L
.50237 .2378 L
.50247 .23783 L
.50257 .23787 L
.50267 .2379 L
.50277 .23793 L
.50287 .23797 L
.50297 .238 L
.50307 .23804 L
.50316 .23807 L
.50326 .23811 L
.50336 .23814 L
.50346 .23818 L
.50356 .23821 L
.50366 .23825 L
.50376 .23829 L
.50385 .23832 L
Mistroke
.50395 .23836 L
.50405 .23839 L
.50415 .23843 L
.50424 .23846 L
.50434 .2385 L
.50444 .23854 L
.50454 .23857 L
.50463 .23861 L
.50473 .23864 L
.50483 .23868 L
.50492 .23872 L
.50502 .23875 L
.50512 .23879 L
.50521 .23883 L
.50531 .23886 L
.50541 .2389 L
.5055 .23893 L
.5056 .23897 L
.5057 .23901 L
.50579 .23905 L
.50589 .23908 L
.50598 .23912 L
.50608 .23916 L
.50617 .23919 L
.50627 .23923 L
.50636 .23927 L
.50646 .23931 L
.50655 .23934 L
.50665 .23938 L
.50674 .23942 L
.50684 .23946 L
.50693 .23949 L
.50703 .23953 L
.50712 .23957 L
.50721 .23961 L
.50731 .23965 L
.5074 .23968 L
.5075 .23972 L
.50759 .23976 L
.50768 .2398 L
.50778 .23984 L
.50787 .23988 L
.50796 .23991 L
.50806 .23995 L
.50815 .23999 L
.50824 .24003 L
.50833 .24007 L
.50843 .24011 L
.50852 .24015 L
.50861 .24019 L
Mistroke
.5087 .24022 L
.50879 .24026 L
.50889 .2403 L
.50898 .24034 L
.50907 .24038 L
.50916 .24042 L
.50925 .24046 L
.50934 .2405 L
.50944 .24054 L
.50953 .24058 L
.50962 .24062 L
.50971 .24066 L
.5098 .2407 L
.50989 .24074 L
.50998 .24078 L
.51007 .24082 L
.51016 .24086 L
.51025 .2409 L
.51034 .24094 L
.51043 .24098 L
.51052 .24102 L
.51061 .24106 L
.5107 .2411 L
.51079 .24114 L
.51088 .24118 L
.51097 .24122 L
.51106 .24127 L
.51115 .24131 L
.51123 .24135 L
.51132 .24139 L
.51141 .24143 L
.5115 .24147 L
.51159 .24151 L
.51168 .24155 L
.51177 .2416 L
.51185 .24164 L
.51194 .24168 L
.51203 .24172 L
.51212 .24176 L
.5122 .2418 L
.51229 .24185 L
.51238 .24189 L
.51247 .24193 L
.51255 .24197 L
.51264 .24201 L
.51273 .24206 L
.51281 .2421 L
.5129 .24214 L
.51299 .24218 L
.51307 .24222 L
Mistroke
.51316 .24227 L
.51325 .24231 L
.51333 .24235 L
.51342 .2424 L
.5135 .24244 L
.51359 .24248 L
.51367 .24252 L
.51376 .24257 L
.51384 .24261 L
.51393 .24265 L
.51401 .2427 L
.5141 .24274 L
.51418 .24278 L
.51427 .24283 L
.51435 .24287 L
.51444 .24291 L
.51452 .24296 L
.51461 .243 L
.51469 .24304 L
.51477 .24309 L
.51486 .24313 L
.51494 .24318 L
.51503 .24322 L
.51511 .24326 L
.51519 .24331 L
.51528 .24335 L
.51536 .2434 L
.51544 .24344 L
.51552 .24348 L
.51561 .24353 L
.51569 .24357 L
.51577 .24362 L
.51585 .24366 L
.51594 .24371 L
.51602 .24375 L
.5161 .2438 L
.51618 .24384 L
.51627 .24389 L
.51635 .24393 L
.51643 .24398 L
.51651 .24402 L
.51659 .24407 L
.51667 .24411 L
.51675 .24416 L
.51683 .2442 L
.51692 .24425 L
.517 .24429 L
.51708 .24434 L
.51716 .24439 L
.51724 .24443 L
Mistroke
.51732 .24448 L
.5174 .24452 L
.51748 .24457 L
.51756 .24462 L
.51764 .24466 L
.51772 .24471 L
.5178 .24475 L
.51788 .2448 L
.51795 .24485 L
.51803 .24489 L
.51811 .24494 L
.51819 .24499 L
.51827 .24503 L
.51835 .24508 L
.51843 .24513 L
.51851 .24517 L
.51858 .24522 L
.51866 .24527 L
.51874 .24531 L
.51882 .24536 L
.5189 .24541 L
.51897 .24545 L
.51905 .2455 L
.51913 .24555 L
.51921 .2456 L
.51928 .24564 L
.51936 .24569 L
.51944 .24574 L
.51951 .24579 L
.51959 .24583 L
.51967 .24588 L
.51974 .24593 L
.51982 .24598 L
.5199 .24602 L
.51997 .24607 L
.52005 .24612 L
.52012 .24617 L
.5202 .24622 L
.52028 .24626 L
.52035 .24631 L
.52043 .24636 L
.5205 .24641 L
.52058 .24646 L
.52065 .24651 L
.52073 .24656 L
.5208 .2466 L
.52088 .24665 L
.52095 .2467 L
.52103 .24675 L
.5211 .2468 L
Mistroke
.52117 .24685 L
.52125 .2469 L
.52132 .24695 L
.5214 .247 L
.52147 .24704 L
.52154 .24709 L
.52162 .24714 L
.52169 .24719 L
.52176 .24724 L
.52184 .24729 L
.52191 .24734 L
.52198 .24739 L
.52205 .24744 L
.52213 .24749 L
.5222 .24754 L
.52227 .24759 L
.52234 .24764 L
.52242 .24769 L
.52249 .24774 L
.52256 .24779 L
.52263 .24784 L
.5227 .24789 L
.52277 .24794 L
.52285 .24799 L
.52292 .24804 L
.52299 .24809 L
.52306 .24814 L
.52313 .24819 L
.5232 .24824 L
.52327 .24829 L
.52334 .24834 L
.52341 .2484 L
.52348 .24845 L
.52355 .2485 L
.52362 .24855 L
.52369 .2486 L
.52376 .24865 L
.52383 .2487 L
.5239 .24875 L
.52397 .2488 L
.52404 .24886 L
.52411 .24891 L
.52418 .24896 L
.52425 .24901 L
.52432 .24906 L
.52438 .24911 L
.52445 .24917 L
.52452 .24922 L
.52459 .24927 L
.52466 .24932 L
Mistroke
.52473 .24937 L
.52479 .24942 L
.52486 .24948 L
.52493 .24953 L
.525 .24958 L
.52506 .24963 L
.52513 .24969 L
.5252 .24974 L
.52527 .24979 L
.52533 .24984 L
.5254 .2499 L
.52547 .24995 L
.52553 .25 L
.5256 .25005 L
.52567 .25011 L
.52573 .25016 L
.5258 .25021 L
.52586 .25026 L
.52593 .25032 L
.526 .25037 L
.52606 .25042 L
.52613 .25048 L
.52619 .25053 L
.52626 .25058 L
.52632 .25064 L
.52639 .25069 L
.52645 .25074 L
.52652 .2508 L
.52658 .25085 L
.52665 .2509 L
.52671 .25096 L
.52678 .25101 L
.52684 .25107 L
.5269 .25112 L
.52697 .25117 L
.52703 .25123 L
.52709 .25128 L
.52716 .25134 L
.52722 .25139 L
.52729 .25144 L
.52735 .2515 L
.52741 .25155 L
.52747 .25161 L
.52754 .25166 L
.5276 .25172 L
.52766 .25177 L
.52772 .25183 L
.52779 .25188 L
.52785 .25193 L
.52791 .25199 L
Mistroke
.52797 .25204 L
.52803 .2521 L
.5281 .25215 L
.52816 .25221 L
.52822 .25226 L
.52828 .25232 L
.52834 .25237 L
.5284 .25243 L
.52846 .25248 L
.52852 .25254 L
.52859 .2526 L
.52865 .25265 L
.52871 .25271 L
.52877 .25276 L
.52883 .25282 L
.52889 .25287 L
.52895 .25293 L
.52901 .25298 L
.52907 .25304 L
.52913 .2531 L
.52919 .25315 L
.52924 .25321 L
.5293 .25326 L
.52936 .25332 L
.52942 .25338 L
.52948 .25343 L
.52954 .25349 L
.5296 .25355 L
.52966 .2536 L
.52972 .25366 L
.52977 .25371 L
.52983 .25377 L
.52989 .25383 L
.52995 .25388 L
.53001 .25394 L
.53006 .254 L
.53012 .25405 L
.53018 .25411 L
.53023 .25417 L
.53029 .25423 L
.53035 .25428 L
.53041 .25434 L
.53046 .2544 L
.53052 .25445 L
.53058 .25451 L
.53063 .25457 L
.53069 .25463 L
.53074 .25468 L
.5308 .25474 L
.53086 .2548 L
Mistroke
.53091 .25485 L
.53097 .25491 L
.53102 .25497 L
.53108 .25503 L
.53113 .25509 L
.53119 .25514 L
.53124 .2552 L
.5313 .25526 L
.53135 .25532 L
.53141 .25538 L
.53146 .25543 L
.53152 .25549 L
.53157 .25555 L
.53163 .25561 L
.53168 .25567 L
.53173 .25572 L
.53179 .25578 L
.53184 .25584 L
.53189 .2559 L
.53195 .25596 L
.532 .25602 L
.53205 .25608 L
.53211 .25613 L
.53216 .25619 L
.53221 .25625 L
.53227 .25631 L
.53232 .25637 L
.53237 .25643 L
.53242 .25649 L
.53248 .25655 L
.53253 .25661 L
.53258 .25666 L
.53263 .25672 L
.53268 .25678 L
.53273 .25684 L
.53279 .2569 L
.53284 .25696 L
.53289 .25702 L
.53294 .25708 L
.53299 .25714 L
.53304 .2572 L
.53309 .25726 L
.53314 .25732 L
.53319 .25738 L
.53324 .25744 L
.53329 .2575 L
.53334 .25756 L
.53339 .25762 L
.53344 .25768 L
.53349 .25774 L
Mistroke
.53354 .2578 L
.53359 .25786 L
.53364 .25792 L
.53369 .25798 L
.53374 .25804 L
.53379 .2581 L
.53384 .25816 L
.53389 .25822 L
.53394 .25828 L
.53398 .25834 L
.53403 .2584 L
.53408 .25846 L
.53413 .25852 L
.53418 .25858 L
.53423 .25864 L
.53427 .2587 L
.53432 .25877 L
.53437 .25883 L
.53442 .25889 L
.53446 .25895 L
.53451 .25901 L
.53456 .25907 L
.5346 .25913 L
.53465 .25919 L
.5347 .25925 L
.53474 .25932 L
.53479 .25938 L
.53484 .25944 L
.53488 .2595 L
.53493 .25956 L
.53497 .25962 L
.53502 .25968 L
.53507 .25975 L
.53511 .25981 L
.53516 .25987 L
.5352 .25993 L
.53525 .25999 L
.53529 .26006 L
.53534 .26012 L
.53538 .26018 L
.53543 .26024 L
.53547 .2603 L
.53552 .26037 L
.53556 .26043 L
.5356 .26049 L
.53565 .26055 L
.53569 .26061 L
.53574 .26068 L
.53578 .26074 L
.53582 .2608 L
Mistroke
.53587 .26086 L
.53591 .26093 L
.53595 .26099 L
.536 .26105 L
.53604 .26111 L
.53608 .26118 L
.53613 .26124 L
.53617 .2613 L
.53621 .26137 L
.53625 .26143 L
.53629 .26149 L
.53634 .26155 L
.53638 .26162 L
.53642 .26168 L
.53646 .26174 L
.5365 .26181 L
.53655 .26187 L
.53659 .26193 L
.53663 .262 L
.53667 .26206 L
.53671 .26212 L
.53675 .26219 L
.53679 .26225 L
.53683 .26231 L
.53687 .26238 L
.53691 .26244 L
.53695 .2625 L
.53699 .26257 L
.53703 .26263 L
.53707 .2627 L
.53711 .26276 L
.53715 .26282 L
.53719 .26289 L
.53723 .26295 L
.53727 .26302 L
.53731 .26308 L
.53735 .26314 L
.53739 .26321 L
.53743 .26327 L
.53747 .26334 L
.53751 .2634 L
.53754 .26346 L
.53758 .26353 L
.53762 .26359 L
.53766 .26366 L
.5377 .26372 L
.53773 .26379 L
.53777 .26385 L
.53781 .26392 L
.53785 .26398 L
Mistroke
.53788 .26405 L
.53792 .26411 L
.53796 .26418 L
.538 .26424 L
.53803 .2643 L
.53807 .26437 L
.53811 .26443 L
.53814 .2645 L
.53818 .26456 L
.53821 .26463 L
.53825 .26469 L
.53829 .26476 L
.53832 .26483 L
.53836 .26489 L
.53839 .26496 L
.53843 .26502 L
.53847 .26509 L
.5385 .26515 L
.53854 .26522 L
.53857 .26528 L
.53861 .26535 L
.53864 .26541 L
.53868 .26548 L
.53871 .26555 L
.53874 .26561 L
.53878 .26568 L
.53881 .26574 L
.53885 .26581 L
.53888 .26587 L
.53891 .26594 L
.53895 .26601 L
.53898 .26607 L
.53902 .26614 L
.53905 .2662 L
.53908 .26627 L
.53911 .26634 L
.53915 .2664 L
.53918 .26647 L
.53921 .26654 L
.53925 .2666 L
.53928 .26667 L
.53931 .26673 L
.53934 .2668 L
.53938 .26687 L
.53941 .26693 L
.53944 .267 L
.53947 .26707 L
.5395 .26713 L
.53953 .2672 L
.53957 .26727 L
Mistroke
.5396 .26733 L
.53963 .2674 L
.53966 .26747 L
.53969 .26753 L
.53972 .2676 L
.53975 .26767 L
.53978 .26774 L
.53981 .2678 L
.53984 .26787 L
.53987 .26794 L
.5399 .268 L
.53993 .26807 L
.53996 .26814 L
.53999 .26821 L
.54002 .26827 L
.54005 .26834 L
.54008 .26841 L
.54011 .26848 L
.54014 .26854 L
.54017 .26861 L
.5402 .26868 L
.54023 .26875 L
.54025 .26881 L
.54028 .26888 L
.54031 .26895 L
.54034 .26902 L
.54037 .26908 L
.5404 .26915 L
.54042 .26922 L
.54045 .26929 L
.54048 .26936 L
.54051 .26942 L
.54053 .26949 L
.54056 .26956 L
.54059 .26963 L
.54062 .2697 L
.54064 .26976 L
.54067 .26983 L
.5407 .2699 L
.54072 .26997 L
.54075 .27004 L
.54078 .2701 L
.5408 .27017 L
.54083 .27024 L
.54085 .27031 L
.54088 .27038 L
.54091 .27045 L
.54093 .27052 L
.54096 .27058 L
.54098 .27065 L
Mistroke
.54101 .27072 L
.54103 .27079 L
.54106 .27086 L
.54108 .27093 L
.54111 .271 L
.54113 .27106 L
.54116 .27113 L
.54118 .2712 L
.5412 .27127 L
.54123 .27134 L
.54125 .27141 L
.54128 .27148 L
.5413 .27155 L
.54132 .27162 L
.54135 .27169 L
.54137 .27175 L
.5414 .27182 L
.54142 .27189 L
.54144 .27196 L
.54146 .27203 L
.54149 .2721 L
.54151 .27217 L
.54153 .27224 L
.54156 .27231 L
.54158 .27238 L
.5416 .27245 L
.54162 .27252 L
.54164 .27259 L
.54167 .27266 L
.54169 .27273 L
.54171 .2728 L
.54173 .27287 L
.54175 .27294 L
.54177 .27301 L
.5418 .27308 L
.54182 .27315 L
.54184 .27321 L
.54186 .27328 L
.54188 .27335 L
.5419 .27342 L
.54192 .27349 L
.54194 .27356 L
.54196 .27363 L
.54198 .2737 L
.542 .27378 L
.54202 .27385 L
.54204 .27392 L
.54206 .27399 L
.54208 .27406 L
.5421 .27413 L
Mistroke
.54212 .2742 L
.54214 .27427 L
.54216 .27434 L
.54218 .27441 L
.5422 .27448 L
.54221 .27455 L
.54223 .27462 L
.54225 .27469 L
.54227 .27476 L
.54229 .27483 L
.54231 .2749 L
.54232 .27497 L
.54234 .27504 L
.54236 .27511 L
.54238 .27518 L
.5424 .27526 L
.54241 .27533 L
.54243 .2754 L
.54245 .27547 L
.54246 .27554 L
.54248 .27561 L
.5425 .27568 L
.54251 .27575 L
.54253 .27582 L
.54255 .27589 L
.54256 .27596 L
.54258 .27604 L
.5426 .27611 L
.54261 .27618 L
.54263 .27625 L
.54264 .27632 L
.54266 .27639 L
.54268 .27646 L
.54269 .27653 L
.54271 .27661 L
.54272 .27668 L
.54274 .27675 L
.54275 .27682 L
.54277 .27689 L
.54278 .27696 L
.5428 .27703 L
.54281 .27711 L
.54283 .27718 L
.54284 .27725 L
.54285 .27732 L
.54287 .27739 L
.54288 .27746 L
.5429 .27754 L
.54291 .27761 L
.54292 .27768 L
Mistroke
.54294 .27775 L
.54295 .27782 L
.54296 .2779 L
.54298 .27797 L
.54299 .27804 L
.543 .27811 L
.54302 .27818 L
.54303 .27826 L
.54304 .27833 L
.54305 .2784 L
.54307 .27847 L
.54308 .27854 L
.54309 .27862 L
.5431 .27869 L
.54311 .27876 L
.54313 .27883 L
.54314 .2789 L
.54315 .27898 L
.54316 .27905 L
.54317 .27912 L
.54318 .27919 L
.54319 .27927 L
.54321 .27934 L
.54322 .27941 L
.54323 .27948 L
.54324 .27956 L
.54325 .27963 L
.54326 .2797 L
.54327 .27977 L
.54328 .27985 L
.54329 .27992 L
.5433 .27999 L
.54331 .28006 L
.54332 .28014 L
.54333 .28021 L
.54334 .28028 L
.54335 .28035 L
.54336 .28043 L
.54337 .2805 L
.54337 .28057 L
.54338 .28065 L
.54339 .28072 L
.5434 .28079 L
.54341 .28086 L
.54342 .28094 L
.54343 .28101 L
.54343 .28108 L
.54344 .28116 L
.54345 .28123 L
.54346 .2813 L
Mistroke
.54347 .28138 L
.54347 .28145 L
.54348 .28152 L
.54349 .2816 L
.5435 .28167 L
.5435 .28174 L
.54351 .28182 L
.54352 .28189 L
.54353 .28196 L
.54353 .28204 L
.54354 .28211 L
.54355 .28218 L
.54355 .28226 L
.54356 .28233 L
.54356 .2824 L
.54357 .28248 L
.54358 .28255 L
.54358 .28262 L
.54359 .2827 L
.54359 .28277 L
.5436 .28284 L
.5436 .28292 L
.54361 .28299 L
.54362 .28306 L
.54362 .28314 L
.54363 .28321 L
.54363 .28328 L
.54363 .28336 L
.54364 .28343 L
.54364 .28351 L
.54365 .28358 L
.54365 .28365 L
.54366 .28373 L
.54366 .2838 L
.54367 .28388 L
.54367 .28395 L
.54367 .28402 L
.54368 .2841 L
.54368 .28417 L
.54368 .28424 L
.54369 .28432 L
.54369 .28439 L
.54369 .28447 L
.5437 .28454 L
.5437 .28462 L
.5437 .28469 L
.5437 .28476 L
.54371 .28484 L
.54371 .28491 L
.54371 .28499 L
Mistroke
.54371 .28506 L
.54372 .28513 L
.54372 .28521 L
.54372 .28528 L
.54372 .28536 L
.54372 .28543 L
.54373 .28551 L
.54373 .28558 L
.54373 .28565 L
.54373 .28573 L
.54373 .2858 L
.54373 .28588 L
.54373 .28595 L
.54373 .28603 L
.54373 .2861 L
.54373 .28618 L
.54373 .28625 L
.54374 .28632 L
.54374 .2864 L
.54374 .28647 L
.54374 .28655 L
.54374 .28662 L
.54374 .2867 L
.54374 .28677 L
.54373 .28685 L
.54373 .28692 L
.54373 .287 L
.54373 .28707 L
.54373 .28715 L
.54373 .28722 L
.54373 .28729 L
.54373 .28737 L
.54373 .28744 L
.54373 .28752 L
.54372 .28759 L
.54372 .28767 L
.54372 .28774 L
.54372 .28782 L
.54372 .28789 L
.54372 .28797 L
.54371 .28804 L
.54371 .28812 L
.54371 .28819 L
.54371 .28827 L
.5437 .28834 L
.5437 .28842 L
.5437 .28849 L
.5437 .28857 L
.54369 .28864 L
.54369 .28872 L
Mistroke
.54369 .28879 L
.54368 .28887 L
.54368 .28894 L
.54368 .28902 L
.54367 .28909 L
.54367 .28917 L
.54366 .28924 L
.54366 .28932 L
.54366 .28939 L
.54365 .28947 L
.54365 .28954 L
.54364 .28962 L
.54364 .2897 L
.54363 .28977 L
.54363 .28985 L
.54363 .28992 L
.54362 .29 L
.54362 .29007 L
.54361 .29015 L
.54361 .29022 L
.5436 .2903 L
.54359 .29037 L
.54359 .29045 L
.54358 .29052 L
.54358 .2906 L
.54357 .29067 L
.54357 .29075 L
.54356 .29083 L
.54355 .2909 L
.54355 .29098 L
.54354 .29105 L
.54353 .29113 L
.54353 .2912 L
.54352 .29128 L
.54351 .29135 L
.54351 .29143 L
.5435 .29151 L
.54349 .29158 L
.54349 .29166 L
.54348 .29173 L
.54347 .29181 L
.54346 .29188 L
.54346 .29196 L
.54345 .29203 L
.54344 .29211 L
.54343 .29219 L
.54342 .29226 L
.54342 .29234 L
.54341 .29241 L
.5434 .29249 L
Mistroke
.54339 .29256 L
.54338 .29264 L
.54337 .29272 L
.54337 .29279 L
.54336 .29287 L
.54335 .29294 L
.54334 .29302 L
.54333 .2931 L
.54332 .29317 L
.54331 .29325 L
.5433 .29332 L
.54329 .2934 L
.54328 .29347 L
.54327 .29355 L
.54326 .29363 L
.54325 .2937 L
.54324 .29378 L
.54323 .29385 L
.54322 .29393 L
.54321 .29401 L
.5432 .29408 L
.54319 .29416 L
.54318 .29423 L
.54317 .29431 L
.54316 .29439 L
.54315 .29446 L
.54314 .29454 L
.54312 .29461 L
.54311 .29469 L
.5431 .29477 L
.54309 .29484 L
.54308 .29492 L
.54307 .29499 L
.54305 .29507 L
.54304 .29515 L
.54303 .29522 L
.54302 .2953 L
.54301 .29537 L
.54299 .29545 L
.54298 .29553 L
.54297 .2956 L
.54296 .29568 L
.54294 .29575 L
.54293 .29583 L
.54292 .29591 L
.5429 .29598 L
.54289 .29606 L
.54288 .29614 L
.54286 .29621 L
.54285 .29629 L
Mistroke
.54284 .29636 L
.54282 .29644 L
.54281 .29652 L
.5428 .29659 L
.54278 .29667 L
.54277 .29675 L
.54275 .29682 L
.54274 .2969 L
.54273 .29697 L
.54271 .29705 L
.5427 .29713 L
.54268 .2972 L
.54267 .29728 L
.54265 .29736 L
.54264 .29743 L
.54262 .29751 L
.54261 .29758 L
.54259 .29766 L
.54258 .29774 L
.54256 .29781 L
.54255 .29789 L
.54253 .29797 L
.54252 .29804 L
.5425 .29812 L
.54248 .29819 L
.54247 .29827 L
.54245 .29835 L
.54244 .29842 L
.54242 .2985 L
.5424 .29858 L
.54239 .29865 L
.54237 .29873 L
.54235 .29881 L
.54234 .29888 L
.54232 .29896 L
.5423 .29903 L
.54228 .29911 L
.54227 .29919 L
.54225 .29926 L
.54223 .29934 L
.54222 .29942 L
.5422 .29949 L
.54218 .29957 L
.54216 .29965 L
.54214 .29972 L
.54213 .2998 L
.54211 .29987 L
.54209 .29995 L
.54207 .30003 L
.54205 .3001 L
Mistroke
.54204 .30018 L
.54202 .30026 L
.542 .30033 L
.54198 .30041 L
.54196 .30049 L
.54194 .30056 L
.54192 .30064 L
.5419 .30072 L
.54189 .30079 L
.54187 .30087 L
.54185 .30094 L
.54183 .30102 L
.54181 .3011 L
.54179 .30117 L
.54177 .30125 L
.54175 .30133 L
.54173 .3014 L
.54171 .30148 L
.54169 .30156 L
.54167 .30163 L
.54165 .30171 L
.54163 .30179 L
.54161 .30186 L
.54159 .30194 L
.54157 .30201 L
.54154 .30209 L
.54152 .30217 L
.5415 .30224 L
.54148 .30232 L
.54146 .3024 L
.54144 .30247 L
.54142 .30255 L
.5414 .30263 L
.54138 .3027 L
.54135 .30278 L
.54133 .30286 L
.54131 .30293 L
.54129 .30301 L
.54127 .30309 L
.54124 .30316 L
.54122 .30324 L
.5412 .30331 L
.54118 .30339 L
.54116 .30347 L
.54113 .30354 L
.54111 .30362 L
.54109 .3037 L
.54106 .30377 L
.54104 .30385 L
.54102 .30393 L
Mistroke
.541 .304 L
.54097 .30408 L
.54095 .30416 L
.54093 .30423 L
.5409 .30431 L
.54088 .30438 L
.54086 .30446 L
.54083 .30454 L
.54081 .30461 L
.54078 .30469 L
.54076 .30477 L
.54074 .30484 L
.54071 .30492 L
.54069 .305 L
.54066 .30507 L
.54064 .30515 L
.54061 .30523 L
.54059 .3053 L
.54056 .30538 L
.54054 .30545 L
.54051 .30553 L
.54049 .30561 L
.54046 .30568 L
.54044 .30576 L
.54041 .30584 L
.54039 .30591 L
.54036 .30599 L
.54034 .30607 L
.54031 .30614 L
.54029 .30622 L
.54026 .30629 L
.54024 .30637 L
.54021 .30645 L
.54018 .30652 L
.54016 .3066 L
.54013 .30668 L
.5401 .30675 L
.54008 .30683 L
.54005 .3069 L
.54003 .30698 L
.54 .30706 L
.53997 .30713 L
.53995 .30721 L
.53992 .30729 L
.53989 .30736 L
.53986 .30744 L
.53984 .30751 L
.53981 .30759 L
.53978 .30767 L
.53976 .30774 L
Mistroke
.53973 .30782 L
.5397 .3079 L
.53967 .30797 L
.53964 .30805 L
.53962 .30812 L
.53959 .3082 L
.53956 .30828 L
.53953 .30835 L
.5395 .30843 L
.53948 .30851 L
.53945 .30858 L
.53942 .30866 L
.53939 .30873 L
.53936 .30881 L
.53933 .30889 L
.5393 .30896 L
.53928 .30904 L
.53925 .30911 L
.53922 .30919 L
.53919 .30927 L
.53916 .30934 L
.53913 .30942 L
.5391 .30949 L
.53907 .30957 L
.53904 .30965 L
.53901 .30972 L
.53898 .3098 L
.53895 .30988 L
.53892 .30995 L
.53889 .31003 L
.53886 .3101 L
.53883 .31018 L
.5388 .31026 L
.53877 .31033 L
.53874 .31041 L
.53871 .31048 L
.53868 .31056 L
.53865 .31063 L
.53862 .31071 L
.53859 .31079 L
.53856 .31086 L
.53853 .31094 L
.5385 .31101 L
.53846 .31109 L
.53843 .31117 L
.5384 .31124 L
.53837 .31132 L
.53834 .31139 L
.53831 .31147 L
.53828 .31155 L
Mistroke
.53824 .31162 L
.53821 .3117 L
.53818 .31177 L
.53815 .31185 L
.53812 .31192 L
.53808 .312 L
.53805 .31208 L
.53802 .31215 L
.53799 .31223 L
.53796 .3123 L
.53792 .31238 L
.53789 .31245 L
.53786 .31253 L
.53782 .31261 L
.53779 .31268 L
.53776 .31276 L
.53773 .31283 L
.53769 .31291 L
.53766 .31298 L
.53763 .31306 L
.53759 .31313 L
.53756 .31321 L
.53753 .31329 L
.53749 .31336 L
.53746 .31344 L
.53743 .31351 L
.53739 .31359 L
.53736 .31366 L
.53732 .31374 L
.53729 .31381 L
.53726 .31389 L
.53722 .31396 L
.53719 .31404 L
.53715 .31412 L
.53712 .31419 L
.53708 .31427 L
.53705 .31434 L
.53702 .31442 L
.53698 .31449 L
.53695 .31457 L
.53691 .31464 L
.53688 .31472 L
.53684 .31479 L
.53681 .31487 L
.53677 .31494 L
.53674 .31502 L
.5367 .31509 L
.53666 .31517 L
.53663 .31524 L
.53659 .31532 L
Mistroke
.53656 .3154 L
.53652 .31547 L
.53649 .31555 L
.53645 .31562 L
.53641 .3157 L
.53638 .31577 L
.53634 .31585 L
.53631 .31592 L
.53627 .316 L
.53623 .31607 L
.5362 .31615 L
.53616 .31622 L
.53612 .3163 L
.53609 .31637 L
.53605 .31645 L
.53601 .31652 L
.53598 .3166 L
.53594 .31667 L
.5359 .31675 L
.53587 .31682 L
.53583 .31689 L
.53579 .31697 L
.53575 .31704 L
.53572 .31712 L
.53568 .31719 L
.53564 .31727 L
.5356 .31734 L
.53557 .31742 L
.53553 .31749 L
.53549 .31757 L
.53545 .31764 L
.53542 .31772 L
.53538 .31779 L
.53534 .31787 L
.5353 .31794 L
.53526 .31802 L
.53522 .31809 L
.53519 .31816 L
.53515 .31824 L
.53511 .31831 L
.53507 .31839 L
.53503 .31846 L
.53499 .31854 L
.53495 .31861 L
.53492 .31869 L
.53488 .31876 L
.53484 .31883 L
.5348 .31891 L
.53476 .31898 L
.53472 .31906 L
Mistroke
.53468 .31913 L
.53464 .31921 L
.5346 .31928 L
.53456 .31935 L
.53452 .31943 L
.53448 .3195 L
.53444 .31958 L
.5344 .31965 L
.53436 .31973 L
.53432 .3198 L
.53428 .31987 L
.53424 .31995 L
.5342 .32002 L
.53416 .3201 L
.53412 .32017 L
.53408 .32024 L
.53404 .32032 L
.534 .32039 L
.53396 .32047 L
.53392 .32054 L
.53388 .32061 L
.53384 .32069 L
.5338 .32076 L
.53376 .32083 L
.53372 .32091 L
.53367 .32098 L
.53363 .32106 L
.53359 .32113 L
.53355 .3212 L
.53351 .32128 L
.53347 .32135 L
.53343 .32142 L
.53339 .3215 L
.53334 .32157 L
.5333 .32165 L
.53326 .32172 L
.53322 .32179 L
.53318 .32187 L
.53313 .32194 L
.53309 .32201 L
.53305 .32209 L
.53301 .32216 L
.53297 .32223 L
.53292 .32231 L
.53288 .32238 L
.53284 .32245 L
.5328 .32253 L
.53275 .3226 L
.53271 .32267 L
.53267 .32275 L
Mistroke
.53263 .32282 L
.53258 .32289 L
.53254 .32297 L
.5325 .32304 L
.53245 .32311 L
.53241 .32319 L
.53237 .32326 L
.53233 .32333 L
.53228 .32341 L
.53224 .32348 L
.5322 .32355 L
.53215 .32362 L
.53211 .3237 L
.53206 .32377 L
.53202 .32384 L
.53198 .32392 L
.53193 .32399 L
.53189 .32406 L
.53185 .32413 L
.5318 .32421 L
.53176 .32428 L
.53171 .32435 L
.53167 .32442 L
.53163 .3245 L
.53158 .32457 L
.53154 .32464 L
.53149 .32472 L
.53145 .32479 L
.5314 .32486 L
.53136 .32493 L
.53131 .32501 L
.53127 .32508 L
.53122 .32515 L
.53118 .32522 L
.53113 .3253 L
.53109 .32537 L
.53104 .32544 L
.531 .32551 L
.53095 .32558 L
.53091 .32566 L
.53086 .32573 L
.53082 .3258 L
.53077 .32587 L
.53073 .32595 L
.53068 .32602 L
.53064 .32609 L
.53059 .32616 L
.53055 .32623 L
.5305 .32631 L
.53045 .32638 L
Mistroke
.53041 .32645 L
.53036 .32652 L
.53032 .32659 L
.53027 .32667 L
.53022 .32674 L
.53018 .32681 L
.53013 .32688 L
.53009 .32695 L
.53004 .32702 L
.52999 .3271 L
.52995 .32717 L
.5299 .32724 L
.52985 .32731 L
.52981 .32738 L
.52976 .32745 L
.52971 .32753 L
.52967 .3276 L
.52962 .32767 L
.52957 .32774 L
.52953 .32781 L
.52948 .32788 L
.52943 .32795 L
.52938 .32803 L
.52934 .3281 L
.52929 .32817 L
.52924 .32824 L
.52919 .32831 L
.52915 .32838 L
.5291 .32845 L
.52905 .32852 L
.529 .3286 L
.52896 .32867 L
.52891 .32874 L
.52886 .32881 L
.52881 .32888 L
.52877 .32895 L
.52872 .32902 L
.52867 .32909 L
.52862 .32916 L
.52857 .32923 L
.52853 .3293 L
.52848 .32938 L
.52843 .32945 L
.52838 .32952 L
.52833 .32959 L
.52828 .32966 L
.52824 .32973 L
.52819 .3298 L
.52814 .32987 L
.52809 .32994 L
Mistroke
.52804 .33001 L
.52799 .33008 L
.52794 .33015 L
.52789 .33022 L
.52785 .33029 L
.5278 .33036 L
.52775 .33043 L
.5277 .3305 L
.52765 .33057 L
.5276 .33064 L
.52755 .33071 L
.5275 .33078 L
.52745 .33085 L
.5274 .33092 L
.52735 .33099 L
.5273 .33106 L
.52725 .33113 L
.5272 .3312 L
.52715 .33127 L
.5271 .33134 L
.52705 .33141 L
.527 .33148 L
.52695 .33155 L
.52691 .33162 L
.52686 .33169 L
.5268 .33176 L
.52675 .33183 L
.5267 .3319 L
.52665 .33197 L
.5266 .33204 L
.52655 .33211 L
.5265 .33218 L
.52645 .33225 L
.5264 .33232 L
.52635 .33239 L
.5263 .33246 L
.52625 .33253 L
.5262 .3326 L
.52615 .33267 L
.5261 .33274 L
.52605 .3328 L
.526 .33287 L
.52595 .33294 L
.5259 .33301 L
.52584 .33308 L
.52579 .33315 L
.52574 .33322 L
.52569 .33329 L
.52564 .33336 L
.52559 .33343 L
Mistroke
.52554 .33349 L
.52549 .33356 L
.52543 .33363 L
.52538 .3337 L
.52533 .33377 L
.52528 .33384 L
.52523 .33391 L
.52518 .33398 L
.52513 .33404 L
.52507 .33411 L
.52502 .33418 L
.52497 .33425 L
.52492 .33432 L
.52487 .33439 L
.52481 .33445 L
.52476 .33452 L
.52471 .33459 L
.52466 .33466 L
.52461 .33473 L
.52455 .3348 L
.5245 .33486 L
.52445 .33493 L
.5244 .335 L
.52434 .33507 L
.52429 .33514 L
.52424 .3352 L
.52419 .33527 L
.52413 .33534 L
.52408 .33541 L
.52403 .33548 L
.52398 .33554 L
.52392 .33561 L
.52387 .33568 L
.52382 .33575 L
.52376 .33581 L
.52371 .33588 L
.52366 .33595 L
.52361 .33602 L
.52355 .33608 L
.5235 .33615 L
.52345 .33622 L
.52339 .33629 L
.52334 .33635 L
.52329 .33642 L
.52323 .33649 L
.52318 .33656 L
.52313 .33662 L
.52307 .33669 L
.52302 .33676 L
.52297 .33682 L
Mistroke
.52291 .33689 L
.52286 .33696 L
.52281 .33702 L
.52275 .33709 L
.5227 .33716 L
.52264 .33723 L
.52259 .33729 L
.52254 .33736 L
.52248 .33743 L
.52243 .33749 L
.52237 .33756 L
.52232 .33763 L
.52227 .33769 L
.52221 .33776 L
.52216 .33782 L
.5221 .33789 L
.52205 .33796 L
.52199 .33802 L
.52194 .33809 L
.52189 .33816 L
.52183 .33822 L
.52178 .33829 L
.52172 .33836 L
.52167 .33842 L
.52161 .33849 L
.52156 .33855 L
.5215 .33862 L
.52145 .33869 L
.52139 .33875 L
.52134 .33882 L
.52129 .33888 L
.52123 .33895 L
.52118 .33901 L
.52112 .33908 L
.52107 .33915 L
.52101 .33921 L
.52096 .33928 L
.5209 .33934 L
.52085 .33941 L
.52079 .33947 L
.52073 .33954 L
.52068 .3396 L
.52062 .33967 L
.52057 .33974 L
.52051 .3398 L
.52046 .33987 L
.5204 .33993 L
.52035 .34 L
.52029 .34006 L
.52024 .34013 L
Mistroke
.52018 .34019 L
.52012 .34026 L
.52007 .34032 L
.52001 .34039 L
.51996 .34045 L
.5199 .34052 L
.51985 .34058 L
.51979 .34065 L
.51973 .34071 L
.51968 .34077 L
.51962 .34084 L
.51957 .3409 L
.51951 .34097 L
.51945 .34103 L
.5194 .3411 L
.51934 .34116 L
.51929 .34123 L
.51923 .34129 L
.51917 .34135 L
.51912 .34142 L
.51906 .34148 L
.519 .34155 L
.51895 .34161 L
.51889 .34168 L
.51884 .34174 L
.51878 .3418 L
.51872 .34187 L
.51867 .34193 L
.51861 .34199 L
.51855 .34206 L
.5185 .34212 L
.51844 .34219 L
.51838 .34225 L
.51833 .34231 L
.51827 .34238 L
.51821 .34244 L
.51816 .3425 L
.5181 .34257 L
.51804 .34263 L
.51798 .34269 L
.51793 .34276 L
.51787 .34282 L
.51781 .34288 L
.51776 .34295 L
.5177 .34301 L
.51764 .34307 L
.51758 .34314 L
.51753 .3432 L
.51747 .34326 L
.51741 .34333 L
Mistroke
.51736 .34339 L
.5173 .34345 L
.51724 .34351 L
.51718 .34358 L
.51713 .34364 L
.51707 .3437 L
.51701 .34376 L
.51695 .34383 L
.5169 .34389 L
.51684 .34395 L
.51678 .34401 L
.51672 .34408 L
.51667 .34414 L
.51661 .3442 L
.51655 .34426 L
.51649 .34433 L
.51643 .34439 L
.51638 .34445 L
.51632 .34451 L
.51626 .34457 L
.5162 .34464 L
.51614 .3447 L
.51609 .34476 L
.51603 .34482 L
.51597 .34488 L
.51591 .34495 L
.51585 .34501 L
.5158 .34507 L
.51574 .34513 L
.51568 .34519 L
.51562 .34525 L
.51556 .34531 L
.51551 .34538 L
.51545 .34544 L
.51539 .3455 L
.51533 .34556 L
.51527 .34562 L
.51521 .34568 L
.51516 .34574 L
.5151 .3458 L
.51504 .34587 L
.51498 .34593 L
.51492 .34599 L
.51486 .34605 L
.5148 .34611 L
.51475 .34617 L
.51469 .34623 L
.51463 .34629 L
.51457 .34635 L
.51451 .34641 L
Mistroke
.51445 .34647 L
.51439 .34653 L
.51433 .34659 L
.51428 .34666 L
.51422 .34672 L
.51416 .34678 L
.5141 .34684 L
.51404 .3469 L
.51398 .34696 L
.51392 .34702 L
.51386 .34708 L
.5138 .34714 L
.51374 .3472 L
.51369 .34726 L
.51363 .34732 L
.51357 .34738 L
.51351 .34744 L
.51345 .3475 L
.51339 .34756 L
.51333 .34762 L
.51327 .34768 L
.51321 .34773 L
.51315 .34779 L
.51309 .34785 L
.51303 .34791 L
.51297 .34797 L
.51292 .34803 L
.51286 .34809 L
.5128 .34815 L
.51274 .34821 L
.51268 .34827 L
.51262 .34833 L
.51256 .34839 L
.5125 .34845 L
.51244 .3485 L
.51238 .34856 L
.51232 .34862 L
.51226 .34868 L
.5122 .34874 L
.51214 .3488 L
.51208 .34886 L
.51202 .34892 L
.51196 .34897 L
.5119 .34903 L
.51184 .34909 L
.51178 .34915 L
.51172 .34921 L
.51166 .34927 L
.5116 .34932 L
.51154 .34938 L
Mistroke
.51148 .34944 L
.51142 .3495 L
.51136 .34956 L
.5113 .34962 L
.51124 .34967 L
.51118 .34973 L
.51112 .34979 L
.51106 .34985 L
.511 .3499 L
.51094 .34996 L
.51088 .35002 L
.51082 .35008 L
.51076 .35014 L
.5107 .35019 L
.51064 .35025 L
.51058 .35031 L
.51052 .35037 L
.51046 .35042 L
.5104 .35048 L
.51034 .35054 L
.51028 .35059 L
.51022 .35065 L
.51016 .35071 L
.5101 .35077 L
.51004 .35082 L
.50998 .35088 L
.50992 .35094 L
.50986 .35099 L
.5098 .35105 L
.50974 .35111 L
.50968 .35116 L
.50962 .35122 L
.50955 .35128 L
.50949 .35133 L
.50943 .35139 L
.50937 .35145 L
.50931 .3515 L
.50925 .35156 L
.50919 .35161 L
.50913 .35167 L
.50907 .35173 L
.50901 .35178 L
.50895 .35184 L
.50889 .35189 L
.50883 .35195 L
.50877 .35201 L
.50871 .35206 L
.50864 .35212 L
.50858 .35217 L
.50852 .35223 L
Mistroke
.50846 .35228 L
.5084 .35234 L
.50834 .3524 L
.50828 .35245 L
.50822 .35251 L
.50816 .35256 L
.5081 .35262 L
.50804 .35267 L
.50797 .35273 L
.50791 .35278 L
.50785 .35284 L
.50779 .35289 L
.50773 .35295 L
.50767 .353 L
.50761 .35306 L
.50755 .35311 L
.50749 .35317 L
.50743 .35322 L
.50736 .35328 L
.5073 .35333 L
.50724 .35339 L
.50718 .35344 L
.50712 .3535 L
.50706 .35355 L
.507 .3536 L
.50694 .35366 L
.50688 .35371 L
.50681 .35377 L
.50675 .35382 L
.50669 .35388 L
.50663 .35393 L
.50657 .35398 L
.50651 .35404 L
.50645 .35409 L
.50639 .35414 L
.50632 .3542 L
.50626 .35425 L
.5062 .35431 L
.50614 .35436 L
.50608 .35441 L
.50602 .35447 L
.50596 .35452 L
.50589 .35457 L
.50583 .35463 L
.50577 .35468 L
.50571 .35473 L
.50565 .35479 L
.50559 .35484 L
.50553 .35489 L
.50546 .35495 L
Mistroke
.5054 .355 L
.50534 .35505 L
.50528 .3551 L
.50522 .35516 L
.50516 .35521 L
.5051 .35526 L
.50503 .35532 L
.50497 .35537 L
.50491 .35542 L
.50485 .35547 L
.50479 .35553 L
.50473 .35558 L
.50466 .35563 L
.5046 .35568 L
.50454 .35573 L
.50448 .35579 L
.50442 .35584 L
.50436 .35589 L
.50429 .35594 L
.50423 .356 L
.50417 .35605 L
.50411 .3561 L
.50405 .35615 L
.50399 .3562 L
.50392 .35625 L
.50386 .35631 L
.5038 .35636 L
.50374 .35641 L
.50368 .35646 L
.50362 .35651 L
.50355 .35656 L
.50349 .35661 L
.50343 .35667 L
.50337 .35672 L
.50331 .35677 L
.50325 .35682 L
.50318 .35687 L
.50312 .35692 L
.50306 .35697 L
.503 .35702 L
.50294 .35707 L
.50288 .35712 L
.50281 .35717 L
.50275 .35723 L
.50269 .35728 L
.50263 .35733 L
.50257 .35738 L
.5025 .35743 L
.50244 .35748 L
.50238 .35753 L
Mistroke
.50232 .35758 L
.50226 .35763 L
.50219 .35768 L
.50213 .35773 L
.50207 .35778 L
.50201 .35783 L
.50195 .35788 L
.50189 .35793 L
.50182 .35798 L
.50176 .35803 L
.5017 .35808 L
.50164 .35813 L
.50158 .35818 L
.50151 .35823 L
.50145 .35828 L
.50139 .35833 L
.50133 .35837 L
.50127 .35842 L
.5012 .35847 L
.50114 .35852 L
.50108 .35857 L
.50102 .35862 L
.50096 .35867 L
.50089 .35872 L
.50083 .35877 L
.50077 .35882 L
.50071 .35887 L
.50065 .35891 L
.50058 .35896 L
.50052 .35901 L
.50046 .35906 L
.5004 .35911 L
.50034 .35916 L
.50027 .35921 L
.50021 .35925 L
.50015 .3593 L
.50009 .35935 L
.50003 .3594 L
.49996 .35945 L
.4999 .35949 L
.49984 .35954 L
.49978 .35959 L
.49972 .35964 L
.49965 .35969 L
.49959 .35973 L
.49953 .35978 L
.49947 .35983 L
.49941 .35988 L
.49934 .35992 L
.49928 .35997 L
Mistroke
.49922 .36002 L
.49916 .36007 L
.4991 .36011 L
.49903 .36016 L
.49897 .36021 L
.49891 .36026 L
.49885 .3603 L
.49879 .36035 L
.49872 .3604 L
.49866 .36044 L
.4986 .36049 L
.49854 .36054 L
.49848 .36058 L
.49841 .36063 L
.49835 .36068 L
.49829 .36072 L
.49823 .36077 L
.49817 .36082 L
.4981 .36086 L
.49804 .36091 L
.49798 .36096 L
.49792 .361 L
.49786 .36105 L
.49779 .3611 L
.49773 .36114 L
.49767 .36119 L
.49761 .36123 L
.49755 .36128 L
.49748 .36133 L
.49742 .36137 L
.49736 .36142 L
.4973 .36146 L
.49724 .36151 L
.49717 .36155 L
.49711 .3616 L
.49705 .36164 L
.49699 .36169 L
.49693 .36174 L
.49686 .36178 L
.4968 .36183 L
.49674 .36187 L
.49668 .36192 L
.49662 .36196 L
.49655 .36201 L
.49649 .36205 L
.49643 .3621 L
.49637 .36214 L
.49631 .36219 L
.49625 .36223 L
.49618 .36228 L
Mistroke
.49612 .36232 L
.49606 .36236 L
.496 .36241 L
.49594 .36245 L
.49587 .3625 L
.49581 .36254 L
.49575 .36259 L
.49569 .36263 L
.49563 .36267 L
.49556 .36272 L
.4955 .36276 L
.49544 .36281 L
.49538 .36285 L
.49532 .36289 L
.49525 .36294 L
.49519 .36298 L
.49513 .36303 L
.49507 .36307 L
.49501 .36311 L
.49495 .36316 L
.49488 .3632 L
.49482 .36324 L
.49476 .36329 L
.4947 .36333 L
.49464 .36337 L
.49457 .36342 L
.49451 .36346 L
.49445 .3635 L
.49439 .36354 L
.49433 .36359 L
.49427 .36363 L
.4942 .36367 L
.49414 .36372 L
.49408 .36376 L
.49402 .3638 L
.49396 .36384 L
.4939 .36389 L
.49383 .36393 L
.49377 .36397 L
.49371 .36401 L
.49365 .36406 L
.49359 .3641 L
.49352 .36414 L
.49346 .36418 L
.4934 .36422 L
.49334 .36427 L
.49328 .36431 L
.49322 .36435 L
.49315 .36439 L
.49309 .36443 L
Mistroke
.49303 .36448 L
.49297 .36452 L
.49291 .36456 L
.49285 .3646 L
.49279 .36464 L
.49272 .36468 L
.49266 .36472 L
.4926 .36477 L
.49254 .36481 L
.49248 .36485 L
.49242 .36489 L
.49235 .36493 L
.49229 .36497 L
.49223 .36501 L
.49217 .36505 L
.49211 .36509 L
.49205 .36513 L
.49199 .36518 L
.49192 .36522 L
.49186 .36526 L
.4918 .3653 L
.49174 .36534 L
.49168 .36538 L
.49162 .36542 L
.49156 .36546 L
.49149 .3655 L
.49143 .36554 L
.49137 .36558 L
.49131 .36562 L
.49125 .36566 L
.49119 .3657 L
.49113 .36574 L
.49106 .36578 L
.491 .36582 L
.49094 .36586 L
.49088 .3659 L
.49082 .36594 L
.49076 .36598 L
.4907 .36602 L
.49064 .36606 L
.49057 .3661 L
.49051 .36613 L
.49045 .36617 L
.49039 .36621 L
.49033 .36625 L
.49027 .36629 L
.49021 .36633 L
.49015 .36637 L
.49008 .36641 L
.49002 .36645 L
Mistroke
.48996 .36649 L
.4899 .36652 L
.48984 .36656 L
.48978 .3666 L
.48972 .36664 L
.48966 .36668 L
.4896 .36672 L
.48953 .36676 L
.48947 .36679 L
.48941 .36683 L
.48935 .36687 L
.48929 .36691 L
.48923 .36695 L
.48917 .36698 L
.48911 .36702 L
.48905 .36706 L
.48899 .3671 L
.48893 .36714 L
.48886 .36717 L
.4888 .36721 L
.48874 .36725 L
.48868 .36729 L
.48862 .36732 L
.48856 .36736 L
.4885 .3674 L
.48844 .36744 L
.48838 .36747 L
.48832 .36751 L
.48826 .36755 L
.4882 .36758 L
.48813 .36762 L
.48807 .36766 L
.48801 .36769 L
.48795 .36773 L
.48789 .36777 L
.48783 .36781 L
.48777 .36784 L
.48771 .36788 L
.48765 .36791 L
.48759 .36795 L
.48753 .36799 L
.48747 .36802 L
.48741 .36806 L
.48735 .3681 L
.48729 .36813 L
.48723 .36817 L
.48717 .3682 L
.4871 .36824 L
.48704 .36828 L
.48698 .36831 L
Mistroke
.48692 .36835 L
.48686 .36838 L
.4868 .36842 L
.48674 .36846 L
.48668 .36849 L
.48662 .36853 L
.48656 .36856 L
.4865 .3686 L
.48644 .36863 L
.48638 .36867 L
.48632 .3687 L
.48626 .36874 L
.4862 .36877 L
.48614 .36881 L
.48608 .36884 L
.48602 .36888 L
.48596 .36891 L
.4859 .36895 L
.48584 .36898 L
.48578 .36902 L
.48572 .36905 L
.48566 .36909 L
.4856 .36912 L
.48554 .36916 L
.48548 .36919 L
.48542 .36922 L
.48536 .36926 L
.4853 .36929 L
.48524 .36933 L
.48518 .36936 L
.48512 .3694 L
.48506 .36943 L
.485 .36946 L
.48494 .3695 L
.48488 .36953 L
.48482 .36957 L
.48476 .3696 L
.4847 .36963 L
.48464 .36967 L
.48458 .3697 L
.48452 .36973 L
.48446 .36977 L
.4844 .3698 L
.48434 .36983 L
.48428 .36987 L
.48422 .3699 L
.48416 .36993 L
.4841 .36997 L
.48404 .37 L
.48398 .37003 L
Mistroke
.48392 .37006 L
.48387 .3701 L
.48381 .37013 L
.48375 .37016 L
.48369 .3702 L
.48363 .37023 L
.48357 .37026 L
.48351 .37029 L
.48345 .37033 L
.48339 .37036 L
.48333 .37039 L
.48327 .37042 L
.48321 .37045 L
.48315 .37049 L
.48309 .37052 L
.48303 .37055 L
.48297 .37058 L
.48292 .37061 L
.48286 .37065 L
.4828 .37068 L
.48274 .37071 L
.48268 .37074 L
.48262 .37077 L
.48256 .3708 L
.4825 .37084 L
.48244 .37087 L
.48238 .3709 L
.48232 .37093 L
.48227 .37096 L
.48221 .37099 L
.48215 .37102 L
.48209 .37105 L
.48203 .37109 L
.48197 .37112 L
.48191 .37115 L
.48185 .37118 L
.48179 .37121 L
.48174 .37124 L
.48168 .37127 L
.48162 .3713 L
.48156 .37133 L
.4815 .37136 L
.48144 .37139 L
.48138 .37142 L
.48133 .37145 L
.48127 .37148 L
.48121 .37151 L
.48115 .37154 L
.48109 .37157 L
.48103 .3716 L
Mistroke
.48097 .37163 L
.48092 .37166 L
.48086 .37169 L
.4808 .37172 L
.48074 .37175 L
.48068 .37178 L
.48062 .37181 L
.48057 .37184 L
.48051 .37187 L
.48045 .3719 L
.48039 .37193 L
.48033 .37196 L
.48027 .37199 L
.48022 .37202 L
.48016 .37205 L
.4801 .37208 L
.48004 .3721 L
.47998 .37213 L
.47992 .37216 L
.47987 .37219 L
.47981 .37222 L
.47975 .37225 L
.47969 .37228 L
.47963 .37231 L
.47958 .37233 L
.47952 .37236 L
.47946 .37239 L
.4794 .37242 L
.47935 .37245 L
.47929 .37248 L
.47923 .3725 L
.47917 .37253 L
.47911 .37256 L
.47906 .37259 L
.479 .37262 L
.47894 .37264 L
.47888 .37267 L
.47883 .3727 L
.47877 .37273 L
.47871 .37276 L
.47865 .37278 L
.4786 .37281 L
.47854 .37284 L
.47848 .37287 L
.47842 .37289 L
.47837 .37292 L
.47831 .37295 L
.47825 .37297 L
.47819 .373 L
.47814 .37303 L
Mistroke
.47808 .37306 L
.47802 .37308 L
.47797 .37311 L
.47791 .37314 L
.47785 .37316 L
.47779 .37319 L
.47774 .37322 L
.47768 .37324 L
.47762 .37327 L
.47757 .3733 L
.47751 .37332 L
.47745 .37335 L
.47739 .37338 L
.47734 .3734 L
.47728 .37343 L
.47722 .37345 L
.47717 .37348 L
.47711 .37351 L
.47705 .37353 L
.477 .37356 L
.47694 .37358 L
.47688 .37361 L
.47683 .37364 L
.47677 .37366 L
.47671 .37369 L
.47666 .37371 L
.4766 .37374 L
.47654 .37376 L
.47649 .37379 L
.47643 .37381 L
.47637 .37384 L
.47632 .37386 L
.47626 .37389 L
.4762 .37392 L
.47615 .37394 L
.47609 .37397 L
.47603 .37399 L
.47598 .37402 L
.47592 .37404 L
.47587 .37406 L
.47581 .37409 L
.47575 .37411 L
.4757 .37414 L
.47564 .37416 L
.47559 .37419 L
.47553 .37421 L
.47547 .37424 L
.47542 .37426 L
.47536 .37429 L
.4753 .37431 L
Mistroke
.47525 .37433 L
.47519 .37436 L
.47514 .37438 L
.47508 .37441 L
.47503 .37443 L
.47497 .37445 L
.47491 .37448 L
.47486 .3745 L
.4748 .37452 L
.47475 .37455 L
.47469 .37457 L
.47464 .3746 L
.47458 .37462 L
.47452 .37464 L
.47447 .37467 L
.47441 .37469 L
.47436 .37471 L
.4743 .37474 L
.47425 .37476 L
.47419 .37478 L
.47414 .3748 L
.47408 .37483 L
.47403 .37485 L
.47397 .37487 L
.47391 .3749 L
.47386 .37492 L
.4738 .37494 L
.47375 .37496 L
.47369 .37499 L
.47364 .37501 L
.47358 .37503 L
.47353 .37505 L
.47347 .37508 L
.47342 .3751 L
.47336 .37512 L
.47331 .37514 L
.47325 .37517 L
.4732 .37519 L
.47314 .37521 L
.47309 .37523 L
.47303 .37525 L
.47298 .37528 L
.47293 .3753 L
.47287 .37532 L
.47282 .37534 L
.47276 .37536 L
.47271 .37538 L
.47265 .37541 L
.4726 .37543 L
.47254 .37545 L
Mistroke
.47249 .37547 L
.47243 .37549 L
.47238 .37551 L
.47233 .37553 L
.47227 .37555 L
.47222 .37557 L
.47216 .3756 L
.47211 .37562 L
.47205 .37564 L
.472 .37566 L
.47195 .37568 L
.47189 .3757 L
.47184 .37572 L
.47178 .37574 L
.47173 .37576 L
.47168 .37578 L
.47162 .3758 L
.47157 .37582 L
.47151 .37584 L
.47146 .37586 L
.47141 .37588 L
.47135 .3759 L
.4713 .37592 L
.47124 .37594 L
.47119 .37596 L
.47114 .37598 L
.47108 .376 L
.47103 .37602 L
.47098 .37604 L
.47092 .37606 L
.47087 .37608 L
.47082 .3761 L
.47076 .37612 L
.47071 .37614 L
.47066 .37616 L
.4706 .37618 L
.47055 .3762 L
.47049 .37622 L
.47044 .37624 L
.47039 .37626 L
.47034 .37628 L
.47028 .3763 L
.47023 .37631 L
.47018 .37633 L
.47012 .37635 L
.47007 .37637 L
.47002 .37639 L
.46996 .37641 L
.46991 .37643 L
.46986 .37645 L
Mistroke
.4698 .37646 L
.46975 .37648 L
.4697 .3765 L
.46965 .37652 L
.46959 .37654 L
.46954 .37656 L
.46949 .37657 L
.46944 .37659 L
.46938 .37661 L
.46933 .37663 L
.46928 .37665 L
.46923 .37667 L
.46917 .37668 L
.46912 .3767 L
.46907 .37672 L
.46902 .37674 L
.46896 .37675 L
.46891 .37677 L
.46886 .37679 L
.46881 .37681 L
.46875 .37682 L
.4687 .37684 L
.46865 .37686 L
.4686 .37688 L
.46855 .37689 L
.46849 .37691 L
.46844 .37693 L
.46839 .37695 L
.46834 .37696 L
.46829 .37698 L
.46823 .377 L
.46818 .37701 L
.46813 .37703 L
.46808 .37705 L
.46803 .37706 L
.46797 .37708 L
.46792 .3771 L
.46787 .37711 L
.46782 .37713 L
.46777 .37715 L
.46772 .37716 L
.46766 .37718 L
.46761 .3772 L
.46756 .37721 L
.46751 .37723 L
.46746 .37724 L
.46741 .37726 L
.46736 .37728 L
.4673 .37729 L
.46725 .37731 L
Mistroke
.4672 .37732 L
.46715 .37734 L
.4671 .37736 L
.46705 .37737 L
.467 .37739 L
.46695 .3774 L
.4669 .37742 L
.46684 .37743 L
.46679 .37745 L
.46674 .37746 L
.46669 .37748 L
.46664 .37749 L
.46659 .37751 L
.46654 .37752 L
.46649 .37754 L
.46644 .37755 L
.46639 .37757 L
.46634 .37758 L
.46629 .3776 L
.46624 .37761 L
.46619 .37763 L
.46614 .37764 L
.46608 .37766 L
.46603 .37767 L
.46598 .37769 L
.46593 .3777 L
.46588 .37772 L
.46583 .37773 L
.46578 .37775 L
.46573 .37776 L
.46568 .37777 L
.46563 .37779 L
.46558 .3778 L
.46553 .37782 L
.46548 .37783 L
.46543 .37785 L
.46538 .37786 L
.46533 .37787 L
.46528 .37789 L
.46523 .3779 L
.46518 .37791 L
.46513 .37793 L
.46508 .37794 L
.46503 .37796 L
.46498 .37797 L
.46493 .37798 L
.46488 .378 L
.46483 .37801 L
.46479 .37802 L
.46474 .37804 L
Mistroke
.46469 .37805 L
.46464 .37806 L
.46459 .37808 L
.46454 .37809 L
.46449 .3781 L
.46444 .37811 L
.46439 .37813 L
.46434 .37814 L
.46429 .37815 L
.46424 .37817 L
.46419 .37818 L
.46414 .37819 L
.4641 .3782 L
.46405 .37822 L
.464 .37823 L
.46395 .37824 L
.4639 .37825 L
.46385 .37827 L
.4638 .37828 L
.46375 .37829 L
.46371 .3783 L
.46366 .37831 L
.46361 .37833 L
.46356 .37834 L
.46351 .37835 L
.46346 .37836 L
.46341 .37837 L
.46337 .37839 L
.46332 .3784 L
.46327 .37841 L
.46322 .37842 L
.46317 .37843 L
.46312 .37845 L
.46308 .37846 L
.46303 .37847 L
.46298 .37848 L
.46293 .37849 L
.46288 .3785 L
.46283 .37851 L
.46279 .37852 L
.46274 .37854 L
.46269 .37855 L
.46264 .37856 L
.46259 .37857 L
.46255 .37858 L
.4625 .37859 L
.46245 .3786 L
.4624 .37861 L
.46236 .37862 L
.46231 .37863 L
Mistroke
.46226 .37865 L
.46221 .37866 L
.46217 .37867 L
.46212 .37868 L
.46207 .37869 L
.46202 .3787 L
.46198 .37871 L
.46193 .37872 L
.46188 .37873 L
.46183 .37874 L
.46179 .37875 L
.46174 .37876 L
.46169 .37877 L
.46165 .37878 L
.4616 .37879 L
.46155 .3788 L
.4615 .37881 L
.46146 .37882 L
.46141 .37883 L
.46136 .37884 L
.46132 .37885 L
.46127 .37886 L
.46122 .37887 L
.46118 .37888 L
.46113 .37889 L
.46108 .3789 L
.46104 .37891 L
.46099 .37891 L
.46094 .37892 L
.4609 .37893 L
.46085 .37894 L
.4608 .37895 L
.46076 .37896 L
.46071 .37897 L
.46066 .37898 L
.46062 .37899 L
.46057 .379 L
.46053 .37901 L
.46048 .37901 L
.46043 .37902 L
.46039 .37903 L
.46034 .37904 L
.4603 .37905 L
.46025 .37906 L
.4602 .37907 L
.46016 .37907 L
.46011 .37908 L
.46007 .37909 L
.46002 .3791 L
.45997 .37911 L
Mistroke
.45993 .37912 L
.45988 .37912 L
.45984 .37913 L
.45979 .37914 L
.45975 .37915 L
.4597 .37916 L
.45966 .37916 L
.45961 .37917 L
.45956 .37918 L
.45952 .37919 L
.45947 .3792 L
.45943 .3792 L
.45938 .37921 L
.45934 .37922 L
.45929 .37923 L
.45925 .37923 L
.4592 .37924 L
.45916 .37925 L
.45911 .37926 L
.45907 .37926 L
.45902 .37927 L
.45898 .37928 L
.45893 .37929 L
.45889 .37929 L
.45884 .3793 L
.4588 .37931 L
.45875 .37931 L
.45871 .37932 L
.45866 .37933 L
.45862 .37933 L
.45858 .37934 L
.45853 .37935 L
.45849 .37935 L
.45844 .37936 L
.4584 .37937 L
.45835 .37937 L
.45831 .37938 L
.45826 .37939 L
.45822 .37939 L
.45818 .3794 L
.45813 .37941 L
.45809 .37941 L
.45804 .37942 L
.458 .37942 L
.45796 .37943 L
.45791 .37944 L
.45787 .37944 L
.45782 .37945 L
.45778 .37946 L
.45774 .37946 L
Mistroke
.45769 .37947 L
.45765 .37947 L
.45761 .37948 L
.45756 .37948 L
.45752 .37949 L
.45747 .3795 L
.45743 .3795 L
.45739 .37951 L
.45734 .37951 L
.4573 .37952 L
.45726 .37952 L
.45721 .37953 L
.45717 .37953 L
.45713 .37954 L
.45708 .37954 L
.45704 .37955 L
.457 .37955 L
.45696 .37956 L
.45691 .37956 L
.45687 .37957 L
.45683 .37957 L
.45678 .37958 L
.45674 .37958 L
.4567 .37959 L
.45665 .37959 L
.45661 .3796 L
.45657 .3796 L
.45653 .37961 L
.45648 .37961 L
.45644 .37962 L
.4564 .37962 L
.45636 .37963 L
.45631 .37963 L
.45627 .37963 L
.45623 .37964 L
.45619 .37964 L
.45614 .37965 L
.4561 .37965 L
.45606 .37966 L
.45602 .37966 L
.45598 .37966 L
.45593 .37967 L
.45589 .37967 L
.45585 .37968 L
.45581 .37968 L
.45577 .37968 L
.45572 .37969 L
.45568 .37969 L
.45564 .37969 L
.4556 .3797 L
Mistroke
.45556 .3797 L
.45551 .37971 L
.45547 .37971 L
.45543 .37971 L
.45539 .37972 L
.45535 .37972 L
.45531 .37972 L
.45527 .37973 L
.45522 .37973 L
.45518 .37973 L
.45514 .37974 L
.4551 .37974 L
.45506 .37974 L
.45502 .37974 L
.45498 .37975 L
.45493 .37975 L
.45489 .37975 L
.45485 .37976 L
.45481 .37976 L
.45477 .37976 L
.45473 .37976 L
.45469 .37977 L
.45465 .37977 L
.45461 .37977 L
.45457 .37978 L
.45453 .37978 L
.45448 .37978 L
.45444 .37978 L
.4544 .37978 L
.45436 .37979 L
.45432 .37979 L
.45428 .37979 L
.45424 .37979 L
.4542 .3798 L
.45416 .3798 L
.45412 .3798 L
.45408 .3798 L
.45404 .3798 L
.454 .37981 L
.45396 .37981 L
.45392 .37981 L
.45388 .37981 L
.45384 .37981 L
.4538 .37982 L
.45376 .37982 L
.45372 .37982 L
.45368 .37982 L
.45364 .37982 L
.4536 .37982 L
.45356 .37982 L
Mistroke
.45352 .37983 L
.45348 .37983 L
.45344 .37983 L
.4534 .37983 L
.45336 .37983 L
.45332 .37983 L
.45328 .37983 L
.45324 .37984 L
.4532 .37984 L
.45316 .37984 L
.45313 .37984 L
.45309 .37984 L
.45305 .37984 L
.45301 .37984 L
.45297 .37984 L
.45293 .37984 L
.45289 .37984 L
.45285 .37984 L
.45281 .37985 L
.45277 .37985 L
.45273 .37985 L
.4527 .37985 L
.45266 .37985 L
.45262 .37985 L
.45258 .37985 L
.45254 .37985 L
.4525 .37985 L
.45246 .37985 L
.45242 .37985 L
.45239 .37985 L
.45235 .37985 L
.45231 .37985 L
.45227 .37985 L
.45223 .37985 L
.45219 .37985 L
.45216 .37985 L
.45212 .37985 L
.45208 .37985 L
.45204 .37985 L
.452 .37985 L
.45196 .37985 L
.45193 .37985 L
.45189 .37985 L
.45185 .37985 L
.45181 .37985 L
.45177 .37985 L
.45174 .37985 L
.4517 .37985 L
.45166 .37985 L
.45162 .37985 L
Mistroke
.45159 .37985 L
.45155 .37984 L
.45151 .37984 L
.45147 .37984 L
.45144 .37984 L
.4514 .37984 L
.45136 .37984 L
.45132 .37984 L
.45129 .37984 L
.45125 .37984 L
.45121 .37984 L
.45117 .37984 L
.45114 .37984 L
.4511 .37983 L
.45106 .37983 L
.45103 .37983 L
.45099 .37983 L
.45095 .37983 L
.45091 .37983 L
.45088 .37983 L
.45084 .37983 L
.4508 .37982 L
.45077 .37982 L
.45073 .37982 L
.45069 .37982 L
.45066 .37982 L
.45062 .37982 L
.45058 .37981 L
.45055 .37981 L
.45051 .37981 L
.45047 .37981 L
.45044 .37981 L
.4504 .37981 L
.45037 .3798 L
.45033 .3798 L
.45029 .3798 L
.45026 .3798 L
.45022 .3798 L
.45018 .37979 L
.45015 .37979 L
.45011 .37979 L
.45008 .37979 L
.45004 .37978 L
.45 .37978 L
.44997 .37978 L
.44993 .37978 L
.4499 .37977 L
.44986 .37977 L
.44983 .37977 L
.44979 .37977 L
Mistroke
.44975 .37976 L
.44972 .37976 L
.44968 .37976 L
.44965 .37976 L
.44961 .37975 L
.44958 .37975 L
.44954 .37975 L
.44951 .37975 L
.44947 .37974 L
.44944 .37974 L
.4494 .37974 L
.44936 .37973 L
.44933 .37973 L
.44929 .37973 L
.44926 .37973 L
.44922 .37972 L
.44919 .37972 L
.44915 .37972 L
.44912 .37971 L
.44908 .37971 L
.44905 .37971 L
.44902 .3797 L
.44898 .3797 L
.44895 .3797 L
.44891 .37969 L
.44888 .37969 L
.44884 .37969 L
.44881 .37968 L
.44877 .37968 L
.44874 .37967 L
.4487 .37967 L
.44867 .37967 L
.44864 .37966 L
.4486 .37966 L
.44857 .37966 L
.44853 .37965 L
.4485 .37965 L
.44846 .37964 L
.44843 .37964 L
.4484 .37964 L
.44836 .37963 L
.44833 .37963 L
.44829 .37962 L
.44826 .37962 L
.44823 .37962 L
.44819 .37961 L
.44816 .37961 L
.44813 .3796 L
.44809 .3796 L
.44806 .37959 L
Mistroke
.44803 .37959 L
.44799 .37959 L
.44796 .37958 L
.44792 .37958 L
.44789 .37957 L
.44786 .37957 L
.44782 .37956 L
.44779 .37956 L
.44776 .37955 L
.44772 .37955 L
.44769 .37954 L
.44766 .37954 L
.44763 .37953 L
.44759 .37953 L
.44756 .37952 L
.44753 .37952 L
.44749 .37951 L
.44746 .37951 L
.44743 .3795 L
.4474 .3795 L
.44736 .37949 L
.44733 .37949 L
.4473 .37948 L
.44726 .37948 L
.44723 .37947 L
.4472 .37947 L
.44717 .37946 L
.44713 .37946 L
.4471 .37945 L
.44707 .37945 L
.44704 .37944 L
.44701 .37944 L
.44697 .37943 L
.44694 .37943 L
.44691 .37942 L
.44688 .37941 L
.44684 .37941 L
.44681 .3794 L
.44678 .3794 L
.44675 .37939 L
.44672 .37939 L
.44668 .37938 L
.44665 .37937 L
.44662 .37937 L
.44659 .37936 L
.44656 .37936 L
.44653 .37935 L
.44649 .37934 L
.44646 .37934 L
.44643 .37933 L
Mistroke
.4464 .37933 L
.44637 .37932 L
.44634 .37931 L
.44631 .37931 L
.44627 .3793 L
.44624 .3793 L
.44621 .37929 L
.44618 .37928 L
.44615 .37928 L
.44612 .37927 L
.44609 .37926 L
.44606 .37926 L
.44602 .37925 L
.44599 .37924 L
.44596 .37924 L
.44593 .37923 L
.4459 .37922 L
.44587 .37922 L
.44584 .37921 L
.44581 .3792 L
.44578 .3792 L
.44575 .37919 L
.44572 .37918 L
.44569 .37918 L
.44566 .37917 L
.44562 .37916 L
.44559 .37916 L
.44556 .37915 L
.44553 .37914 L
.4455 .37913 L
.44547 .37913 L
.44544 .37912 L
.44541 .37911 L
.44538 .37911 L
.44535 .3791 L
.44532 .37909 L
.44529 .37908 L
.44526 .37908 L
.44523 .37907 L
.4452 .37906 L
.44517 .37906 L
.44514 .37905 L
.44511 .37904 L
.44508 .37903 L
.44505 .37903 L
.44502 .37902 L
.44499 .37901 L
.44496 .379 L
.44493 .37899 L
.44491 .37899 L
Mistroke
.44488 .37898 L
.44485 .37897 L
.44482 .37896 L
.44479 .37896 L
.44476 .37895 L
.44473 .37894 L
.4447 .37893 L
.44467 .37892 L
.44464 .37892 L
.44461 .37891 L
.44458 .3789 L
.44455 .37889 L
.44453 .37888 L
.4445 .37888 L
.44447 .37887 L
.44444 .37886 L
.44441 .37885 L
.44438 .37884 L
.44435 .37884 L
.44432 .37883 L
.4443 .37882 L
.44427 .37881 L
.44424 .3788 L
.44421 .37879 L
.44418 .37878 L
.44415 .37878 L
.44412 .37877 L
.4441 .37876 L
.44407 .37875 L
.44404 .37874 L
.44401 .37873 L
.44398 .37872 L
.44395 .37872 L
.44393 .37871 L
.4439 .3787 L
.44387 .37869 L
.44384 .37868 L
.44381 .37867 L
.44379 .37866 L
.44376 .37865 L
.44373 .37865 L
.4437 .37864 L
.44367 .37863 L
.44365 .37862 L
.44362 .37861 L
.44359 .3786 L
.44356 .37859 L
.44354 .37858 L
.44351 .37857 L
.44348 .37856 L
Mistroke
.44345 .37855 L
.44343 .37855 L
.4434 .37854 L
.44337 .37853 L
.44334 .37852 L
.44332 .37851 L
.44329 .3785 L
.44326 .37849 L
.44324 .37848 L
.44321 .37847 L
.44318 .37846 L
.44316 .37845 L
.44313 .37844 L
.4431 .37843 L
.44307 .37842 L
.44305 .37841 L
.44302 .3784 L
.44299 .37839 L
.44297 .37838 L
.44294 .37837 L
.44291 .37836 L
.44289 .37835 L
.44286 .37834 L
.44283 .37834 L
.44281 .37833 L
.44278 .37832 L
.44275 .37831 L
.44273 .3783 L
.4427 .37829 L
.44268 .37828 L
.44265 .37827 L
.44262 .37826 L
.4426 .37825 L
.44257 .37823 L
.44255 .37822 L
.44252 .37821 L
.44249 .3782 L
.44247 .37819 L
.44244 .37818 L
.44242 .37817 L
.44239 .37816 L
.44236 .37815 L
.44234 .37814 L
.44231 .37813 L
.44229 .37812 L
.44226 .37811 L
.44224 .3781 L
.44221 .37809 L
.44218 .37808 L
.44216 .37807 L
Mistroke
.44213 .37806 L
.44211 .37805 L
.44208 .37804 L
.44206 .37803 L
.44203 .37802 L
.44201 .37801 L
.44198 .37799 L
.44196 .37798 L
.44193 .37797 L
.44191 .37796 L
.44188 .37795 L
.44186 .37794 L
.44183 .37793 L
.44181 .37792 L
.44178 .37791 L
.44176 .3779 L
.44173 .37789 L
.44171 .37787 L
.44168 .37786 L
.44166 .37785 L
.44163 .37784 L
.44161 .37783 L
.44158 .37782 L
.44156 .37781 L
.44153 .3778 L
.44151 .37778 L
.44149 .37777 L
.44146 .37776 L
.44144 .37775 L
.44141 .37774 L
.44139 .37773 L
.44136 .37772 L
.44134 .37771 L
.44132 .37769 L
.44129 .37768 L
.44127 .37767 L
.44124 .37766 L
.44122 .37765 L
.4412 .37764 L
.44117 .37762 L
.44115 .37761 L
.44112 .3776 L
.4411 .37759 L
.44108 .37758 L
.44105 .37757 L
.44103 .37755 L
.44101 .37754 L
.44098 .37753 L
.44096 .37752 L
.44093 .37751 L
Mistroke
.44091 .3775 L
.44089 .37748 L
.44086 .37747 L
.44084 .37746 L
.44082 .37745 L
.44079 .37744 L
.44077 .37742 L
.44075 .37741 L
.44072 .3774 L
.4407 .37739 L
.44068 .37738 L
.44066 .37736 L
.44063 .37735 L
.44061 .37734 L
.44059 .37733 L
.44056 .37731 L
.44054 .3773 L
.44052 .37729 L
.4405 .37728 L
.44047 .37727 L
.44045 .37725 L
.44043 .37724 L
.4404 .37723 L
.44038 .37722 L
.44036 .3772 L
.44034 .37719 L
.44031 .37718 L
.44029 .37717 L
.44027 .37715 L
.44025 .37714 L
.44023 .37713 L
.4402 .37712 L
.44018 .3771 L
.44016 .37709 L
.44014 .37708 L
.44011 .37706 L
.44009 .37705 L
.44007 .37704 L
.44005 .37703 L
.44003 .37701 L
.44 .377 L
.43998 .37699 L
.43996 .37698 L
.43994 .37696 L
.43992 .37695 L
.4399 .37694 L
.43987 .37692 L
.43985 .37691 L
.43983 .3769 L
.43981 .37688 L
Mistroke
.43979 .37687 L
.43977 .37686 L
.43974 .37685 L
.43972 .37683 L
.4397 .37682 L
.43968 .37681 L
.43966 .37679 L
.43964 .37678 L
.43962 .37677 L
.4396 .37675 L
.43957 .37674 L
.43955 .37673 L
.43953 .37671 L
.43951 .3767 L
.43949 .37669 L
.43947 .37667 L
.43945 .37666 L
.43943 .37665 L
.43941 .37663 L
.43939 .37662 L
.43936 .37661 L
.43934 .37659 L
.43932 .37658 L
.4393 .37657 L
.43928 .37655 L
.43926 .37654 L
.43924 .37652 L
.43922 .37651 L
.4392 .3765 L
.43918 .37648 L
.43916 .37647 L
.43914 .37646 L
.43912 .37644 L
.4391 .37643 L
.43908 .37642 L
.43906 .3764 L
.43904 .37639 L
.43902 .37637 L
.439 .37636 L
.43898 .37635 L
.43896 .37633 L
.43894 .37632 L
.43892 .3763 L
.4389 .37629 L
.43888 .37628 L
.43886 .37626 L
.43884 .37625 L
.43882 .37623 L
.4388 .37622 L
.43878 .37621 L
Mistroke
.43876 .37619 L
.43874 .37618 L
.43872 .37616 L
.4387 .37615 L
.43868 .37614 L
.43866 .37612 L
.43864 .37611 L
.43862 .37609 L
.4386 .37608 L
.43858 .37606 L
.43856 .37605 L
.43855 .37604 L
.43853 .37602 L
.43851 .37601 L
.43849 .37599 L
.43847 .37598 L
.43845 .37596 L
.43843 .37595 L
.43841 .37593 L
.43839 .37592 L
.43837 .37591 L
.43835 .37589 L
.43834 .37588 L
.43832 .37586 L
.4383 .37585 L
.43828 .37583 L
.43826 .37582 L
.43824 .3758 L
.43822 .37579 L
.43821 .37577 L
.43819 .37576 L
.43817 .37575 L
.43815 .37573 L
.43813 .37572 L
.43811 .3757 L
.43809 .37569 L
.43808 .37567 L
.43806 .37566 L
.43804 .37564 L
.43802 .37563 L
.438 .37561 L
.43799 .3756 L
.43797 .37558 L
.43795 .37557 L
.43793 .37555 L
.43791 .37554 L
.4379 .37552 L
.43788 .37551 L
.43786 .37549 L
.43784 .37548 L
Mistroke
.43782 .37546 L
.43781 .37545 L
.43779 .37543 L
.43777 .37542 L
.43775 .3754 L
.43774 .37539 L
.43772 .37537 L
.4377 .37536 L
.43768 .37534 L
.43767 .37533 L
.43765 .37531 L
.43763 .3753 L
.43761 .37528 L
.4376 .37527 L
.43758 .37525 L
.43756 .37523 L
.43754 .37522 L
.43753 .3752 L
.43751 .37519 L
.43749 .37517 L
.43748 .37516 L
.43746 .37514 L
.43744 .37513 L
.43742 .37511 L
.43741 .3751 L
.43739 .37508 L
.43737 .37506 L
.43736 .37505 L
.43734 .37503 L
.43732 .37502 L
.43731 .375 L
.43729 .37499 L
.43727 .37497 L
.43726 .37496 L
.43724 .37494 L
.43722 .37492 L
.43721 .37491 L
.43719 .37489 L
.43717 .37488 L
.43716 .37486 L
.43714 .37485 L
.43713 .37483 L
.43711 .37481 L
.43709 .3748 L
.43708 .37478 L
.43706 .37477 L
.43704 .37475 L
.43703 .37474 L
.43701 .37472 L
.437 .3747 L
Mistroke
.43698 .37469 L
.43696 .37467 L
.43695 .37466 L
.43693 .37464 L
.43692 .37462 L
.4369 .37461 L
.43689 .37459 L
.43687 .37458 L
.43685 .37456 L
.43684 .37454 L
.43682 .37453 L
.43681 .37451 L
.43679 .3745 L
.43678 .37448 L
.43676 .37446 L
.43675 .37445 L
.43673 .37443 L
.43671 .37441 L
.4367 .3744 L
.43668 .37438 L
.43667 .37437 L
.43665 .37435 L
.43664 .37433 L
.43662 .37432 L
.43661 .3743 L
.43659 .37428 L
.43658 .37427 L
.43656 .37425 L
.43655 .37424 L
.43653 .37422 L
.43652 .3742 L
.4365 .37419 L
.43649 .37417 L
.43647 .37415 L
.43646 .37414 L
.43644 .37412 L
.43643 .3741 L
.43641 .37409 L
.4364 .37407 L
.43638 .37405 L
.43637 .37404 L
.43636 .37402 L
.43634 .374 L
.43633 .37399 L
.43631 .37397 L
.4363 .37396 L
.43628 .37394 L
.43627 .37392 L
.43625 .37391 L
.43624 .37389 L
Mistroke
.43623 .37387 L
.43621 .37386 L
.4362 .37384 L
.43618 .37382 L
.43617 .37381 L
.43616 .37379 L
.43614 .37377 L
.43613 .37375 L
.43611 .37374 L
.4361 .37372 L
.43609 .3737 L
.43607 .37369 L
.43606 .37367 L
.43604 .37365 L
.43603 .37364 L
.43602 .37362 L
.436 .3736 L
.43599 .37359 L
.43598 .37357 L
.43596 .37355 L
.43595 .37354 L
.43594 .37352 L
.43592 .3735 L
.43591 .37348 L
.4359 .37347 L
.43588 .37345 L
.43587 .37343 L
.43586 .37342 L
.43584 .3734 L
.43583 .37338 L
.43582 .37337 L
.4358 .37335 L
.43579 .37333 L
.43578 .37331 L
.43576 .3733 L
.43575 .37328 L
.43574 .37326 L
.43572 .37325 L
.43571 .37323 L
.4357 .37321 L
.43569 .37319 L
.43567 .37318 L
.43566 .37316 L
.43565 .37314 L
.43563 .37313 L
.43562 .37311 L
.43561 .37309 L
.4356 .37307 L
.43558 .37306 L
.43557 .37304 L
Mistroke
.43556 .37302 L
.43555 .373 L
.43553 .37299 L
.43552 .37297 L
.43551 .37295 L
.4355 .37293 L
.43548 .37292 L
.43547 .3729 L
.43546 .37288 L
.43545 .37286 L
.43543 .37285 L
.43542 .37283 L
.43541 .37281 L
.4354 .37279 L
.43539 .37278 L
.43537 .37276 L
.43536 .37274 L
.43535 .37272 L
.43534 .37271 L
.43533 .37269 L
.43531 .37267 L
.4353 .37265 L
.43529 .37264 L
.43528 .37262 L
.43527 .3726 L
.43526 .37258 L
.43524 .37257 L
.43523 .37255 L
.43522 .37253 L
.43521 .37251 L
.4352 .3725 L
.43519 .37248 L
.43517 .37246 L
.43516 .37244 L
.43515 .37242 L
.43514 .37241 L
.43513 .37239 L
.43512 .37237 L
.43511 .37235 L
.4351 .37234 L
.43508 .37232 L
.43507 .3723 L
.43506 .37228 L
.43505 .37226 L
.43504 .37225 L
.43503 .37223 L
.43502 .37221 L
.43501 .37219 L
.435 .37218 L
.43498 .37216 L
Mistroke
.43497 .37214 L
.43496 .37212 L
.43495 .3721 L
.43494 .37209 L
.43493 .37207 L
.43492 .37205 L
.43491 .37203 L
.4349 .37201 L
.43489 .372 L
.43488 .37198 L
.43487 .37196 L
.43486 .37194 L
.43485 .37192 L
.43484 .37191 L
.43483 .37189 L
.43481 .37187 L
.4348 .37185 L
.43479 .37183 L
.43478 .37182 L
.43477 .3718 L
.43476 .37178 L
.43475 .37176 L
.43474 .37174 L
.43473 .37173 L
.43472 .37171 L
.43471 .37169 L
.4347 .37167 L
.43469 .37165 L
.43468 .37163 L
.43467 .37162 L
.43466 .3716 L
.43465 .37158 L
.43464 .37156 L
.43463 .37154 L
.43462 .37153 L
.43461 .37151 L
.4346 .37149 L
.43459 .37147 L
.43458 .37145 L
.43457 .37143 L
.43457 .37142 L
.43456 .3714 L
.43455 .37138 L
.43454 .37136 L
.43453 .37134 L
.43452 .37132 L
.43451 .37131 L
.4345 .37129 L
.43449 .37127 L
.43448 .37125 L
Mistroke
.43447 .37123 L
.43446 .37121 L
.43445 .3712 L
.43444 .37118 L
.43443 .37116 L
.43442 .37114 L
.43442 .37112 L
.43441 .3711 L
.4344 .37108 L
.43439 .37107 L
.43438 .37105 L
.43437 .37103 L
.43436 .37101 L
.43435 .37099 L
.43434 .37097 L
.43434 .37096 L
.43433 .37094 L
.43432 .37092 L
.43431 .3709 L
.4343 .37088 L
.43429 .37086 L
.43428 .37084 L
.43427 .37083 L
.43427 .37081 L
.43426 .37079 L
.43425 .37077 L
.43424 .37075 L
.43423 .37073 L
.43422 .37071 L
.43421 .3707 L
.43421 .37068 L
.4342 .37066 L
.43419 .37064 L
.43418 .37062 L
.43417 .3706 L
.43417 .37058 L
.43416 .37056 L
.43415 .37055 L
.43414 .37053 L
.43413 .37051 L
.43412 .37049 L
.43412 .37047 L
.43411 .37045 L
.4341 .37043 L
.43409 .37041 L
.43408 .3704 L
.43408 .37038 L
.43407 .37036 L
.43406 .37034 L
.43405 .37032 L
Mistroke
.43405 .3703 L
.43404 .37028 L
.43403 .37026 L
.43402 .37025 L
.43401 .37023 L
.43401 .37021 L
.434 .37019 L
.43399 .37017 L
.43398 .37015 L
.43398 .37013 L
.43397 .37011 L
.43396 .3701 L
.43395 .37008 L
.43395 .37006 L
.43394 .37004 L
.43393 .37002 L
.43393 .37 L
.43392 .36998 L
.43391 .36996 L
.4339 .36994 L
.4339 .36993 L
.43389 .36991 L
.43388 .36989 L
.43388 .36987 L
.43387 .36985 L
.43386 .36983 L
.43385 .36981 L
.43385 .36979 L
.43384 .36977 L
.43383 .36975 L
.43383 .36974 L
.43382 .36972 L
.43381 .3697 L
.43381 .36968 L
.4338 .36966 L
.43379 .36964 L
.43379 .36962 L
.43378 .3696 L
.43377 .36958 L
.43377 .36956 L
.43376 .36955 L
.43375 .36953 L
.43375 .36951 L
.43374 .36949 L
.43373 .36947 L
.43373 .36945 L
.43372 .36943 L
.43371 .36941 L
.43371 .36939 L
.4337 .36937 L
Mistroke
.4337 .36935 L
.43369 .36934 L
.43368 .36932 L
.43368 .3693 L
.43367 .36928 L
.43366 .36926 L
.43366 .36924 L
.43365 .36922 L
.43365 .3692 L
.43364 .36918 L
.43363 .36916 L
.43363 .36914 L
.43362 .36913 L
.43362 .36911 L
.43361 .36909 L
.4336 .36907 L
.4336 .36905 L
.43359 .36903 L
.43359 .36901 L
.43358 .36899 L
.43358 .36897 L
.43357 .36895 L
.43356 .36893 L
.43356 .36891 L
.43355 .36889 L
.43355 .36888 L
.43354 .36886 L
.43354 .36884 L
.43353 .36882 L
.43353 .3688 L
.43352 .36878 L
.43351 .36876 L
.43351 .36874 L
.4335 .36872 L
.4335 .3687 L
.43349 .36868 L
.43349 .36866 L
.43348 .36864 L
.43348 .36863 L
.43347 .36861 L
.43347 .36859 L
.43346 .36857 L
.43346 .36855 L
.43345 .36853 L
.43345 .36851 L
.43344 .36849 L
.43344 .36847 L
.43343 .36845 L
.43343 .36843 L
.43342 .36841 L
Mistroke
.43342 .36839 L
.43341 .36837 L
.43341 .36835 L
.4334 .36834 L
.4334 .36832 L
.43339 .3683 L
.43339 .36828 L
.43338 .36826 L
.43338 .36824 L
.43337 .36822 L
.43337 .3682 L
.43337 .36818 L
.43336 .36816 L
.43336 .36814 L
.43335 .36812 L
.43335 .3681 L
.43334 .36808 L
.43334 .36806 L
.43333 .36804 L
.43333 .36803 L
.43333 .36801 L
.43332 .36799 L
.43332 .36797 L
.43331 .36795 L
.43331 .36793 L
.4333 .36791 L
.4333 .36789 L
.4333 .36787 L
.43329 .36785 L
.43329 .36783 L
.43328 .36781 L
.43328 .36779 L
.43328 .36777 L
.43327 .36775 L
.43327 .36773 L
.43326 .36771 L
.43326 .36769 L
.43326 .36767 L
.43325 .36766 L
.43325 .36764 L
.43325 .36762 L
.43324 .3676 L
.43324 .36758 L
.43323 .36756 L
.43323 .36754 L
.43323 .36752 L
.43322 .3675 L
.43322 .36748 L
.43322 .36746 L
.43321 .36744 L
Mistroke
.43321 .36742 L
.43321 .3674 L
.4332 .36738 L
.4332 .36736 L
.43319 .36734 L
.43319 .36732 L
.43319 .3673 L
.43318 .36728 L
.43318 .36727 L
.43318 .36725 L
.43317 .36723 L
.43317 .36721 L
.43317 .36719 L
.43317 .36717 L
.43316 .36715 L
.43316 .36713 L
.43316 .36711 L
.43315 .36709 L
.43315 .36707 L
.43315 .36705 L
.43314 .36703 L
.43314 .36701 L
.43314 .36699 L
.43313 .36697 L
.43313 .36695 L
.43313 .36693 L
.43313 .36691 L
.43312 .36689 L
.43312 .36687 L
.43312 .36685 L
.43312 .36684 L
.43311 .36682 L
.43311 .3668 L
.43311 .36678 L
.4331 .36676 L
.4331 .36674 L
.4331 .36672 L
.4331 .3667 L
.43309 .36668 L
.43309 .36666 L
.43309 .36664 L
.43309 .36662 L
.43308 .3666 L
.43308 .36658 L
.43308 .36656 L
.43308 .36654 L
.43307 .36652 L
.43307 .3665 L
.43307 .36648 L
.43307 .36646 L
Mistroke
.43307 .36644 L
.43306 .36642 L
.43306 .3664 L
.43306 .36638 L
.43306 .36636 L
.43306 .36635 L
.43305 .36633 L
.43305 .36631 L
.43305 .36629 L
.43305 .36627 L
.43304 .36625 L
.43304 .36623 L
.43304 .36621 L
.43304 .36619 L
.43304 .36617 L
.43304 .36615 L
.43303 .36613 L
.43303 .36611 L
.43303 .36609 L
.43303 .36607 L
.43303 .36605 L
.43302 .36603 L
.43302 .36601 L
.43302 .36599 L
.43302 .36597 L
.43302 .36595 L
.43302 .36593 L
.43302 .36591 L
.43301 .36589 L
.43301 .36587 L
.43301 .36585 L
.43301 .36583 L
.43301 .36582 L
.43301 .3658 L
.433 .36578 L
.433 .36576 L
.433 .36574 L
.433 .36572 L
.433 .3657 L
.433 .36568 L
.433 .36566 L
.433 .36564 L
.43299 .36562 L
.43299 .3656 L
.43299 .36558 L
.43299 .36556 L
.43299 .36554 L
.43299 .36552 L
.43299 .3655 L
.43299 .36548 L
Mistroke
.43299 .36546 L
.43298 .36544 L
.43298 .36542 L
.43298 .3654 L
.43298 .36538 L
.43298 .36536 L
.43298 .36534 L
.43298 .36532 L
.43298 .3653 L
.43298 .36528 L
.43298 .36527 L
.43298 .36525 L
.43298 .36523 L
.43297 .36521 L
.43297 .36519 L
.43297 .36517 L
.43297 .36515 L
.43297 .36513 L
.43297 .36511 L
.43297 .36509 L
.43297 .36507 L
.43297 .36505 L
.43297 .36503 L
.43297 .36501 L
.43297 .36499 L
.43297 .36497 L
.43297 .36495 L
.43297 .36493 L
.43297 .36491 L
.43297 .36489 L
.43297 .36487 L
.43297 .36485 L
.43297 .36483 L
.43297 .36481 L
.43297 .36479 L
.43297 .36477 L
.43297 .36475 L
.43297 .36474 L
.43297 .36472 L
.43297 .3647 L
.43297 .36468 L
.43297 .36466 L
.43297 .36464 L
.43297 .36462 L
.43297 .3646 L
.43297 .36458 L
.43297 .36456 L
.43297 .36454 L
.43297 .36452 L
.43297 .3645 L
Mistroke
.43297 .36448 L
.43297 .36446 L
.43297 .36444 L
.43297 .36442 L
.43297 .3644 L
.43297 .36438 L
.43297 .36436 L
.43297 .36434 L
.43297 .36432 L
.43297 .3643 L
.43297 .36428 L
.43297 .36426 L
.43297 .36424 L
.43297 .36423 L
.43297 .36421 L
.43297 .36419 L
.43297 .36417 L
.43297 .36415 L
.43297 .36413 L
.43297 .36411 L
.43297 .36409 L
.43297 .36407 L
.43298 .36405 L
.43298 .36403 L
.43298 .36401 L
.43298 .36399 L
.43298 .36397 L
.43298 .36395 L
.43298 .36393 L
.43298 .36391 L
.43298 .36389 L
.43298 .36387 L
.43298 .36385 L
.43298 .36383 L
.43298 .36381 L
.43299 .36379 L
.43299 .36377 L
.43299 .36376 L
.43299 .36374 L
.43299 .36372 L
.43299 .3637 L
.43299 .36368 L
.43299 .36366 L
.43299 .36364 L
.433 .36362 L
.433 .3636 L
.433 .36358 L
.433 .36356 L
.433 .36354 L
.433 .36352 L
Mistroke
.433 .3635 L
.433 .36348 L
.433 .36346 L
.43301 .36344 L
.43301 .36342 L
.43301 .3634 L
.43301 .36338 L
.43301 .36336 L
.43301 .36335 L
.43301 .36333 L
.43302 .36331 L
.43302 .36329 L
.43302 .36327 L
.43302 .36325 L
.43302 .36323 L
.43302 .36321 L
.43303 .36319 L
.43303 .36317 L
.43303 .36315 L
.43303 .36313 L
.43303 .36311 L
.43303 .36309 L
.43304 .36307 L
.43304 .36305 L
.43304 .36303 L
.43304 .36301 L
.43304 .36299 L
.43304 .36297 L
.43305 .36296 L
.43305 .36294 L
.43305 .36292 L
.43305 .3629 L
.43305 .36288 L
.43306 .36286 L
.43306 .36284 L
.43306 .36282 L
.43306 .3628 L
.43306 .36278 L
.43307 .36276 L
.43307 .36274 L
.43307 .36272 L
.43307 .3627 L
.43307 .36268 L
.43308 .36266 L
.43308 .36264 L
.43308 .36263 L
.43308 .36261 L
.43309 .36259 L
.43309 .36257 L
.43309 .36255 L
Mistroke
.43309 .36253 L
.43309 .36251 L
.4331 .36249 L
.4331 .36247 L
.4331 .36245 L
.4331 .36243 L
.43311 .36241 L
.43311 .36239 L
.43311 .36237 L
.43311 .36235 L
.43312 .36233 L
.43312 .36232 L
.43312 .3623 L
.43312 .36228 L
.43313 .36226 L
.43313 .36224 L
.43313 .36222 L
.43313 .3622 L
.43314 .36218 L
.43314 .36216 L
.43314 .36214 L
.43315 .36212 L
.43315 .3621 L
.43315 .36208 L
.43315 .36206 L
.43316 .36204 L
.43316 .36203 L
.43316 .36201 L
.43317 .36199 L
.43317 .36197 L
.43317 .36195 L
.43317 .36193 L
.43318 .36191 L
.43318 .36189 L
.43318 .36187 L
.43319 .36185 L
.43319 .36183 L
.43319 .36181 L
.4332 .36179 L
.4332 .36177 L
.4332 .36176 L
.4332 .36174 L
.43321 .36172 L
.43321 .3617 L
.43321 .36168 L
.43322 .36166 L
.43322 .36164 L
.43322 .36162 L
.43323 .3616 L
.43323 .36158 L
Mistroke
.43323 .36156 L
.43324 .36154 L
.43324 .36152 L
.43324 .36151 L
.43325 .36149 L
.43325 .36147 L
.43325 .36145 L
.43326 .36143 L
.43326 .36141 L
.43326 .36139 L
.43327 .36137 L
.43327 .36135 L
.43327 .36133 L
.43328 .36131 L
.43328 .36129 L
.43329 .36128 L
.43329 .36126 L
.43329 .36124 L
.4333 .36122 L
.4333 .3612 L
.4333 .36118 L
.43331 .36116 L
.43331 .36114 L
.43331 .36112 L
.43332 .3611 L
.43332 .36108 L
.43333 .36107 L
.43333 .36105 L
.43333 .36103 L
.43334 .36101 L
.43334 .36099 L
.43334 .36097 L
.43335 .36095 L
.43335 .36093 L
.43336 .36091 L
.43336 .36089 L
.43336 .36088 L
.43337 .36086 L
.43337 .36084 L
.43338 .36082 L
.43338 .3608 L
.43338 .36078 L
.43339 .36076 L
.43339 .36074 L
.4334 .36072 L
.4334 .3607 L
.43341 .36069 L
.43341 .36067 L
.43341 .36065 L
.43342 .36063 L
Mistroke
.43342 .36061 L
.43343 .36059 L
.43343 .36057 L
.43343 .36055 L
.43344 .36053 L
.43344 .36051 L
.43345 .3605 L
.43345 .36048 L
.43346 .36046 L
.43346 .36044 L
.43346 .36042 L
.43347 .3604 L
.43347 .36038 L
.43348 .36036 L
.43348 .36034 L
.43349 .36033 L
.43349 .36031 L
.4335 .36029 L
.4335 .36027 L
.43351 .36025 L
.43351 .36023 L
.43351 .36021 L
.43352 .36019 L
.43352 .36017 L
.43353 .36016 L
.43353 .36014 L
.43354 .36012 L
.43354 .3601 L
.43355 .36008 L
.43355 .36006 L
.43356 .36004 L
.43356 .36002 L
.43357 .36001 L
.43357 .35999 L
.43358 .35997 L
.43358 .35995 L
.43359 .35993 L
.43359 .35991 L
.4336 .35989 L
.4336 .35987 L
.4336 .35986 L
.43361 .35984 L
.43361 .35982 L
.43362 .3598 L
.43362 .35978 L
.43363 .35976 L
.43363 .35974 L
.43364 .35972 L
.43364 .35971 L
.43365 .35969 L
Mistroke
.43365 .35967 L
.43366 .35965 L
.43367 .35963 L
.43367 .35961 L
.43368 .35959 L
.43368 .35957 L
.43369 .35956 L
.43369 .35954 L
.4337 .35952 L
.4337 .3595 L
.43371 .35948 L
.43371 .35946 L
.43372 .35944 L
.43372 .35943 L
.43373 .35941 L
.43373 .35939 L
.43374 .35937 L
.43374 .35935 L
.43375 .35933 L
.43375 .35931 L
.43376 .3593 L
.43377 .35928 L
.43377 .35926 L
.43378 .35924 L
.43378 .35922 L
.43379 .3592 L
.43379 .35918 L
.4338 .35917 L
.4338 .35915 L
.43381 .35913 L
.43381 .35911 L
.43382 .35909 L
.43383 .35907 L
.43383 .35905 L
.43384 .35904 L
.43384 .35902 L
.43385 .359 L
.43385 .35898 L
.43386 .35896 L
.43387 .35894 L
.43387 .35893 L
.43388 .35891 L
.43388 .35889 L
.43389 .35887 L
.43389 .35885 L
.4339 .35883 L
.43391 .35882 L
.43391 .3588 L
.43392 .35878 L
.43392 .35876 L
Mistroke
.43393 .35874 L
.43394 .35872 L
.43394 .35871 L
.43395 .35869 L
.43395 .35867 L
.43396 .35865 L
.43397 .35863 L
.43397 .35861 L
.43398 .3586 L
.43398 .35858 L
.43399 .35856 L
.434 .35854 L
.434 .35852 L
.43401 .3585 L
.43401 .35849 L
.43402 .35847 L
.43403 .35845 L
.43403 .35843 L
.43404 .35841 L
.43404 .35839 L
.43405 .35838 L
.43406 .35836 L
.43406 .35834 L
.43407 .35832 L
.43408 .3583 L
.43408 .35829 L
.43409 .35827 L
.43409 .35825 L
.4341 .35823 L
.43411 .35821 L
.43411 .35819 L
.43412 .35818 L
.43413 .35816 L
.43413 .35814 L
.43414 .35812 L
.43414 .3581 L
.43415 .35809 L
.43416 .35807 L
.43416 .35805 L
.43417 .35803 L
.43418 .35801 L
.43418 .358 L
.43419 .35798 L
.4342 .35796 L
.4342 .35794 L
.43421 .35792 L
.43422 .3579 L
.43422 .35789 L
.43423 .35787 L
.43424 .35785 L
Mistroke
.43424 .35783 L
.43425 .35781 L
.43426 .3578 L
.43426 .35778 L
.43427 .35776 L
.43428 .35774 L
.43428 .35772 L
.43429 .35771 L
.4343 .35769 L
.4343 .35767 L
.43431 .35765 L
.43432 .35764 L
.43432 .35762 L
.43433 .3576 L
.43434 .35758 L
.43434 .35756 L
.43435 .35755 L
.43436 .35753 L
.43436 .35751 L
.43437 .35749 L
.43438 .35747 L
.43439 .35746 L
.43439 .35744 L
.4344 .35742 L
.43441 .3574 L
.43441 .35739 L
.43442 .35737 L
.43443 .35735 L
.43443 .35733 L
.43444 .35731 L
.43445 .3573 L
.43446 .35728 L
.43446 .35726 L
.43447 .35724 L
.43448 .35723 L
.43448 .35721 L
.43449 .35719 L
.4345 .35717 L
.43451 .35715 L
.43451 .35714 L
.43452 .35712 L
.43453 .3571 L
.43453 .35708 L
.43454 .35707 L
.43455 .35705 L
.43456 .35703 L
.43456 .35701 L
.43457 .357 L
.43458 .35698 L
.43458 .35696 L
Mistroke
.43459 .35694 L
.4346 .35692 L
.43461 .35691 L
.43461 .35689 L
.43462 .35687 L
.43463 .35685 L
.43464 .35684 L
.43464 .35682 L
.43465 .3568 L
.43466 .35678 L
.43467 .35677 L
.43467 .35675 L
.43468 .35673 L
.43469 .35671 L
.4347 .3567 L
.4347 .35668 L
.43471 .35666 L
.43472 .35664 L
.43473 .35663 L
.43473 .35661 L
.43474 .35659 L
.43475 .35657 L
.43476 .35656 L
.43476 .35654 L
.43477 .35652 L
.43478 .3565 L
.43479 .35649 L
.43479 .35647 L
.4348 .35645 L
.43481 .35644 L
.43482 .35642 L
.43483 .3564 L
.43483 .35638 L
.43484 .35637 L
.43485 .35635 L
.43486 .35633 L
.43486 .35631 L
.43487 .3563 L
.43488 .35628 L
.43489 .35626 L
.4349 .35624 L
.4349 .35623 L
.43491 .35621 L
.43492 .35619 L
.43493 .35618 L
.43493 .35616 L
.43494 .35614 L
.43495 .35612 L
.43496 .35611 L
.43497 .35609 L
Mistroke
.43497 .35607 L
.43498 .35606 L
.43499 .35604 L
.435 .35602 L
.43501 .356 L
.43501 .35599 L
.43502 .35597 L
.43503 .35595 L
.43504 .35594 L
.43505 .35592 L
.43505 .3559 L
.43506 .35588 L
.43507 .35587 L
.43508 .35585 L
.43509 .35583 L
.4351 .35582 L
.4351 .3558 L
.43511 .35578 L
.43512 .35576 L
.43513 .35575 L
.43514 .35573 L
.43514 .35571 L
.43515 .3557 L
.43516 .35568 L
.43517 .35566 L
.43518 .35565 L
.43519 .35563 L
.43519 .35561 L
.4352 .35559 L
.43521 .35558 L
.43522 .35556 L
.43523 .35554 L
.43524 .35553 L
.43524 .35551 L
.43525 .35549 L
.43526 .35548 L
.43527 .35546 L
.43528 .35544 L
.43529 .35543 L
.43529 .35541 L
.4353 .35539 L
.43531 .35537 L
.43532 .35536 L
.43533 .35534 L
.43534 .35532 L
.43534 .35531 L
.43535 .35529 L
.43536 .35527 L
.43537 .35526 L
.43538 .35524 L
Mistroke
.43539 .35522 L
.4354 .35521 L
.4354 .35519 L
.43541 .35517 L
.43542 .35516 L
.43543 .35514 L
.43544 .35512 L
.43545 .35511 L
.43546 .35509 L
.43546 .35507 L
.43547 .35506 L
.43548 .35504 L
.43549 .35502 L
.4355 .35501 L
.43551 .35499 L
.43552 .35497 L
.43552 .35496 L
.43553 .35494 L
.43554 .35492 L
.43555 .35491 L
.43556 .35489 L
.43557 .35487 L
.43558 .35486 L
.43559 .35484 L
.43559 .35482 L
.4356 .35481 L
.43561 .35479 L
.43562 .35478 L
.43563 .35476 L
.43564 .35474 L
.43565 .35473 L
.43566 .35471 L
.43567 .35469 L
.43567 .35468 L
.43568 .35466 L
.43569 .35464 L
.4357 .35463 L
.43571 .35461 L
.43572 .35459 L
.43573 .35458 L
.43574 .35456 L
.43575 .35455 L
.43575 .35453 L
.43576 .35451 L
.43577 .3545 L
.43578 .35448 L
.43579 .35446 L
.4358 .35445 L
.43581 .35443 L
.43582 .35441 L
Mistroke
.43583 .3544 L
.43584 .35438 L
.43585 .35437 L
.43585 .35435 L
.43586 .35433 L
.43587 .35432 L
.43588 .3543 L
.43589 .35428 L
.4359 .35427 L
.43591 .35425 L
.43592 .35424 L
.43593 .35422 L
.43594 .3542 L
.43595 .35419 L
.43595 .35417 L
.43596 .35416 L
.43597 .35414 L
.43598 .35412 L
.43599 .35411 L
.436 .35409 L
.43601 .35408 L
.43602 .35406 L
.43603 .35404 L
.43604 .35403 L
.43605 .35401 L
.43606 .35399 L
.43607 .35398 L
.43608 .35396 L
.43608 .35395 L
.43609 .35393 L
.4361 .35392 L
.43611 .3539 L
.43612 .35388 L
.43613 .35387 L
.43614 .35385 L
.43615 .35384 L
.43616 .35382 L
.43617 .3538 L
.43618 .35379 L
.43619 .35377 L
.4362 .35376 L
.43621 .35374 L
.43622 .35372 L
.43623 .35371 L
.43624 .35369 L
.43624 .35368 L
.43625 .35366 L
.43626 .35364 L
.43627 .35363 L
.43628 .35361 L
Mistroke
.43629 .3536 L
.4363 .35358 L
.43631 .35357 L
.43632 .35355 L
.43633 .35353 L
.43634 .35352 L
.43635 .3535 L
.43636 .35349 L
.43637 .35347 L
.43638 .35346 L
.43639 .35344 L
.4364 .35342 L
.43641 .35341 L
.43642 .35339 L
.43643 .35338 L
.43644 .35336 L
.43645 .35335 L
.43646 .35333 L
.43647 .35332 L
.43648 .3533 L
.43648 .35328 L
.43649 .35327 L
.4365 .35325 L
.43651 .35324 L
.43652 .35322 L
.43653 .35321 L
.43654 .35319 L
.43655 .35318 L
.43656 .35316 L
.43657 .35314 L
.43658 .35313 L
.43659 .35311 L
.4366 .3531 L
.43661 .35308 L
.43662 .35307 L
.43663 .35305 L
.43664 .35304 L
.43665 .35302 L
.43666 .35301 L
.43667 .35299 L
.43668 .35297 L
.43669 .35296 L
.4367 .35294 L
.43671 .35293 L
.43672 .35291 L
.43673 .3529 L
.43674 .35288 L
.43675 .35287 L
.43676 .35285 L
.43677 .35284 L
Mistroke
.43678 .35282 L
.43679 .35281 L
.4368 .35279 L
.43681 .35278 L
.43682 .35276 L
.43683 .35275 L
.43684 .35273 L
.43685 .35272 L
.43686 .3527 L
.43687 .35268 L
.43688 .35267 L
.43689 .35265 L
.4369 .35264 L
.43691 .35262 L
.43692 .35261 L
.43693 .35259 L
.43694 .35258 L
.43695 .35256 L
.43696 .35255 L
.43697 .35253 L
.43698 .35252 L
.43699 .3525 L
.437 .35249 L
.43701 .35247 L
.43702 .35246 L
.43703 .35244 L
.43704 .35243 L
.43705 .35241 L
.43706 .3524 L
.43707 .35238 L
.43708 .35237 L
.43709 .35235 L
.4371 .35234 L
.43711 .35232 L
.43712 .35231 L
.43713 .35229 L
.43714 .35228 L
.43715 .35226 L
.43716 .35225 L
.43717 .35223 L
.43718 .35222 L
.4372 .35221 L
.43721 .35219 L
.43722 .35218 L
.43723 .35216 L
.43724 .35215 L
.43725 .35213 L
.43726 .35212 L
.43727 .3521 L
.43728 .35209 L
Mistroke
.43729 .35207 L
.4373 .35206 L
.43731 .35204 L
.43732 .35203 L
.43733 .35201 L
.43734 .352 L
.43735 .35198 L
.43736 .35197 L
.43737 .35195 L
.43738 .35194 L
.43739 .35193 L
.4374 .35191 L
.43741 .3519 L
.43742 .35188 L
.43743 .35187 L
.43744 .35185 L
.43745 .35184 L
.43746 .35182 L
.43748 .35181 L
.43749 .35179 L
.4375 .35178 L
.43751 .35177 L
.43752 .35175 L
.43753 .35174 L
.43754 .35172 L
.43755 .35171 L
.43756 .35169 L
.43757 .35168 L
.43758 .35166 L
.43759 .35165 L
.4376 .35164 L
.43761 .35162 L
.43762 .35161 L
.43763 .35159 L
.43764 .35158 L
.43765 .35156 L
.43766 .35155 L
.43768 .35153 L
.43769 .35152 L
.4377 .35151 L
.43771 .35149 L
.43772 .35148 L
.43773 .35146 L
.43774 .35145 L
.43775 .35143 L
.43776 .35142 L
.43777 .35141 L
.43778 .35139 L
.43779 .35138 L
.4378 .35136 L
Mistroke
.43781 .35135 L
.43782 .35134 L
.43783 .35132 L
.43785 .35131 L
.43786 .35129 L
.43787 .35128 L
.43788 .35126 L
.43789 .35125 L
.4379 .35124 L
.43791 .35122 L
.43792 .35121 L
.43793 .35119 L
.43794 .35118 L
.43795 .35117 L
.43796 .35115 L
.43797 .35114 L
.43798 .35112 L
.438 .35111 L
.43801 .3511 L
.43802 .35108 L
.43803 .35107 L
.43804 .35105 L
.43805 .35104 L
.43806 .35103 L
.43807 .35101 L
.43808 .351 L
.43809 .35098 L
.4381 .35097 L
.43811 .35096 L
.43813 .35094 L
.43814 .35093 L
.43815 .35092 L
.43816 .3509 L
.43817 .35089 L
.43818 .35087 L
.43819 .35086 L
.4382 .35085 L
.43821 .35083 L
.43822 .35082 L
.43823 .3508 L
.43824 .35079 L
.43826 .35078 L
.43827 .35076 L
.43828 .35075 L
.43829 .35074 L
.4383 .35072 L
.43831 .35071 L
.43832 .3507 L
.43833 .35068 L
.43834 .35067 L
Mistroke
.43835 .35065 L
.43836 .35064 L
.43838 .35063 L
.43839 .35061 L
.4384 .3506 L
.43841 .35059 L
.43842 .35057 L
.43843 .35056 L
.43844 .35055 L
.43845 .35053 L
.43846 .35052 L
.43847 .35051 L
.43849 .35049 L
.4385 .35048 L
.43851 .35046 L
.43852 .35045 L
.43853 .35044 L
.43854 .35042 L
.43855 .35041 L
.43856 .3504 L
.43857 .35038 L
.43859 .35037 L
.4386 .35036 L
.43861 .35034 L
.43862 .35033 L
.43863 .35032 L
.43864 .3503 L
.43865 .35029 L
.43866 .35028 L
.43867 .35026 L
.43868 .35025 L
.4387 .35024 L
.43871 .35022 L
.43872 .35021 L
.43873 .3502 L
.43874 .35018 L
.43875 .35017 L
.43876 .35016 L
.43877 .35014 L
.43878 .35013 L
.4388 .35012 L
.43881 .35011 L
.43882 .35009 L
.43883 .35008 L
.43884 .35007 L
.43885 .35005 L
.43886 .35004 L
.43887 .35003 L
.43889 .35001 L
.4389 .35 L
Mistroke
.43891 .34999 L
.43892 .34997 L
.43893 .34996 L
.43894 .34995 L
.43895 .34994 L
.43896 .34992 L
.43897 .34991 L
.43899 .3499 L
.439 .34988 L
.43901 .34987 L
.43902 .34986 L
.43903 .34984 L
.43904 .34983 L
.43905 .34982 L
.43906 .34981 L
.43908 .34979 L
.43909 .34978 L
.4391 .34977 L
.43911 .34975 L
.43912 .34974 L
.43913 .34973 L
.43914 .34972 L
.43915 .3497 L
.43917 .34969 L
.43918 .34968 L
.43919 .34966 L
.4392 .34965 L
.43921 .34964 L
.43922 .34963 L
.43923 .34961 L
.43925 .3496 L
.43926 .34959 L
.43927 .34958 L
.43928 .34956 L
.43929 .34955 L
.4393 .34954 L
.43931 .34952 L
.43932 .34951 L
.43934 .3495 L
.43935 .34949 L
.43936 .34947 L
.43937 .34946 L
.43938 .34945 L
.43939 .34944 L
.4394 .34942 L
.43942 .34941 L
.43943 .3494 L
.43944 .34939 L
.43945 .34937 L
.43946 .34936 L
Mistroke
.43947 .34935 L
.43948 .34934 L
.43949 .34932 L
.43951 .34931 L
.43952 .3493 L
.43953 .34929 L
.43954 .34927 L
.43955 .34926 L
.43956 .34925 L
.43957 .34924 L
.43959 .34922 L
.4396 .34921 L
.43961 .3492 L
.43962 .34919 L
.43963 .34918 L
.43964 .34916 L
.43965 .34915 L
.43967 .34914 L
.43968 .34913 L
.43969 .34911 L
.4397 .3491 L
.43971 .34909 L
.43972 .34908 L
.43973 .34907 L
.43975 .34905 L
.43976 .34904 L
.43977 .34903 L
.43978 .34902 L
.43979 .349 L
.4398 .34899 L
.43982 .34898 L
.43983 .34897 L
.43984 .34896 L
.43985 .34894 L
.43986 .34893 L
.43987 .34892 L
.43988 .34891 L
.4399 .3489 L
.43991 .34888 L
.43992 .34887 L
.43993 .34886 L
.43994 .34885 L
.43995 .34884 L
.43996 .34882 L
.43998 .34881 L
.43999 .3488 L
.44 .34879 L
.44001 .34878 L
.44002 .34876 L
.44003 .34875 L
Mistroke
.44005 .34874 L
.44006 .34873 L
.44007 .34872 L
.44008 .3487 L
.44009 .34869 L
.4401 .34868 L
.44011 .34867 L
.44013 .34866 L
.44014 .34864 L
.44015 .34863 L
.44016 .34862 L
.44017 .34861 L
.44018 .3486 L
.4402 .34859 L
.44021 .34857 L
.44022 .34856 L
.44023 .34855 L
.44024 .34854 L
.44025 .34853 L
.44027 .34852 L
.44028 .3485 L
.44029 .34849 L
.4403 .34848 L
.44031 .34847 L
.44032 .34846 L
.44033 .34845 L
.44035 .34843 L
.44036 .34842 L
.44037 .34841 L
.44038 .3484 L
.44039 .34839 L
.4404 .34838 L
.44042 .34836 L
.44043 .34835 L
.44044 .34834 L
.44045 .34833 L
.44046 .34832 L
.44047 .34831 L
.44049 .3483 L
.4405 .34828 L
.44051 .34827 L
.44052 .34826 L
.44053 .34825 L
.44054 .34824 L
.44056 .34823 L
.44057 .34822 L
.44058 .3482 L
.44059 .34819 L
.4406 .34818 L
.44061 .34817 L
Mistroke
.44063 .34816 L
.44064 .34815 L
.44065 .34814 L
.44066 .34813 L
.44067 .34811 L
.44068 .3481 L
.4407 .34809 L
.44071 .34808 L
.44072 .34807 L
.44073 .34806 L
.44074 .34805 L
.44075 .34804 L
.44077 .34802 L
.44078 .34801 L
.44079 .348 L
.4408 .34799 L
.44081 .34798 L
.44082 .34797 L
.44084 .34796 L
.44085 .34795 L
.44086 .34794 L
.44087 .34792 L
.44088 .34791 L
.44089 .3479 L
.44091 .34789 L
.44092 .34788 L
.44093 .34787 L
.44094 .34786 L
.44095 .34785 L
.44096 .34784 L
.44098 .34783 L
.44099 .34781 L
.441 .3478 L
.44101 .34779 L
.44102 .34778 L
.44103 .34777 L
.44105 .34776 L
.44106 .34775 L
.44107 .34774 L
.44108 .34773 L
.44109 .34772 L
.4411 .34771 L
.44112 .34769 L
.44113 .34768 L
.44114 .34767 L
.44115 .34766 L
.44116 .34765 L
.44118 .34764 L
.44119 .34763 L
.4412 .34762 L
Mistroke
.44121 .34761 L
.44122 .3476 L
.44123 .34759 L
.44125 .34758 L
.44126 .34757 L
.44127 .34756 L
.44128 .34754 L
.44129 .34753 L
.4413 .34752 L
.44132 .34751 L
.44133 .3475 L
.44134 .34749 L
.44135 .34748 L
.44136 .34747 L
.44137 .34746 L
.44139 .34745 L
.4414 .34744 L
.44141 .34743 L
.44142 .34742 L
.44143 .34741 L
.44145 .3474 L
.44146 .34739 L
.44147 .34738 L
.44148 .34736 L
.44149 .34735 L
.4415 .34734 L
.44152 .34733 L
.44153 .34732 L
.44154 .34731 L
.44155 .3473 L
.44156 .34729 L
.44157 .34728 L
.44159 .34727 L
.4416 .34726 L
.44161 .34725 L
.44162 .34724 L
.44163 .34723 L
.44165 .34722 L
.44166 .34721 L
.44167 .3472 L
.44168 .34719 L
.44169 .34718 L
.4417 .34717 L
.44172 .34716 L
.44173 .34715 L
.44174 .34714 L
.44175 .34713 L
.44176 .34712 L
.44177 .34711 L
.44179 .3471 L
Mistroke
.4418 .34709 L
.44181 .34708 L
.44182 .34707 L
.44183 .34706 L
.44185 .34705 L
.44186 .34704 L
.44187 .34703 L
.44188 .34702 L
.44189 .34701 L
.4419 .347 L
.44192 .34699 L
.44193 .34698 L
.44194 .34697 L
.44195 .34696 L
.44196 .34695 L
.44198 .34694 L
.44199 .34693 L
.442 .34692 L
.44201 .34691 L
.44202 .3469 L
.44203 .34689 L
.44205 .34688 L
.44206 .34687 L
.44207 .34686 L
.44208 .34685 L
.44209 .34684 L
.4421 .34683 L
.44212 .34682 L
.44213 .34681 L
.44214 .3468 L
.44215 .34679 L
.44216 .34678 L
.44218 .34677 L
.44219 .34676 L
.4422 .34675 L
.44221 .34674 L
.44222 .34673 L
.44223 .34672 L
.44225 .34671 L
.44226 .3467 L
.44227 .34669 L
.44228 .34668 L
.44229 .34667 L
.44231 .34666 L
.44232 .34665 L
.44233 .34664 L
.44234 .34663 L
.44235 .34662 L
.44236 .34661 L
.44238 .3466 L
Mistroke
.44239 .34659 L
.4424 .34659 L
.44241 .34658 L
.44242 .34657 L
.44243 .34656 L
.44245 .34655 L
.44246 .34654 L
.44247 .34653 L
.44248 .34652 L
.44249 .34651 L
.44251 .3465 L
.44252 .34649 L
.44253 .34648 L
.44254 .34647 L
.44255 .34646 L
.44256 .34645 L
.44258 .34644 L
.44259 .34643 L
.4426 .34642 L
.44261 .34642 L
.44262 .34641 L
.44264 .3464 L
.44265 .34639 L
.44266 .34638 L
.44267 .34637 L
.44268 .34636 L
.44269 .34635 L
.44271 .34634 L
.44272 .34633 L
.44273 .34632 L
.44274 .34631 L
.44275 .3463 L
.44276 .3463 L
.44278 .34629 L
.44279 .34628 L
.4428 .34627 L
.44281 .34626 L
.44282 .34625 L
.44284 .34624 L
.44285 .34623 L
.44286 .34622 L
.44287 .34621 L
.44288 .3462 L
.44289 .34619 L
.44291 .34619 L
.44292 .34618 L
.44293 .34617 L
.44294 .34616 L
.44295 .34615 L
.44296 .34614 L
Mistroke
.44298 .34613 L
.44299 .34612 L
.443 .34611 L
.44301 .3461 L
.44302 .3461 L
.44304 .34609 L
.44305 .34608 L
.44306 .34607 L
.44307 .34606 L
.44308 .34605 L
.44309 .34604 L
.44311 .34603 L
.44312 .34603 L
.44313 .34602 L
.44314 .34601 L
.44315 .346 L
.44316 .34599 L
.44318 .34598 L
.44319 .34597 L
.4432 .34596 L
.44321 .34595 L
.44322 .34595 L
.44323 .34594 L
.44325 .34593 L
.44326 .34592 L
.44327 .34591 L
.44328 .3459 L
.44329 .34589 L
.44331 .34589 L
.44332 .34588 L
.44333 .34587 L
.44334 .34586 L
.44335 .34585 L
.44336 .34584 L
.44338 .34583 L
.44339 .34583 L
.4434 .34582 L
.44341 .34581 L
.44342 .3458 L
.44343 .34579 L
.44345 .34578 L
.44346 .34577 L
.44347 .34577 L
.44348 .34576 L
.44349 .34575 L
.4435 .34574 L
.44352 .34573 L
.44353 .34572 L
.44354 .34571 L
.44355 .34571 L
Mistroke
.44356 .3457 L
.44357 .34569 L
.44359 .34568 L
.4436 .34567 L
.44361 .34566 L
.44362 .34566 L
.44363 .34565 L
.44364 .34564 L
.44366 .34563 L
.44367 .34562 L
.44368 .34561 L
.44369 .34561 L
.4437 .3456 L
.44371 .34559 L
.44373 .34558 L
.44374 .34557 L
.44375 .34557 L
.44376 .34556 L
.44377 .34555 L
.44378 .34554 L
.4438 .34553 L
.44381 .34552 L
.44382 .34552 L
.44383 .34551 L
.44384 .3455 L
.44385 .34549 L
.44387 .34548 L
.44388 .34548 L
.44389 .34547 L
.4439 .34546 L
.44391 .34545 L
.44392 .34544 L
.44394 .34544 L
.44395 .34543 L
.44396 .34542 L
.44397 .34541 L
.44398 .3454 L
.44399 .3454 L
.44401 .34539 L
.44402 .34538 L
.44403 .34537 L
.44404 .34536 L
.44405 .34536 L
.44406 .34535 L
.44408 .34534 L
.44409 .34533 L
.4441 .34532 L
.44411 .34532 L
.44412 .34531 L
.44413 .3453 L
Mistroke
.44415 .34529 L
.44416 .34529 L
.44417 .34528 L
.44418 .34527 L
.44419 .34526 L
.4442 .34525 L
.44422 .34525 L
.44423 .34524 L
.44424 .34523 L
.44425 .34522 L
.44426 .34522 L
.44427 .34521 L
.44429 .3452 L
.4443 .34519 L
.44431 .34518 L
.44432 .34518 L
.44433 .34517 L
.44434 .34516 L
.44435 .34515 L
.44437 .34515 L
.44438 .34514 L
.44439 .34513 L
.4444 .34512 L
.44441 .34512 L
.44442 .34511 L
.44444 .3451 L
.44445 .34509 L
.44446 .34509 L
.44447 .34508 L
.44448 .34507 L
.44449 .34506 L
.4445 .34506 L
.44452 .34505 L
.44453 .34504 L
.44454 .34503 L
.44455 .34503 L
.44456 .34502 L
.44457 .34501 L
.44459 .345 L
.4446 .345 L
.44461 .34499 L
.44462 .34498 L
.44463 .34497 L
.44464 .34497 L
.44465 .34496 L
.44467 .34495 L
.44468 .34495 L
.44469 .34494 L
.4447 .34493 L
.44471 .34492 L
Mistroke
.44472 .34492 L
.44474 .34491 L
.44475 .3449 L
.44476 .34489 L
.44477 .34489 L
.44478 .34488 L
.44479 .34487 L
.4448 .34487 L
.44482 .34486 L
.44483 .34485 L
.44484 .34484 L
.44485 .34484 L
.44486 .34483 L
.44487 .34482 L
.44488 .34482 L
.4449 .34481 L
.44491 .3448 L
.44492 .3448 L
.44493 .34479 L
.44494 .34478 L
.44495 .34477 L
.44496 .34477 L
.44498 .34476 L
.44499 .34475 L
.445 .34475 L
.44501 .34474 L
.44502 .34473 L
.44503 .34473 L
.44504 .34472 L
.44506 .34471 L
.44507 .3447 L
.44508 .3447 L
.44509 .34469 L
.4451 .34468 L
.44511 .34468 L
.44512 .34467 L
.44514 .34466 L
.44515 .34466 L
.44516 .34465 L
.44517 .34464 L
.44518 .34464 L
.44519 .34463 L
.4452 .34462 L
.44522 .34462 L
.44523 .34461 L
.44524 .3446 L
.44525 .3446 L
.44526 .34459 L
.44527 .34458 L
.44528 .34458 L
Mistroke
.4453 .34457 L
.44531 .34456 L
.44532 .34455 L
.44533 .34455 L
.44534 .34454 L
.44535 .34454 L
.44536 .34453 L
.44537 .34452 L
.44539 .34452 L
.4454 .34451 L
.44541 .3445 L
.44542 .3445 L
.44543 .34449 L
.44544 .34448 L
.44545 .34448 L
.44547 .34447 L
.44548 .34446 L
.44549 .34446 L
.4455 .34445 L
.44551 .34444 L
.44552 .34444 L
.44553 .34443 L
.44554 .34442 L
.44556 .34442 L
.44557 .34441 L
.44558 .3444 L
.44559 .3444 L
.4456 .34439 L
.44561 .34439 L
.44562 .34438 L
.44563 .34437 L
.44565 .34437 L
.44566 .34436 L
.44567 .34435 L
.44568 .34435 L
.44569 .34434 L
.4457 .34433 L
.44571 .34433 L
.44572 .34432 L
.44574 .34432 L
.44575 .34431 L
.44576 .3443 L
.44577 .3443 L
.44578 .34429 L
.44579 .34428 L
.4458 .34428 L
.44581 .34427 L
.44583 .34427 L
.44584 .34426 L
.44585 .34425 L
Mistroke
.44586 .34425 L
.44587 .34424 L
.44588 .34424 L
.44589 .34423 L
.4459 .34422 L
.44592 .34422 L
.44593 .34421 L
.44594 .34421 L
.44595 .3442 L
.44596 .34419 L
.44597 .34419 L
.44598 .34418 L
.44599 .34418 L
.446 .34417 L
.44602 .34416 L
.44603 .34416 L
.44604 .34415 L
.44605 .34415 L
.44606 .34414 L
.44607 .34413 L
.44608 .34413 L
.44609 .34412 L
.4461 .34412 L
.44612 .34411 L
.44613 .3441 L
.44614 .3441 L
.44615 .34409 L
.44616 .34409 L
.44617 .34408 L
.44618 .34407 L
.44619 .34407 L
.4462 .34406 L
.44622 .34406 L
.44623 .34405 L
.44624 .34405 L
.44625 .34404 L
.44626 .34403 L
.44627 .34403 L
.44628 .34402 L
.44629 .34402 L
.4463 .34401 L
.44632 .34401 L
.44633 .344 L
.44634 .34399 L
.44635 .34399 L
.44636 .34398 L
.44637 .34398 L
.44638 .34397 L
.44639 .34397 L
.4464 .34396 L
Mistroke
.44641 .34395 L
.44643 .34395 L
.44644 .34394 L
.44645 .34394 L
.44646 .34393 L
.44647 .34393 L
.44648 .34392 L
.44649 .34392 L
.4465 .34391 L
.44651 .3439 L
.44652 .3439 L
.44654 .34389 L
.44655 .34389 L
.44656 .34388 L
.44657 .34388 L
.44658 .34387 L
.44659 .34387 L
.4466 .34386 L
.44661 .34386 L
.44662 .34385 L
.44663 .34384 L
.44664 .34384 L
.44666 .34383 L
.44667 .34383 L
.44668 .34382 L
.44669 .34382 L
.4467 .34381 L
.44671 .34381 L
.44672 .3438 L
.44673 .3438 L
.44674 .34379 L
.44675 .34379 L
.44676 .34378 L
.44678 .34378 L
.44679 .34377 L
.4468 .34377 L
.44681 .34376 L
.44682 .34376 L
.44683 .34375 L
.44684 .34374 L
.44685 .34374 L
.44686 .34373 L
.44687 .34373 L
.44688 .34372 L
.44689 .34372 L
.44691 .34371 L
.44692 .34371 L
.44693 .3437 L
.44694 .3437 L
.44695 .34369 L
Mistroke
.44696 .34369 L
.44697 .34368 L
.44698 .34368 L
.44699 .34367 L
.447 .34367 L
.44701 .34366 L
.44702 .34366 L
.44703 .34365 L
.44705 .34365 L
.44706 .34364 L
.44707 .34364 L
.44708 .34363 L
.44709 .34363 L
.4471 .34362 L
.44711 .34362 L
.44712 .34361 L
.44713 .34361 L
.44714 .3436 L
.44715 .3436 L
.44716 .34359 L
.44717 .34359 L
.44719 .34358 L
.4472 .34358 L
.44721 .34357 L
.44722 .34357 L
.44723 .34357 L
.44724 .34356 L
.44725 .34356 L
.44726 .34355 L
.44727 .34355 L
.44728 .34354 L
.44729 .34354 L
.4473 .34353 L
.44731 .34353 L
.44732 .34352 L
.44733 .34352 L
.44735 .34351 L
.44736 .34351 L
.44737 .3435 L
.44738 .3435 L
.44739 .34349 L
.4474 .34349 L
.44741 .34348 L
.44742 .34348 L
.44743 .34348 L
.44744 .34347 L
.44745 .34347 L
.44746 .34346 L
.44747 .34346 L
.44748 .34345 L
Mistroke
.44749 .34345 L
.4475 .34344 L
.44751 .34344 L
.44753 .34343 L
.44754 .34343 L
.44755 .34343 L
.44756 .34342 L
.44757 .34342 L
.44758 .34341 L
.44759 .34341 L
.4476 .3434 L
.44761 .3434 L
.44762 .34339 L
.44763 .34339 L
.44764 .34339 L
.44765 .34338 L
.44766 .34338 L
.44767 .34337 L
.44768 .34337 L
.44769 .34336 L
.4477 .34336 L
.44771 .34335 L
.44772 .34335 L
.44774 .34335 L
.44775 .34334 L
.44776 .34334 L
.44777 .34333 L
.44778 .34333 L
.44779 .34332 L
.4478 .34332 L
.44781 .34332 L
.44782 .34331 L
.44783 .34331 L
.44784 .3433 L
.44785 .3433 L
.44786 .3433 L
.44787 .34329 L
.44788 .34329 L
.44789 .34328 L
.4479 .34328 L
.44791 .34327 L
.44792 .34327 L
.44793 .34327 L
.44794 .34326 L
.44795 .34326 L
.44796 .34325 L
.44797 .34325 L
.44798 .34325 L
.44799 .34324 L
.44801 .34324 L
Mistroke
.44802 .34323 L
.44803 .34323 L
.44804 .34323 L
.44805 .34322 L
.44806 .34322 L
.44807 .34321 L
.44808 .34321 L
.44809 .34321 L
.4481 .3432 L
.44811 .3432 L
.44812 .34319 L
.44813 .34319 L
.44814 .34319 L
.44815 .34318 L
.44816 .34318 L
.44817 .34317 L
.44818 .34317 L
.44819 .34317 L
.4482 .34316 L
.44821 .34316 L
.44822 .34315 L
.44823 .34315 L
.44824 .34315 L
.44825 .34314 L
.44826 .34314 L
.44827 .34314 L
.44828 .34313 L
.44829 .34313 L
.4483 .34312 L
.44831 .34312 L
.44832 .34312 L
.44833 .34311 L
.44834 .34311 L
.44835 .34311 L
.44836 .3431 L
.44837 .3431 L
.44838 .34309 L
.44839 .34309 L
.4484 .34309 L
.44841 .34308 L
.44842 .34308 L
.44843 .34308 L
.44844 .34307 L
.44845 .34307 L
.44846 .34307 L
.44847 .34306 L
.44848 .34306 L
.44849 .34305 L
.4485 .34305 L
.44851 .34305 L
Mistroke
.44852 .34304 L
.44853 .34304 L
.44854 .34304 L
.44855 .34303 L
.44856 .34303 L
.44857 .34303 L
.44858 .34302 L
.44859 .34302 L
.4486 .34302 L
.44861 .34301 L
.44862 .34301 L
.44863 .34301 L
.44864 .343 L
.44865 .343 L
.44866 .343 L
.44867 .34299 L
.44868 .34299 L
.44869 .34299 L
.4487 .34298 L
.44871 .34298 L
.44872 .34298 L
.44873 .34297 L
.44874 .34297 L
.44875 .34297 L
.44876 .34296 L
.44877 .34296 L
.44878 .34296 L
.44879 .34295 L
.4488 .34295 L
.44881 .34295 L
.44882 .34294 L
.44883 .34294 L
.44884 .34294 L
.44885 .34293 L
.44886 .34293 L
.44887 .34293 L
.44888 .34292 L
.44889 .34292 L
.4489 .34292 L
.44891 .34291 L
.44892 .34291 L
.44893 .34291 L
.44894 .3429 L
.44895 .3429 L
.44896 .3429 L
.44897 .34289 L
.44898 .34289 L
.44899 .34289 L
.449 .34288 L
.44901 .34288 L
Mistroke
.44902 .34288 L
.44903 .34288 L
.44904 .34287 L
.44905 .34287 L
.44906 .34287 L
.44907 .34286 L
.44908 .34286 L
.44909 .34286 L
.4491 .34285 L
.44911 .34285 L
.44912 .34285 L
.44913 .34285 L
.44914 .34284 L
.44915 .34284 L
.44916 .34284 L
.44917 .34283 L
.44918 .34283 L
.44919 .34283 L
.44919 .34283 L
.4492 .34282 L
.44921 .34282 L
.44922 .34282 L
.44923 .34281 L
.44924 .34281 L
.44925 .34281 L
.44926 .34281 L
.44927 .3428 L
.44928 .3428 L
.44929 .3428 L
.4493 .34279 L
.44931 .34279 L
.44932 .34279 L
.44933 .34279 L
.44934 .34278 L
.44935 .34278 L
.44936 .34278 L
.44937 .34277 L
.44938 .34277 L
.44939 .34277 L
.4494 .34277 L
.44941 .34276 L
.44942 .34276 L
.44942 .34276 L
.44943 .34276 L
.44944 .34275 L
.44945 .34275 L
.44946 .34275 L
.44947 .34274 L
.44948 .34274 L
.44949 .34274 L
Mistroke
.4495 .34274 L
.44951 .34273 L
.44952 .34273 L
.44953 .34273 L
.44954 .34273 L
.44955 .34272 L
.44956 .34272 L
.44957 .34272 L
.44958 .34272 L
.44959 .34271 L
.4496 .34271 L
.4496 .34271 L
.44961 .34271 L
.44962 .3427 L
.44963 .3427 L
.44964 .3427 L
.44965 .3427 L
.44966 .34269 L
.44967 .34269 L
.44968 .34269 L
.44969 .34269 L
.4497 .34268 L
.44971 .34268 L
.44972 .34268 L
.44973 .34268 L
.44974 .34267 L
.44974 .34267 L
.44975 .34267 L
.44976 .34267 L
.44977 .34267 L
.44978 .34266 L
.44979 .34266 L
.4498 .34266 L
.44981 .34266 L
.44982 .34265 L
.44983 .34265 L
.44984 .34265 L
.44985 .34265 L
.44986 .34264 L
.44987 .34264 L
.44987 .34264 L
.44988 .34264 L
.44989 .34264 L
.4499 .34263 L
.44991 .34263 L
.44992 .34263 L
.44993 .34263 L
.44994 .34262 L
.44995 .34262 L
.44996 .34262 L
Mistroke
.44997 .34262 L
.44998 .34262 L
.44998 .34261 L
.44999 .34261 L
.45 .34261 L
.45001 .34261 L
.45002 .34261 L
.45003 .3426 L
.45004 .3426 L
.45005 .3426 L
.45006 .3426 L
.45007 .3426 L
.45008 .34259 L
.45009 .34259 L
.45009 .34259 L
.4501 .34259 L
.45011 .34258 L
.45012 .34258 L
.45013 .34258 L
.45014 .34258 L
.45015 .34258 L
.45016 .34257 L
.45017 .34257 L
.45018 .34257 L
.45018 .34257 L
.45019 .34257 L
.4502 .34257 L
.45021 .34256 L
.45022 .34256 L
.45023 .34256 L
.45024 .34256 L
.45025 .34256 L
.45026 .34255 L
.45027 .34255 L
.45027 .34255 L
.45028 .34255 L
.45029 .34255 L
.4503 .34254 L
.45031 .34254 L
.45032 .34254 L
.45033 .34254 L
.45034 .34254 L
.45035 .34254 L
.45035 .34253 L
.45036 .34253 L
.45037 .34253 L
.45038 .34253 L
.45039 .34253 L
.4504 .34252 L
.45041 .34252 L
Mistroke
.45042 .34252 L
.45043 .34252 L
.45043 .34252 L
.45044 .34252 L
.45045 .34251 L
.45046 .34251 L
.45047 .34251 L
.45048 .34251 L
.45049 .34251 L
.4505 .34251 L
.4505 .3425 L
.45051 .3425 L
.45052 .3425 L
.45053 .3425 L
.45054 .3425 L
.45055 .3425 L
.45056 .34249 L
.45057 .34249 L
.45057 .34249 L
.45058 .34249 L
.45059 .34249 L
.4506 .34249 L
.45061 .34249 L
.45062 .34248 L
.45063 .34248 L
.45064 .34248 L
.45064 .34248 L
.45065 .34248 L
.45066 .34248 L
.45067 .34248 L
.45068 .34247 L
.45069 .34247 L
.4507 .34247 L
.4507 .34247 L
.45071 .34247 L
.45072 .34247 L
.45073 .34246 L
.45074 .34246 L
.45075 .34246 L
.45076 .34246 L
.45077 .34246 L
.45077 .34246 L
.45078 .34246 L
.45079 .34246 L
.4508 .34245 L
.45081 .34245 L
.45082 .34245 L
.45083 .34245 L
.45083 .34245 L
.45084 .34245 L
Mistroke
.45085 .34245 L
.45086 .34244 L
.45087 .34244 L
.45088 .34244 L
.45088 .34244 L
.45089 .34244 L
.4509 .34244 L
.45091 .34244 L
.45092 .34244 L
.45093 .34243 L
.45094 .34243 L
.45094 .34243 L
.45095 .34243 L
.45096 .34243 L
.45097 .34243 L
.45098 .34243 L
.45099 .34243 L
.45099 .34242 L
.451 .34242 L
.45101 .34242 L
.45102 .34242 L
.45103 .34242 L
.45104 .34242 L
.45104 .34242 L
.45105 .34242 L
.45106 .34242 L
.45107 .34241 L
.45108 .34241 L
.45109 .34241 L
.45109 .34241 L
.4511 .34241 L
.45111 .34241 L
.45112 .34241 L
.45113 .34241 L
.45114 .34241 L
.45114 .34241 L
.45115 .3424 L
.45116 .3424 L
.45117 .3424 L
.45118 .3424 L
.45119 .3424 L
.45119 .3424 L
.4512 .3424 L
.45121 .3424 L
.45122 .3424 L
.45123 .3424 L
.45124 .34239 L
.45124 .34239 L
.45125 .34239 L
.45126 .34239 L
Mistroke
.45127 .34239 L
.45128 .34239 L
.45128 .34239 L
.45129 .34239 L
.4513 .34239 L
.45131 .34239 L
.45132 .34239 L
.45132 .34238 L
.45133 .34238 L
.45134 .34238 L
.45135 .34238 L
.45136 .34238 L
.45137 .34238 L
.45137 .34238 L
.45138 .34238 L
.45139 .34238 L
.4514 .34238 L
.45141 .34238 L
.45141 .34238 L
.45142 .34238 L
.45143 .34237 L
.45144 .34237 L
.45145 .34237 L
.45145 .34237 L
.45146 .34237 L
.45147 .34237 L
.45148 .34237 L
.45149 .34237 L
.45149 .34237 L
.4515 .34237 L
.45151 .34237 L
.45152 .34237 L
.45153 .34237 L
.45153 .34237 L
.45154 .34236 L
.45155 .34236 L
.45156 .34236 L
.45157 .34236 L
.45157 .34236 L
.45158 .34236 L
.45159 .34236 L
.4516 .34236 L
.45161 .34236 L
.45161 .34236 L
.45162 .34236 L
.45163 .34236 L
.45164 .34236 L
.45164 .34236 L
.45165 .34236 L
.45166 .34236 L
Mistroke
.45167 .34236 L
.45168 .34235 L
.45168 .34235 L
.45169 .34235 L
.4517 .34235 L
.45171 .34235 L
.45171 .34235 L
.45172 .34235 L
.45173 .34235 L
.45174 .34235 L
.45175 .34235 L
.45175 .34235 L
.45176 .34235 L
.45177 .34235 L
.45178 .34235 L
.45178 .34235 L
.45179 .34235 L
.4518 .34235 L
.45181 .34235 L
.45182 .34235 L
.45182 .34235 L
.45183 .34235 L
.45184 .34235 L
.45185 .34235 L
.45185 .34235 L
.45186 .34234 L
.45187 .34234 L
.45188 .34234 L
.45188 .34234 L
.45189 .34234 L
.4519 .34234 L
.45191 .34234 L
.45191 .34234 L
.45192 .34234 L
.45193 .34234 L
.45194 .34234 L
.45195 .34234 L
.45195 .34234 L
.45196 .34234 L
.45197 .34234 L
.45198 .34234 L
.45198 .34234 L
.45199 .34234 L
.452 .34234 L
.45201 .34234 L
.45201 .34234 L
.45202 .34234 L
.45203 .34234 L
.45204 .34234 L
.45204 .34234 L
Mistroke
.45205 .34234 L
.45206 .34234 L
.45207 .34234 L
.45207 .34234 L
.45208 .34234 L
.45209 .34234 L
.4521 .34234 L
.4521 .34234 L
.45211 .34234 L
.45212 .34234 L
.45213 .34234 L
.45213 .34234 L
.45214 .34234 L
.45215 .34234 L
.45215 .34234 L
.45216 .34234 L
.45217 .34234 L
.45218 .34234 L
.45218 .34234 L
.45219 .34234 L
.4522 .34234 L
.45221 .34234 L
.45221 .34234 L
.45222 .34234 L
.45223 .34234 L
.45224 .34234 L
.45224 .34234 L
.45225 .34234 L
.45226 .34234 L
.45226 .34234 L
.45227 .34234 L
.45228 .34234 L
.45229 .34234 L
.45229 .34234 L
.4523 .34234 L
.45231 .34234 L
.45232 .34234 L
.45232 .34234 L
.45233 .34234 L
.45234 .34234 L
.45234 .34234 L
.45235 .34234 L
.45236 .34234 L
.45237 .34234 L
.45237 .34234 L
.45238 .34234 L
.45239 .34234 L
.45239 .34234 L
.4524 .34234 L
.45241 .34234 L
Mistroke
.45242 .34234 L
.45242 .34234 L
.45243 .34234 L
.45244 .34234 L
.45244 .34234 L
.45245 .34234 L
.45246 .34234 L
.45247 .34234 L
.45247 .34234 L
.45248 .34234 L
.45249 .34234 L
.45249 .34234 L
.4525 .34234 L
.45251 .34234 L
.45251 .34234 L
.45252 .34234 L
.45253 .34234 L
.45254 .34234 L
.45254 .34235 L
.45255 .34235 L
.45256 .34235 L
.45256 .34235 L
.45257 .34235 L
.45258 .34235 L
.45258 .34235 L
.45259 .34235 L
.4526 .34235 L
.45261 .34235 L
.45261 .34235 L
.45262 .34235 L
.45263 .34235 L
.45263 .34235 L
.45264 .34235 L
.45265 .34235 L
.45265 .34235 L
.45266 .34235 L
.45267 .34235 L
.45267 .34235 L
.45268 .34235 L
.45269 .34235 L
.45269 .34235 L
.4527 .34235 L
.45271 .34235 L
.45272 .34236 L
.45272 .34236 L
.45273 .34236 L
.45274 .34236 L
.45274 .34236 L
.45275 .34236 L
.45276 .34236 L
Mistroke
.45276 .34236 L
.45277 .34236 L
.45278 .34236 L
.45278 .34236 L
.45279 .34236 L
.4528 .34236 L
.4528 .34236 L
.45281 .34236 L
.45282 .34236 L
.45282 .34236 L
.45283 .34236 L
.45284 .34237 L
.45284 .34237 L
.45285 .34237 L
.45286 .34237 L
.45286 .34237 L
.45287 .34237 L
.45288 .34237 L
.45288 .34237 L
.45289 .34237 L
.4529 .34237 L
.4529 .34237 L
.45291 .34237 L
.45292 .34237 L
.45292 .34237 L
.45293 .34237 L
.45294 .34238 L
.45294 .34238 L
.45295 .34238 L
.45296 .34238 L
.45296 .34238 L
.45297 .34238 L
.45298 .34238 L
.45298 .34238 L
.45299 .34238 L
.45299 .34238 L
.453 .34238 L
.45301 .34238 L
.45301 .34238 L
.45302 .34238 L
.45303 .34239 L
.45303 .34239 L
.45304 .34239 L
.45305 .34239 L
.45305 .34239 L
.45306 .34239 L
.45307 .34239 L
.45307 .34239 L
.45308 .34239 L
.45309 .34239 L
Mistroke
.45309 .34239 L
.4531 .34239 L
.4531 .3424 L
.45311 .3424 L
.45312 .3424 L
.45312 .3424 L
.45313 .3424 L
.45314 .3424 L
.45314 .3424 L
.45315 .3424 L
.45316 .3424 L
.45316 .3424 L
.45317 .3424 L
.45317 .34241 L
.45318 .34241 L
.45319 .34241 L
.45319 .34241 L
.4532 .34241 L
.45321 .34241 L
.45321 .34241 L
.45322 .34241 L
.45322 .34241 L
.45323 .34241 L
.45324 .34242 L
.45324 .34242 L
.45325 .34242 L
.45326 .34242 L
.45326 .34242 L
.45327 .34242 L
.45327 .34242 L
.45328 .34242 L
.45329 .34242 L
.45329 .34242 L
.4533 .34243 L
.45331 .34243 L
.45331 .34243 L
.45332 .34243 L
.45332 .34243 L
.45333 .34243 L
.45334 .34243 L
.45334 .34243 L
.45335 .34243 L
.45335 .34244 L
.45336 .34244 L
.45337 .34244 L
.45337 .34244 L
.45338 .34244 L
.45338 .34244 L
.45339 .34244 L
.4534 .34244 L
Mistroke
.4534 .34244 L
.45341 .34245 L
.45341 .34245 L
.45342 .34245 L
.45343 .34245 L
.45343 .34245 L
.45344 .34245 L
.45344 .34245 L
.45345 .34245 L
.45346 .34245 L
.45346 .34246 L
.45347 .34246 L
.45347 .34246 L
.45348 .34246 L
.45349 .34246 L
.45349 .34246 L
.4535 .34246 L
.4535 .34246 L
.45351 .34247 L
.45352 .34247 L
.45352 .34247 L
.45353 .34247 L
.45353 .34247 L
.45354 .34247 L
.45355 .34247 L
.45355 .34247 L
.45356 .34248 L
.45356 .34248 L
.45357 .34248 L
.45357 .34248 L
.45358 .34248 L
.45359 .34248 L
.45359 .34248 L
.4536 .34249 L
.4536 .34249 L
.45361 .34249 L
.45362 .34249 L
.45362 .34249 L
.45363 .34249 L
.45363 .34249 L
.45364 .34249 L
.45364 .3425 L
.45365 .3425 L
.45366 .3425 L
.45366 .3425 L
.45367 .3425 L
.45367 .3425 L
.45368 .3425 L
.45368 .34251 L
.45369 .34251 L
Mistroke
.4537 .34251 L
.4537 .34251 L
.45371 .34251 L
.45371 .34251 L
.45372 .34251 L
.45372 .34252 L
.45373 .34252 L
.45374 .34252 L
.45374 .34252 L
.45375 .34252 L
.45375 .34252 L
.45376 .34252 L
.45376 .34253 L
.45377 .34253 L
.45377 .34253 L
.45378 .34253 L
.45379 .34253 L
.45379 .34253 L
.4538 .34254 L
.4538 .34254 L
.45381 .34254 L
.45381 .34254 L
.45382 .34254 L
.45382 .34254 L
.45383 .34254 L
.45384 .34255 L
.45384 .34255 L
.45385 .34255 L
.45385 .34255 L
.45386 .34255 L
.45386 .34255 L
.45387 .34256 L
.45387 .34256 L
.45388 .34256 L
.45388 .34256 L
.45389 .34256 L
.4539 .34256 L
.4539 .34257 L
.45391 .34257 L
.45391 .34257 L
.45392 .34257 L
.45392 .34257 L
.45393 .34257 L
.45393 .34258 L
.45394 .34258 L
.45394 .34258 L
.45395 .34258 L
.45395 .34258 L
.45396 .34258 L
.45396 .34259 L
Mistroke
.45397 .34259 L
.45398 .34259 L
.45398 .34259 L
.45399 .34259 L
.45399 .34259 L
.454 .3426 L
.454 .3426 L
.45401 .3426 L
.45401 .3426 L
.45402 .3426 L
.45402 .3426 L
.45403 .34261 L
.45403 .34261 L
.45404 .34261 L
.45404 .34261 L
.45405 .34261 L
.45405 .34262 L
.45406 .34262 L
.45406 .34262 L
.45407 .34262 L
.45407 .34262 L
.45408 .34262 L
.45409 .34263 L
.45409 .34263 L
.4541 .34263 L
.4541 .34263 L
.45411 .34263 L
.45411 .34264 L
.45412 .34264 L
.45412 .34264 L
.45413 .34264 L
.45413 .34264 L
.45414 .34264 L
.45414 .34265 L
.45415 .34265 L
.45415 .34265 L
.45416 .34265 L
.45416 .34265 L
.45417 .34266 L
.45417 .34266 L
.45418 .34266 L
.45418 .34266 L
.45419 .34266 L
.45419 .34267 L
.4542 .34267 L
.4542 .34267 L
.45421 .34267 L
.45421 .34267 L
.45422 .34267 L
.45422 .34268 L
Mistroke
.45423 .34268 L
.45423 .34268 L
.45424 .34268 L
.45424 .34268 L
.45425 .34269 L
.45425 .34269 L
.45426 .34269 L
.45426 .34269 L
.45427 .34269 L
.45427 .3427 L
.45428 .3427 L
.45428 .3427 L
.45429 .3427 L
.45429 .3427 L
.4543 .34271 L
.4543 .34271 L
.45431 .34271 L
.45431 .34271 L
.45431 .34271 L
.45432 .34272 L
.45432 .34272 L
.45433 .34272 L
.45433 .34272 L
.45434 .34272 L
.45434 .34273 L
.45435 .34273 L
.45435 .34273 L
.45436 .34273 L
.45436 .34273 L
.45437 .34274 L
.45437 .34274 L
.45438 .34274 L
.45438 .34274 L
.45439 .34275 L
.45439 .34275 L
.4544 .34275 L
.4544 .34275 L
.45441 .34275 L
.45441 .34276 L
.45441 .34276 L
.45442 .34276 L
.45442 .34276 L
.45443 .34276 L
.45443 .34277 L
.45444 .34277 L
.45444 .34277 L
.45445 .34277 L
.45445 .34278 L
.45446 .34278 L
.45446 .34278 L
Mistroke
.45447 .34278 L
.45447 .34278 L
.45447 .34279 L
.45448 .34279 L
.45448 .34279 L
.45449 .34279 L
.45449 .34279 L
.4545 .3428 L
.4545 .3428 L
.45451 .3428 L
.45451 .3428 L
.45452 .34281 L
.45452 .34281 L
.45452 .34281 L
.45453 .34281 L
.45453 .34281 L
.45454 .34282 L
.45454 .34282 L
.45455 .34282 L
.45455 .34282 L
.45456 .34283 L
.45456 .34283 L
.45456 .34283 L
.45457 .34283 L
.45457 .34284 L
.45458 .34284 L
.45458 .34284 L
.45459 .34284 L
.45459 .34284 L
.4546 .34285 L
.4546 .34285 L
.4546 .34285 L
.45461 .34285 L
.45461 .34286 L
.45462 .34286 L
.45462 .34286 L
.45463 .34286 L
.45463 .34287 L
.45463 .34287 L
.45464 .34287 L
.45464 .34287 L
.45465 .34287 L
.45465 .34288 L
.45466 .34288 L
.45466 .34288 L
.45466 .34288 L
.45467 .34289 L
.45467 .34289 L
.45468 .34289 L
.45468 .34289 L
Mistroke
.45469 .3429 L
.45469 .3429 L
.45469 .3429 L
.4547 .3429 L
.4547 .34291 L
.45471 .34291 L
.45471 .34291 L
.45472 .34291 L
.45472 .34292 L
.45472 .34292 L
.45473 .34292 L
.45473 .34292 L
.45474 .34293 L
.45474 .34293 L
.45474 .34293 L
.45475 .34293 L
.45475 .34293 L
.45476 .34294 L
.45476 .34294 L
.45477 .34294 L
.45477 .34294 L
.45477 .34295 L
.45478 .34295 L
.45478 .34295 L
.45479 .34295 L
.45479 .34296 L
.45479 .34296 L
.4548 .34296 L
.4548 .34296 L
.45481 .34297 L
.45481 .34297 L
.45481 .34297 L
.45482 .34297 L
.45482 .34298 L
.45483 .34298 L
.45483 .34298 L
.45483 .34298 L
.45484 .34299 L
.45484 .34299 L
.45485 .34299 L
.45485 .34299 L
.45485 .343 L
.45486 .343 L
.45486 .343 L
.45487 .34301 L
.45487 .34301 L
.45487 .34301 L
.45488 .34301 L
.45488 .34302 L
.45489 .34302 L
Mistroke
.45489 .34302 L
.45489 .34302 L
.4549 .34303 L
.4549 .34303 L
.4549 .34303 L
.45491 .34303 L
.45491 .34304 L
.45492 .34304 L
.45492 .34304 L
.45492 .34304 L
.45493 .34305 L
.45493 .34305 L
.45494 .34305 L
.45494 .34305 L
.45494 .34306 L
.45495 .34306 L
.45495 .34306 L
.45495 .34307 L
.45496 .34307 L
.45496 .34307 L
.45497 .34307 L
.45497 .34308 L
.45497 .34308 L
.45498 .34308 L
.45498 .34308 L
.45498 .34309 L
.45499 .34309 L
.45499 .34309 L
.455 .34309 L
.455 .3431 L
.455 .3431 L
.45501 .3431 L
.45501 .34311 L
.45501 .34311 L
.45502 .34311 L
.45502 .34311 L
.45502 .34312 L
.45503 .34312 L
.45503 .34312 L
.45504 .34312 L
.45504 .34313 L
.45504 .34313 L
.45505 .34313 L
.45505 .34314 L
.45505 .34314 L
.45506 .34314 L
.45506 .34314 L
.45506 .34315 L
.45507 .34315 L
.45507 .34315 L
Mistroke
.45508 .34315 L
.45508 .34316 L
.45508 .34316 L
.45509 .34316 L
.45509 .34317 L
.45509 .34317 L
.4551 .34317 L
.4551 .34317 L
.4551 .34318 L
.45511 .34318 L
.45511 .34318 L
.45511 .34319 L
.45512 .34319 L
.45512 .34319 L
.45512 .34319 L
.45513 .3432 L
.45513 .3432 L
.45513 .3432 L
.45514 .3432 L
.45514 .34321 L
.45514 .34321 L
.45515 .34321 L
.45515 .34322 L
.45515 .34322 L
.45516 .34322 L
.45516 .34322 L
.45516 .34323 L
.45517 .34323 L
.45517 .34323 L
.45518 .34324 L
.45518 .34324 L
.45518 .34324 L
.45519 .34324 L
.45519 .34325 L
.45519 .34325 L
.45519 .34325 L
.4552 .34326 L
.4552 .34326 L
.4552 .34326 L
.45521 .34327 L
.45521 .34327 L
.45521 .34327 L
.45522 .34327 L
.45522 .34328 L
.45522 .34328 L
.45523 .34328 L
.45523 .34329 L
.45523 .34329 L
.45524 .34329 L
.45524 .34329 L
Mistroke
.45524 .3433 L
.45525 .3433 L
.45525 .3433 L
.45525 .34331 L
.45526 .34331 L
.45526 .34331 L
.45526 .34331 L
.45527 .34332 L
.45527 .34332 L
.45527 .34332 L
.45528 .34333 L
.45528 .34333 L
.45528 .34333 L
.45528 .34334 L
.45529 .34334 L
.45529 .34334 L
.45529 .34334 L
.4553 .34335 L
.4553 .34335 L
.4553 .34335 L
.45531 .34336 L
.45531 .34336 L
.45531 .34336 L
.45532 .34337 L
.45532 .34337 L
.45532 .34337 L
.45532 .34337 L
.45533 .34338 L
.45533 .34338 L
.45533 .34338 L
.45534 .34339 L
.45534 .34339 L
.45534 .34339 L
.45535 .3434 L
.45535 .3434 L
.45535 .3434 L
.45535 .3434 L
.45536 .34341 L
.45536 .34341 L
.45536 .34341 L
.45537 .34342 L
.45537 .34342 L
.45537 .34342 L
.45538 .34343 L
.45538 .34343 L
.45538 .34343 L
.45538 .34344 L
.45539 .34344 L
.45539 .34344 L
.45539 .34344 L
Mistroke
.4554 .34345 L
.4554 .34345 L
.4554 .34345 L
.4554 .34346 L
.45541 .34346 L
.45541 .34346 L
.45541 .34347 L
.45542 .34347 L
.45542 .34347 L
.45542 .34348 L
.45542 .34348 L
.45543 .34348 L
.45543 .34348 L
.45543 .34349 L
.45544 .34349 L
.45544 .34349 L
.45544 .3435 L
.45544 .3435 L
.45545 .3435 L
.45545 .34351 L
.45545 .34351 L
.45545 .34351 L
.45546 .34352 L
.45546 .34352 L
.45546 .34352 L
.45547 .34353 L
.45547 .34353 L
.45547 .34353 L
.45547 .34353 L
.45548 .34354 L
.45548 .34354 L
.45548 .34354 L
.45548 .34355 L
.45549 .34355 L
.45549 .34355 L
.45549 .34356 L
.45549 .34356 L
.4555 .34356 L
.4555 .34357 L
.4555 .34357 L
.45551 .34357 L
.45551 .34358 L
.45551 .34358 L
.45551 .34358 L
.45552 .34359 L
.45552 .34359 L
.45552 .34359 L
.45552 .3436 L
.45553 .3436 L
.45553 .3436 L
Mistroke
.45553 .3436 L
.45553 .34361 L
.45554 .34361 L
.45554 .34361 L
.45554 .34362 L
.45554 .34362 L
.45555 .34362 L
.45555 .34363 L
.45555 .34363 L
.45555 .34363 L
.45556 .34364 L
.45556 .34364 L
.45556 .34364 L
.45556 .34365 L
.45557 .34365 L
.45557 .34365 L
.45557 .34366 L
.45557 .34366 L
.45558 .34366 L
.45558 .34367 L
.45558 .34367 L
.45558 .34367 L
.45559 .34368 L
.45559 .34368 L
.45559 .34368 L
.45559 .34369 L
.4556 .34369 L
.4556 .34369 L
.4556 .3437 L
.4556 .3437 L
.4556 .3437 L
.45561 .34371 L
.45561 .34371 L
.45561 .34371 L
.45561 .34372 L
.45562 .34372 L
.45562 .34372 L
.45562 .34373 L
.45562 .34373 L
.45563 .34373 L
.45563 .34374 L
.45563 .34374 L
.45563 .34374 L
.45563 .34375 L
.45564 .34375 L
.45564 .34375 L
.45564 .34376 L
.45564 .34376 L
.45565 .34376 L
.45565 .34377 L
Mistroke
.45565 .34377 L
.45565 .34377 L
.45566 .34378 L
.45566 .34378 L
.45566 .34378 L
.45566 .34379 L
.45566 .34379 L
.45567 .34379 L
.45567 .3438 L
.45567 .3438 L
.45567 .3438 L
.45567 .34381 L
.45568 .34381 L
.45568 .34381 L
.45568 .34382 L
.45568 .34382 L
.45569 .34382 L
.45569 .34383 L
.45569 .34383 L
.45569 .34383 L
.45569 .34384 L
.4557 .34384 L
.4557 .34384 L
.4557 .34385 L
.4557 .34385 L
.4557 .34385 L
.45571 .34386 L
.45571 .34386 L
.45571 .34386 L
.45571 .34387 L
.45571 .34387 L
.45572 .34387 L
.45572 .34388 L
.45572 .34388 L
.45572 .34388 L
.45573 .34389 L
.45573 .34389 L
.45573 .34389 L
.45573 .3439 L
.45573 .3439 L
.45574 .3439 L
.45574 .34391 L
.45574 .34391 L
.45574 .34391 L
.45574 .34392 L
.45574 .34392 L
.45575 .34392 L
.45575 .34393 L
.45575 .34393 L
.45575 .34393 L
Mistroke
.45575 .34394 L
.45576 .34394 L
.45576 .34394 L
.45576 .34395 L
.45576 .34395 L
.45576 .34395 L
.45577 .34396 L
.45577 .34396 L
.45577 .34397 L
.45577 .34397 L
.45577 .34397 L
.45578 .34398 L
.45578 .34398 L
.45578 .34398 L
.45578 .34399 L
.45578 .34399 L
.45578 .34399 L
.45579 .344 L
.45579 .344 L
.45579 .344 L
.45579 .34401 L
.45579 .34401 L
.4558 .34401 L
.4558 .34402 L
.4558 .34402 L
.4558 .34402 L
.4558 .34403 L
.4558 .34403 L
.45581 .34403 L
.45581 .34404 L
.45581 .34404 L
.45581 .34404 L
.45581 .34405 L
.45581 .34405 L
.45582 .34406 L
.45582 .34406 L
.45582 .34406 L
.45582 .34407 L
.45582 .34407 L
.45583 .34407 L
.45583 .34408 L
.45583 .34408 L
.45583 .34408 L
.45583 .34409 L
.45583 .34409 L
.45584 .34409 L
.45584 .3441 L
.45584 .3441 L
.45584 .3441 L
.45584 .34411 L
Mistroke
.45584 .34411 L
.45584 .34411 L
.45585 .34412 L
.45585 .34412 L
.45585 .34413 L
.45585 .34413 L
.45585 .34413 L
.45585 .34414 L
.45586 .34414 L
.45586 .34414 L
.45586 .34415 L
.45586 .34415 L
.45586 .34415 L
.45586 .34416 L
.45587 .34416 L
.45587 .34416 L
.45587 .34417 L
.45587 .34417 L
.45587 .34417 L
.45587 .34418 L
.45587 .34418 L
.45588 .34419 L
.45588 .34419 L
.45588 .34419 L
.45588 .3442 L
.45588 .3442 L
.45588 .3442 L
.45588 .34421 L
.45589 .34421 L
.45589 .34421 L
.45589 .34422 L
.45589 .34422 L
.45589 .34422 L
.45589 .34423 L
.4559 .34423 L
.4559 .34424 L
.4559 .34424 L
.4559 .34424 L
.4559 .34425 L
.4559 .34425 L
.4559 .34425 L
.4559 .34426 L
.45591 .34426 L
.45591 .34426 L
.45591 .34427 L
.45591 .34427 L
.45591 .34427 L
.45591 .34428 L
.45591 .34428 L
.45592 .34429 L
Mistroke
.45592 .34429 L
.45592 .34429 L
.45592 .3443 L
.45592 .3443 L
.45592 .3443 L
.45592 .34431 L
.45593 .34431 L
.45593 .34431 L
.45593 .34432 L
.45593 .34432 L
.45593 .34433 L
.45593 .34433 L
.45593 .34433 L
.45593 .34434 L
.45594 .34434 L
.45594 .34434 L
.45594 .34435 L
.45594 .34435 L
.45594 .34435 L
.45594 .34436 L
.45594 .34436 L
.45594 .34436 L
.45595 .34437 L
.45595 .34437 L
.45595 .34438 L
.45595 .34438 L
.45595 .34438 L
.45595 .34439 L
.45595 .34439 L
.45595 .34439 L
.45595 .3444 L
.45596 .3444 L
.45596 .3444 L
.45596 .34441 L
.45596 .34441 L
.45596 .34442 L
.45596 .34442 L
.45596 .34442 L
.45596 .34443 L
.45596 .34443 L
.45597 .34443 L
.45597 .34444 L
.45597 .34444 L
.45597 .34444 L
.45597 .34445 L
.45597 .34445 L
.45597 .34446 L
.45597 .34446 L
.45597 .34446 L
.45598 .34447 L
Mistroke
.45598 .34447 L
.45598 .34447 L
.45598 .34448 L
.45598 .34448 L
.45598 .34448 L
.45598 .34449 L
.45598 .34449 L
.45598 .3445 L
.45598 .3445 L
.45599 .3445 L
.45599 .34451 L
.45599 .34451 L
.45599 .34451 L
.45599 .34452 L
.45599 .34452 L
.45599 .34453 L
.45599 .34453 L
.45599 .34453 L
.45599 .34454 L
.456 .34454 L
.456 .34454 L
.456 .34455 L
.456 .34455 L
.456 .34455 L
.456 .34456 L
.456 .34456 L
.456 .34457 L
.456 .34457 L
.456 .34457 L
.456 .34458 L
.45601 .34458 L
.45601 .34458 L
.45601 .34459 L
.45601 .34459 L
.45601 .34459 L
.45601 .3446 L
.45601 .3446 L
.45601 .34461 L
.45601 .34461 L
.45601 .34461 L
.45601 .34462 L
.45602 .34462 L
.45602 .34462 L
.45602 .34463 L
.45602 .34463 L
.45602 .34464 L
.45602 .34464 L
.45602 .34464 L
.45602 .34465 L
.45602 .34465 L
Mistroke
.45602 .34465 L
.45602 .34466 L
.45602 .34466 L
.45602 .34467 L
.45603 .34467 L
.45603 .34467 L
.45603 .34468 L
.45603 .34468 L
.45603 .34468 L
.45603 .34469 L
.45603 .34469 L
.45603 .34469 L
.45603 .3447 L
.45603 .3447 L
.45603 .34471 L
.45603 .34471 L
.45603 .34471 L
.45604 .34472 L
.45604 .34472 L
.45604 .34472 L
.45604 .34473 L
.45604 .34473 L
.45604 .34474 L
.45604 .34474 L
.45604 .34474 L
.45604 .34475 L
.45604 .34475 L
.45604 .34475 L
.45604 .34476 L
.45604 .34476 L
.45604 .34477 L
.45604 .34477 L
.45604 .34477 L
.45605 .34478 L
.45605 .34478 L
.45605 .34478 L
.45605 .34479 L
.45605 .34479 L
.45605 .3448 L
.45605 .3448 L
.45605 .3448 L
.45605 .34481 L
.45605 .34481 L
.45605 .34481 L
.45605 .34482 L
.45605 .34482 L
.45605 .34482 L
.45605 .34483 L
.45605 .34483 L
.45605 .34484 L
Mistroke
.45606 .34484 L
.45606 .34484 L
.45606 .34485 L
.45606 .34485 L
.45606 .34485 L
.45606 .34486 L
.45606 .34486 L
.45606 .34487 L
.45606 .34487 L
.45606 .34487 L
.45606 .34488 L
.45606 .34488 L
.45606 .34488 L
.45606 .34489 L
.45606 .34489 L
.45606 .3449 L
.45606 .3449 L
.45606 .3449 L
.45606 .34491 L
.45606 .34491 L
.45606 .34491 L
.45607 .34492 L
.45607 .34492 L
.45607 .34493 L
.45607 .34493 L
.45607 .34493 L
.45607 .34494 L
.45607 .34494 L
.45607 .34494 L
.45607 .34495 L
.45607 .34495 L
.45607 .34496 L
.45607 .34496 L
.45607 .34496 L
.45607 .34497 L
.45607 .34497 L
.45607 .34497 L
.45607 .34498 L
.45607 .34498 L
.45607 .34499 L
.45607 .34499 L
.45607 .34499 L
.45607 .345 L
.45607 .345 L
.45607 .345 L
.45607 .34501 L
.45607 .34501 L
.45607 .34502 L
.45607 .34502 L
.45607 .34502 L
Mistroke
.45608 .34503 L
.45608 .34503 L
.45608 .34503 L
.45608 .34504 L
.45608 .34504 L
.45608 .34505 L
.45608 .34505 L
.45608 .34505 L
.45608 .34506 L
.45608 .34506 L
.45608 .34506 L
.45608 .34507 L
.45608 .34507 L
.45608 .34508 L
.45608 .34508 L
.45608 .34508 L
.45608 .34509 L
.45608 .34509 L
.45608 .34509 L
.45608 .3451 L
.45608 .3451 L
.45608 .34511 L
.45608 .34511 L
.45608 .34511 L
.45608 .34512 L
.45608 .34512 L
.45608 .34512 L
.45608 .34513 L
.45608 .34513 L
.45608 .34514 L
.45608 .34514 L
.45608 .34514 L
.45608 .34515 L
.45608 .34515 L
.45608 .34515 L
.45608 .34516 L
.45608 .34516 L
.45608 .34517 L
.45608 .34517 L
.45608 .34517 L
.45608 .34518 L
.45608 .34518 L
.45608 .34518 L
.45608 .34519 L
.45608 .34519 L
.45608 .3452 L
.45608 .3452 L
.45608 .3452 L
.45608 .34521 L
.45608 .34521 L
Mistroke
.45608 .34521 L
.45608 .34522 L
.45608 .34522 L
.45608 .34523 L
.45608 .34523 L
.45608 .34523 L
.45608 .34524 L
.45608 .34524 L
.45608 .34524 L
.45608 .34525 L
.45608 .34525 L
.45608 .34526 L
.45608 .34526 L
.45608 .34526 L
.45608 .34527 L
.45608 .34527 L
.45608 .34527 L
.45608 .34528 L
.45608 .34528 L
.45608 .34529 L
.45608 .34529 L
.45608 .34529 L
.45608 .3453 L
.45608 .3453 L
.45608 .34531 L
.45608 .34531 L
.45608 .34531 L
.45608 .34532 L
.45608 .34532 L
.45608 .34532 L
.45608 .34533 L
.45608 .34533 L
.45608 .34534 L
.45608 .34534 L
.45608 .34534 L
.45608 .34535 L
.45608 .34535 L
.45608 .34535 L
.45608 .34536 L
.45608 .34536 L
.45608 .34537 L
.45608 .34537 L
.45608 .34537 L
.45608 .34538 L
.45608 .34538 L
.45608 .34538 L
.45608 .34539 L
.45608 .34539 L
.45608 .3454 L
.45608 .3454 L
Mistroke
.45608 .3454 L
.45608 .34541 L
.45608 .34541 L
.45608 .34541 L
.45608 .34542 L
.45608 .34542 L
.45608 .34543 L
.45608 .34543 L
.45608 .34543 L
.45608 .34544 L
.45608 .34544 L
.45608 .34544 L
.45608 .34545 L
.45608 .34545 L
.45608 .34546 L
.45608 .34546 L
.45608 .34546 L
.45607 .34547 L
.45607 .34547 L
.45607 .34547 L
.45607 .34548 L
.45607 .34548 L
.45607 .34549 L
.45607 .34549 L
.45607 .34549 L
.45607 .3455 L
.45607 .3455 L
.45607 .3455 L
.45607 .34551 L
.45607 .34551 L
.45607 .34552 L
.45607 .34552 L
.45607 .34552 L
.45607 .34553 L
.45607 .34553 L
.45607 .34553 L
.45607 .34554 L
.45607 .34554 L
.45607 .34555 L
.45607 .34555 L
.45607 .34555 L
.45607 .34556 L
.45607 .34556 L
.45607 .34556 L
.45607 .34557 L
.45607 .34557 L
.45607 .34558 L
.45606 .34558 L
.45606 .34558 L
.45606 .34559 L
Mistroke
.45606 .34559 L
.45606 .34559 L
.45606 .3456 L
.45606 .3456 L
.45606 .34561 L
.45606 .34561 L
.45606 .34561 L
.45606 .34562 L
.45606 .34562 L
.45606 .34562 L
.45606 .34563 L
.45606 .34563 L
.45606 .34564 L
.45606 .34564 L
.45606 .34564 L
.45606 .34565 L
.45606 .34565 L
.45606 .34565 L
.45606 .34566 L
.45606 .34566 L
.45605 .34567 L
.45605 .34567 L
.45605 .34567 L
.45605 .34568 L
.45605 .34568 L
.45605 .34568 L
.45605 .34569 L
.45605 .34569 L
.45605 .3457 L
.45605 .3457 L
.45605 .3457 L
.45605 .34571 L
.45605 .34571 L
.45605 .34571 L
.45605 .34572 L
.45605 .34572 L
.45605 .34573 L
.45605 .34573 L
.45605 .34573 L
.45604 .34574 L
.45604 .34574 L
.45604 .34574 L
.45604 .34575 L
.45604 .34575 L
.45604 .34576 L
.45604 .34576 L
.45604 .34576 L
.45604 .34577 L
.45604 .34577 L
.45604 .34577 L
Mistroke
.45604 .34578 L
.45604 .34578 L
.45604 .34578 L
.45604 .34579 L
.45604 .34579 L
.45604 .3458 L
.45603 .3458 L
.45603 .3458 L
.45603 .34581 L
.45603 .34581 L
.45603 .34581 L
.45603 .34582 L
.45603 .34582 L
.45603 .34583 L
.45603 .34583 L
.45603 .34583 L
.45603 .34584 L
.45603 .34584 L
.45603 .34584 L
.45603 .34585 L
.45603 .34585 L
.45602 .34586 L
.45602 .34586 L
.45602 .34586 L
.45602 .34587 L
.45602 .34587 L
.45602 .34587 L
.45602 .34588 L
.45602 .34588 L
.45602 .34589 L
.45602 .34589 L
.45602 .34589 L
.45602 .3459 L
.45602 .3459 L
.45602 .3459 L
.45601 .34591 L
.45601 .34591 L
.45601 .34591 L
.45601 .34592 L
.45601 .34592 L
.45601 .34593 L
.45601 .34593 L
.45601 .34593 L
.45601 .34594 L
.45601 .34594 L
.45601 .34594 L
.45601 .34595 L
.45601 .34595 L
.456 .34596 L
.456 .34596 L
Mistroke
.456 .34596 L
.456 .34597 L
.456 .34597 L
.456 .34597 L
.456 .34598 L
.456 .34598 L
.456 .34599 L
.456 .34599 L
.456 .34599 L
.456 .346 L
.45599 .346 L
.45599 .346 L
.45599 .34601 L
.45599 .34601 L
.45599 .34601 L
.45599 .34602 L
.45599 .34602 L
.45599 .34603 L
.45599 .34603 L
.45599 .34603 L
.45599 .34604 L
.45599 .34604 L
.45598 .34604 L
.45598 .34605 L
.45598 .34605 L
.45598 .34605 L
.45598 .34606 L
.45598 .34606 L
.45598 .34607 L
.45598 .34607 L
.45598 .34607 L
.45598 .34608 L
.45598 .34608 L
.45597 .34608 L
.45597 .34609 L
.45597 .34609 L
.45597 .3461 L
.45597 .3461 L
.45597 .3461 L
.45597 .34611 L
.45597 .34611 L
.45597 .34611 L
.45597 .34612 L
.45596 .34612 L
.45596 .34612 L
.45596 .34613 L
.45596 .34613 L
.45596 .34614 L
.45596 .34614 L
.45596 .34614 L
Mistroke
.45596 .34615 L
.45596 .34615 L
.45596 .34615 L
.45596 .34616 L
.45595 .34616 L
.45595 .34616 L
.45595 .34617 L
.45595 .34617 L
.45595 .34618 L
.45595 .34618 L
.45595 .34618 L
.45595 .34619 L
.45595 .34619 L
.45594 .34619 L
.45594 .3462 L
.45594 .3462 L
.45594 .3462 L
.45594 .34621 L
.45594 .34621 L
.45594 .34622 L
.45594 .34622 L
.45594 .34622 L
.45594 .34623 L
.45593 .34623 L
.45593 .34623 L
.45593 .34624 L
.45593 .34624 L
.45593 .34624 L
.45593 .34625 L
.45593 .34625 L
.45593 .34626 L
.45593 .34626 L
.45592 .34626 L
.45592 .34627 L
.45592 .34627 L
.45592 .34627 L
.45592 .34628 L
.45592 .34628 L
.45592 .34628 L
.45592 .34629 L
.45592 .34629 L
.45591 .3463 L
.45591 .3463 L
.45591 .3463 L
.45591 .34631 L
.45591 .34631 L
.45591 .34631 L
.45591 .34632 L
.45591 .34632 L
.45591 .34632 L
Mistroke
.4559 .34633 L
.4559 .34633 L
.4559 .34634 L
.4559 .34634 L
.4559 .34634 L
.4559 .34635 L
.4559 .34635 L
.4559 .34635 L
.4559 .34636 L
.45589 .34636 L
.45589 .34636 L
.45589 .34637 L
.45589 .34637 L
.45589 .34637 L
.45589 .34638 L
.45589 .34638 L
.45589 .34639 L
.45588 .34639 L
.45588 .34639 L
.45588 .3464 L
.45588 .3464 L
.45588 .3464 L
.45588 .34641 L
.45588 .34641 L
.45588 .34641 L
.45587 .34642 L
.45587 .34642 L
.45587 .34642 L
.45587 .34643 L
.45587 .34643 L
.45587 .34644 L
.45587 .34644 L
.45587 .34644 L
.45586 .34645 L
.45586 .34645 L
.45586 .34645 L
.45586 .34646 L
.45586 .34646 L
.45586 .34646 L
.45586 .34647 L
.45586 .34647 L
.45585 .34647 L
.45585 .34648 L
.45585 .34648 L
.45585 .34649 L
.45585 .34649 L
.45585 .34649 L
.45585 .3465 L
.45585 .3465 L
.45584 .3465 L
Mistroke
.45584 .34651 L
.45584 .34651 L
.45584 .34651 L
.45584 .34652 L
.45584 .34652 L
.45584 .34652 L
.45583 .34653 L
.45583 .34653 L
.45583 .34653 L
.45583 .34654 L
.45583 .34654 L
.45583 .34655 L
.45583 .34655 L
.45583 .34655 L
.45582 .34656 L
.45582 .34656 L
.45582 .34656 L
.45582 .34657 L
.45582 .34657 L
.45582 .34657 L
.45582 .34658 L
.45581 .34658 L
.45581 .34658 L
.45581 .34659 L
.45581 .34659 L
.45581 .34659 L
.45581 .3466 L
.45581 .3466 L
.4558 .34661 L
.4558 .34661 L
.4558 .34661 L
.4558 .34662 L
.4558 .34662 L
.4558 .34662 L
.4558 .34663 L
.45579 .34663 L
.45579 .34663 L
.45579 .34664 L
.45579 .34664 L
.45579 .34664 L
.45579 .34665 L
.45579 .34665 L
.45578 .34665 L
.45578 .34666 L
.45578 .34666 L
.45578 .34666 L
.45578 .34667 L
.45578 .34667 L
.45578 .34667 L
.45577 .34668 L
Mistroke
.45577 .34668 L
.45577 .34669 L
.45577 .34669 L
.45577 .34669 L
.45577 .3467 L
.45577 .3467 L
.45576 .3467 L
.45576 .34671 L
.45576 .34671 L
.45576 .34671 L
.45576 .34672 L
.45576 .34672 L
.45576 .34672 L
.45575 .34673 L
.45575 .34673 L
.45575 .34673 L
.45575 .34674 L
.45575 .34674 L
.45575 .34674 L
.45574 .34675 L
.45574 .34675 L
.45574 .34675 L
.45574 .34676 L
.45574 .34676 L
.45574 .34676 L
.45574 .34677 L
.45573 .34677 L
.45573 .34678 L
.45573 .34678 L
.45573 .34678 L
.45573 .34679 L
.45573 .34679 L
.45573 .34679 L
.45572 .3468 L
.45572 .3468 L
.45572 .3468 L
.45572 .34681 L
.45572 .34681 L
.45572 .34681 L
.45571 .34682 L
.45571 .34682 L
.45571 .34682 L
.45571 .34683 L
.45571 .34683 L
.45571 .34683 L
.4557 .34684 L
.4557 .34684 L
.4557 .34684 L
.4557 .34685 L
.4557 .34685 L
Mistroke
.4557 .34685 L
.4557 .34686 L
.45569 .34686 L
.45569 .34686 L
.45569 .34687 L
.45569 .34687 L
.45569 .34687 L
.45569 .34688 L
.45568 .34688 L
.45568 .34688 L
.45568 .34689 L
.45568 .34689 L
.45568 .34689 L
.45568 .3469 L
.45567 .3469 L
.45567 .3469 L
.45567 .34691 L
.45567 .34691 L
.45567 .34691 L
.45567 .34692 L
.45566 .34692 L
.45566 .34693 L
.45566 .34693 L
.45566 .34693 L
.45566 .34694 L
.45566 .34694 L
.45565 .34694 L
.45565 .34695 L
.45565 .34695 L
.45565 .34695 L
.45565 .34696 L
.45565 .34696 L
.45564 .34696 L
.45564 .34697 L
.45564 .34697 L
.45564 .34697 L
.45564 .34698 L
.45564 .34698 L
.45563 .34698 L
.45563 .34699 L
.45563 .34699 L
.45563 .34699 L
.45563 .347 L
.45563 .347 L
.45562 .347 L
.45562 .34701 L
.45562 .34701 L
.45562 .34701 L
.45562 .34702 L
.45562 .34702 L
Mistroke
.45561 .34702 L
.45561 .34703 L
.45561 .34703 L
.45561 .34703 L
.45561 .34704 L
.45561 .34704 L
.4556 .34704 L
.4556 .34705 L
.4556 .34705 L
.4556 .34705 L
.4556 .34706 L
.45559 .34706 L
.45559 .34706 L
.45559 .34707 L
.45559 .34707 L
.45559 .34707 L
.45559 .34708 L
.45558 .34708 L
.45558 .34708 L
.45558 .34709 L
.45558 .34709 L
.45558 .34709 L
.45558 .34709 L
.45557 .3471 L
.45557 .3471 L
.45557 .3471 L
.45557 .34711 L
.45557 .34711 L
.45556 .34711 L
.45556 .34712 L
.45556 .34712 L
.45556 .34712 L
.45556 .34713 L
.45556 .34713 L
.45555 .34713 L
.45555 .34714 L
.45555 .34714 L
.45555 .34714 L
.45555 .34715 L
.45554 .34715 L
.45554 .34715 L
.45554 .34716 L
.45554 .34716 L
.45554 .34716 L
.45554 .34717 L
.45553 .34717 L
.45553 .34717 L
.45553 .34718 L
.45553 .34718 L
.45553 .34718 L
Mistroke
.45552 .34719 L
.45552 .34719 L
.45552 .34719 L
.45552 .3472 L
.45552 .3472 L
.45552 .3472 L
.45551 .34721 L
.45551 .34721 L
.45551 .34721 L
.45551 .34722 L
.45551 .34722 L
.4555 .34722 L
.4555 .34723 L
.4555 .34723 L
.4555 .34723 L
.4555 .34723 L
.4555 .34724 L
.45549 .34724 L
.45549 .34724 L
.45549 .34725 L
.45549 .34725 L
.45549 .34725 L
.45548 .34726 L
.45548 .34726 L
.45548 .34726 L
.45548 .34727 L
.45548 .34727 L
.45547 .34727 L
.45547 .34728 L
.45547 .34728 L
.45547 .34728 L
.45547 .34729 L
.45546 .34729 L
.45546 .34729 L
.45546 .3473 L
.45546 .3473 L
.45546 .3473 L
.45546 .3473 L
.45545 .34731 L
.45545 .34731 L
.45545 .34731 L
.45545 .34732 L
.45545 .34732 L
.45544 .34732 L
.45544 .34733 L
.45544 .34733 L
.45544 .34733 L
.45544 .34734 L
.45543 .34734 L
.45543 .34734 L
Mistroke
.45543 .34735 L
.45543 .34735 L
.45543 .34735 L
.45542 .34736 L
.45542 .34736 L
.45542 .34736 L
.45542 .34736 L
.45542 .34737 L
.45541 .34737 L
.45541 .34737 L
.45541 .34738 L
.45541 .34738 L
.45541 .34738 L
.4554 .34739 L
.4554 .34739 L
.4554 .34739 L
.4554 .3474 L
.4554 .3474 L
.4554 .3474 L
.45539 .34741 L
.45539 .34741 L
.45539 .34741 L
.45539 .34741 L
.45539 .34742 L
.45538 .34742 L
.45538 .34742 L
.45538 .34743 L
.45538 .34743 L
.45538 .34743 L
.45537 .34744 L
.45537 .34744 L
.45537 .34744 L
.45537 .34745 L
.45537 .34745 L
.45536 .34745 L
.45536 .34746 L
.45536 .34746 L
.45536 .34746 L
.45536 .34746 L
.45535 .34747 L
.45535 .34747 L
.45535 .34747 L
.45535 .34748 L
.45535 .34748 L
.45534 .34748 L
.45534 .34749 L
.45534 .34749 L
.45534 .34749 L
.45534 .34749 L
.45533 .3475 L
Mistroke
.45533 .3475 L
.45533 .3475 L
.45533 .34751 L
.45532 .34751 L
.45532 .34751 L
.45532 .34752 L
.45532 .34752 L
.45532 .34752 L
.45531 .34753 L
.45531 .34753 L
.45531 .34753 L
.45531 .34753 L
.45531 .34754 L
.4553 .34754 L
.4553 .34754 L
.4553 .34755 L
.4553 .34755 L
.4553 .34755 L
.45529 .34756 L
.45529 .34756 L
.45529 .34756 L
.45529 .34756 L
.45529 .34757 L
.45528 .34757 L
.45528 .34757 L
.45528 .34758 L
.45528 .34758 L
.45528 .34758 L
.45527 .34759 L
.45527 .34759 L
.45527 .34759 L
.45527 .34759 L
.45527 .3476 L
.45526 .3476 L
.45526 .3476 L
.45526 .34761 L
.45526 .34761 L
.45525 .34761 L
.45525 .34762 L
.45525 .34762 L
.45525 .34762 L
.45525 .34762 L
.45524 .34763 L
.45524 .34763 L
.45524 .34763 L
.45524 .34764 L
.45524 .34764 L
.45523 .34764 L
.45523 .34765 L
.45523 .34765 L
Mistroke
.45523 .34765 L
.45523 .34765 L
.45522 .34766 L
.45522 .34766 L
.45522 .34766 L
.45522 .34767 L
.45521 .34767 L
.45521 .34767 L
.45521 .34767 L
.45521 .34768 L
.45521 .34768 L
.4552 .34768 L
.4552 .34769 L
.4552 .34769 L
.4552 .34769 L
.4552 .3477 L
.45519 .3477 L
.45519 .3477 L
.45519 .3477 L
.45519 .34771 L
.45518 .34771 L
.45518 .34771 L
.45518 .34772 L
.45518 .34772 L
.45518 .34772 L
.45517 .34772 L
.45517 .34773 L
.45517 .34773 L
.45517 .34773 L
.45517 .34774 L
.45516 .34774 L
.45516 .34774 L
.45516 .34774 L
.45516 .34775 L
.45515 .34775 L
.45515 .34775 L
.45515 .34776 L
.45515 .34776 L
.45515 .34776 L
.45514 .34776 L
.45514 .34777 L
.45514 .34777 L
.45514 .34777 L
.45514 .34778 L
.45513 .34778 L
.45513 .34778 L
.45513 .34778 L
.45513 .34779 L
.45512 .34779 L
.45512 .34779 L
Mistroke
.45512 .3478 L
.45512 .3478 L
.45512 .3478 L
.45511 .3478 L
.45511 .34781 L
.45511 .34781 L
.45511 .34781 L
.4551 .34782 L
.4551 .34782 L
.4551 .34782 L
.4551 .34782 L
.4551 .34783 L
.45509 .34783 L
.45509 .34783 L
.45509 .34784 L
.45509 .34784 L
.45508 .34784 L
.45508 .34784 L
.45508 .34785 L
.45508 .34785 L
.45508 .34785 L
.45507 .34786 L
.45507 .34786 L
.45507 .34786 L
.45507 .34786 L
.45506 .34787 L
.45506 .34787 L
.45506 .34787 L
.45506 .34788 L
.45506 .34788 L
.45505 .34788 L
.45505 .34788 L
.45505 .34789 L
.45505 .34789 L
.45504 .34789 L
.45504 .34789 L
.45504 .3479 L
.45504 .3479 L
.45504 .3479 L
.45503 .34791 L
.45503 .34791 L
.45503 .34791 L
.45503 .34791 L
.45502 .34792 L
.45502 .34792 L
.45502 .34792 L
.45502 .34793 L
.45502 .34793 L
.45501 .34793 L
.45501 .34793 L
Mistroke
.45501 .34794 L
.45501 .34794 L
.455 .34794 L
.455 .34794 L
.455 .34795 L
.455 .34795 L
.455 .34795 L
.45499 .34796 L
.45499 .34796 L
.45499 .34796 L
.45499 .34796 L
.45498 .34797 L
.45498 .34797 L
.45498 .34797 L
.45498 .34797 L
.45498 .34798 L
.45497 .34798 L
.45497 .34798 L
.45497 .34799 L
.45497 .34799 L
.45496 .34799 L
.45496 .34799 L
.45496 .348 L
.45496 .348 L
.45495 .348 L
.45495 .348 L
.45495 .34801 L
.45495 .34801 L
.45495 .34801 L
.45494 .34801 L
.45494 .34802 L
.45494 .34802 L
.45494 .34802 L
.45493 .34803 L
.45493 .34803 L
.45493 .34803 L
.45493 .34803 L
.45493 .34804 L
.45492 .34804 L
.45492 .34804 L
.45492 .34804 L
.45492 .34805 L
.45491 .34805 L
.45491 .34805 L
.45491 .34805 L
.45491 .34806 L
.4549 .34806 L
.4549 .34806 L
.4549 .34807 L
.4549 .34807 L
Mistroke
.4549 .34807 L
.45489 .34807 L
.45489 .34808 L
.45489 .34808 L
.45489 .34808 L
.45488 .34808 L
.45488 .34809 L
.45488 .34809 L
.45488 .34809 L
.45487 .34809 L
.45487 .3481 L
.45487 .3481 L
.45487 .3481 L
.45487 .3481 L
.45486 .34811 L
.45486 .34811 L
.45486 .34811 L
.45486 .34811 L
.45485 .34812 L
.45485 .34812 L
.45485 .34812 L
.45485 .34813 L
.45484 .34813 L
.45484 .34813 L
.45484 .34813 L
.45484 .34814 L
.45484 .34814 L
.45483 .34814 L
.45483 .34814 L
.45483 .34815 L
.45483 .34815 L
.45482 .34815 L
.45482 .34815 L
.45482 .34816 L
.45482 .34816 L
.45481 .34816 L
.45481 .34816 L
.45481 .34817 L
.45481 .34817 L
.4548 .34817 L
.4548 .34817 L
.4548 .34818 L
.4548 .34818 L
.4548 .34818 L
.45479 .34818 L
.45479 .34819 L
.45479 .34819 L
.45479 .34819 L
.45478 .34819 L
.45478 .3482 L
Mistroke
.45478 .3482 L
.45478 .3482 L
.45477 .3482 L
.45477 .34821 L
.45477 .34821 L
.45477 .34821 L
.45477 .34821 L
.45476 .34822 L
.45476 .34822 L
.45476 .34822 L
.45476 .34822 L
.45475 .34823 L
.45475 .34823 L
.45475 .34823 L
.45475 .34823 L
.45474 .34824 L
.45474 .34824 L
.45474 .34824 L
.45474 .34824 L
.45473 .34825 L
.45473 .34825 L
.45473 .34825 L
.45473 .34825 L
.45473 .34826 L
.45472 .34826 L
.45472 .34826 L
.45472 .34826 L
.45472 .34827 L
.45471 .34827 L
.45471 .34827 L
.45471 .34827 L
.45471 .34828 L
.4547 .34828 L
.4547 .34828 L
.4547 .34828 L
.4547 .34829 L
.45469 .34829 L
.45469 .34829 L
.45469 .34829 L
.45469 .3483 L
.45468 .3483 L
.45468 .3483 L
.45468 .3483 L
.45468 .34831 L
.45468 .34831 L
.45467 .34831 L
.45467 .34831 L
.45467 .34832 L
.45467 .34832 L
.45466 .34832 L
Mistroke
.45466 .34832 L
.45466 .34832 L
.45466 .34833 L
.45465 .34833 L
.45465 .34833 L
.45465 .34833 L
.45465 .34834 L
.45464 .34834 L
.45464 .34834 L
.45464 .34834 L
.45464 .34835 L
.45464 .34835 L
.45463 .34835 L
.45463 .34835 L
.45463 .34836 L
.45463 .34836 L
.45462 .34836 L
.45462 .34836 L
.45462 .34837 L
.45462 .34837 L
.45461 .34837 L
.45461 .34837 L
.45461 .34837 L
.45461 .34838 L
.4546 .34838 L
.4546 .34838 L
.4546 .34838 L
.4546 .34839 L
.45459 .34839 L
.45459 .34839 L
.45459 .34839 L
.45459 .3484 L
.45458 .3484 L
.45458 .3484 L
.45458 .3484 L
.45458 .34841 L
.45458 .34841 L
.45457 .34841 L
.45457 .34841 L
.45457 .34841 L
.45457 .34842 L
.45456 .34842 L
.45456 .34842 L
.45456 .34842 L
.45456 .34843 L
.45455 .34843 L
.45455 .34843 L
.45455 .34843 L
.45455 .34844 L
.45454 .34844 L
Mistroke
.45454 .34844 L
.45454 .34844 L
.45454 .34844 L
.45453 .34845 L
.45453 .34845 L
.45453 .34845 L
.45453 .34845 L
.45452 .34846 L
.45452 .34846 L
.45452 .34846 L
.45452 .34846 L
.45452 .34846 L
.45451 .34847 L
.45451 .34847 L
.45451 .34847 L
.45451 .34847 L
.4545 .34848 L
.4545 .34848 L
.4545 .34848 L
.4545 .34848 L
.45449 .34849 L
.45449 .34849 L
.45449 .34849 L
.45449 .34849 L
.45448 .34849 L
.45448 .3485 L
.45448 .3485 L
.45448 .3485 L
.45447 .3485 L
.45447 .34851 L
.45447 .34851 L
.45447 .34851 L
.45446 .34851 L
.45446 .34851 L
.45446 .34852 L
.45446 .34852 L
.45445 .34852 L
.45445 .34852 L
.45445 .34853 L
.45445 .34853 L
.45445 .34853 L
.45444 .34853 L
.45444 .34853 L
.45444 .34854 L
.45444 .34854 L
.45443 .34854 L
.45443 .34854 L
.45443 .34854 L
.45443 .34855 L
.45442 .34855 L
Mistroke
.45442 .34855 L
.45442 .34855 L
.45442 .34856 L
.45441 .34856 L
.45441 .34856 L
.45441 .34856 L
.45441 .34856 L
.4544 .34857 L
.4544 .34857 L
.4544 .34857 L
.4544 .34857 L
.45439 .34858 L
.45439 .34858 L
.45439 .34858 L
.45439 .34858 L
.45438 .34858 L
.45438 .34859 L
.45438 .34859 L
.45438 .34859 L
.45438 .34859 L
.45437 .34859 L
.45437 .3486 L
.45437 .3486 L
.45437 .3486 L
.45436 .3486 L
.45436 .3486 L
.45436 .34861 L
.45436 .34861 L
.45435 .34861 L
.45435 .34861 L
.45435 .34862 L
.45435 .34862 L
.45434 .34862 L
.45434 .34862 L
.45434 .34862 L
.45434 .34863 L
.45433 .34863 L
.45433 .34863 L
.45433 .34863 L
.45433 .34863 L
.45432 .34864 L
.45432 .34864 L
.45432 .34864 L
.45432 .34864 L
.45431 .34864 L
.45431 .34865 L
.45431 .34865 L
.45431 .34865 L
.4543 .34865 L
.4543 .34866 L
Mistroke
.4543 .34866 L
.4543 .34866 L
.45429 .34866 L
.45429 .34866 L
.45429 .34867 L
.45429 .34867 L
.45429 .34867 L
.45428 .34867 L
.45428 .34867 L
.45428 .34868 L
.45428 .34868 L
.45427 .34868 L
.45427 .34868 L
.45427 .34868 L
.45427 .34869 L
.45426 .34869 L
.45426 .34869 L
.45426 .34869 L
.45426 .34869 L
.45425 .3487 L
.45425 .3487 L
.45425 .3487 L
.45425 .3487 L
.45424 .3487 L
.45424 .34871 L
.45424 .34871 L
.45424 .34871 L
.45423 .34871 L
.45423 .34871 L
.45423 .34872 L
.45423 .34872 L
.45422 .34872 L
.45422 .34872 L
.45422 .34872 L
.45422 .34873 L
.45421 .34873 L
.45421 .34873 L
.45421 .34873 L
.45421 .34873 L
.4542 .34874 L
.4542 .34874 L
.4542 .34874 L
.4542 .34874 L
.4542 .34874 L
.45419 .34875 L
.45419 .34875 L
.45419 .34875 L
.45419 .34875 L
.45418 .34875 L
.45418 .34875 L
Mistroke
.45418 .34876 L
.45418 .34876 L
.45417 .34876 L
.45417 .34876 L
.45417 .34876 L
.45417 .34877 L
.45416 .34877 L
.45416 .34877 L
.45416 .34877 L
.45416 .34877 L
.45415 .34878 L
.45415 .34878 L
.45415 .34878 L
.45415 .34878 L
.45414 .34878 L
.45414 .34879 L
.45414 .34879 L
.45414 .34879 L
.45413 .34879 L
.45413 .34879 L
.45413 .3488 L
.45413 .3488 L
.45412 .3488 L
.45412 .3488 L
.45412 .3488 L
.45412 .3488 L
.45411 .34881 L
.45411 .34881 L
.45411 .34881 L
.45411 .34881 L
.45411 .34881 L
.4541 .34882 L
.4541 .34882 L
.4541 .34882 L
.4541 .34882 L
.45409 .34882 L
.45409 .34882 L
.45409 .34883 L
.45409 .34883 L
.45408 .34883 L
.45408 .34883 L
.45408 .34883 L
.45408 .34884 L
.45407 .34884 L
.45407 .34884 L
.45407 .34884 L
.45407 .34884 L
.45406 .34885 L
.45406 .34885 L
.45406 .34885 L
Mistroke
.45406 .34885 L
.45405 .34885 L
.45405 .34885 L
.45405 .34886 L
.45405 .34886 L
.45404 .34886 L
.45404 .34886 L
.45404 .34886 L
.45404 .34887 L
.45403 .34887 L
.45403 .34887 L
.45403 .34887 L
.45403 .34887 L
.45403 .34887 L
.45402 .34888 L
.45402 .34888 L
.45402 .34888 L
.45402 .34888 L
.45401 .34888 L
.45401 .34888 L
.45401 .34889 L
.45401 .34889 L
.454 .34889 L
.454 .34889 L
.454 .34889 L
.454 .3489 L
.45399 .3489 L
.45399 .3489 L
.45399 .3489 L
.45399 .3489 L
.45398 .3489 L
.45398 .34891 L
.45398 .34891 L
.45398 .34891 L
.45397 .34891 L
.45397 .34891 L
.45397 .34891 L
.45397 .34892 L
.45396 .34892 L
.45396 .34892 L
.45396 .34892 L
.45396 .34892 L
.45395 .34892 L
.45395 .34893 L
.45395 .34893 L
.45395 .34893 L
.45395 .34893 L
.45394 .34893 L
.45394 .34894 L
.45394 .34894 L
Mistroke
.45394 .34894 L
.45393 .34894 L
.45393 .34894 L
.45393 .34894 L
.45393 .34895 L
.45392 .34895 L
.45392 .34895 L
.45392 .34895 L
.45392 .34895 L
.45391 .34895 L
.45391 .34896 L
.45391 .34896 L
.45391 .34896 L
.4539 .34896 L
.4539 .34896 L
.4539 .34896 L
.4539 .34897 L
.45389 .34897 L
.45389 .34897 L
.45389 .34897 L
.45389 .34897 L
.45389 .34897 L
.45388 .34898 L
.45388 .34898 L
.45388 .34898 L
.45388 .34898 L
.45387 .34898 L
.45387 .34898 L
.45387 .34899 L
.45387 .34899 L
.45386 .34899 L
.45386 .34899 L
.45386 .34899 L
.45386 .34899 L
.45385 .349 L
.45385 .349 L
.45385 .349 L
.45385 .349 L
.45384 .349 L
.45384 .349 L
.45384 .349 L
.45384 .34901 L
.45383 .34901 L
.45383 .34901 L
.45383 .34901 L
.45383 .34901 L
.45382 .34901 L
.45382 .34902 L
.45382 .34902 L
.45382 .34902 L
Mistroke
.45382 .34902 L
.45381 .34902 L
.45381 .34902 L
.45381 .34903 L
.45381 .34903 L
.4538 .34903 L
.4538 .34903 L
.4538 .34903 L
.4538 .34903 L
.45379 .34903 L
.45379 .34904 L
.45379 .34904 L
.45379 .34904 L
.45378 .34904 L
.45378 .34904 L
.45378 .34904 L
.45378 .34905 L
.45377 .34905 L
.45377 .34905 L
.45377 .34905 L
.45377 .34905 L
.45377 .34905 L
.45376 .34905 L
.45376 .34906 L
.45376 .34906 L
.45376 .34906 L
.45375 .34906 L
.45375 .34906 L
.45375 .34906 L
.45375 .34907 L
.45374 .34907 L
.45374 .34907 L
.45374 .34907 L
.45374 .34907 L
.45373 .34907 L
.45373 .34907 L
.45373 .34908 L
.45373 .34908 L
.45372 .34908 L
.45372 .34908 L
.45372 .34908 L
.45372 .34908 L
.45372 .34909 L
.45371 .34909 L
.45371 .34909 L
.45371 .34909 L
.45371 .34909 L
.4537 .34909 L
.4537 .34909 L
.4537 .3491 L
Mistroke
.4537 .3491 L
.45369 .3491 L
.45369 .3491 L
.45369 .3491 L
.45369 .3491 L
.45368 .3491 L
.45368 .34911 L
.45368 .34911 L
.45368 .34911 L
.45367 .34911 L
.45367 .34911 L
.45367 .34911 L
.45367 .34911 L
.45367 .34912 L
.45366 .34912 L
.45366 .34912 L
.45366 .34912 L
.45366 .34912 L
.45365 .34912 L
.45365 .34912 L
.45365 .34913 L
.45365 .34913 L
.45364 .34913 L
.45364 .34913 L
.45364 .34913 L
.45364 .34913 L
.45363 .34913 L
.45363 .34914 L
.45363 .34914 L
.45363 .34914 L
.45363 .34914 L
.45362 .34914 L
.45362 .34914 L
.45362 .34914 L
.45362 .34915 L
.45361 .34915 L
.45361 .34915 L
.45361 .34915 L
.45361 .34915 L
.4536 .34915 L
.4536 .34915 L
.4536 .34915 L
.4536 .34916 L
.45359 .34916 L
.45359 .34916 L
.45359 .34916 L
.45359 .34916 L
.45359 .34916 L
.45358 .34916 L
.45358 .34917 L
Mistroke
.45358 .34917 L
.45358 .34917 L
.45357 .34917 L
.45357 .34917 L
.45357 .34917 L
.45357 .34917 L
.45356 .34918 L
.45356 .34918 L
.45356 .34918 L
.45356 .34918 L
.45355 .34918 L
.45355 .34918 L
.45355 .34918 L
.45355 .34918 L
.45355 .34919 L
.45354 .34919 L
.45354 .34919 L
.45354 .34919 L
.45354 .34919 L
.45353 .34919 L
.45353 .34919 L
.45353 .3492 L
.45353 .3492 L
.45352 .3492 L
.45352 .3492 L
.45352 .3492 L
.45352 .3492 L
.45352 .3492 L
.45351 .3492 L
.45351 .34921 L
.45351 .34921 L
.45351 .34921 L
.4535 .34921 L
.4535 .34921 L
.4535 .34921 L
.4535 .34921 L
.45349 .34921 L
.45349 .34922 L
.45349 .34922 L
.45349 .34922 L
.45349 .34922 L
.45348 .34922 L
.45348 .34922 L
.45348 .34922 L
.45348 .34922 L
.45347 .34923 L
.45347 .34923 L
.45347 .34923 L
.45347 .34923 L
.45346 .34923 L
Mistroke
.45346 .34923 L
.45346 .34923 L
.45346 .34923 L
.45346 .34924 L
.45345 .34924 L
.45345 .34924 L
.45345 .34924 L
.45345 .34924 L
.45344 .34924 L
.45344 .34924 L
.45344 .34924 L
.45344 .34925 L
.45343 .34925 L
.45343 .34925 L
.45343 .34925 L
.45343 .34925 L
.45343 .34925 L
.45342 .34925 L
.45342 .34925 L
.45342 .34925 L
.45342 .34926 L
.45341 .34926 L
.45341 .34926 L
.45341 .34926 L
.45341 .34926 L
.4534 .34926 L
.4534 .34926 L
.4534 .34926 L
.4534 .34927 L
.4534 .34927 L
.45339 .34927 L
.45339 .34927 L
.45339 .34927 L
.45339 .34927 L
.45338 .34927 L
.45338 .34927 L
.45338 .34927 L
.45338 .34928 L
.45338 .34928 L
.45337 .34928 L
.45337 .34928 L
.45337 .34928 L
.45337 .34928 L
.45336 .34928 L
.45336 .34928 L
.45336 .34929 L
.45336 .34929 L
.45335 .34929 L
.45335 .34929 L
.45335 .34929 L
Mistroke
.45335 .34929 L
.45335 .34929 L
.45334 .34929 L
.45334 .34929 L
.45334 .3493 L
.45334 .3493 L
.45333 .3493 L
.45333 .3493 L
.45333 .3493 L
.45333 .3493 L
.45333 .3493 L
.45332 .3493 L
.45332 .3493 L
.45332 .34931 L
.45332 .34931 L
.45331 .34931 L
.45331 .34931 L
.45331 .34931 L
.45331 .34931 L
.45331 .34931 L
.4533 .34931 L
.4533 .34931 L
.4533 .34932 L
.4533 .34932 L
.45329 .34932 L
.45329 .34932 L
.45329 .34932 L
.45329 .34932 L
.45328 .34932 L
.45328 .34932 L
.45328 .34932 L
.45328 .34932 L
.45328 .34933 L
.45327 .34933 L
.45327 .34933 L
.45327 .34933 L
.45327 .34933 L
.45326 .34933 L
.45326 .34933 L
.45326 .34933 L
.45326 .34933 L
.45326 .34934 L
.45325 .34934 L
.45325 .34934 L
.45325 .34934 L
.45325 .34934 L
.45324 .34934 L
.45324 .34934 L
.45324 .34934 L
.45324 .34934 L
Mistroke
.45324 .34934 L
.45323 .34935 L
.45323 .34935 L
.45323 .34935 L
.45323 .34935 L
.45322 .34935 L
.45322 .34935 L
.45322 .34935 L
.45322 .34935 L
.45322 .34935 L
.45321 .34935 L
.45321 .34936 L
.45321 .34936 L
.45321 .34936 L
.4532 .34936 L
.4532 .34936 L
.4532 .34936 L
.4532 .34936 L
.4532 .34936 L
.45319 .34936 L
.45319 .34936 L
.45319 .34937 L
.45319 .34937 L
.45319 .34937 L
.45318 .34937 L
.45318 .34937 L
.45318 .34937 L
.45318 .34937 L
.45317 .34937 L
.45317 .34937 L
.45317 .34937 L
.45317 .34937 L
.45317 .34938 L
.45316 .34938 L
.45316 .34938 L
.45316 .34938 L
.45316 .34938 L
.45315 .34938 L
.45315 .34938 L
.45315 .34938 L
.45315 .34938 L
.45315 .34938 L
.45314 .34939 L
.45314 .34939 L
.45314 .34939 L
.45314 .34939 L
.45313 .34939 L
.45313 .34939 L
.45313 .34939 L
.45313 .34939 L
Mistroke
.45313 .34939 L
.45312 .34939 L
.45312 .34939 L
.45312 .3494 L
.45312 .3494 L
.45312 .3494 L
.45311 .3494 L
.45311 .3494 L
.45311 .3494 L
.45311 .3494 L
.4531 .3494 L
.4531 .3494 L
.4531 .3494 L
.4531 .3494 L
.4531 .3494 L
.45309 .34941 L
.45309 .34941 L
.45309 .34941 L
.45309 .34941 L
.45309 .34941 L
.45308 .34941 L
.45308 .34941 L
.45308 .34941 L
.45308 .34941 L
.45307 .34941 L
.45307 .34941 L
.45307 .34942 L
.45307 .34942 L
.45307 .34942 L
.45306 .34942 L
.45306 .34942 L
.45306 .34942 L
.45306 .34942 L
.45306 .34942 L
.45305 .34942 L
.45305 .34942 L
.45305 .34942 L
.45305 .34942 L
.45304 .34943 L
.45304 .34943 L
.45304 .34943 L
.45304 .34943 L
.45304 .34943 L
.45303 .34943 L
.45303 .34943 L
.45303 .34943 L
.45303 .34943 L
.45303 .34943 L
.45302 .34943 L
.45302 .34943 L
Mistroke
.45302 .34944 L
.45302 .34944 L
.45301 .34944 L
.45301 .34944 L
.45301 .34944 L
.45301 .34944 L
.45301 .34944 L
.453 .34944 L
.453 .34944 L
.453 .34944 L
.453 .34944 L
.453 .34944 L
.45299 .34944 L
.45299 .34945 L
.45299 .34945 L
.45299 .34945 L
.45299 .34945 L
.45298 .34945 L
.45298 .34945 L
.45298 .34945 L
.45298 .34945 L
.45297 .34945 L
.45297 .34945 L
.45297 .34945 L
.45297 .34945 L
.45297 .34945 L
.45296 .34946 L
.45296 .34946 L
.45296 .34946 L
.45296 .34946 L
.45296 .34946 L
.45295 .34946 L
.45295 .34946 L
.45295 .34946 L
.45295 .34946 L
.45295 .34946 L
.45294 .34946 L
.45294 .34946 L
.45294 .34946 L
.45294 .34947 L
.45294 .34947 L
.45293 .34947 L
.45293 .34947 L
.45293 .34947 L
.45293 .34947 L
.45293 .34947 L
.45292 .34947 L
.45292 .34947 L
.45292 .34947 L
.45292 .34947 L
Mistroke
.45291 .34947 L
.45291 .34947 L
.45291 .34947 L
.45291 .34947 L
.45291 .34948 L
.4529 .34948 L
.4529 .34948 L
.4529 .34948 L
.4529 .34948 L
.4529 .34948 L
.45289 .34948 L
.45289 .34948 L
.45289 .34948 L
.45289 .34948 L
.45289 .34948 L
.45288 .34948 L
.45288 .34948 L
.45288 .34948 L
.45288 .34949 L
.45288 .34949 L
.45287 .34949 L
.45287 .34949 L
.45287 .34949 L
.45287 .34949 L
.45287 .34949 L
.45286 .34949 L
.45286 .34949 L
.45286 .34949 L
.45286 .34949 L
.45286 .34949 L
.45285 .34949 L
.45285 .34949 L
.45285 .34949 L
.45285 .34949 L
.45285 .3495 L
.45284 .3495 L
.45284 .3495 L
.45284 .3495 L
.45284 .3495 L
.45284 .3495 L
.45283 .3495 L
.45283 .3495 L
.45283 .3495 L
.45283 .3495 L
.45283 .3495 L
.45282 .3495 L
.45282 .3495 L
.45282 .3495 L
.45282 .3495 L
.45282 .3495 L
Mistroke
.45281 .34951 L
.45281 .34951 L
.45281 .34951 L
.45281 .34951 L
.45281 .34951 L
.4528 .34951 L
.4528 .34951 L
.4528 .34951 L
.4528 .34951 L
.4528 .34951 L
.45279 .34951 L
.45279 .34951 L
.45279 .34951 L
.45279 .34951 L
.45279 .34951 L
.45278 .34951 L
.45278 .34951 L
.45278 .34952 L
.45278 .34952 L
.45278 .34952 L
.45277 .34952 L
.45277 .34952 L
.45277 .34952 L
.45277 .34952 L
.45277 .34952 L
.45276 .34952 L
.45276 .34952 L
.45276 .34952 L
.45276 .34952 L
.45276 .34952 L
.45275 .34952 L
.45275 .34952 L
.45275 .34952 L
.45275 .34952 L
.45275 .34952 L
.45274 .34953 L
.45274 .34953 L
.45274 .34953 L
.45274 .34953 L
.45274 .34953 L
.45273 .34953 L
.45273 .34953 L
.45273 .34953 L
.45273 .34953 L
.45273 .34953 L
.45272 .34953 L
.45272 .34953 L
.45272 .34953 L
.45272 .34953 L
.45272 .34953 L
Mistroke
.45272 .34953 L
.45271 .34953 L
.45271 .34953 L
.45271 .34953 L
.45271 .34954 L
.45271 .34954 L
.4527 .34954 L
.4527 .34954 L
.4527 .34954 L
.4527 .34954 L
.4527 .34954 L
.45269 .34954 L
.45269 .34954 L
.45269 .34954 L
.45269 .34954 L
.45269 .34954 L
.45268 .34954 L
.45268 .34954 L
.45268 .34954 L
.45268 .34954 L
.45268 .34954 L
.45267 .34954 L
.45267 .34954 L
.45267 .34954 L
.45267 .34954 L
.45267 .34955 L
.45267 .34955 L
.45266 .34955 L
.45266 .34955 L
.45266 .34955 L
.45266 .34955 L
.45266 .34955 L
.45265 .34955 L
.45265 .34955 L
.45265 .34955 L
.45265 .34955 L
.45265 .34955 L
.45264 .34955 L
.45264 .34955 L
.45264 .34955 L
.45264 .34955 L
.45264 .34955 L
.45264 .34955 L
.45263 .34955 L
.45263 .34955 L
.45263 .34955 L
.45263 .34955 L
.45263 .34955 L
.45262 .34956 L
.45262 .34956 L
Mistroke
.45262 .34956 L
.45262 .34956 L
.45262 .34956 L
.45261 .34956 L
.45261 .34956 L
.45261 .34956 L
.45261 .34956 L
.45261 .34956 L
.45261 .34956 L
.4526 .34956 L
.4526 .34956 L
.4526 .34956 L
.4526 .34956 L
.4526 .34956 L
.45259 .34956 L
.45259 .34956 L
.45259 .34956 L
.45259 .34956 L
.45259 .34956 L
.45258 .34956 L
.45258 .34956 L
.45258 .34956 L
.45258 .34956 L
.45258 .34956 L
.45258 .34957 L
.45257 .34957 L
.45257 .34957 L
.45257 .34957 L
.45257 .34957 L
.45257 .34957 L
.45256 .34957 L
.45256 .34957 L
.45256 .34957 L
.45256 .34957 L
.45256 .34957 L
.45256 .34957 L
.45255 .34957 L
.45255 .34957 L
.45255 .34957 L
.45255 .34957 L
.45255 .34957 L
.45254 .34957 L
.45254 .34957 L
.45254 .34957 L
.45254 .34957 L
.45254 .34957 L
.45254 .34957 L
.45253 .34957 L
.45253 .34957 L
.45253 .34957 L
Mistroke
.45253 .34957 L
.45253 .34957 L
.45252 .34957 L
.45252 .34958 L
.45252 .34958 L
.45252 .34958 L
.45252 .34958 L
.45252 .34958 L
.45251 .34958 L
.45251 .34958 L
.45251 .34958 L
.45251 .34958 L
.45251 .34958 L
.45251 .34958 L
.4525 .34958 L
.4525 .34958 L
.4525 .34958 L
.4525 .34958 L
.4525 .34958 L
.45249 .34958 L
.45249 .34958 L
.45249 .34958 L
.45249 .34958 L
.45249 .34958 L
.45249 .34958 L
.45248 .34958 L
.45248 .34958 L
.45248 .34958 L
.45248 .34958 L
.45248 .34958 L
.45248 .34958 L
.45247 .34958 L
.45247 .34958 L
.45247 .34958 L
.45247 .34958 L
.45247 .34958 L
.45246 .34958 L
.45246 .34959 L
.45246 .34959 L
.45246 .34959 L
.45246 .34959 L
.45246 .34959 L
.45245 .34959 L
.45245 .34959 L
.45245 .34959 L
.45245 .34959 L
.45245 .34959 L
.45245 .34959 L
.45244 .34959 L
.45244 .34959 L
Mistroke
.45244 .34959 L
.45244 .34959 L
.45244 .34959 L
.45244 .34959 L
.45243 .34959 L
.45243 .34959 L
.45243 .34959 L
.45243 .34959 L
.45243 .34959 L
.45242 .34959 L
.45242 .34959 L
.45242 .34959 L
.45242 .34959 L
.45242 .34959 L
.45242 .34959 L
.45241 .34959 L
.45241 .34959 L
.45241 .34959 L
.45241 .34959 L
.45241 .34959 L
.45241 .34959 L
.4524 .34959 L
.4524 .34959 L
.4524 .34959 L
.4524 .34959 L
.4524 .34959 L
.4524 .34959 L
.45239 .34959 L
.45239 .34959 L
.45239 .34959 L
.45239 .34959 L
.45239 .34959 L
.45239 .34959 L
.45238 .3496 L
.45238 .3496 L
.45238 .3496 L
.45238 .3496 L
.45238 .3496 L
.45238 .3496 L
.45237 .3496 L
.45237 .3496 L
.45237 .3496 L
.45237 .3496 L
.45237 .3496 L
.45237 .3496 L
.45236 .3496 L
.45236 .3496 L
.45236 .3496 L
.45236 .3496 L
.45236 .3496 L
Mistroke
.45236 .3496 L
.45235 .3496 L
.45235 .3496 L
.45235 .3496 L
.45235 .3496 L
.45235 .3496 L
.45235 .3496 L
.45234 .3496 L
.45234 .3496 L
.45234 .3496 L
.45234 .3496 L
.45234 .3496 L
.45234 .3496 L
.45233 .3496 L
.45233 .3496 L
.45233 .3496 L
.45233 .3496 L
.45233 .3496 L
.45233 .3496 L
.45232 .3496 L
.45232 .3496 L
.45232 .3496 L
.45232 .3496 L
.45232 .3496 L
.45232 .3496 L
.45231 .3496 L
.45231 .3496 L
.45231 .3496 L
.45231 .3496 L
.45231 .3496 L
.45231 .3496 L
.4523 .3496 L
.4523 .3496 L
.4523 .3496 L
.4523 .3496 L
.4523 .3496 L
.4523 .3496 L
.4523 .3496 L
.45229 .3496 L
.45229 .3496 L
.45229 .3496 L
.45229 .3496 L
.45229 .3496 L
.45229 .3496 L
.45228 .3496 L
.45228 .3496 L
.45228 .3496 L
.45228 .3496 L
.45228 .3496 L
.45228 .3496 L
Mistroke
.45227 .3496 L
.45227 .3496 L
.45227 .3496 L
.45227 .3496 L
.45227 .3496 L
.45227 .3496 L
.45227 .3496 L
.45226 .3496 L
.45226 .3496 L
.45226 .3496 L
.45226 .3496 L
.45226 .3496 L
.45226 .3496 L
.45225 .3496 L
.45225 .3496 L
.45225 .3496 L
.45225 .3496 L
.45225 .3496 L
.45225 .3496 L
.45224 .3496 L
.45224 .3496 L
.45224 .3496 L
.45224 .3496 L
.45224 .3496 L
.45224 .3496 L
.45224 .3496 L
.45223 .3496 L
.45223 .3496 L
.45223 .34961 L
.45223 .34961 L
.45223 .34961 L
.45223 .34961 L
.45222 .34961 L
.45222 .34961 L
.45222 .34961 L
.45222 .34961 L
.45222 .34961 L
.45222 .34961 L
.45222 .34961 L
.45221 .34961 L
.45221 .34961 L
.45221 .34961 L
.45221 .34961 L
.45221 .34961 L
.45221 .34961 L
.4522 .34961 L
.4522 .34961 L
.4522 .34961 L
.4522 .34961 L
.4522 .34961 L
Mistroke
.4522 .34961 L
.4522 .34961 L
.45219 .34961 L
.45219 .34961 L
.45219 .34961 L
.45219 .34961 L
.45219 .34961 L
.45219 .34961 L
.45219 .34961 L
.45218 .34961 L
.45218 .34961 L
.45218 .34961 L
.45218 .34961 L
.45218 .34961 L
.45218 .34961 L
.45217 .34961 L
.45217 .34961 L
.45217 .34961 L
.45217 .34961 L
.45217 .34961 L
.45217 .3496 L
.45217 .3496 L
.45216 .3496 L
.45216 .3496 L
.45216 .3496 L
.45216 .3496 L
.45216 .3496 L
.45216 .3496 L
.45216 .3496 L
.45215 .3496 L
.45215 .3496 L
.45215 .3496 L
.45215 .3496 L
.45215 .3496 L
.45215 .3496 L
.45215 .3496 L
.45214 .3496 L
.45214 .3496 L
.45214 .3496 L
.45214 .3496 L
.45214 .3496 L
.45214 .3496 L
.45214 .3496 L
.45213 .3496 L
.45213 .3496 L
.45213 .3496 L
.45213 .3496 L
.45213 .3496 L
.45213 .3496 L
.45213 .3496 L
Mistroke
.45212 .3496 L
.45212 .3496 L
.45212 .3496 L
.45212 .3496 L
.45212 .3496 L
.45212 .3496 L
.45212 .3496 L
.45211 .3496 L
.45211 .3496 L
.45211 .3496 L
.45211 .3496 L
.45211 .3496 L
.45211 .3496 L
.45211 .3496 L
.4521 .3496 L
.4521 .3496 L
.4521 .3496 L
.4521 .3496 L
.4521 .3496 L
.4521 .3496 L
.4521 .3496 L
.45209 .3496 L
.45209 .3496 L
.45209 .3496 L
.45209 .3496 L
.45209 .3496 L
.45209 .3496 L
.45209 .3496 L
.45208 .3496 L
.45208 .3496 L
.45208 .3496 L
.45208 .3496 L
.45208 .3496 L
.45208 .3496 L
.45208 .3496 L
.45207 .3496 L
.45207 .3496 L
.45207 .3496 L
.45207 .3496 L
.45207 .3496 L
.45207 .3496 L
.45207 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
.45206 .3496 L
Mistroke
.45205 .3496 L
.45205 .3496 L
.45205 .3496 L
.45205 .3496 L
.45205 .3496 L
.45205 .3496 L
.45205 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45204 .3496 L
.45203 .3496 L
.45203 .3496 L
.45203 .3496 L
.45203 .3496 L
.45203 .34959 L
.45203 .34959 L
.45203 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45202 .34959 L
.45201 .34959 L
.45201 .34959 L
.45201 .34959 L
.45201 .34959 L
.45201 .34959 L
.45201 .34959 L
.45201 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.452 .34959 L
.45199 .34959 L
.45199 .34959 L
.45199 .34959 L
.45199 .34959 L
.45199 .34959 L
Mistroke
.45199 .34959 L
.45199 .34959 L
.45199 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45198 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45197 .34959 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45196 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45195 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45194 .34958 L
.45193 .34958 L
.45193 .34958 L
.45193 .34958 L
.45193 .34958 L
.45193 .34958 L
.45193 .34958 L
.45193 .34958 L
Mistroke
.45193 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34958 L
.45192 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.45191 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.4519 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45189 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34957 L
.45188 .34956 L
.45188 .34956 L
.45187 .34956 L
.45187 .34956 L
.45187 .34956 L
.45187 .34956 L
.45187 .34956 L
.45187 .34956 L
Mistroke
.45187 .34956 L
.45187 .34956 L
.45187 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45186 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45185 .34956 L
.45184 .34956 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45184 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45183 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45182 .34955 L
.45181 .34955 L
.45181 .34954 L
Mistroke
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.45181 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.4518 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34954 L
.45179 .34953 L
.45179 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45178 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45177 .34953 L
.45176 .34953 L
.45176 .34953 L
.45176 .34952 L
Mistroke
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45176 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45175 .34952 L
.45174 .34952 L
.45174 .34952 L
.45174 .34952 L
.45174 .34952 L
.45174 .34951 L
.45174 .34951 L
.45174 .34951 L
.45174 .34951 L
.45174 .34951 L
.45174 .34951 L
.45174 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45173 .34951 L
.45172 .34951 L
.45172 .34951 L
.45172 .34951 L
.45172 .34951 L
.45172 .3495 L
.45172 .3495 L
.45172 .3495 L
.45172 .3495 L
.45172 .3495 L
.45172 .3495 L
.45172 .3495 L
Mistroke
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.45171 .3495 L
.4517 .3495 L
.4517 .3495 L
.4517 .3495 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.4517 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45169 .34949 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45168 .34948 L
.45167 .34948 L
.45167 .34948 L
.45167 .34948 L
.45167 .34948 L
Mistroke
.45167 .34948 L
.45167 .34948 L
.45167 .34948 L
.45167 .34948 L
.45167 .34947 L
.45167 .34947 L
.45167 .34947 L
.45167 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45166 .34947 L
.45165 .34947 L
.45165 .34947 L
.45165 .34947 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45165 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34946 L
.45164 .34945 L
.45164 .34945 L
.45164 .34945 L
.45164 .34945 L
.45164 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
Mistroke
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45163 .34945 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45162 .34944 L
.45161 .34944 L
.45161 .34944 L
.45161 .34944 L
.45161 .34944 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.45161 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34943 L
.4516 .34942 L
.4516 .34942 L
.4516 .34942 L
.4516 .34942 L
.4516 .34942 L
.4516 .34942 L
Mistroke
.4516 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34942 L
.45159 .34941 L
.45159 .34941 L
.45159 .34941 L
.45159 .34941 L
.45159 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .34941 L
.45158 .3494 L
.45158 .3494 L
.45158 .3494 L
.45158 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .3494 L
.45157 .34939 L
.45157 .34939 L
.45157 .34939 L
.45157 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
Mistroke
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34939 L
.45156 .34938 L
.45156 .34938 L
.45156 .34938 L
.45156 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34938 L
.45155 .34937 L
.45155 .34937 L
.45155 .34937 L
.45155 .34937 L
.45155 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34937 L
.45154 .34936 L
.45154 .34936 L
.45154 .34936 L
.45154 .34936 L
.45154 .34936 L
.45154 .34936 L
.45153 .34936 L
.45153 .34936 L
.45153 .34936 L
Mistroke
.45153 .34936 L
.45153 .34936 L
.45153 .34936 L
.45153 .34936 L
.45153 .34936 L
.45153 .34936 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45153 .34935 L
.45152 .34935 L
.45152 .34935 L
.45152 .34935 L
.45152 .34935 L
.45152 .34935 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45152 .34934 L
.45151 .34934 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
.45151 .34933 L
Mistroke
.45151 .34933 L
.45151 .34932 L
.45151 .34932 L
.45151 .34932 L
.45151 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34932 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.4515 .34931 L
.45149 .34931 L
.45149 .34931 L
.45149 .34931 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .3493 L
.45149 .34929 L
.45149 .34929 L
.45149 .34929 L
.45149 .34929 L
.45149 .34929 L
.45149 .34929 L
Mistroke
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34929 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34928 L
.45148 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34927 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
.45147 .34926 L
Mistroke
.45147 .34926 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34925 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34924 L
.45146 .34923 L
.45146 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34923 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
Mistroke
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34922 L
.45145 .34921 L
.45145 .34921 L
.45145 .34921 L
.45145 .34921 L
.45145 .34921 L
.45145 .34921 L
.45145 .34921 L
.45144 .34921 L
.45144 .34921 L
.45144 .34921 L
.45144 .34921 L
.45144 .34921 L
.45144 .34921 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .3492 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34919 L
.45144 .34918 L
.45144 .34918 L
.45144 .34918 L
.45144 .34918 L
Mistroke
.45144 .34918 L
.45144 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34918 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34917 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34916 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45143 .34915 L
.45142 .34914 L
Mistroke
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34914 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34913 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34912 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
.45142 .34911 L
Mistroke
.45142 .34911 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .3491 L
.45142 .34909 L
.45142 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34909 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34908 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
Mistroke
.45141 .34907 L
.45141 .34907 L
.45141 .34907 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34906 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34905 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34904 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
Mistroke
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34903 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34902 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .34901 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .349 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
Mistroke
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34899 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34898 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34897 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34896 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
Mistroke
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34895 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34894 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34893 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34892 L
.45141 .34891 L
.45142 .34891 L
.45142 .34891 L
Mistroke
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .34891 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .3489 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34889 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34888 L
.45142 .34887 L
Mistroke
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34887 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45142 .34886 L
.45143 .34886 L
.45143 .34886 L
.45143 .34886 L
.45143 .34886 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34885 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
.45143 .34884 L
Mistroke
.45143 .34884 L
.45143 .34884 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34883 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45143 .34882 L
.45144 .34882 L
.45144 .34882 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .34881 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
Mistroke
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .3488 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34879 L
.45144 .34878 L
.45144 .34878 L
.45144 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34878 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34877 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
Mistroke
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34876 L
.45145 .34875 L
.45145 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34875 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34874 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45146 .34873 L
.45147 .34873 L
Mistroke
.45147 .34873 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34872 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .34871 L
.45147 .3487 L
.45147 .3487 L
.45147 .3487 L
.45147 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .3487 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
Mistroke
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34869 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45148 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34868 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34867 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.45149 .34866 L
.4515 .34866 L
.4515 .34866 L
.4515 .34866 L
.4515 .34866 L
Mistroke
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34865 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.4515 .34864 L
.45151 .34864 L
.45151 .34864 L
.45151 .34864 L
.45151 .34864 L
.45151 .34864 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34863 L
.45151 .34862 L
.45151 .34862 L
.45151 .34862 L
.45151 .34862 L
.45151 .34862 L
.45151 .34862 L
Mistroke
.45151 .34862 L
.45151 .34862 L
.45151 .34862 L
.45152 .34862 L
.45152 .34862 L
.45152 .34862 L
.45152 .34862 L
.45152 .34862 L
.45152 .34862 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .34861 L
.45152 .3486 L
.45152 .3486 L
.45152 .3486 L
.45152 .3486 L
.45152 .3486 L
.45152 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .3486 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
Mistroke
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34859 L
.45153 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34858 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45154 .34857 L
.45155 .34857 L
.45155 .34857 L
.45155 .34857 L
.45155 .34857 L
.45155 .34857 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
.45155 .34856 L
Mistroke
.45155 .34856 L
.45155 .34855 L
.45155 .34855 L
.45155 .34855 L
.45155 .34855 L
.45155 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34855 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45156 .34854 L
.45157 .34854 L
.45157 .34854 L
.45157 .34854 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
.45157 .34853 L
Mistroke
.45157 .34852 L
.45157 .34852 L
.45157 .34852 L
.45157 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34852 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45158 .34851 L
.45159 .34851 L
.45159 .34851 L
.45159 .34851 L
.45159 .34851 L
.45159 .34851 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .3485 L
.45159 .34849 L
Mistroke
.45159 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34849 L
.4516 .34848 L
.4516 .34848 L
.4516 .34848 L
.4516 .34848 L
.4516 .34848 L
.4516 .34848 L
.4516 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34848 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45161 .34847 L
.45162 .34847 L
.45162 .34847 L
.45162 .34847 L
.45162 .34847 L
Mistroke
.45162 .34847 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45162 .34846 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34845 L
.45163 .34844 L
.45163 .34844 L
.45163 .34844 L
.45163 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
Mistroke
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34844 L
.45164 .34843 L
.45164 .34843 L
.45164 .34843 L
.45164 .34843 L
.45164 .34843 L
.45164 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34843 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45165 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34842 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
Mistroke
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45166 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .34841 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45167 .3484 L
.45168 .3484 L
.45168 .3484 L
.45168 .3484 L
.45168 .3484 L
.45168 .3484 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45168 .34839 L
.45169 .34839 L
.45169 .34839 L
.45169 .34839 L
.45169 .34839 L
Mistroke
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.45169 .34838 L
.4517 .34838 L
.4517 .34838 L
.4517 .34838 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.4517 .34837 L
.45171 .34837 L
.45171 .34837 L
.45171 .34837 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
Mistroke
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45171 .34836 L
.45172 .34836 L
.45172 .34836 L
.45172 .34836 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45172 .34835 L
.45173 .34835 L
.45173 .34835 L
.45173 .34835 L
.45173 .34835 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45173 .34834 L
.45174 .34834 L
Mistroke
.45174 .34834 L
.45174 .34834 L
.45174 .34834 L
.45174 .34834 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45174 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34833 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45175 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
.45176 .34832 L
Mistroke
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45176 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .34831 L
.45177 .3483 L
.45177 .3483 L
.45177 .3483 L
.45177 .3483 L
.45177 .3483 L
.45177 .3483 L
.45177 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .3483 L
.45178 .34829 L
.45178 .34829 L
.45178 .34829 L
Mistroke
.45178 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.45179 .34829 L
.4518 .34829 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.4518 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34828 L
.45181 .34827 L
.45181 .34827 L
Mistroke
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45181 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34827 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45182 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
.45183 .34826 L
Mistroke
.45183 .34826 L
.45183 .34826 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45184 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34825 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45185 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
Mistroke
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34824 L
.45186 .34823 L
.45186 .34823 L
.45186 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45187 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34823 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
Mistroke
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45188 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34822 L
.45189 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.4519 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
Mistroke
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .34821 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45191 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45192 .3482 L
.45193 .3482 L
.45193 .3482 L
.45193 .3482 L
.45193 .3482 L
.45193 .3482 L
.45193 .3482 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
Mistroke
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45193 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45194 .34819 L
.45195 .34819 L
.45195 .34819 L
.45195 .34819 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
.45195 .34818 L
Mistroke
.45195 .34818 L
.45195 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45196 .34818 L
.45197 .34818 L
.45197 .34818 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45197 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
Mistroke
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45198 .34817 L
.45199 .34817 L
.45199 .34817 L
.45199 .34817 L
.45199 .34817 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.45199 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
Mistroke
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.452 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34816 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45201 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
Mistroke
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45202 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34815 L
.45203 .34814 L
.45203 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
Mistroke
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45204 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45205 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34814 L
.45206 .34813 L
.45206 .34813 L
.45206 .34813 L
.45206 .34813 L
.45206 .34813 L
Mistroke
.45206 .34813 L
.45206 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45207 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
.45208 .34813 L
Mistroke
.45208 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.45209 .34813 L
.4521 .34813 L
.4521 .34813 L
.4521 .34813 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
.4521 .34812 L
Mistroke
.4521 .34812 L
.4521 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45211 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
Mistroke
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45212 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45213 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
Mistroke
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34812 L
.45214 .34811 L
.45214 .34811 L
.45214 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45215 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
Mistroke
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45216 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45217 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
Mistroke
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45218 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
Mistroke
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.45219 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.4522 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
Mistroke
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45221 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
Mistroke
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45222 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45223 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
Mistroke
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45224 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
Mistroke
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34811 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45225 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
Mistroke
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45226 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
Mistroke
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45227 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
Mistroke
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45228 .34812 L
.45229 .34812 L
.45229 .34812 L
.45229 .34812 L
.45229 .34812 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
Mistroke
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.45229 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
Mistroke
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.4523 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34813 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
Mistroke
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45231 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
Mistroke
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34814 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45232 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
Mistroke
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34815 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
Mistroke
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45233 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
Mistroke
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34816 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
Mistroke
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45234 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34817 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
Mistroke
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
Mistroke
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34818 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45235 .34819 L
.45236 .34819 L
Mistroke
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .34819 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
Mistroke
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .3482 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
Mistroke
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
.45236 .34821 L
Mistroke
.45236 .34821 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
Mistroke
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34822 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
Mistroke
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34823 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
Mistroke
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34824 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
Mistroke
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
Mistroke
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34825 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
Mistroke
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34826 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
Mistroke
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34827 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45236 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
Mistroke
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
Mistroke
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
Mistroke
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .34829 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
Mistroke
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45235 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
Mistroke
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
Mistroke
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34831 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
Mistroke
.45234 .34832 L
.45234 .34832 L
.45234 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
Mistroke
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
Mistroke
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45233 .34833 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
Mistroke
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
Mistroke
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45232 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
Mistroke
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34836 L
.45231 .34836 L
Mistroke
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.45231 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
Mistroke
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
Mistroke
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.4523 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
Mistroke
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
Mistroke
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45229 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
Mistroke
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
Mistroke
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
Mistroke
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
Mistroke
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
Mistroke
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
Mistroke
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45226 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
Mistroke
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
Mistroke
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
Mistroke
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
Mistroke
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
Mistroke
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45224 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
Mistroke
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
Mistroke
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
Mistroke
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
Mfstroke
1 .835 0 r
.53696 .29073 m
.53696 .2908 L
.53696 .29087 L
.53696 .29094 L
.53696 .29101 L
.53696 .29108 L
.53696 .29115 L
.53696 .29122 L
.53695 .29129 L
.53695 .29136 L
.53695 .29143 L
.53695 .2915 L
.53695 .29157 L
.53695 .29164 L
.53694 .29171 L
.53694 .29178 L
.53694 .29185 L
.53694 .29192 L
.53694 .29199 L
.53693 .29206 L
.53693 .29213 L
.53693 .2922 L
.53693 .29227 L
.53692 .29234 L
.53692 .29241 L
.53692 .29248 L
.53691 .29255 L
.53691 .29262 L
.53691 .2927 L
.5369 .29277 L
.5369 .29284 L
.5369 .29291 L
.53689 .29298 L
.53689 .29305 L
.53689 .29312 L
.53688 .29319 L
.53688 .29326 L
.53687 .29333 L
.53687 .2934 L
.53687 .29347 L
.53686 .29354 L
.53686 .29361 L
.53685 .29368 L
.53685 .29375 L
.53684 .29382 L
.53684 .29389 L
.53683 .29396 L
.53683 .29403 L
.53682 .29411 L
.53682 .29418 L
Mistroke
.53681 .29425 L
.53681 .29432 L
.5368 .29439 L
.5368 .29446 L
.53679 .29453 L
.53678 .2946 L
.53678 .29467 L
.53677 .29474 L
.53677 .29481 L
.53676 .29488 L
.53675 .29495 L
.53675 .29502 L
.53674 .2951 L
.53673 .29517 L
.53673 .29524 L
.53672 .29531 L
.53671 .29538 L
.53671 .29545 L
.5367 .29552 L
.53669 .29559 L
.53668 .29566 L
.53668 .29573 L
.53667 .2958 L
.53666 .29587 L
.53665 .29595 L
.53665 .29602 L
.53664 .29609 L
.53663 .29616 L
.53662 .29623 L
.53661 .2963 L
.53661 .29637 L
.5366 .29644 L
.53659 .29651 L
.53658 .29658 L
.53657 .29665 L
.53656 .29673 L
.53655 .2968 L
.53655 .29687 L
.53654 .29694 L
.53653 .29701 L
.53652 .29708 L
.53651 .29715 L
.5365 .29722 L
.53649 .29729 L
.53648 .29737 L
.53647 .29744 L
.53646 .29751 L
.53645 .29758 L
.53644 .29765 L
.53643 .29772 L
Mistroke
.53642 .29779 L
.53641 .29786 L
.5364 .29793 L
.53639 .29801 L
.53638 .29808 L
.53637 .29815 L
.53636 .29822 L
.53635 .29829 L
.53634 .29836 L
.53633 .29843 L
.53631 .2985 L
.5363 .29857 L
.53629 .29865 L
.53628 .29872 L
.53627 .29879 L
.53626 .29886 L
.53625 .29893 L
.53623 .299 L
.53622 .29907 L
.53621 .29914 L
.5362 .29922 L
.53619 .29929 L
.53617 .29936 L
.53616 .29943 L
.53615 .2995 L
.53614 .29957 L
.53612 .29964 L
.53611 .29971 L
.5361 .29979 L
.53609 .29986 L
.53607 .29993 L
.53606 .3 L
.53605 .30007 L
.53603 .30014 L
.53602 .30021 L
.53601 .30028 L
.53599 .30036 L
.53598 .30043 L
.53597 .3005 L
.53595 .30057 L
.53594 .30064 L
.53592 .30071 L
.53591 .30078 L
.5359 .30086 L
.53588 .30093 L
.53587 .301 L
.53585 .30107 L
.53584 .30114 L
.53582 .30121 L
.53581 .30128 L
Mistroke
.5358 .30135 L
.53578 .30143 L
.53577 .3015 L
.53575 .30157 L
.53574 .30164 L
.53572 .30171 L
.5357 .30178 L
.53569 .30185 L
.53567 .30193 L
.53566 .302 L
.53564 .30207 L
.53563 .30214 L
.53561 .30221 L
.5356 .30228 L
.53558 .30235 L
.53556 .30243 L
.53555 .3025 L
.53553 .30257 L
.53551 .30264 L
.5355 .30271 L
.53548 .30278 L
.53546 .30285 L
.53545 .30293 L
.53543 .303 L
.53541 .30307 L
.5354 .30314 L
.53538 .30321 L
.53536 .30328 L
.53535 .30335 L
.53533 .30343 L
.53531 .3035 L
.53529 .30357 L
.53528 .30364 L
.53526 .30371 L
.53524 .30378 L
.53522 .30385 L
.53521 .30393 L
.53519 .304 L
.53517 .30407 L
.53515 .30414 L
.53513 .30421 L
.53511 .30428 L
.5351 .30435 L
.53508 .30443 L
.53506 .3045 L
.53504 .30457 L
.53502 .30464 L
.535 .30471 L
.53498 .30478 L
.53496 .30485 L
Mistroke
.53494 .30493 L
.53493 .305 L
.53491 .30507 L
.53489 .30514 L
.53487 .30521 L
.53485 .30528 L
.53483 .30535 L
.53481 .30543 L
.53479 .3055 L
.53477 .30557 L
.53475 .30564 L
.53473 .30571 L
.53471 .30578 L
.53469 .30585 L
.53467 .30593 L
.53465 .306 L
.53463 .30607 L
.53461 .30614 L
.53459 .30621 L
.53456 .30628 L
.53454 .30635 L
.53452 .30643 L
.5345 .3065 L
.53448 .30657 L
.53446 .30664 L
.53444 .30671 L
.53442 .30678 L
.5344 .30685 L
.53437 .30692 L
.53435 .307 L
.53433 .30707 L
.53431 .30714 L
.53429 .30721 L
.53427 .30728 L
.53424 .30735 L
.53422 .30742 L
.5342 .3075 L
.53418 .30757 L
.53415 .30764 L
.53413 .30771 L
.53411 .30778 L
.53409 .30785 L
.53406 .30792 L
.53404 .30799 L
.53402 .30807 L
.534 .30814 L
.53397 .30821 L
.53395 .30828 L
.53393 .30835 L
.5339 .30842 L
Mistroke
.53388 .30849 L
.53386 .30857 L
.53383 .30864 L
.53381 .30871 L
.53379 .30878 L
.53376 .30885 L
.53374 .30892 L
.53371 .30899 L
.53369 .30906 L
.53367 .30913 L
.53364 .30921 L
.53362 .30928 L
.53359 .30935 L
.53357 .30942 L
.53354 .30949 L
.53352 .30956 L
.5335 .30963 L
.53347 .3097 L
.53345 .30978 L
.53342 .30985 L
.5334 .30992 L
.53337 .30999 L
.53335 .31006 L
.53332 .31013 L
.5333 .3102 L
.53327 .31027 L
.53324 .31034 L
.53322 .31042 L
.53319 .31049 L
.53317 .31056 L
.53314 .31063 L
.53312 .3107 L
.53309 .31077 L
.53306 .31084 L
.53304 .31091 L
.53301 .31098 L
.53299 .31106 L
.53296 .31113 L
.53293 .3112 L
.53291 .31127 L
.53288 .31134 L
.53285 .31141 L
.53283 .31148 L
.5328 .31155 L
.53277 .31162 L
.53275 .31169 L
.53272 .31177 L
.53269 .31184 L
.53267 .31191 L
.53264 .31198 L
Mistroke
.53261 .31205 L
.53258 .31212 L
.53256 .31219 L
.53253 .31226 L
.5325 .31233 L
.53247 .3124 L
.53245 .31247 L
.53242 .31255 L
.53239 .31262 L
.53236 .31269 L
.53233 .31276 L
.53231 .31283 L
.53228 .3129 L
.53225 .31297 L
.53222 .31304 L
.53219 .31311 L
.53216 .31318 L
.53213 .31325 L
.53211 .31332 L
.53208 .3134 L
.53205 .31347 L
.53202 .31354 L
.53199 .31361 L
.53196 .31368 L
.53193 .31375 L
.5319 .31382 L
.53187 .31389 L
.53184 .31396 L
.53181 .31403 L
.53179 .3141 L
.53176 .31417 L
.53173 .31424 L
.5317 .31431 L
.53167 .31438 L
.53164 .31445 L
.53161 .31453 L
.53158 .3146 L
.53155 .31467 L
.53152 .31474 L
.53149 .31481 L
.53146 .31488 L
.53143 .31495 L
.53139 .31502 L
.53136 .31509 L
.53133 .31516 L
.5313 .31523 L
.53127 .3153 L
.53124 .31537 L
.53121 .31544 L
.53118 .31551 L
Mistroke
.53115 .31558 L
.53112 .31565 L
.53109 .31572 L
.53106 .31579 L
.53102 .31586 L
.53099 .31593 L
.53096 .316 L
.53093 .31607 L
.5309 .31614 L
.53087 .31621 L
.53083 .31629 L
.5308 .31636 L
.53077 .31643 L
.53074 .3165 L
.53071 .31657 L
.53067 .31664 L
.53064 .31671 L
.53061 .31678 L
.53058 .31685 L
.53054 .31692 L
.53051 .31699 L
.53048 .31706 L
.53045 .31713 L
.53041 .3172 L
.53038 .31727 L
.53035 .31734 L
.53032 .31741 L
.53028 .31748 L
.53025 .31755 L
.53022 .31762 L
.53018 .31769 L
.53015 .31776 L
.53012 .31783 L
.53008 .3179 L
.53005 .31797 L
.53002 .31804 L
.52998 .31811 L
.52995 .31818 L
.52992 .31825 L
.52988 .31832 L
.52985 .31839 L
.52981 .31846 L
.52978 .31852 L
.52975 .31859 L
.52971 .31866 L
.52968 .31873 L
.52964 .3188 L
.52961 .31887 L
.52957 .31894 L
.52954 .31901 L
Mistroke
.52951 .31908 L
.52947 .31915 L
.52944 .31922 L
.5294 .31929 L
.52937 .31936 L
.52933 .31943 L
.5293 .3195 L
.52926 .31957 L
.52923 .31964 L
.52919 .31971 L
.52916 .31978 L
.52912 .31985 L
.52909 .31992 L
.52905 .31999 L
.52901 .32006 L
.52898 .32012 L
.52894 .32019 L
.52891 .32026 L
.52887 .32033 L
.52884 .3204 L
.5288 .32047 L
.52876 .32054 L
.52873 .32061 L
.52869 .32068 L
.52866 .32075 L
.52862 .32082 L
.52858 .32089 L
.52855 .32096 L
.52851 .32102 L
.52847 .32109 L
.52844 .32116 L
.5284 .32123 L
.52836 .3213 L
.52833 .32137 L
.52829 .32144 L
.52825 .32151 L
.52822 .32158 L
.52818 .32165 L
.52814 .32171 L
.52811 .32178 L
.52807 .32185 L
.52803 .32192 L
.52799 .32199 L
.52796 .32206 L
.52792 .32213 L
.52788 .3222 L
.52784 .32227 L
.52781 .32233 L
.52777 .3224 L
.52773 .32247 L
Mistroke
.52769 .32254 L
.52766 .32261 L
.52762 .32268 L
.52758 .32275 L
.52754 .32281 L
.5275 .32288 L
.52747 .32295 L
.52743 .32302 L
.52739 .32309 L
.52735 .32316 L
.52731 .32323 L
.52727 .32329 L
.52724 .32336 L
.5272 .32343 L
.52716 .3235 L
.52712 .32357 L
.52708 .32364 L
.52704 .3237 L
.527 .32377 L
.52696 .32384 L
.52692 .32391 L
.52689 .32398 L
.52685 .32405 L
.52681 .32411 L
.52677 .32418 L
.52673 .32425 L
.52669 .32432 L
.52665 .32439 L
.52661 .32445 L
.52657 .32452 L
.52653 .32459 L
.52649 .32466 L
.52645 .32473 L
.52641 .32479 L
.52637 .32486 L
.52633 .32493 L
.52629 .325 L
.52625 .32507 L
.52621 .32513 L
.52617 .3252 L
.52613 .32527 L
.52609 .32534 L
.52605 .32541 L
.52601 .32547 L
.52597 .32554 L
.52593 .32561 L
.52589 .32568 L
.52585 .32574 L
.52581 .32581 L
.52577 .32588 L
Mistroke
.52573 .32595 L
.52568 .32601 L
.52564 .32608 L
.5256 .32615 L
.52556 .32622 L
.52552 .32628 L
.52548 .32635 L
.52544 .32642 L
.5254 .32649 L
.52536 .32655 L
.52531 .32662 L
.52527 .32669 L
.52523 .32675 L
.52519 .32682 L
.52515 .32689 L
.52511 .32696 L
.52506 .32702 L
.52502 .32709 L
.52498 .32716 L
.52494 .32722 L
.5249 .32729 L
.52486 .32736 L
.52481 .32743 L
.52477 .32749 L
.52473 .32756 L
.52469 .32763 L
.52464 .32769 L
.5246 .32776 L
.52456 .32783 L
.52452 .32789 L
.52447 .32796 L
.52443 .32803 L
.52439 .32809 L
.52435 .32816 L
.5243 .32823 L
.52426 .32829 L
.52422 .32836 L
.52418 .32843 L
.52413 .32849 L
.52409 .32856 L
.52405 .32863 L
.524 .32869 L
.52396 .32876 L
.52392 .32883 L
.52387 .32889 L
.52383 .32896 L
.52379 .32903 L
.52374 .32909 L
.5237 .32916 L
.52366 .32922 L
Mistroke
.52361 .32929 L
.52357 .32936 L
.52353 .32942 L
.52348 .32949 L
.52344 .32956 L
.52339 .32962 L
.52335 .32969 L
.52331 .32975 L
.52326 .32982 L
.52322 .32989 L
.52317 .32995 L
.52313 .33002 L
.52309 .33008 L
.52304 .33015 L
.523 .33022 L
.52295 .33028 L
.52291 .33035 L
.52286 .33041 L
.52282 .33048 L
.52278 .33054 L
.52273 .33061 L
.52269 .33068 L
.52264 .33074 L
.5226 .33081 L
.52255 .33087 L
.52251 .33094 L
.52246 .331 L
.52242 .33107 L
.52237 .33113 L
.52233 .3312 L
.52228 .33126 L
.52224 .33133 L
.52219 .3314 L
.52215 .33146 L
.5221 .33153 L
.52206 .33159 L
.52201 .33166 L
.52197 .33172 L
.52192 .33179 L
.52187 .33185 L
.52183 .33192 L
.52178 .33198 L
.52174 .33205 L
.52169 .33211 L
.52165 .33218 L
.5216 .33224 L
.52155 .33231 L
.52151 .33237 L
.52146 .33244 L
.52142 .3325 L
Mistroke
.52137 .33257 L
.52132 .33263 L
.52128 .3327 L
.52123 .33276 L
.52119 .33282 L
.52114 .33289 L
.52109 .33295 L
.52105 .33302 L
.521 .33308 L
.52095 .33315 L
.52091 .33321 L
.52086 .33328 L
.52081 .33334 L
.52077 .33341 L
.52072 .33347 L
.52067 .33353 L
.52063 .3336 L
.52058 .33366 L
.52053 .33373 L
.52049 .33379 L
.52044 .33385 L
.52039 .33392 L
.52035 .33398 L
.5203 .33405 L
.52025 .33411 L
.5202 .33417 L
.52016 .33424 L
.52011 .3343 L
.52006 .33437 L
.52001 .33443 L
.51997 .33449 L
.51992 .33456 L
.51987 .33462 L
.51982 .33469 L
.51978 .33475 L
.51973 .33481 L
.51968 .33488 L
.51963 .33494 L
.51959 .335 L
.51954 .33507 L
.51949 .33513 L
.51944 .33519 L
.51939 .33526 L
.51935 .33532 L
.5193 .33538 L
.51925 .33545 L
.5192 .33551 L
.51915 .33557 L
.51911 .33564 L
.51906 .3357 L
Mistroke
.51901 .33576 L
.51896 .33583 L
.51891 .33589 L
.51886 .33595 L
.51882 .33601 L
.51877 .33608 L
.51872 .33614 L
.51867 .3362 L
.51862 .33627 L
.51857 .33633 L
.51852 .33639 L
.51848 .33645 L
.51843 .33652 L
.51838 .33658 L
.51833 .33664 L
.51828 .33671 L
.51823 .33677 L
.51818 .33683 L
.51813 .33689 L
.51808 .33696 L
.51803 .33702 L
.51799 .33708 L
.51794 .33714 L
.51789 .3372 L
.51784 .33727 L
.51779 .33733 L
.51774 .33739 L
.51769 .33745 L
.51764 .33752 L
.51759 .33758 L
.51754 .33764 L
.51749 .3377 L
.51744 .33776 L
.51739 .33783 L
.51734 .33789 L
.51729 .33795 L
.51724 .33801 L
.51719 .33807 L
.51714 .33814 L
.51709 .3382 L
.51704 .33826 L
.51699 .33832 L
.51694 .33838 L
.51689 .33844 L
.51684 .3385 L
.51679 .33857 L
.51674 .33863 L
.51669 .33869 L
.51664 .33875 L
.51659 .33881 L
Mistroke
.51654 .33887 L
.51649 .33893 L
.51644 .339 L
.51639 .33906 L
.51634 .33912 L
.51629 .33918 L
.51624 .33924 L
.51619 .3393 L
.51614 .33936 L
.51609 .33942 L
.51604 .33948 L
.51599 .33955 L
.51594 .33961 L
.51589 .33967 L
.51584 .33973 L
.51579 .33979 L
.51573 .33985 L
.51568 .33991 L
.51563 .33997 L
.51558 .34003 L
.51553 .34009 L
.51548 .34015 L
.51543 .34021 L
.51538 .34027 L
.51533 .34033 L
.51528 .34039 L
.51522 .34045 L
.51517 .34051 L
.51512 .34057 L
.51507 .34064 L
.51502 .3407 L
.51497 .34076 L
.51492 .34082 L
.51487 .34088 L
.51481 .34094 L
.51476 .341 L
.51471 .34106 L
.51466 .34112 L
.51461 .34118 L
.51456 .34123 L
.5145 .34129 L
.51445 .34135 L
.5144 .34141 L
.51435 .34147 L
.5143 .34153 L
.51425 .34159 L
.51419 .34165 L
.51414 .34171 L
.51409 .34177 L
.51404 .34183 L
Mistroke
.51399 .34189 L
.51393 .34195 L
.51388 .34201 L
.51383 .34207 L
.51378 .34213 L
.51373 .34219 L
.51367 .34225 L
.51362 .3423 L
.51357 .34236 L
.51352 .34242 L
.51346 .34248 L
.51341 .34254 L
.51336 .3426 L
.51331 .34266 L
.51325 .34272 L
.5132 .34278 L
.51315 .34283 L
.5131 .34289 L
.51305 .34295 L
.51299 .34301 L
.51294 .34307 L
.51289 .34313 L
.51283 .34319 L
.51278 .34324 L
.51273 .3433 L
.51268 .34336 L
.51262 .34342 L
.51257 .34348 L
.51252 .34354 L
.51247 .34359 L
.51241 .34365 L
.51236 .34371 L
.51231 .34377 L
.51225 .34383 L
.5122 .34388 L
.51215 .34394 L
.51209 .344 L
.51204 .34406 L
.51199 .34412 L
.51194 .34417 L
.51188 .34423 L
.51183 .34429 L
.51178 .34435 L
.51172 .3444 L
.51167 .34446 L
.51162 .34452 L
.51156 .34458 L
.51151 .34463 L
.51146 .34469 L
.5114 .34475 L
Mistroke
.51135 .34481 L
.5113 .34486 L
.51124 .34492 L
.51119 .34498 L
.51114 .34504 L
.51108 .34509 L
.51103 .34515 L
.51097 .34521 L
.51092 .34526 L
.51087 .34532 L
.51081 .34538 L
.51076 .34543 L
.51071 .34549 L
.51065 .34555 L
.5106 .3456 L
.51054 .34566 L
.51049 .34572 L
.51044 .34577 L
.51038 .34583 L
.51033 .34589 L
.51028 .34594 L
.51022 .346 L
.51017 .34606 L
.51011 .34611 L
.51006 .34617 L
.51001 .34622 L
.50995 .34628 L
.5099 .34634 L
.50984 .34639 L
.50979 .34645 L
.50973 .34651 L
.50968 .34656 L
.50963 .34662 L
.50957 .34667 L
.50952 .34673 L
.50946 .34678 L
.50941 .34684 L
.50935 .3469 L
.5093 .34695 L
.50925 .34701 L
.50919 .34706 L
.50914 .34712 L
.50908 .34717 L
.50903 .34723 L
.50897 .34728 L
.50892 .34734 L
.50886 .3474 L
.50881 .34745 L
.50876 .34751 L
.5087 .34756 L
Mistroke
.50865 .34762 L
.50859 .34767 L
.50854 .34773 L
.50848 .34778 L
.50843 .34784 L
.50837 .34789 L
.50832 .34795 L
.50826 .348 L
.50821 .34805 L
.50815 .34811 L
.5081 .34816 L
.50804 .34822 L
.50799 .34827 L
.50793 .34833 L
.50788 .34838 L
.50782 .34844 L
.50777 .34849 L
.50771 .34855 L
.50766 .3486 L
.5076 .34865 L
.50755 .34871 L
.50749 .34876 L
.50744 .34882 L
.50738 .34887 L
.50733 .34892 L
.50727 .34898 L
.50722 .34903 L
.50716 .34909 L
.50711 .34914 L
.50705 .34919 L
.507 .34925 L
.50694 .3493 L
.50689 .34935 L
.50683 .34941 L
.50678 .34946 L
.50672 .34952 L
.50667 .34957 L
.50661 .34962 L
.50656 .34968 L
.5065 .34973 L
.50644 .34978 L
.50639 .34984 L
.50633 .34989 L
.50628 .34994 L
.50622 .34999 L
.50617 .35005 L
.50611 .3501 L
.50606 .35015 L
.506 .35021 L
.50594 .35026 L
Mistroke
.50589 .35031 L
.50583 .35037 L
.50578 .35042 L
.50572 .35047 L
.50567 .35052 L
.50561 .35058 L
.50556 .35063 L
.5055 .35068 L
.50544 .35073 L
.50539 .35079 L
.50533 .35084 L
.50528 .35089 L
.50522 .35094 L
.50517 .35099 L
.50511 .35105 L
.50505 .3511 L
.505 .35115 L
.50494 .3512 L
.50489 .35125 L
.50483 .35131 L
.50477 .35136 L
.50472 .35141 L
.50466 .35146 L
.50461 .35151 L
.50455 .35157 L
.50449 .35162 L
.50444 .35167 L
.50438 .35172 L
.50433 .35177 L
.50427 .35182 L
.50421 .35187 L
.50416 .35193 L
.5041 .35198 L
.50405 .35203 L
.50399 .35208 L
.50393 .35213 L
.50388 .35218 L
.50382 .35223 L
.50377 .35228 L
.50371 .35233 L
.50365 .35239 L
.5036 .35244 L
.50354 .35249 L
.50348 .35254 L
.50343 .35259 L
.50337 .35264 L
.50332 .35269 L
.50326 .35274 L
.5032 .35279 L
.50315 .35284 L
Mistroke
.50309 .35289 L
.50303 .35294 L
.50298 .35299 L
.50292 .35304 L
.50287 .35309 L
.50281 .35314 L
.50275 .35319 L
.5027 .35324 L
.50264 .35329 L
.50258 .35334 L
.50253 .35339 L
.50247 .35344 L
.50241 .35349 L
.50236 .35354 L
.5023 .35359 L
.50224 .35364 L
.50219 .35369 L
.50213 .35374 L
.50208 .35379 L
.50202 .35384 L
.50196 .35389 L
.50191 .35394 L
.50185 .35399 L
.50179 .35404 L
.50174 .35409 L
.50168 .35413 L
.50162 .35418 L
.50157 .35423 L
.50151 .35428 L
.50145 .35433 L
.5014 .35438 L
.50134 .35443 L
.50128 .35448 L
.50123 .35453 L
.50117 .35458 L
.50111 .35462 L
.50106 .35467 L
.501 .35472 L
.50094 .35477 L
.50089 .35482 L
.50083 .35487 L
.50077 .35491 L
.50072 .35496 L
.50066 .35501 L
.5006 .35506 L
.50055 .35511 L
.50049 .35516 L
.50043 .3552 L
.50038 .35525 L
.50032 .3553 L
Mistroke
.50026 .35535 L
.50021 .3554 L
.50015 .35544 L
.50009 .35549 L
.50004 .35554 L
.49998 .35559 L
.49992 .35563 L
.49986 .35568 L
.49981 .35573 L
.49975 .35578 L
.49969 .35582 L
.49964 .35587 L
.49958 .35592 L
.49952 .35597 L
.49947 .35601 L
.49941 .35606 L
.49935 .35611 L
.4993 .35615 L
.49924 .3562 L
.49918 .35625 L
.49913 .3563 L
.49907 .35634 L
.49901 .35639 L
.49895 .35644 L
.4989 .35648 L
.49884 .35653 L
.49878 .35658 L
.49873 .35662 L
.49867 .35667 L
.49861 .35671 L
.49856 .35676 L
.4985 .35681 L
.49844 .35685 L
.49838 .3569 L
.49833 .35695 L
.49827 .35699 L
.49821 .35704 L
.49816 .35708 L
.4981 .35713 L
.49804 .35718 L
.49799 .35722 L
.49793 .35727 L
.49787 .35731 L
.49781 .35736 L
.49776 .3574 L
.4977 .35745 L
.49764 .3575 L
.49759 .35754 L
.49753 .35759 L
.49747 .35763 L
Mistroke
.49742 .35768 L
.49736 .35772 L
.4973 .35777 L
.49724 .35781 L
.49719 .35786 L
.49713 .3579 L
.49707 .35795 L
.49702 .35799 L
.49696 .35804 L
.4969 .35808 L
.49685 .35813 L
.49679 .35817 L
.49673 .35822 L
.49667 .35826 L
.49662 .35831 L
.49656 .35835 L
.4965 .3584 L
.49645 .35844 L
.49639 .35849 L
.49633 .35853 L
.49627 .35857 L
.49622 .35862 L
.49616 .35866 L
.4961 .35871 L
.49605 .35875 L
.49599 .35879 L
.49593 .35884 L
.49587 .35888 L
.49582 .35893 L
.49576 .35897 L
.4957 .35901 L
.49565 .35906 L
.49559 .3591 L
.49553 .35915 L
.49548 .35919 L
.49542 .35923 L
.49536 .35928 L
.4953 .35932 L
.49525 .35936 L
.49519 .35941 L
.49513 .35945 L
.49508 .35949 L
.49502 .35954 L
.49496 .35958 L
.4949 .35962 L
.49485 .35966 L
.49479 .35971 L
.49473 .35975 L
.49468 .35979 L
.49462 .35984 L
Mistroke
.49456 .35988 L
.4945 .35992 L
.49445 .35996 L
.49439 .36001 L
.49433 .36005 L
.49428 .36009 L
.49422 .36013 L
.49416 .36018 L
.4941 .36022 L
.49405 .36026 L
.49399 .3603 L
.49393 .36035 L
.49388 .36039 L
.49382 .36043 L
.49376 .36047 L
.49371 .36051 L
.49365 .36056 L
.49359 .3606 L
.49353 .36064 L
.49348 .36068 L
.49342 .36072 L
.49336 .36076 L
.49331 .36081 L
.49325 .36085 L
.49319 .36089 L
.49314 .36093 L
.49308 .36097 L
.49302 .36101 L
.49296 .36105 L
.49291 .3611 L
.49285 .36114 L
.49279 .36118 L
.49274 .36122 L
.49268 .36126 L
.49262 .3613 L
.49256 .36134 L
.49251 .36138 L
.49245 .36142 L
.49239 .36146 L
.49234 .3615 L
.49228 .36154 L
.49222 .36159 L
.49217 .36163 L
.49211 .36167 L
.49205 .36171 L
.492 .36175 L
.49194 .36179 L
.49188 .36183 L
.49182 .36187 L
.49177 .36191 L
Mistroke
.49171 .36195 L
.49165 .36199 L
.4916 .36203 L
.49154 .36207 L
.49148 .36211 L
.49143 .36215 L
.49137 .36219 L
.49131 .36223 L
.49126 .36227 L
.4912 .36231 L
.49114 .36235 L
.49108 .36239 L
.49103 .36242 L
.49097 .36246 L
.49091 .3625 L
.49086 .36254 L
.4908 .36258 L
.49074 .36262 L
.49069 .36266 L
.49063 .3627 L
.49057 .36274 L
.49052 .36278 L
.49046 .36282 L
.4904 .36285 L
.49035 .36289 L
.49029 .36293 L
.49023 .36297 L
.49018 .36301 L
.49012 .36305 L
.49006 .36309 L
.49001 .36313 L
.48995 .36316 L
.48989 .3632 L
.48984 .36324 L
.48978 .36328 L
.48972 .36332 L
.48967 .36336 L
.48961 .36339 L
.48955 .36343 L
.4895 .36347 L
.48944 .36351 L
.48938 .36354 L
.48933 .36358 L
.48927 .36362 L
.48921 .36366 L
.48916 .3637 L
.4891 .36373 L
.48904 .36377 L
.48899 .36381 L
.48893 .36385 L
Mistroke
.48887 .36388 L
.48882 .36392 L
.48876 .36396 L
.4887 .364 L
.48865 .36403 L
.48859 .36407 L
.48853 .36411 L
.48848 .36414 L
.48842 .36418 L
.48836 .36422 L
.48831 .36425 L
.48825 .36429 L
.48819 .36433 L
.48814 .36436 L
.48808 .3644 L
.48803 .36444 L
.48797 .36447 L
.48791 .36451 L
.48786 .36455 L
.4878 .36458 L
.48774 .36462 L
.48769 .36466 L
.48763 .36469 L
.48757 .36473 L
.48752 .36476 L
.48746 .3648 L
.48741 .36484 L
.48735 .36487 L
.48729 .36491 L
.48724 .36494 L
.48718 .36498 L
.48712 .36502 L
.48707 .36505 L
.48701 .36509 L
.48696 .36512 L
.4869 .36516 L
.48684 .36519 L
.48679 .36523 L
.48673 .36526 L
.48667 .3653 L
.48662 .36533 L
.48656 .36537 L
.48651 .3654 L
.48645 .36544 L
.48639 .36548 L
.48634 .36551 L
.48628 .36554 L
.48623 .36558 L
.48617 .36561 L
.48611 .36565 L
Mistroke
.48606 .36568 L
.486 .36572 L
.48595 .36575 L
.48589 .36579 L
.48583 .36582 L
.48578 .36586 L
.48572 .36589 L
.48567 .36593 L
.48561 .36596 L
.48555 .36599 L
.4855 .36603 L
.48544 .36606 L
.48539 .3661 L
.48533 .36613 L
.48527 .36616 L
.48522 .3662 L
.48516 .36623 L
.48511 .36627 L
.48505 .3663 L
.48499 .36633 L
.48494 .36637 L
.48488 .3664 L
.48483 .36643 L
.48477 .36647 L
.48472 .3665 L
.48466 .36653 L
.4846 .36657 L
.48455 .3666 L
.48449 .36663 L
.48444 .36667 L
.48438 .3667 L
.48433 .36673 L
.48427 .36677 L
.48422 .3668 L
.48416 .36683 L
.4841 .36686 L
.48405 .3669 L
.48399 .36693 L
.48394 .36696 L
.48388 .36699 L
.48383 .36703 L
.48377 .36706 L
.48372 .36709 L
.48366 .36712 L
.48361 .36716 L
.48355 .36719 L
.48349 .36722 L
.48344 .36725 L
.48338 .36728 L
.48333 .36732 L
Mistroke
.48327 .36735 L
.48322 .36738 L
.48316 .36741 L
.48311 .36744 L
.48305 .36748 L
.483 .36751 L
.48294 .36754 L
.48289 .36757 L
.48283 .3676 L
.48278 .36763 L
.48272 .36767 L
.48267 .3677 L
.48261 .36773 L
.48256 .36776 L
.4825 .36779 L
.48244 .36782 L
.48239 .36785 L
.48233 .36788 L
.48228 .36792 L
.48222 .36795 L
.48217 .36798 L
.48211 .36801 L
.48206 .36804 L
.482 .36807 L
.48195 .3681 L
.4819 .36813 L
.48184 .36816 L
.48179 .36819 L
.48173 .36822 L
.48168 .36825 L
.48162 .36828 L
.48157 .36831 L
.48151 .36834 L
.48146 .36837 L
.4814 .3684 L
.48135 .36843 L
.48129 .36846 L
.48124 .36849 L
.48118 .36852 L
.48113 .36855 L
.48107 .36858 L
.48102 .36861 L
.48096 .36864 L
.48091 .36867 L
.48086 .3687 L
.4808 .36873 L
.48075 .36876 L
.48069 .36879 L
.48064 .36882 L
.48058 .36885 L
Mistroke
.48053 .36888 L
.48047 .36891 L
.48042 .36894 L
.48036 .36897 L
.48031 .369 L
.48026 .36902 L
.4802 .36905 L
.48015 .36908 L
.48009 .36911 L
.48004 .36914 L
.47998 .36917 L
.47993 .3692 L
.47988 .36923 L
.47982 .36925 L
.47977 .36928 L
.47971 .36931 L
.47966 .36934 L
.47961 .36937 L
.47955 .3694 L
.4795 .36942 L
.47944 .36945 L
.47939 .36948 L
.47933 .36951 L
.47928 .36954 L
.47923 .36956 L
.47917 .36959 L
.47912 .36962 L
.47907 .36965 L
.47901 .36968 L
.47896 .3697 L
.4789 .36973 L
.47885 .36976 L
.4788 .36979 L
.47874 .36981 L
.47869 .36984 L
.47863 .36987 L
.47858 .3699 L
.47853 .36992 L
.47847 .36995 L
.47842 .36998 L
.47837 .37001 L
.47831 .37003 L
.47826 .37006 L
.4782 .37009 L
.47815 .37011 L
.4781 .37014 L
.47804 .37017 L
.47799 .37019 L
.47794 .37022 L
.47788 .37025 L
Mistroke
.47783 .37027 L
.47778 .3703 L
.47772 .37033 L
.47767 .37035 L
.47762 .37038 L
.47756 .37041 L
.47751 .37043 L
.47746 .37046 L
.4774 .37048 L
.47735 .37051 L
.4773 .37054 L
.47724 .37056 L
.47719 .37059 L
.47714 .37061 L
.47708 .37064 L
.47703 .37067 L
.47698 .37069 L
.47693 .37072 L
.47687 .37074 L
.47682 .37077 L
.47677 .37079 L
.47671 .37082 L
.47666 .37084 L
.47661 .37087 L
.47655 .3709 L
.4765 .37092 L
.47645 .37095 L
.4764 .37097 L
.47634 .371 L
.47629 .37102 L
.47624 .37105 L
.47618 .37107 L
.47613 .3711 L
.47608 .37112 L
.47603 .37115 L
.47597 .37117 L
.47592 .37119 L
.47587 .37122 L
.47582 .37124 L
.47576 .37127 L
.47571 .37129 L
.47566 .37132 L
.47561 .37134 L
.47555 .37137 L
.4755 .37139 L
.47545 .37141 L
.4754 .37144 L
.47534 .37146 L
.47529 .37149 L
.47524 .37151 L
Mistroke
.47519 .37153 L
.47513 .37156 L
.47508 .37158 L
.47503 .37161 L
.47498 .37163 L
.47493 .37165 L
.47487 .37168 L
.47482 .3717 L
.47477 .37172 L
.47472 .37175 L
.47467 .37177 L
.47461 .37179 L
.47456 .37182 L
.47451 .37184 L
.47446 .37186 L
.47441 .37189 L
.47435 .37191 L
.4743 .37193 L
.47425 .37196 L
.4742 .37198 L
.47415 .372 L
.47409 .37202 L
.47404 .37205 L
.47399 .37207 L
.47394 .37209 L
.47389 .37211 L
.47384 .37214 L
.47378 .37216 L
.47373 .37218 L
.47368 .3722 L
.47363 .37223 L
.47358 .37225 L
.47353 .37227 L
.47348 .37229 L
.47342 .37232 L
.47337 .37234 L
.47332 .37236 L
.47327 .37238 L
.47322 .3724 L
.47317 .37243 L
.47312 .37245 L
.47306 .37247 L
.47301 .37249 L
.47296 .37251 L
.47291 .37253 L
.47286 .37256 L
.47281 .37258 L
.47276 .3726 L
.47271 .37262 L
.47265 .37264 L
Mistroke
.4726 .37266 L
.47255 .37268 L
.4725 .37271 L
.47245 .37273 L
.4724 .37275 L
.47235 .37277 L
.4723 .37279 L
.47225 .37281 L
.4722 .37283 L
.47215 .37285 L
.4721 .37287 L
.47204 .37289 L
.47199 .37291 L
.47194 .37294 L
.47189 .37296 L
.47184 .37298 L
.47179 .373 L
.47174 .37302 L
.47169 .37304 L
.47164 .37306 L
.47159 .37308 L
.47154 .3731 L
.47149 .37312 L
.47144 .37314 L
.47139 .37316 L
.47134 .37318 L
.47129 .3732 L
.47124 .37322 L
.47119 .37324 L
.47114 .37326 L
.47109 .37328 L
.47104 .3733 L
.47099 .37332 L
.47094 .37334 L
.47089 .37336 L
.47084 .37338 L
.47078 .3734 L
.47073 .37341 L
.47068 .37343 L
.47064 .37345 L
.47059 .37347 L
.47054 .37349 L
.47049 .37351 L
.47044 .37353 L
.47039 .37355 L
.47034 .37357 L
.47029 .37359 L
.47024 .37361 L
.47019 .37362 L
.47014 .37364 L
Mistroke
.47009 .37366 L
.47004 .37368 L
.46999 .3737 L
.46994 .37372 L
.46989 .37374 L
.46984 .37375 L
.46979 .37377 L
.46974 .37379 L
.46969 .37381 L
.46964 .37383 L
.46959 .37385 L
.46954 .37386 L
.46949 .37388 L
.46944 .3739 L
.4694 .37392 L
.46935 .37394 L
.4693 .37395 L
.46925 .37397 L
.4692 .37399 L
.46915 .37401 L
.4691 .37403 L
.46905 .37404 L
.469 .37406 L
.46895 .37408 L
.4689 .3741 L
.46886 .37411 L
.46881 .37413 L
.46876 .37415 L
.46871 .37417 L
.46866 .37418 L
.46861 .3742 L
.46856 .37422 L
.46851 .37423 L
.46847 .37425 L
.46842 .37427 L
.46837 .37429 L
.46832 .3743 L
.46827 .37432 L
.46822 .37434 L
.46817 .37435 L
.46813 .37437 L
.46808 .37439 L
.46803 .3744 L
.46798 .37442 L
.46793 .37444 L
.46788 .37445 L
.46784 .37447 L
.46779 .37448 L
.46774 .3745 L
.46769 .37452 L
Mistroke
.46764 .37453 L
.46759 .37455 L
.46755 .37457 L
.4675 .37458 L
.46745 .3746 L
.4674 .37461 L
.46735 .37463 L
.46731 .37465 L
.46726 .37466 L
.46721 .37468 L
.46716 .37469 L
.46711 .37471 L
.46707 .37472 L
.46702 .37474 L
.46697 .37476 L
.46692 .37477 L
.46688 .37479 L
.46683 .3748 L
.46678 .37482 L
.46673 .37483 L
.46669 .37485 L
.46664 .37486 L
.46659 .37488 L
.46654 .37489 L
.4665 .37491 L
.46645 .37492 L
.4664 .37494 L
.46635 .37495 L
.46631 .37497 L
.46626 .37498 L
.46621 .375 L
.46616 .37501 L
.46612 .37503 L
.46607 .37504 L
.46602 .37505 L
.46598 .37507 L
.46593 .37508 L
.46588 .3751 L
.46583 .37511 L
.46579 .37513 L
.46574 .37514 L
.46569 .37516 L
.46565 .37517 L
.4656 .37518 L
.46555 .3752 L
.46551 .37521 L
.46546 .37523 L
.46541 .37524 L
.46537 .37525 L
.46532 .37527 L
Mistroke
.46527 .37528 L
.46523 .37529 L
.46518 .37531 L
.46513 .37532 L
.46509 .37534 L
.46504 .37535 L
.46499 .37536 L
.46495 .37538 L
.4649 .37539 L
.46486 .3754 L
.46481 .37542 L
.46476 .37543 L
.46472 .37544 L
.46467 .37546 L
.46462 .37547 L
.46458 .37548 L
.46453 .37549 L
.46449 .37551 L
.46444 .37552 L
.46439 .37553 L
.46435 .37555 L
.4643 .37556 L
.46426 .37557 L
.46421 .37558 L
.46416 .3756 L
.46412 .37561 L
.46407 .37562 L
.46403 .37563 L
.46398 .37565 L
.46394 .37566 L
.46389 .37567 L
.46384 .37568 L
.4638 .3757 L
.46375 .37571 L
.46371 .37572 L
.46366 .37573 L
.46362 .37574 L
.46357 .37576 L
.46353 .37577 L
.46348 .37578 L
.46344 .37579 L
.46339 .3758 L
.46335 .37581 L
.4633 .37583 L
.46325 .37584 L
.46321 .37585 L
.46316 .37586 L
.46312 .37587 L
.46307 .37588 L
.46303 .3759 L
Mistroke
.46298 .37591 L
.46294 .37592 L
.46289 .37593 L
.46285 .37594 L
.4628 .37595 L
.46276 .37596 L
.46272 .37597 L
.46267 .37599 L
.46263 .376 L
.46258 .37601 L
.46254 .37602 L
.46249 .37603 L
.46245 .37604 L
.4624 .37605 L
.46236 .37606 L
.46231 .37607 L
.46227 .37608 L
.46223 .37609 L
.46218 .3761 L
.46214 .37611 L
.46209 .37612 L
.46205 .37614 L
.462 .37615 L
.46196 .37616 L
.46192 .37617 L
.46187 .37618 L
.46183 .37619 L
.46178 .3762 L
.46174 .37621 L
.4617 .37622 L
.46165 .37623 L
.46161 .37624 L
.46156 .37625 L
.46152 .37626 L
.46148 .37627 L
.46143 .37628 L
.46139 .37629 L
.46134 .37629 L
.4613 .3763 L
.46126 .37631 L
.46121 .37632 L
.46117 .37633 L
.46113 .37634 L
.46108 .37635 L
.46104 .37636 L
.461 .37637 L
.46095 .37638 L
.46091 .37639 L
.46087 .3764 L
.46082 .37641 L
Mistroke
.46078 .37642 L
.46074 .37643 L
.46069 .37643 L
.46065 .37644 L
.46061 .37645 L
.46056 .37646 L
.46052 .37647 L
.46048 .37648 L
.46043 .37649 L
.46039 .3765 L
.46035 .3765 L
.46031 .37651 L
.46026 .37652 L
.46022 .37653 L
.46018 .37654 L
.46013 .37655 L
.46009 .37656 L
.46005 .37656 L
.46001 .37657 L
.45996 .37658 L
.45992 .37659 L
.45988 .3766 L
.45984 .3766 L
.45979 .37661 L
.45975 .37662 L
.45971 .37663 L
.45967 .37664 L
.45962 .37664 L
.45958 .37665 L
.45954 .37666 L
.4595 .37667 L
.45946 .37667 L
.45941 .37668 L
.45937 .37669 L
.45933 .3767 L
.45929 .37671 L
.45925 .37671 L
.4592 .37672 L
.45916 .37673 L
.45912 .37673 L
.45908 .37674 L
.45904 .37675 L
.45899 .37676 L
.45895 .37676 L
.45891 .37677 L
.45887 .37678 L
.45883 .37678 L
.45879 .37679 L
.45874 .3768 L
.4587 .37681 L
Mistroke
.45866 .37681 L
.45862 .37682 L
.45858 .37683 L
.45854 .37683 L
.4585 .37684 L
.45845 .37685 L
.45841 .37685 L
.45837 .37686 L
.45833 .37687 L
.45829 .37687 L
.45825 .37688 L
.45821 .37688 L
.45817 .37689 L
.45812 .3769 L
.45808 .3769 L
.45804 .37691 L
.458 .37692 L
.45796 .37692 L
.45792 .37693 L
.45788 .37693 L
.45784 .37694 L
.4578 .37695 L
.45776 .37695 L
.45772 .37696 L
.45768 .37696 L
.45763 .37697 L
.45759 .37698 L
.45755 .37698 L
.45751 .37699 L
.45747 .37699 L
.45743 .377 L
.45739 .377 L
.45735 .37701 L
.45731 .37701 L
.45727 .37702 L
.45723 .37702 L
.45719 .37703 L
.45715 .37704 L
.45711 .37704 L
.45707 .37705 L
.45703 .37705 L
.45699 .37706 L
.45695 .37706 L
.45691 .37707 L
.45687 .37707 L
.45683 .37708 L
.45679 .37708 L
.45675 .37709 L
.45671 .37709 L
.45667 .37709 L
Mistroke
.45663 .3771 L
.45659 .3771 L
.45655 .37711 L
.45651 .37711 L
.45647 .37712 L
.45643 .37712 L
.45639 .37713 L
.45635 .37713 L
.45632 .37714 L
.45628 .37714 L
.45624 .37714 L
.4562 .37715 L
.45616 .37715 L
.45612 .37716 L
.45608 .37716 L
.45604 .37717 L
.456 .37717 L
.45596 .37717 L
.45592 .37718 L
.45588 .37718 L
.45584 .37719 L
.45581 .37719 L
.45577 .37719 L
.45573 .3772 L
.45569 .3772 L
.45565 .3772 L
.45561 .37721 L
.45557 .37721 L
.45553 .37721 L
.4555 .37722 L
.45546 .37722 L
.45542 .37723 L
.45538 .37723 L
.45534 .37723 L
.4553 .37724 L
.45526 .37724 L
.45523 .37724 L
.45519 .37724 L
.45515 .37725 L
.45511 .37725 L
.45507 .37725 L
.45504 .37726 L
.455 .37726 L
.45496 .37726 L
.45492 .37727 L
.45488 .37727 L
.45484 .37727 L
.45481 .37727 L
.45477 .37728 L
.45473 .37728 L
Mistroke
.45469 .37728 L
.45466 .37729 L
.45462 .37729 L
.45458 .37729 L
.45454 .37729 L
.4545 .3773 L
.45447 .3773 L
.45443 .3773 L
.45439 .3773 L
.45435 .3773 L
.45432 .37731 L
.45428 .37731 L
.45424 .37731 L
.4542 .37731 L
.45417 .37732 L
.45413 .37732 L
.45409 .37732 L
.45405 .37732 L
.45402 .37732 L
.45398 .37733 L
.45394 .37733 L
.45391 .37733 L
.45387 .37733 L
.45383 .37733 L
.4538 .37733 L
.45376 .37734 L
.45372 .37734 L
.45368 .37734 L
.45365 .37734 L
.45361 .37734 L
.45357 .37734 L
.45354 .37735 L
.4535 .37735 L
.45346 .37735 L
.45343 .37735 L
.45339 .37735 L
.45335 .37735 L
.45332 .37735 L
.45328 .37735 L
.45324 .37736 L
.45321 .37736 L
.45317 .37736 L
.45314 .37736 L
.4531 .37736 L
.45306 .37736 L
.45303 .37736 L
.45299 .37736 L
.45295 .37736 L
.45292 .37736 L
.45288 .37736 L
Mistroke
.45285 .37737 L
.45281 .37737 L
.45277 .37737 L
.45274 .37737 L
.4527 .37737 L
.45267 .37737 L
.45263 .37737 L
.4526 .37737 L
.45256 .37737 L
.45252 .37737 L
.45249 .37737 L
.45245 .37737 L
.45242 .37737 L
.45238 .37737 L
.45235 .37737 L
.45231 .37737 L
.45228 .37737 L
.45224 .37737 L
.45221 .37737 L
.45217 .37737 L
.45213 .37737 L
.4521 .37737 L
.45206 .37737 L
.45203 .37737 L
.45199 .37737 L
.45196 .37737 L
.45192 .37737 L
.45189 .37737 L
.45185 .37737 L
.45182 .37737 L
.45178 .37737 L
.45175 .37737 L
.45171 .37737 L
.45168 .37737 L
.45164 .37737 L
.45161 .37737 L
.45158 .37737 L
.45154 .37737 L
.45151 .37737 L
.45147 .37736 L
.45144 .37736 L
.4514 .37736 L
.45137 .37736 L
.45133 .37736 L
.4513 .37736 L
.45127 .37736 L
.45123 .37736 L
.4512 .37736 L
.45116 .37736 L
.45113 .37736 L
Mistroke
.45109 .37735 L
.45106 .37735 L
.45103 .37735 L
.45099 .37735 L
.45096 .37735 L
.45092 .37735 L
.45089 .37735 L
.45086 .37735 L
.45082 .37734 L
.45079 .37734 L
.45075 .37734 L
.45072 .37734 L
.45069 .37734 L
.45065 .37734 L
.45062 .37733 L
.45059 .37733 L
.45055 .37733 L
.45052 .37733 L
.45049 .37733 L
.45045 .37733 L
.45042 .37732 L
.45039 .37732 L
.45035 .37732 L
.45032 .37732 L
.45029 .37732 L
.45025 .37731 L
.45022 .37731 L
.45019 .37731 L
.45015 .37731 L
.45012 .37731 L
.45009 .3773 L
.45005 .3773 L
.45002 .3773 L
.44999 .3773 L
.44996 .37729 L
.44992 .37729 L
.44989 .37729 L
.44986 .37729 L
.44983 .37728 L
.44979 .37728 L
.44976 .37728 L
.44973 .37728 L
.44969 .37727 L
.44966 .37727 L
.44963 .37727 L
.4496 .37727 L
.44956 .37726 L
.44953 .37726 L
.4495 .37726 L
.44947 .37726 L
Mistroke
.44944 .37725 L
.4494 .37725 L
.44937 .37725 L
.44934 .37724 L
.44931 .37724 L
.44928 .37724 L
.44924 .37723 L
.44921 .37723 L
.44918 .37723 L
.44915 .37723 L
.44912 .37722 L
.44908 .37722 L
.44905 .37722 L
.44902 .37721 L
.44899 .37721 L
.44896 .37721 L
.44892 .3772 L
.44889 .3772 L
.44886 .3772 L
.44883 .37719 L
.4488 .37719 L
.44877 .37718 L
.44874 .37718 L
.4487 .37718 L
.44867 .37717 L
.44864 .37717 L
.44861 .37717 L
.44858 .37716 L
.44855 .37716 L
.44852 .37715 L
.44849 .37715 L
.44845 .37715 L
.44842 .37714 L
.44839 .37714 L
.44836 .37713 L
.44833 .37713 L
.4483 .37713 L
.44827 .37712 L
.44824 .37712 L
.44821 .37711 L
.44818 .37711 L
.44815 .37711 L
.44812 .3771 L
.44808 .3771 L
.44805 .37709 L
.44802 .37709 L
.44799 .37708 L
.44796 .37708 L
.44793 .37708 L
.4479 .37707 L
Mistroke
.44787 .37707 L
.44784 .37706 L
.44781 .37706 L
.44778 .37705 L
.44775 .37705 L
.44772 .37704 L
.44769 .37704 L
.44766 .37703 L
.44763 .37703 L
.4476 .37702 L
.44757 .37702 L
.44754 .37701 L
.44751 .37701 L
.44748 .377 L
.44745 .377 L
.44742 .37699 L
.44739 .37699 L
.44736 .37698 L
.44733 .37698 L
.4473 .37697 L
.44727 .37697 L
.44724 .37696 L
.44721 .37696 L
.44718 .37695 L
.44715 .37695 L
.44712 .37694 L
.4471 .37694 L
.44707 .37693 L
.44704 .37693 L
.44701 .37692 L
.44698 .37692 L
.44695 .37691 L
.44692 .3769 L
.44689 .3769 L
.44686 .37689 L
.44683 .37689 L
.4468 .37688 L
.44677 .37688 L
.44675 .37687 L
.44672 .37687 L
.44669 .37686 L
.44666 .37685 L
.44663 .37685 L
.4466 .37684 L
.44657 .37684 L
.44654 .37683 L
.44652 .37682 L
.44649 .37682 L
.44646 .37681 L
.44643 .37681 L
Mistroke
.4464 .3768 L
.44637 .37679 L
.44634 .37679 L
.44632 .37678 L
.44629 .37678 L
.44626 .37677 L
.44623 .37676 L
.4462 .37676 L
.44618 .37675 L
.44615 .37674 L
.44612 .37674 L
.44609 .37673 L
.44606 .37672 L
.44603 .37672 L
.44601 .37671 L
.44598 .37671 L
.44595 .3767 L
.44592 .37669 L
.4459 .37669 L
.44587 .37668 L
.44584 .37667 L
.44581 .37667 L
.44578 .37666 L
.44576 .37665 L
.44573 .37665 L
.4457 .37664 L
.44567 .37663 L
.44565 .37663 L
.44562 .37662 L
.44559 .37661 L
.44556 .3766 L
.44554 .3766 L
.44551 .37659 L
.44548 .37658 L
.44546 .37658 L
.44543 .37657 L
.4454 .37656 L
.44537 .37655 L
.44535 .37655 L
.44532 .37654 L
.44529 .37653 L
.44527 .37653 L
.44524 .37652 L
.44521 .37651 L
.44519 .3765 L
.44516 .3765 L
.44513 .37649 L
.44511 .37648 L
.44508 .37647 L
.44505 .37647 L
Mistroke
.44503 .37646 L
.445 .37645 L
.44497 .37644 L
.44495 .37644 L
.44492 .37643 L
.44489 .37642 L
.44487 .37641 L
.44484 .37641 L
.44481 .3764 L
.44479 .37639 L
.44476 .37638 L
.44474 .37637 L
.44471 .37637 L
.44468 .37636 L
.44466 .37635 L
.44463 .37634 L
.44461 .37634 L
.44458 .37633 L
.44455 .37632 L
.44453 .37631 L
.4445 .3763 L
.44448 .3763 L
.44445 .37629 L
.44442 .37628 L
.4444 .37627 L
.44437 .37626 L
.44435 .37625 L
.44432 .37625 L
.4443 .37624 L
.44427 .37623 L
.44424 .37622 L
.44422 .37621 L
.44419 .3762 L
.44417 .3762 L
.44414 .37619 L
.44412 .37618 L
.44409 .37617 L
.44407 .37616 L
.44404 .37615 L
.44402 .37614 L
.44399 .37614 L
.44397 .37613 L
.44394 .37612 L
.44392 .37611 L
.44389 .3761 L
.44387 .37609 L
.44384 .37608 L
.44382 .37608 L
.44379 .37607 L
.44377 .37606 L
Mistroke
.44374 .37605 L
.44372 .37604 L
.44369 .37603 L
.44367 .37602 L
.44364 .37601 L
.44362 .376 L
.44359 .376 L
.44357 .37599 L
.44355 .37598 L
.44352 .37597 L
.4435 .37596 L
.44347 .37595 L
.44345 .37594 L
.44342 .37593 L
.4434 .37592 L
.44338 .37591 L
.44335 .3759 L
.44333 .37589 L
.4433 .37589 L
.44328 .37588 L
.44326 .37587 L
.44323 .37586 L
.44321 .37585 L
.44318 .37584 L
.44316 .37583 L
.44314 .37582 L
.44311 .37581 L
.44309 .3758 L
.44306 .37579 L
.44304 .37578 L
.44302 .37577 L
.44299 .37576 L
.44297 .37575 L
.44295 .37574 L
.44292 .37573 L
.4429 .37572 L
.44288 .37571 L
.44285 .3757 L
.44283 .37569 L
.44281 .37568 L
.44278 .37567 L
.44276 .37566 L
.44274 .37565 L
.44271 .37564 L
.44269 .37563 L
.44267 .37562 L
.44264 .37561 L
.44262 .3756 L
.4426 .37559 L
.44257 .37558 L
Mistroke
.44255 .37557 L
.44253 .37556 L
.44251 .37555 L
.44248 .37554 L
.44246 .37553 L
.44244 .37552 L
.44241 .37551 L
.44239 .3755 L
.44237 .37549 L
.44235 .37548 L
.44232 .37547 L
.4423 .37546 L
.44228 .37545 L
.44226 .37544 L
.44223 .37543 L
.44221 .37542 L
.44219 .37541 L
.44217 .3754 L
.44215 .37539 L
.44212 .37538 L
.4421 .37537 L
.44208 .37536 L
.44206 .37535 L
.44203 .37534 L
.44201 .37532 L
.44199 .37531 L
.44197 .3753 L
.44195 .37529 L
.44192 .37528 L
.4419 .37527 L
.44188 .37526 L
.44186 .37525 L
.44184 .37524 L
.44182 .37523 L
.44179 .37522 L
.44177 .37521 L
.44175 .3752 L
.44173 .37518 L
.44171 .37517 L
.44169 .37516 L
.44166 .37515 L
.44164 .37514 L
.44162 .37513 L
.4416 .37512 L
.44158 .37511 L
.44156 .3751 L
.44154 .37508 L
.44151 .37507 L
.44149 .37506 L
.44147 .37505 L
Mistroke
.44145 .37504 L
.44143 .37503 L
.44141 .37502 L
.44139 .37501 L
.44137 .37499 L
.44135 .37498 L
.44133 .37497 L
.4413 .37496 L
.44128 .37495 L
.44126 .37494 L
.44124 .37493 L
.44122 .37491 L
.4412 .3749 L
.44118 .37489 L
.44116 .37488 L
.44114 .37487 L
.44112 .37486 L
.4411 .37485 L
.44108 .37483 L
.44106 .37482 L
.44104 .37481 L
.44102 .3748 L
.441 .37479 L
.44098 .37478 L
.44095 .37476 L
.44093 .37475 L
.44091 .37474 L
.44089 .37473 L
.44087 .37472 L
.44085 .3747 L
.44083 .37469 L
.44081 .37468 L
.44079 .37467 L
.44077 .37466 L
.44075 .37465 L
.44073 .37463 L
.44071 .37462 L
.44069 .37461 L
.44067 .3746 L
.44066 .37458 L
.44064 .37457 L
.44062 .37456 L
.4406 .37455 L
.44058 .37454 L
.44056 .37452 L
.44054 .37451 L
.44052 .3745 L
.4405 .37449 L
.44048 .37448 L
.44046 .37446 L
Mistroke
.44044 .37445 L
.44042 .37444 L
.4404 .37443 L
.44038 .37441 L
.44036 .3744 L
.44034 .37439 L
.44032 .37438 L
.44031 .37436 L
.44029 .37435 L
.44027 .37434 L
.44025 .37433 L
.44023 .37431 L
.44021 .3743 L
.44019 .37429 L
.44017 .37428 L
.44015 .37426 L
.44014 .37425 L
.44012 .37424 L
.4401 .37423 L
.44008 .37421 L
.44006 .3742 L
.44004 .37419 L
.44002 .37418 L
.44 .37416 L
.43999 .37415 L
.43997 .37414 L
.43995 .37412 L
.43993 .37411 L
.43991 .3741 L
.43989 .37409 L
.43988 .37407 L
.43986 .37406 L
.43984 .37405 L
.43982 .37403 L
.4398 .37402 L
.43978 .37401 L
.43977 .374 L
.43975 .37398 L
.43973 .37397 L
.43971 .37396 L
.43969 .37394 L
.43968 .37393 L
.43966 .37392 L
.43964 .3739 L
.43962 .37389 L
.4396 .37388 L
.43959 .37387 L
.43957 .37385 L
.43955 .37384 L
.43953 .37383 L
Mistroke
.43952 .37381 L
.4395 .3738 L
.43948 .37379 L
.43946 .37377 L
.43945 .37376 L
.43943 .37375 L
.43941 .37373 L
.43939 .37372 L
.43938 .37371 L
.43936 .37369 L
.43934 .37368 L
.43932 .37367 L
.43931 .37365 L
.43929 .37364 L
.43927 .37363 L
.43926 .37361 L
.43924 .3736 L
.43922 .37358 L
.43921 .37357 L
.43919 .37356 L
.43917 .37354 L
.43915 .37353 L
.43914 .37352 L
.43912 .3735 L
.4391 .37349 L
.43909 .37348 L
.43907 .37346 L
.43905 .37345 L
.43904 .37343 L
.43902 .37342 L
.439 .37341 L
.43899 .37339 L
.43897 .37338 L
.43895 .37337 L
.43894 .37335 L
.43892 .37334 L
.4389 .37332 L
.43889 .37331 L
.43887 .3733 L
.43886 .37328 L
.43884 .37327 L
.43882 .37326 L
.43881 .37324 L
.43879 .37323 L
.43877 .37321 L
.43876 .3732 L
.43874 .37319 L
.43873 .37317 L
.43871 .37316 L
.43869 .37314 L
Mistroke
.43868 .37313 L
.43866 .37311 L
.43865 .3731 L
.43863 .37309 L
.43861 .37307 L
.4386 .37306 L
.43858 .37304 L
.43857 .37303 L
.43855 .37302 L
.43854 .373 L
.43852 .37299 L
.43851 .37297 L
.43849 .37296 L
.43847 .37294 L
.43846 .37293 L
.43844 .37292 L
.43843 .3729 L
.43841 .37289 L
.4384 .37287 L
.43838 .37286 L
.43837 .37284 L
.43835 .37283 L
.43834 .37282 L
.43832 .3728 L
.43831 .37279 L
.43829 .37277 L
.43828 .37276 L
.43826 .37274 L
.43825 .37273 L
.43823 .37271 L
.43822 .3727 L
.4382 .37268 L
.43819 .37267 L
.43817 .37266 L
.43816 .37264 L
.43814 .37263 L
.43813 .37261 L
.43811 .3726 L
.4381 .37258 L
.43808 .37257 L
.43807 .37255 L
.43805 .37254 L
.43804 .37252 L
.43802 .37251 L
.43801 .37249 L
.438 .37248 L
.43798 .37246 L
.43797 .37245 L
.43795 .37243 L
.43794 .37242 L
Mistroke
.43792 .37241 L
.43791 .37239 L
.4379 .37238 L
.43788 .37236 L
.43787 .37235 L
.43785 .37233 L
.43784 .37232 L
.43782 .3723 L
.43781 .37229 L
.4378 .37227 L
.43778 .37226 L
.43777 .37224 L
.43775 .37223 L
.43774 .37221 L
.43773 .3722 L
.43771 .37218 L
.4377 .37217 L
.43769 .37215 L
.43767 .37214 L
.43766 .37212 L
.43764 .37211 L
.43763 .37209 L
.43762 .37208 L
.4376 .37206 L
.43759 .37204 L
.43758 .37203 L
.43756 .37201 L
.43755 .372 L
.43754 .37198 L
.43752 .37197 L
.43751 .37195 L
.4375 .37194 L
.43748 .37192 L
.43747 .37191 L
.43746 .37189 L
.43744 .37188 L
.43743 .37186 L
.43742 .37185 L
.4374 .37183 L
.43739 .37182 L
.43738 .3718 L
.43737 .37178 L
.43735 .37177 L
.43734 .37175 L
.43733 .37174 L
.43731 .37172 L
.4373 .37171 L
.43729 .37169 L
.43728 .37168 L
.43726 .37166 L
Mistroke
.43725 .37165 L
.43724 .37163 L
.43722 .37161 L
.43721 .3716 L
.4372 .37158 L
.43719 .37157 L
.43717 .37155 L
.43716 .37154 L
.43715 .37152 L
.43714 .37151 L
.43713 .37149 L
.43711 .37147 L
.4371 .37146 L
.43709 .37144 L
.43708 .37143 L
.43706 .37141 L
.43705 .3714 L
.43704 .37138 L
.43703 .37136 L
.43702 .37135 L
.437 .37133 L
.43699 .37132 L
.43698 .3713 L
.43697 .37129 L
.43696 .37127 L
.43694 .37125 L
.43693 .37124 L
.43692 .37122 L
.43691 .37121 L
.4369 .37119 L
.43688 .37117 L
.43687 .37116 L
.43686 .37114 L
.43685 .37113 L
.43684 .37111 L
.43683 .37109 L
.43681 .37108 L
.4368 .37106 L
.43679 .37105 L
.43678 .37103 L
.43677 .37102 L
.43676 .371 L
.43675 .37098 L
.43673 .37097 L
.43672 .37095 L
.43671 .37093 L
.4367 .37092 L
.43669 .3709 L
.43668 .37089 L
.43667 .37087 L
Mistroke
.43666 .37085 L
.43664 .37084 L
.43663 .37082 L
.43662 .37081 L
.43661 .37079 L
.4366 .37077 L
.43659 .37076 L
.43658 .37074 L
.43657 .37073 L
.43656 .37071 L
.43655 .37069 L
.43654 .37068 L
.43652 .37066 L
.43651 .37064 L
.4365 .37063 L
.43649 .37061 L
.43648 .3706 L
.43647 .37058 L
.43646 .37056 L
.43645 .37055 L
.43644 .37053 L
.43643 .37051 L
.43642 .3705 L
.43641 .37048 L
.4364 .37046 L
.43639 .37045 L
.43638 .37043 L
.43637 .37042 L
.43636 .3704 L
.43635 .37038 L
.43634 .37037 L
.43633 .37035 L
.43632 .37033 L
.43631 .37032 L
.4363 .3703 L
.43629 .37028 L
.43628 .37027 L
.43627 .37025 L
.43626 .37024 L
.43625 .37022 L
.43624 .3702 L
.43623 .37019 L
.43622 .37017 L
.43621 .37015 L
.4362 .37014 L
.43619 .37012 L
.43618 .3701 L
.43617 .37009 L
.43616 .37007 L
.43615 .37005 L
Mistroke
.43614 .37004 L
.43613 .37002 L
.43612 .37 L
.43611 .36999 L
.4361 .36997 L
.43609 .36995 L
.43608 .36994 L
.43607 .36992 L
.43606 .3699 L
.43605 .36989 L
.43604 .36987 L
.43603 .36985 L
.43602 .36984 L
.43602 .36982 L
.43601 .3698 L
.436 .36979 L
.43599 .36977 L
.43598 .36975 L
.43597 .36974 L
.43596 .36972 L
.43595 .3697 L
.43594 .36969 L
.43593 .36967 L
.43592 .36965 L
.43592 .36964 L
.43591 .36962 L
.4359 .3696 L
.43589 .36958 L
.43588 .36957 L
.43587 .36955 L
.43586 .36953 L
.43585 .36952 L
.43584 .3695 L
.43584 .36948 L
.43583 .36947 L
.43582 .36945 L
.43581 .36943 L
.4358 .36942 L
.43579 .3694 L
.43578 .36938 L
.43578 .36936 L
.43577 .36935 L
.43576 .36933 L
.43575 .36931 L
.43574 .3693 L
.43573 .36928 L
.43573 .36926 L
.43572 .36925 L
.43571 .36923 L
.4357 .36921 L
Mistroke
.43569 .36919 L
.43569 .36918 L
.43568 .36916 L
.43567 .36914 L
.43566 .36913 L
.43565 .36911 L
.43564 .36909 L
.43564 .36908 L
.43563 .36906 L
.43562 .36904 L
.43561 .36902 L
.43561 .36901 L
.4356 .36899 L
.43559 .36897 L
.43558 .36896 L
.43557 .36894 L
.43557 .36892 L
.43556 .3689 L
.43555 .36889 L
.43554 .36887 L
.43554 .36885 L
.43553 .36884 L
.43552 .36882 L
.43551 .3688 L
.43551 .36878 L
.4355 .36877 L
.43549 .36875 L
.43548 .36873 L
.43548 .36872 L
.43547 .3687 L
.43546 .36868 L
.43545 .36866 L
.43545 .36865 L
.43544 .36863 L
.43543 .36861 L
.43542 .36859 L
.43542 .36858 L
.43541 .36856 L
.4354 .36854 L
.4354 .36853 L
.43539 .36851 L
.43538 .36849 L
.43538 .36847 L
.43537 .36846 L
.43536 .36844 L
.43535 .36842 L
.43535 .3684 L
.43534 .36839 L
.43533 .36837 L
.43533 .36835 L
Mistroke
.43532 .36833 L
.43531 .36832 L
.43531 .3683 L
.4353 .36828 L
.43529 .36826 L
.43529 .36825 L
.43528 .36823 L
.43527 .36821 L
.43527 .3682 L
.43526 .36818 L
.43525 .36816 L
.43525 .36814 L
.43524 .36813 L
.43523 .36811 L
.43523 .36809 L
.43522 .36807 L
.43522 .36806 L
.43521 .36804 L
.4352 .36802 L
.4352 .368 L
.43519 .36799 L
.43518 .36797 L
.43518 .36795 L
.43517 .36793 L
.43517 .36792 L
.43516 .3679 L
.43515 .36788 L
.43515 .36786 L
.43514 .36785 L
.43514 .36783 L
.43513 .36781 L
.43512 .36779 L
.43512 .36778 L
.43511 .36776 L
.43511 .36774 L
.4351 .36772 L
.43509 .3677 L
.43509 .36769 L
.43508 .36767 L
.43508 .36765 L
.43507 .36763 L
.43507 .36762 L
.43506 .3676 L
.43505 .36758 L
.43505 .36756 L
.43504 .36755 L
.43504 .36753 L
.43503 .36751 L
.43503 .36749 L
.43502 .36748 L
Mistroke
.43502 .36746 L
.43501 .36744 L
.435 .36742 L
.435 .36741 L
.43499 .36739 L
.43499 .36737 L
.43498 .36735 L
.43498 .36733 L
.43497 .36732 L
.43497 .3673 L
.43496 .36728 L
.43496 .36726 L
.43495 .36725 L
.43495 .36723 L
.43494 .36721 L
.43494 .36719 L
.43493 .36718 L
.43493 .36716 L
.43492 .36714 L
.43492 .36712 L
.43491 .3671 L
.43491 .36709 L
.4349 .36707 L
.4349 .36705 L
.43489 .36703 L
.43489 .36702 L
.43488 .367 L
.43488 .36698 L
.43487 .36696 L
.43487 .36694 L
.43486 .36693 L
.43486 .36691 L
.43486 .36689 L
.43485 .36687 L
.43485 .36686 L
.43484 .36684 L
.43484 .36682 L
.43483 .3668 L
.43483 .36678 L
.43482 .36677 L
.43482 .36675 L
.43482 .36673 L
.43481 .36671 L
.43481 .36669 L
.4348 .36668 L
.4348 .36666 L
.43479 .36664 L
.43479 .36662 L
.43479 .36661 L
.43478 .36659 L
Mistroke
.43478 .36657 L
.43477 .36655 L
.43477 .36653 L
.43476 .36652 L
.43476 .3665 L
.43476 .36648 L
.43475 .36646 L
.43475 .36644 L
.43474 .36643 L
.43474 .36641 L
.43474 .36639 L
.43473 .36637 L
.43473 .36636 L
.43473 .36634 L
.43472 .36632 L
.43472 .3663 L
.43471 .36628 L
.43471 .36627 L
.43471 .36625 L
.4347 .36623 L
.4347 .36621 L
.4347 .36619 L
.43469 .36618 L
.43469 .36616 L
.43468 .36614 L
.43468 .36612 L
.43468 .3661 L
.43467 .36609 L
.43467 .36607 L
.43467 .36605 L
.43466 .36603 L
.43466 .36601 L
.43466 .366 L
.43465 .36598 L
.43465 .36596 L
.43465 .36594 L
.43464 .36592 L
.43464 .36591 L
.43464 .36589 L
.43463 .36587 L
.43463 .36585 L
.43463 .36584 L
.43463 .36582 L
.43462 .3658 L
.43462 .36578 L
.43462 .36576 L
.43461 .36575 L
.43461 .36573 L
.43461 .36571 L
.4346 .36569 L
Mistroke
.4346 .36567 L
.4346 .36566 L
.4346 .36564 L
.43459 .36562 L
.43459 .3656 L
.43459 .36558 L
.43458 .36557 L
.43458 .36555 L
.43458 .36553 L
.43458 .36551 L
.43457 .36549 L
.43457 .36548 L
.43457 .36546 L
.43457 .36544 L
.43456 .36542 L
.43456 .3654 L
.43456 .36538 L
.43456 .36537 L
.43455 .36535 L
.43455 .36533 L
.43455 .36531 L
.43455 .36529 L
.43454 .36528 L
.43454 .36526 L
.43454 .36524 L
.43454 .36522 L
.43453 .3652 L
.43453 .36519 L
.43453 .36517 L
.43453 .36515 L
.43452 .36513 L
.43452 .36511 L
.43452 .3651 L
.43452 .36508 L
.43452 .36506 L
.43451 .36504 L
.43451 .36502 L
.43451 .36501 L
.43451 .36499 L
.43451 .36497 L
.4345 .36495 L
.4345 .36493 L
.4345 .36492 L
.4345 .3649 L
.4345 .36488 L
.43449 .36486 L
.43449 .36484 L
.43449 .36483 L
.43449 .36481 L
.43449 .36479 L
Mistroke
.43449 .36477 L
.43448 .36475 L
.43448 .36473 L
.43448 .36472 L
.43448 .3647 L
.43448 .36468 L
.43448 .36466 L
.43447 .36464 L
.43447 .36463 L
.43447 .36461 L
.43447 .36459 L
.43447 .36457 L
.43447 .36455 L
.43446 .36454 L
.43446 .36452 L
.43446 .3645 L
.43446 .36448 L
.43446 .36446 L
.43446 .36445 L
.43446 .36443 L
.43446 .36441 L
.43445 .36439 L
.43445 .36437 L
.43445 .36436 L
.43445 .36434 L
.43445 .36432 L
.43445 .3643 L
.43445 .36428 L
.43445 .36426 L
.43444 .36425 L
.43444 .36423 L
.43444 .36421 L
.43444 .36419 L
.43444 .36417 L
.43444 .36416 L
.43444 .36414 L
.43444 .36412 L
.43444 .3641 L
.43444 .36408 L
.43444 .36407 L
.43443 .36405 L
.43443 .36403 L
.43443 .36401 L
.43443 .36399 L
.43443 .36398 L
.43443 .36396 L
.43443 .36394 L
.43443 .36392 L
.43443 .3639 L
.43443 .36388 L
Mistroke
.43443 .36387 L
.43443 .36385 L
.43443 .36383 L
.43443 .36381 L
.43442 .36379 L
.43442 .36378 L
.43442 .36376 L
.43442 .36374 L
.43442 .36372 L
.43442 .3637 L
.43442 .36369 L
.43442 .36367 L
.43442 .36365 L
.43442 .36363 L
.43442 .36361 L
.43442 .3636 L
.43442 .36358 L
.43442 .36356 L
.43442 .36354 L
.43442 .36352 L
.43442 .3635 L
.43442 .36349 L
.43442 .36347 L
.43442 .36345 L
.43442 .36343 L
.43442 .36341 L
.43442 .3634 L
.43442 .36338 L
.43442 .36336 L
.43442 .36334 L
.43442 .36332 L
.43442 .36331 L
.43442 .36329 L
.43442 .36327 L
.43442 .36325 L
.43442 .36323 L
.43442 .36322 L
.43442 .3632 L
.43442 .36318 L
.43442 .36316 L
.43442 .36314 L
.43442 .36313 L
.43442 .36311 L
.43442 .36309 L
.43442 .36307 L
.43442 .36305 L
.43442 .36303 L
.43442 .36302 L
.43442 .363 L
.43442 .36298 L
Mistroke
.43442 .36296 L
.43442 .36294 L
.43442 .36293 L
.43442 .36291 L
.43443 .36289 L
.43443 .36287 L
.43443 .36285 L
.43443 .36284 L
.43443 .36282 L
.43443 .3628 L
.43443 .36278 L
.43443 .36276 L
.43443 .36275 L
.43443 .36273 L
.43443 .36271 L
.43443 .36269 L
.43443 .36267 L
.43443 .36266 L
.43443 .36264 L
.43444 .36262 L
.43444 .3626 L
.43444 .36258 L
.43444 .36257 L
.43444 .36255 L
.43444 .36253 L
.43444 .36251 L
.43444 .36249 L
.43444 .36248 L
.43444 .36246 L
.43445 .36244 L
.43445 .36242 L
.43445 .3624 L
.43445 .36239 L
.43445 .36237 L
.43445 .36235 L
.43445 .36233 L
.43445 .36231 L
.43445 .3623 L
.43446 .36228 L
.43446 .36226 L
.43446 .36224 L
.43446 .36222 L
.43446 .36221 L
.43446 .36219 L
.43446 .36217 L
.43446 .36215 L
.43447 .36213 L
.43447 .36212 L
.43447 .3621 L
.43447 .36208 L
Mistroke
.43447 .36206 L
.43447 .36204 L
.43447 .36203 L
.43448 .36201 L
.43448 .36199 L
.43448 .36197 L
.43448 .36195 L
.43448 .36194 L
.43448 .36192 L
.43449 .3619 L
.43449 .36188 L
.43449 .36186 L
.43449 .36185 L
.43449 .36183 L
.43449 .36181 L
.4345 .36179 L
.4345 .36177 L
.4345 .36176 L
.4345 .36174 L
.4345 .36172 L
.4345 .3617 L
.43451 .36168 L
.43451 .36167 L
.43451 .36165 L
.43451 .36163 L
.43451 .36161 L
.43452 .3616 L
.43452 .36158 L
.43452 .36156 L
.43452 .36154 L
.43452 .36152 L
.43453 .36151 L
.43453 .36149 L
.43453 .36147 L
.43453 .36145 L
.43453 .36143 L
.43454 .36142 L
.43454 .3614 L
.43454 .36138 L
.43454 .36136 L
.43454 .36135 L
.43455 .36133 L
.43455 .36131 L
.43455 .36129 L
.43455 .36127 L
.43456 .36126 L
.43456 .36124 L
.43456 .36122 L
.43456 .3612 L
.43457 .36118 L
Mistroke
.43457 .36117 L
.43457 .36115 L
.43457 .36113 L
.43458 .36111 L
.43458 .3611 L
.43458 .36108 L
.43458 .36106 L
.43459 .36104 L
.43459 .36102 L
.43459 .36101 L
.43459 .36099 L
.4346 .36097 L
.4346 .36095 L
.4346 .36094 L
.4346 .36092 L
.43461 .3609 L
.43461 .36088 L
.43461 .36086 L
.43461 .36085 L
.43462 .36083 L
.43462 .36081 L
.43462 .36079 L
.43463 .36078 L
.43463 .36076 L
.43463 .36074 L
.43463 .36072 L
.43464 .3607 L
.43464 .36069 L
.43464 .36067 L
.43465 .36065 L
.43465 .36063 L
.43465 .36062 L
.43465 .3606 L
.43466 .36058 L
.43466 .36056 L
.43466 .36054 L
.43467 .36053 L
.43467 .36051 L
.43467 .36049 L
.43468 .36047 L
.43468 .36046 L
.43468 .36044 L
.43469 .36042 L
.43469 .3604 L
.43469 .36039 L
.43469 .36037 L
.4347 .36035 L
.4347 .36033 L
.4347 .36031 L
.43471 .3603 L
Mistroke
.43471 .36028 L
.43471 .36026 L
.43472 .36024 L
.43472 .36023 L
.43472 .36021 L
.43473 .36019 L
.43473 .36017 L
.43473 .36016 L
.43474 .36014 L
.43474 .36012 L
.43474 .3601 L
.43475 .36009 L
.43475 .36007 L
.43476 .36005 L
.43476 .36003 L
.43476 .36002 L
.43477 .36 L
.43477 .35998 L
.43477 .35996 L
.43478 .35995 L
.43478 .35993 L
.43478 .35991 L
.43479 .35989 L
.43479 .35987 L
.43479 .35986 L
.4348 .35984 L
.4348 .35982 L
.43481 .3598 L
.43481 .35979 L
.43481 .35977 L
.43482 .35975 L
.43482 .35973 L
.43483 .35972 L
.43483 .3597 L
.43483 .35968 L
.43484 .35966 L
.43484 .35965 L
.43484 .35963 L
.43485 .35961 L
.43485 .35959 L
.43486 .35958 L
.43486 .35956 L
.43486 .35954 L
.43487 .35953 L
.43487 .35951 L
.43488 .35949 L
.43488 .35947 L
.43488 .35946 L
.43489 .35944 L
.43489 .35942 L
Mistroke
.4349 .3594 L
.4349 .35939 L
.43491 .35937 L
.43491 .35935 L
.43491 .35933 L
.43492 .35932 L
.43492 .3593 L
.43493 .35928 L
.43493 .35926 L
.43493 .35925 L
.43494 .35923 L
.43494 .35921 L
.43495 .35919 L
.43495 .35918 L
.43496 .35916 L
.43496 .35914 L
.43497 .35912 L
.43497 .35911 L
.43497 .35909 L
.43498 .35907 L
.43498 .35906 L
.43499 .35904 L
.43499 .35902 L
.435 .359 L
.435 .35899 L
.43501 .35897 L
.43501 .35895 L
.43501 .35893 L
.43502 .35892 L
.43502 .3589 L
.43503 .35888 L
.43503 .35887 L
.43504 .35885 L
.43504 .35883 L
.43505 .35881 L
.43505 .3588 L
.43506 .35878 L
.43506 .35876 L
.43507 .35874 L
.43507 .35873 L
.43507 .35871 L
.43508 .35869 L
.43508 .35868 L
.43509 .35866 L
.43509 .35864 L
.4351 .35862 L
.4351 .35861 L
.43511 .35859 L
.43511 .35857 L
.43512 .35856 L
Mistroke
.43512 .35854 L
.43513 .35852 L
.43513 .3585 L
.43514 .35849 L
.43514 .35847 L
.43515 .35845 L
.43515 .35844 L
.43516 .35842 L
.43516 .3584 L
.43517 .35838 L
.43517 .35837 L
.43518 .35835 L
.43518 .35833 L
.43519 .35832 L
.43519 .3583 L
.4352 .35828 L
.4352 .35827 L
.43521 .35825 L
.43521 .35823 L
.43522 .35821 L
.43522 .3582 L
.43523 .35818 L
.43524 .35816 L
.43524 .35815 L
.43525 .35813 L
.43525 .35811 L
.43526 .35809 L
.43526 .35808 L
.43527 .35806 L
.43527 .35804 L
.43528 .35803 L
.43528 .35801 L
.43529 .35799 L
.43529 .35798 L
.4353 .35796 L
.4353 .35794 L
.43531 .35793 L
.43532 .35791 L
.43532 .35789 L
.43533 .35787 L
.43533 .35786 L
.43534 .35784 L
.43534 .35782 L
.43535 .35781 L
.43535 .35779 L
.43536 .35777 L
.43537 .35776 L
.43537 .35774 L
.43538 .35772 L
.43538 .35771 L
Mistroke
.43539 .35769 L
.43539 .35767 L
.4354 .35765 L
.4354 .35764 L
.43541 .35762 L
.43542 .3576 L
.43542 .35759 L
.43543 .35757 L
.43543 .35755 L
.43544 .35754 L
.43544 .35752 L
.43545 .3575 L
.43546 .35749 L
.43546 .35747 L
.43547 .35745 L
.43547 .35744 L
.43548 .35742 L
.43549 .3574 L
.43549 .35739 L
.4355 .35737 L
.4355 .35735 L
.43551 .35734 L
.43552 .35732 L
.43552 .3573 L
.43553 .35729 L
.43553 .35727 L
.43554 .35725 L
.43555 .35724 L
.43555 .35722 L
.43556 .3572 L
.43556 .35719 L
.43557 .35717 L
.43558 .35715 L
.43558 .35714 L
.43559 .35712 L
.43559 .3571 L
.4356 .35709 L
.43561 .35707 L
.43561 .35705 L
.43562 .35704 L
.43562 .35702 L
.43563 .357 L
.43564 .35699 L
.43564 .35697 L
.43565 .35695 L
.43566 .35694 L
.43566 .35692 L
.43567 .3569 L
.43567 .35689 L
.43568 .35687 L
Mistroke
.43569 .35685 L
.43569 .35684 L
.4357 .35682 L
.43571 .35681 L
.43571 .35679 L
.43572 .35677 L
.43573 .35676 L
.43573 .35674 L
.43574 .35672 L
.43574 .35671 L
.43575 .35669 L
.43576 .35667 L
.43576 .35666 L
.43577 .35664 L
.43578 .35662 L
.43578 .35661 L
.43579 .35659 L
.4358 .35657 L
.4358 .35656 L
.43581 .35654 L
.43582 .35653 L
.43582 .35651 L
.43583 .35649 L
.43584 .35648 L
.43584 .35646 L
.43585 .35644 L
.43586 .35643 L
.43586 .35641 L
.43587 .3564 L
.43588 .35638 L
.43588 .35636 L
.43589 .35635 L
.4359 .35633 L
.4359 .35631 L
.43591 .3563 L
.43592 .35628 L
.43592 .35626 L
.43593 .35625 L
.43594 .35623 L
.43594 .35622 L
.43595 .3562 L
.43596 .35618 L
.43596 .35617 L
.43597 .35615 L
.43598 .35614 L
.43598 .35612 L
.43599 .3561 L
.436 .35609 L
.43601 .35607 L
.43601 .35605 L
Mistroke
.43602 .35604 L
.43603 .35602 L
.43603 .35601 L
.43604 .35599 L
.43605 .35597 L
.43605 .35596 L
.43606 .35594 L
.43607 .35593 L
.43607 .35591 L
.43608 .35589 L
.43609 .35588 L
.4361 .35586 L
.4361 .35584 L
.43611 .35583 L
.43612 .35581 L
.43612 .3558 L
.43613 .35578 L
.43614 .35576 L
.43615 .35575 L
.43615 .35573 L
.43616 .35572 L
.43617 .3557 L
.43617 .35568 L
.43618 .35567 L
.43619 .35565 L
.4362 .35564 L
.4362 .35562 L
.43621 .3556 L
.43622 .35559 L
.43623 .35557 L
.43623 .35556 L
.43624 .35554 L
.43625 .35553 L
.43625 .35551 L
.43626 .35549 L
.43627 .35548 L
.43628 .35546 L
.43628 .35545 L
.43629 .35543 L
.4363 .35541 L
.43631 .3554 L
.43631 .35538 L
.43632 .35537 L
.43633 .35535 L
.43634 .35534 L
.43634 .35532 L
.43635 .3553 L
.43636 .35529 L
.43637 .35527 L
.43637 .35526 L
Mistroke
.43638 .35524 L
.43639 .35522 L
.4364 .35521 L
.4364 .35519 L
.43641 .35518 L
.43642 .35516 L
.43643 .35515 L
.43643 .35513 L
.43644 .35511 L
.43645 .3551 L
.43646 .35508 L
.43646 .35507 L
.43647 .35505 L
.43648 .35504 L
.43649 .35502 L
.43649 .35501 L
.4365 .35499 L
.43651 .35497 L
.43652 .35496 L
.43653 .35494 L
.43653 .35493 L
.43654 .35491 L
.43655 .3549 L
.43656 .35488 L
.43656 .35486 L
.43657 .35485 L
.43658 .35483 L
.43659 .35482 L
.4366 .3548 L
.4366 .35479 L
.43661 .35477 L
.43662 .35476 L
.43663 .35474 L
.43663 .35473 L
.43664 .35471 L
.43665 .35469 L
.43666 .35468 L
.43667 .35466 L
.43667 .35465 L
.43668 .35463 L
.43669 .35462 L
.4367 .3546 L
.43671 .35459 L
.43671 .35457 L
.43672 .35456 L
.43673 .35454 L
.43674 .35452 L
.43675 .35451 L
.43675 .35449 L
.43676 .35448 L
Mistroke
.43677 .35446 L
.43678 .35445 L
.43679 .35443 L
.43679 .35442 L
.4368 .3544 L
.43681 .35439 L
.43682 .35437 L
.43683 .35436 L
.43683 .35434 L
.43684 .35433 L
.43685 .35431 L
.43686 .3543 L
.43687 .35428 L
.43688 .35426 L
.43688 .35425 L
.43689 .35423 L
.4369 .35422 L
.43691 .3542 L
.43692 .35419 L
.43692 .35417 L
.43693 .35416 L
.43694 .35414 L
.43695 .35413 L
.43696 .35411 L
.43697 .3541 L
.43697 .35408 L
.43698 .35407 L
.43699 .35405 L
.437 .35404 L
.43701 .35402 L
.43702 .35401 L
.43702 .35399 L
.43703 .35398 L
.43704 .35396 L
.43705 .35395 L
.43706 .35393 L
.43707 .35392 L
.43707 .3539 L
.43708 .35389 L
.43709 .35387 L
.4371 .35386 L
.43711 .35384 L
.43712 .35383 L
.43712 .35381 L
.43713 .3538 L
.43714 .35378 L
.43715 .35377 L
.43716 .35375 L
.43717 .35374 L
.43718 .35372 L
Mistroke
.43718 .35371 L
.43719 .35369 L
.4372 .35368 L
.43721 .35366 L
.43722 .35365 L
.43723 .35363 L
.43724 .35362 L
.43724 .3536 L
.43725 .35359 L
.43726 .35357 L
.43727 .35356 L
.43728 .35354 L
.43729 .35353 L
.4373 .35351 L
.4373 .3535 L
.43731 .35349 L
.43732 .35347 L
.43733 .35346 L
.43734 .35344 L
.43735 .35343 L
.43736 .35341 L
.43737 .3534 L
.43737 .35338 L
.43738 .35337 L
.43739 .35335 L
.4374 .35334 L
.43741 .35332 L
.43742 .35331 L
.43743 .35329 L
.43743 .35328 L
.43744 .35327 L
.43745 .35325 L
.43746 .35324 L
.43747 .35322 L
.43748 .35321 L
.43749 .35319 L
.4375 .35318 L
.43751 .35316 L
.43751 .35315 L
.43752 .35313 L
.43753 .35312 L
.43754 .3531 L
.43755 .35309 L
.43756 .35308 L
.43757 .35306 L
.43758 .35305 L
.43759 .35303 L
.43759 .35302 L
.4376 .353 L
.43761 .35299 L
Mistroke
.43762 .35297 L
.43763 .35296 L
.43764 .35295 L
.43765 .35293 L
.43766 .35292 L
.43767 .3529 L
.43767 .35289 L
.43768 .35287 L
.43769 .35286 L
.4377 .35285 L
.43771 .35283 L
.43772 .35282 L
.43773 .3528 L
.43774 .35279 L
.43775 .35277 L
.43776 .35276 L
.43777 .35274 L
.43777 .35273 L
.43778 .35272 L
.43779 .3527 L
.4378 .35269 L
.43781 .35267 L
.43782 .35266 L
.43783 .35265 L
.43784 .35263 L
.43785 .35262 L
.43786 .3526 L
.43787 .35259 L
.43787 .35257 L
.43788 .35256 L
.43789 .35255 L
.4379 .35253 L
.43791 .35252 L
.43792 .3525 L
.43793 .35249 L
.43794 .35248 L
.43795 .35246 L
.43796 .35245 L
.43797 .35243 L
.43798 .35242 L
.43799 .3524 L
.43799 .35239 L
.438 .35238 L
.43801 .35236 L
.43802 .35235 L
.43803 .35233 L
.43804 .35232 L
.43805 .35231 L
.43806 .35229 L
.43807 .35228 L
Mistroke
.43808 .35226 L
.43809 .35225 L
.4381 .35224 L
.43811 .35222 L
.43812 .35221 L
.43812 .3522 L
.43813 .35218 L
.43814 .35217 L
.43815 .35215 L
.43816 .35214 L
.43817 .35213 L
.43818 .35211 L
.43819 .3521 L
.4382 .35208 L
.43821 .35207 L
.43822 .35206 L
.43823 .35204 L
.43824 .35203 L
.43825 .35202 L
.43826 .352 L
.43827 .35199 L
.43828 .35197 L
.43828 .35196 L
.43829 .35195 L
.4383 .35193 L
.43831 .35192 L
.43832 .35191 L
.43833 .35189 L
.43834 .35188 L
.43835 .35186 L
.43836 .35185 L
.43837 .35184 L
.43838 .35182 L
.43839 .35181 L
.4384 .3518 L
.43841 .35178 L
.43842 .35177 L
.43843 .35176 L
.43844 .35174 L
.43845 .35173 L
.43846 .35171 L
.43847 .3517 L
.43848 .35169 L
.43849 .35167 L
.43849 .35166 L
.4385 .35165 L
.43851 .35163 L
.43852 .35162 L
.43853 .35161 L
.43854 .35159 L
Mistroke
.43855 .35158 L
.43856 .35157 L
.43857 .35155 L
.43858 .35154 L
.43859 .35153 L
.4386 .35151 L
.43861 .3515 L
.43862 .35149 L
.43863 .35147 L
.43864 .35146 L
.43865 .35145 L
.43866 .35143 L
.43867 .35142 L
.43868 .35141 L
.43869 .35139 L
.4387 .35138 L
.43871 .35137 L
.43872 .35135 L
.43873 .35134 L
.43874 .35133 L
.43875 .35131 L
.43876 .3513 L
.43877 .35129 L
.43878 .35127 L
.43879 .35126 L
.4388 .35125 L
.43881 .35123 L
.43882 .35122 L
.43883 .35121 L
.43884 .35119 L
.43885 .35118 L
.43886 .35117 L
.43887 .35115 L
.43887 .35114 L
.43888 .35113 L
.43889 .35111 L
.4389 .3511 L
.43891 .35109 L
.43892 .35108 L
.43893 .35106 L
.43894 .35105 L
.43895 .35104 L
.43896 .35102 L
.43897 .35101 L
.43898 .351 L
.43899 .35098 L
.439 .35097 L
.43901 .35096 L
.43902 .35095 L
.43903 .35093 L
Mistroke
.43904 .35092 L
.43905 .35091 L
.43906 .35089 L
.43907 .35088 L
.43908 .35087 L
.43909 .35085 L
.4391 .35084 L
.43911 .35083 L
.43912 .35082 L
.43913 .3508 L
.43914 .35079 L
.43915 .35078 L
.43916 .35076 L
.43917 .35075 L
.43918 .35074 L
.43919 .35073 L
.4392 .35071 L
.43921 .3507 L
.43922 .35069 L
.43923 .35067 L
.43924 .35066 L
.43925 .35065 L
.43926 .35064 L
.43927 .35062 L
.43928 .35061 L
.43929 .3506 L
.4393 .35059 L
.43931 .35057 L
.43932 .35056 L
.43933 .35055 L
.43934 .35054 L
.43935 .35052 L
.43936 .35051 L
.43937 .3505 L
.43938 .35048 L
.43939 .35047 L
.4394 .35046 L
.43942 .35045 L
.43943 .35043 L
.43944 .35042 L
.43945 .35041 L
.43946 .3504 L
.43947 .35038 L
.43948 .35037 L
.43949 .35036 L
.4395 .35035 L
.43951 .35033 L
.43952 .35032 L
.43953 .35031 L
.43954 .3503 L
Mistroke
.43955 .35028 L
.43956 .35027 L
.43957 .35026 L
.43958 .35025 L
.43959 .35023 L
.4396 .35022 L
.43961 .35021 L
.43962 .3502 L
.43963 .35019 L
.43964 .35017 L
.43965 .35016 L
.43966 .35015 L
.43967 .35014 L
.43968 .35012 L
.43969 .35011 L
.4397 .3501 L
.43971 .35009 L
.43972 .35007 L
.43973 .35006 L
.43974 .35005 L
.43975 .35004 L
.43976 .35003 L
.43977 .35001 L
.43978 .35 L
.43979 .34999 L
.4398 .34998 L
.43981 .34996 L
.43982 .34995 L
.43983 .34994 L
.43985 .34993 L
.43986 .34992 L
.43987 .3499 L
.43988 .34989 L
.43989 .34988 L
.4399 .34987 L
.43991 .34986 L
.43992 .34984 L
.43993 .34983 L
.43994 .34982 L
.43995 .34981 L
.43996 .3498 L
.43997 .34978 L
.43998 .34977 L
.43999 .34976 L
.44 .34975 L
.44001 .34974 L
.44002 .34972 L
.44003 .34971 L
.44004 .3497 L
.44005 .34969 L
Mistroke
.44006 .34968 L
.44007 .34966 L
.44008 .34965 L
.44009 .34964 L
.4401 .34963 L
.44012 .34962 L
.44013 .3496 L
.44014 .34959 L
.44015 .34958 L
.44016 .34957 L
.44017 .34956 L
.44018 .34955 L
.44019 .34953 L
.4402 .34952 L
.44021 .34951 L
.44022 .3495 L
.44023 .34949 L
.44024 .34947 L
.44025 .34946 L
.44026 .34945 L
.44027 .34944 L
.44028 .34943 L
.44029 .34942 L
.4403 .3494 L
.44031 .34939 L
.44032 .34938 L
.44034 .34937 L
.44035 .34936 L
.44036 .34935 L
.44037 .34933 L
.44038 .34932 L
.44039 .34931 L
.4404 .3493 L
.44041 .34929 L
.44042 .34928 L
.44043 .34927 L
.44044 .34925 L
.44045 .34924 L
.44046 .34923 L
.44047 .34922 L
.44048 .34921 L
.44049 .3492 L
.4405 .34918 L
.44051 .34917 L
.44052 .34916 L
.44054 .34915 L
.44055 .34914 L
.44056 .34913 L
.44057 .34912 L
.44058 .3491 L
Mistroke
.44059 .34909 L
.4406 .34908 L
.44061 .34907 L
.44062 .34906 L
.44063 .34905 L
.44064 .34904 L
.44065 .34903 L
.44066 .34901 L
.44067 .349 L
.44068 .34899 L
.44069 .34898 L
.4407 .34897 L
.44072 .34896 L
.44073 .34895 L
.44074 .34894 L
.44075 .34892 L
.44076 .34891 L
.44077 .3489 L
.44078 .34889 L
.44079 .34888 L
.4408 .34887 L
.44081 .34886 L
.44082 .34885 L
.44083 .34883 L
.44084 .34882 L
.44085 .34881 L
.44086 .3488 L
.44088 .34879 L
.44089 .34878 L
.4409 .34877 L
.44091 .34876 L
.44092 .34875 L
.44093 .34874 L
.44094 .34872 L
.44095 .34871 L
.44096 .3487 L
.44097 .34869 L
.44098 .34868 L
.44099 .34867 L
.441 .34866 L
.44101 .34865 L
.44102 .34864 L
.44104 .34863 L
.44105 .34861 L
.44106 .3486 L
.44107 .34859 L
.44108 .34858 L
.44109 .34857 L
.4411 .34856 L
.44111 .34855 L
Mistroke
.44112 .34854 L
.44113 .34853 L
.44114 .34852 L
.44115 .34851 L
.44116 .34849 L
.44117 .34848 L
.44119 .34847 L
.4412 .34846 L
.44121 .34845 L
.44122 .34844 L
.44123 .34843 L
.44124 .34842 L
.44125 .34841 L
.44126 .3484 L
.44127 .34839 L
.44128 .34838 L
.44129 .34837 L
.4413 .34836 L
.44131 .34834 L
.44133 .34833 L
.44134 .34832 L
.44135 .34831 L
.44136 .3483 L
.44137 .34829 L
.44138 .34828 L
.44139 .34827 L
.4414 .34826 L
.44141 .34825 L
.44142 .34824 L
.44143 .34823 L
.44144 .34822 L
.44145 .34821 L
.44147 .3482 L
.44148 .34819 L
.44149 .34818 L
.4415 .34817 L
.44151 .34815 L
.44152 .34814 L
.44153 .34813 L
.44154 .34812 L
.44155 .34811 L
.44156 .3481 L
.44157 .34809 L
.44158 .34808 L
.44159 .34807 L
.44161 .34806 L
.44162 .34805 L
.44163 .34804 L
.44164 .34803 L
.44165 .34802 L
Mistroke
.44166 .34801 L
.44167 .348 L
.44168 .34799 L
.44169 .34798 L
.4417 .34797 L
.44171 .34796 L
.44172 .34795 L
.44174 .34794 L
.44175 .34793 L
.44176 .34792 L
.44177 .34791 L
.44178 .3479 L
.44179 .34789 L
.4418 .34788 L
.44181 .34787 L
.44182 .34786 L
.44183 .34785 L
.44184 .34784 L
.44185 .34783 L
.44187 .34782 L
.44188 .34781 L
.44189 .3478 L
.4419 .34779 L
.44191 .34778 L
.44192 .34777 L
.44193 .34776 L
.44194 .34775 L
.44195 .34774 L
.44196 .34773 L
.44197 .34772 L
.44198 .34771 L
.442 .3477 L
.44201 .34769 L
.44202 .34768 L
.44203 .34767 L
.44204 .34766 L
.44205 .34765 L
.44206 .34764 L
.44207 .34763 L
.44208 .34762 L
.44209 .34761 L
.4421 .3476 L
.44211 .34759 L
.44213 .34758 L
.44214 .34757 L
.44215 .34756 L
.44216 .34755 L
.44217 .34754 L
.44218 .34753 L
.44219 .34752 L
Mistroke
.4422 .34751 L
.44221 .3475 L
.44222 .34749 L
.44223 .34748 L
.44225 .34747 L
.44226 .34746 L
.44227 .34745 L
.44228 .34744 L
.44229 .34743 L
.4423 .34742 L
.44231 .34741 L
.44232 .3474 L
.44233 .34739 L
.44234 .34738 L
.44235 .34737 L
.44237 .34736 L
.44238 .34735 L
.44239 .34734 L
.4424 .34733 L
.44241 .34733 L
.44242 .34732 L
.44243 .34731 L
.44244 .3473 L
.44245 .34729 L
.44246 .34728 L
.44247 .34727 L
.44249 .34726 L
.4425 .34725 L
.44251 .34724 L
.44252 .34723 L
.44253 .34722 L
.44254 .34721 L
.44255 .3472 L
.44256 .34719 L
.44257 .34718 L
.44258 .34717 L
.44259 .34716 L
.4426 .34715 L
.44262 .34715 L
.44263 .34714 L
.44264 .34713 L
.44265 .34712 L
.44266 .34711 L
.44267 .3471 L
.44268 .34709 L
.44269 .34708 L
.4427 .34707 L
.44271 .34706 L
.44272 .34705 L
.44274 .34704 L
Mistroke
.44275 .34703 L
.44276 .34703 L
.44277 .34702 L
.44278 .34701 L
.44279 .347 L
.4428 .34699 L
.44281 .34698 L
.44282 .34697 L
.44283 .34696 L
.44284 .34695 L
.44286 .34694 L
.44287 .34693 L
.44288 .34692 L
.44289 .34692 L
.4429 .34691 L
.44291 .3469 L
.44292 .34689 L
.44293 .34688 L
.44294 .34687 L
.44295 .34686 L
.44296 .34685 L
.44298 .34684 L
.44299 .34683 L
.443 .34683 L
.44301 .34682 L
.44302 .34681 L
.44303 .3468 L
.44304 .34679 L
.44305 .34678 L
.44306 .34677 L
.44307 .34676 L
.44308 .34675 L
.4431 .34675 L
.44311 .34674 L
.44312 .34673 L
.44313 .34672 L
.44314 .34671 L
.44315 .3467 L
.44316 .34669 L
.44317 .34668 L
.44318 .34667 L
.44319 .34667 L
.4432 .34666 L
.44322 .34665 L
.44323 .34664 L
.44324 .34663 L
.44325 .34662 L
.44326 .34661 L
.44327 .3466 L
.44328 .3466 L
Mistroke
.44329 .34659 L
.4433 .34658 L
.44331 .34657 L
.44332 .34656 L
.44334 .34655 L
.44335 .34654 L
.44336 .34654 L
.44337 .34653 L
.44338 .34652 L
.44339 .34651 L
.4434 .3465 L
.44341 .34649 L
.44342 .34648 L
.44343 .34648 L
.44344 .34647 L
.44346 .34646 L
.44347 .34645 L
.44348 .34644 L
.44349 .34643 L
.4435 .34642 L
.44351 .34642 L
.44352 .34641 L
.44353 .3464 L
.44354 .34639 L
.44355 .34638 L
.44356 .34637 L
.44358 .34637 L
.44359 .34636 L
.4436 .34635 L
.44361 .34634 L
.44362 .34633 L
.44363 .34632 L
.44364 .34632 L
.44365 .34631 L
.44366 .3463 L
.44367 .34629 L
.44368 .34628 L
.4437 .34627 L
.44371 .34627 L
.44372 .34626 L
.44373 .34625 L
.44374 .34624 L
.44375 .34623 L
.44376 .34622 L
.44377 .34622 L
.44378 .34621 L
.44379 .3462 L
.4438 .34619 L
.44381 .34618 L
.44383 .34618 L
Mistroke
.44384 .34617 L
.44385 .34616 L
.44386 .34615 L
.44387 .34614 L
.44388 .34613 L
.44389 .34613 L
.4439 .34612 L
.44391 .34611 L
.44392 .3461 L
.44393 .34609 L
.44395 .34609 L
.44396 .34608 L
.44397 .34607 L
.44398 .34606 L
.44399 .34605 L
.444 .34605 L
.44401 .34604 L
.44402 .34603 L
.44403 .34602 L
.44404 .34601 L
.44405 .34601 L
.44406 .346 L
.44408 .34599 L
.44409 .34598 L
.4441 .34598 L
.44411 .34597 L
.44412 .34596 L
.44413 .34595 L
.44414 .34594 L
.44415 .34594 L
.44416 .34593 L
.44417 .34592 L
.44418 .34591 L
.44419 .3459 L
.44421 .3459 L
.44422 .34589 L
.44423 .34588 L
.44424 .34587 L
.44425 .34587 L
.44426 .34586 L
.44427 .34585 L
.44428 .34584 L
.44429 .34584 L
.4443 .34583 L
.44431 .34582 L
.44432 .34581 L
.44434 .3458 L
.44435 .3458 L
.44436 .34579 L
.44437 .34578 L
Mistroke
.44438 .34577 L
.44439 .34577 L
.4444 .34576 L
.44441 .34575 L
.44442 .34574 L
.44443 .34574 L
.44444 .34573 L
.44445 .34572 L
.44447 .34571 L
.44448 .34571 L
.44449 .3457 L
.4445 .34569 L
.44451 .34568 L
.44452 .34568 L
.44453 .34567 L
.44454 .34566 L
.44455 .34565 L
.44456 .34565 L
.44457 .34564 L
.44458 .34563 L
.44459 .34562 L
.44461 .34562 L
.44462 .34561 L
.44463 .3456 L
.44464 .34559 L
.44465 .34559 L
.44466 .34558 L
.44467 .34557 L
.44468 .34557 L
.44469 .34556 L
.4447 .34555 L
.44471 .34554 L
.44472 .34554 L
.44473 .34553 L
.44475 .34552 L
.44476 .34551 L
.44477 .34551 L
.44478 .3455 L
.44479 .34549 L
.4448 .34549 L
.44481 .34548 L
.44482 .34547 L
.44483 .34546 L
.44484 .34546 L
.44485 .34545 L
.44486 .34544 L
.44487 .34544 L
.44489 .34543 L
.4449 .34542 L
.44491 .34541 L
Mistroke
.44492 .34541 L
.44493 .3454 L
.44494 .34539 L
.44495 .34539 L
.44496 .34538 L
.44497 .34537 L
.44498 .34537 L
.44499 .34536 L
.445 .34535 L
.44501 .34534 L
.44502 .34534 L
.44504 .34533 L
.44505 .34532 L
.44506 .34532 L
.44507 .34531 L
.44508 .3453 L
.44509 .3453 L
.4451 .34529 L
.44511 .34528 L
.44512 .34528 L
.44513 .34527 L
.44514 .34526 L
.44515 .34525 L
.44516 .34525 L
.44517 .34524 L
.44518 .34523 L
.4452 .34523 L
.44521 .34522 L
.44522 .34521 L
.44523 .34521 L
.44524 .3452 L
.44525 .34519 L
.44526 .34519 L
.44527 .34518 L
.44528 .34517 L
.44529 .34517 L
.4453 .34516 L
.44531 .34515 L
.44532 .34515 L
.44533 .34514 L
.44534 .34513 L
.44536 .34513 L
.44537 .34512 L
.44538 .34511 L
.44539 .34511 L
.4454 .3451 L
.44541 .34509 L
.44542 .34509 L
.44543 .34508 L
.44544 .34507 L
Mistroke
.44545 .34507 L
.44546 .34506 L
.44547 .34505 L
.44548 .34505 L
.44549 .34504 L
.4455 .34503 L
.44551 .34503 L
.44552 .34502 L
.44554 .34502 L
.44555 .34501 L
.44556 .345 L
.44557 .345 L
.44558 .34499 L
.44559 .34498 L
.4456 .34498 L
.44561 .34497 L
.44562 .34496 L
.44563 .34496 L
.44564 .34495 L
.44565 .34494 L
.44566 .34494 L
.44567 .34493 L
.44568 .34493 L
.44569 .34492 L
.4457 .34491 L
.44572 .34491 L
.44573 .3449 L
.44574 .34489 L
.44575 .34489 L
.44576 .34488 L
.44577 .34488 L
.44578 .34487 L
.44579 .34486 L
.4458 .34486 L
.44581 .34485 L
.44582 .34484 L
.44583 .34484 L
.44584 .34483 L
.44585 .34483 L
.44586 .34482 L
.44587 .34481 L
.44588 .34481 L
.44589 .3448 L
.4459 .3448 L
.44591 .34479 L
.44593 .34478 L
.44594 .34478 L
.44595 .34477 L
.44596 .34477 L
.44597 .34476 L
Mistroke
.44598 .34475 L
.44599 .34475 L
.446 .34474 L
.44601 .34473 L
.44602 .34473 L
.44603 .34472 L
.44604 .34472 L
.44605 .34471 L
.44606 .34471 L
.44607 .3447 L
.44608 .34469 L
.44609 .34469 L
.4461 .34468 L
.44611 .34468 L
.44612 .34467 L
.44613 .34466 L
.44615 .34466 L
.44616 .34465 L
.44617 .34465 L
.44618 .34464 L
.44619 .34463 L
.4462 .34463 L
.44621 .34462 L
.44622 .34462 L
.44623 .34461 L
.44624 .34461 L
.44625 .3446 L
.44626 .34459 L
.44627 .34459 L
.44628 .34458 L
.44629 .34458 L
.4463 .34457 L
.44631 .34457 L
.44632 .34456 L
.44633 .34455 L
.44634 .34455 L
.44635 .34454 L
.44636 .34454 L
.44637 .34453 L
.44638 .34453 L
.44639 .34452 L
.4464 .34451 L
.44641 .34451 L
.44643 .3445 L
.44644 .3445 L
.44645 .34449 L
.44646 .34449 L
.44647 .34448 L
.44648 .34448 L
.44649 .34447 L
Mistroke
.4465 .34446 L
.44651 .34446 L
.44652 .34445 L
.44653 .34445 L
.44654 .34444 L
.44655 .34444 L
.44656 .34443 L
.44657 .34443 L
.44658 .34442 L
.44659 .34441 L
.4466 .34441 L
.44661 .3444 L
.44662 .3444 L
.44663 .34439 L
.44664 .34439 L
.44665 .34438 L
.44666 .34438 L
.44667 .34437 L
.44668 .34437 L
.44669 .34436 L
.4467 .34436 L
.44671 .34435 L
.44672 .34435 L
.44673 .34434 L
.44674 .34433 L
.44675 .34433 L
.44676 .34432 L
.44677 .34432 L
.44678 .34431 L
.4468 .34431 L
.44681 .3443 L
.44682 .3443 L
.44683 .34429 L
.44684 .34429 L
.44685 .34428 L
.44686 .34428 L
.44687 .34427 L
.44688 .34427 L
.44689 .34426 L
.4469 .34426 L
.44691 .34425 L
.44692 .34425 L
.44693 .34424 L
.44694 .34424 L
.44695 .34423 L
.44696 .34423 L
.44697 .34422 L
.44698 .34422 L
.44699 .34421 L
.447 .34421 L
Mistroke
.44701 .3442 L
.44702 .3442 L
.44703 .34419 L
.44704 .34419 L
.44705 .34418 L
.44706 .34418 L
.44707 .34417 L
.44708 .34417 L
.44709 .34416 L
.4471 .34416 L
.44711 .34415 L
.44712 .34415 L
.44713 .34414 L
.44714 .34414 L
.44715 .34413 L
.44716 .34413 L
.44717 .34412 L
.44718 .34412 L
.44719 .34411 L
.4472 .34411 L
.44721 .3441 L
.44722 .3441 L
.44723 .34409 L
.44724 .34409 L
.44725 .34408 L
.44726 .34408 L
.44727 .34407 L
.44728 .34407 L
.44729 .34406 L
.4473 .34406 L
.44731 .34405 L
.44732 .34405 L
.44733 .34405 L
.44734 .34404 L
.44735 .34404 L
.44736 .34403 L
.44737 .34403 L
.44738 .34402 L
.44739 .34402 L
.4474 .34401 L
.44741 .34401 L
.44742 .344 L
.44743 .344 L
.44744 .34399 L
.44745 .34399 L
.44746 .34398 L
.44747 .34398 L
.44748 .34398 L
.44749 .34397 L
.4475 .34397 L
Mistroke
.44751 .34396 L
.44752 .34396 L
.44753 .34395 L
.44754 .34395 L
.44755 .34394 L
.44756 .34394 L
.44757 .34393 L
.44758 .34393 L
.44759 .34393 L
.4476 .34392 L
.44761 .34392 L
.44762 .34391 L
.44763 .34391 L
.44764 .3439 L
.44765 .3439 L
.44766 .34389 L
.44767 .34389 L
.44768 .34389 L
.44769 .34388 L
.4477 .34388 L
.44771 .34387 L
.44772 .34387 L
.44773 .34386 L
.44774 .34386 L
.44775 .34386 L
.44776 .34385 L
.44777 .34385 L
.44778 .34384 L
.44779 .34384 L
.4478 .34383 L
.44781 .34383 L
.44782 .34383 L
.44783 .34382 L
.44784 .34382 L
.44785 .34381 L
.44785 .34381 L
.44786 .3438 L
.44787 .3438 L
.44788 .3438 L
.44789 .34379 L
.4479 .34379 L
.44791 .34378 L
.44792 .34378 L
.44793 .34378 L
.44794 .34377 L
.44795 .34377 L
.44796 .34376 L
.44797 .34376 L
.44798 .34376 L
.44799 .34375 L
Mistroke
.448 .34375 L
.44801 .34374 L
.44802 .34374 L
.44803 .34373 L
.44804 .34373 L
.44805 .34373 L
.44806 .34372 L
.44807 .34372 L
.44808 .34371 L
.44809 .34371 L
.4481 .34371 L
.44811 .3437 L
.44812 .3437 L
.44813 .3437 L
.44814 .34369 L
.44815 .34369 L
.44816 .34368 L
.44817 .34368 L
.44818 .34368 L
.44818 .34367 L
.44819 .34367 L
.4482 .34366 L
.44821 .34366 L
.44822 .34366 L
.44823 .34365 L
.44824 .34365 L
.44825 .34364 L
.44826 .34364 L
.44827 .34364 L
.44828 .34363 L
.44829 .34363 L
.4483 .34363 L
.44831 .34362 L
.44832 .34362 L
.44833 .34361 L
.44834 .34361 L
.44835 .34361 L
.44836 .3436 L
.44837 .3436 L
.44838 .3436 L
.44839 .34359 L
.4484 .34359 L
.4484 .34358 L
.44841 .34358 L
.44842 .34358 L
.44843 .34357 L
.44844 .34357 L
.44845 .34357 L
.44846 .34356 L
.44847 .34356 L
Mistroke
.44848 .34356 L
.44849 .34355 L
.4485 .34355 L
.44851 .34355 L
.44852 .34354 L
.44853 .34354 L
.44854 .34353 L
.44855 .34353 L
.44856 .34353 L
.44857 .34352 L
.44858 .34352 L
.44858 .34352 L
.44859 .34351 L
.4486 .34351 L
.44861 .34351 L
.44862 .3435 L
.44863 .3435 L
.44864 .3435 L
.44865 .34349 L
.44866 .34349 L
.44867 .34349 L
.44868 .34348 L
.44869 .34348 L
.4487 .34348 L
.44871 .34347 L
.44872 .34347 L
.44873 .34347 L
.44873 .34346 L
.44874 .34346 L
.44875 .34346 L
.44876 .34345 L
.44877 .34345 L
.44878 .34345 L
.44879 .34344 L
.4488 .34344 L
.44881 .34344 L
.44882 .34343 L
.44883 .34343 L
.44884 .34343 L
.44885 .34342 L
.44886 .34342 L
.44886 .34342 L
.44887 .34341 L
.44888 .34341 L
.44889 .34341 L
.4489 .3434 L
.44891 .3434 L
.44892 .3434 L
.44893 .34339 L
.44894 .34339 L
Mistroke
.44895 .34339 L
.44896 .34338 L
.44897 .34338 L
.44898 .34338 L
.44898 .34338 L
.44899 .34337 L
.449 .34337 L
.44901 .34337 L
.44902 .34336 L
.44903 .34336 L
.44904 .34336 L
.44905 .34335 L
.44906 .34335 L
.44907 .34335 L
.44908 .34334 L
.44909 .34334 L
.44909 .34334 L
.4491 .34334 L
.44911 .34333 L
.44912 .34333 L
.44913 .34333 L
.44914 .34332 L
.44915 .34332 L
.44916 .34332 L
.44917 .34331 L
.44918 .34331 L
.44919 .34331 L
.4492 .34331 L
.4492 .3433 L
.44921 .3433 L
.44922 .3433 L
.44923 .34329 L
.44924 .34329 L
.44925 .34329 L
.44926 .34329 L
.44927 .34328 L
.44928 .34328 L
.44929 .34328 L
.44929 .34327 L
.4493 .34327 L
.44931 .34327 L
.44932 .34327 L
.44933 .34326 L
.44934 .34326 L
.44935 .34326 L
.44936 .34326 L
.44937 .34325 L
.44938 .34325 L
.44938 .34325 L
.44939 .34324 L
Mistroke
.4494 .34324 L
.44941 .34324 L
.44942 .34324 L
.44943 .34323 L
.44944 .34323 L
.44945 .34323 L
.44946 .34323 L
.44947 .34322 L
.44947 .34322 L
.44948 .34322 L
.44949 .34321 L
.4495 .34321 L
.44951 .34321 L
.44952 .34321 L
.44953 .3432 L
.44954 .3432 L
.44955 .3432 L
.44955 .3432 L
.44956 .34319 L
.44957 .34319 L
.44958 .34319 L
.44959 .34319 L
.4496 .34318 L
.44961 .34318 L
.44962 .34318 L
.44962 .34318 L
.44963 .34317 L
.44964 .34317 L
.44965 .34317 L
.44966 .34317 L
.44967 .34316 L
.44968 .34316 L
.44969 .34316 L
.44969 .34316 L
.4497 .34315 L
.44971 .34315 L
.44972 .34315 L
.44973 .34315 L
.44974 .34315 L
.44975 .34314 L
.44976 .34314 L
.44976 .34314 L
.44977 .34314 L
.44978 .34313 L
.44979 .34313 L
.4498 .34313 L
.44981 .34313 L
.44982 .34312 L
.44983 .34312 L
.44983 .34312 L
Mistroke
.44984 .34312 L
.44985 .34311 L
.44986 .34311 L
.44987 .34311 L
.44988 .34311 L
.44989 .34311 L
.4499 .3431 L
.4499 .3431 L
.44991 .3431 L
.44992 .3431 L
.44993 .34309 L
.44994 .34309 L
.44995 .34309 L
.44996 .34309 L
.44996 .34309 L
.44997 .34308 L
.44998 .34308 L
.44999 .34308 L
.45 .34308 L
.45001 .34308 L
.45002 .34307 L
.45002 .34307 L
.45003 .34307 L
.45004 .34307 L
.45005 .34306 L
.45006 .34306 L
.45007 .34306 L
.45008 .34306 L
.45008 .34306 L
.45009 .34305 L
.4501 .34305 L
.45011 .34305 L
.45012 .34305 L
.45013 .34305 L
.45014 .34304 L
.45014 .34304 L
.45015 .34304 L
.45016 .34304 L
.45017 .34304 L
.45018 .34303 L
.45019 .34303 L
.45019 .34303 L
.4502 .34303 L
.45021 .34303 L
.45022 .34303 L
.45023 .34302 L
.45024 .34302 L
.45024 .34302 L
.45025 .34302 L
.45026 .34302 L
Mistroke
.45027 .34301 L
.45028 .34301 L
.45029 .34301 L
.4503 .34301 L
.4503 .34301 L
.45031 .343 L
.45032 .343 L
.45033 .343 L
.45034 .343 L
.45035 .343 L
.45035 .343 L
.45036 .34299 L
.45037 .34299 L
.45038 .34299 L
.45039 .34299 L
.4504 .34299 L
.4504 .34298 L
.45041 .34298 L
.45042 .34298 L
.45043 .34298 L
.45044 .34298 L
.45044 .34298 L
.45045 .34297 L
.45046 .34297 L
.45047 .34297 L
.45048 .34297 L
.45049 .34297 L
.45049 .34297 L
.4505 .34296 L
.45051 .34296 L
.45052 .34296 L
.45053 .34296 L
.45054 .34296 L
.45054 .34296 L
.45055 .34295 L
.45056 .34295 L
.45057 .34295 L
.45058 .34295 L
.45058 .34295 L
.45059 .34295 L
.4506 .34295 L
.45061 .34294 L
.45062 .34294 L
.45063 .34294 L
.45063 .34294 L
.45064 .34294 L
.45065 .34294 L
.45066 .34293 L
.45067 .34293 L
.45067 .34293 L
Mistroke
.45068 .34293 L
.45069 .34293 L
.4507 .34293 L
.45071 .34293 L
.45071 .34292 L
.45072 .34292 L
.45073 .34292 L
.45074 .34292 L
.45075 .34292 L
.45075 .34292 L
.45076 .34292 L
.45077 .34291 L
.45078 .34291 L
.45079 .34291 L
.45079 .34291 L
.4508 .34291 L
.45081 .34291 L
.45082 .34291 L
.45083 .34291 L
.45083 .3429 L
.45084 .3429 L
.45085 .3429 L
.45086 .3429 L
.45087 .3429 L
.45087 .3429 L
.45088 .3429 L
.45089 .34289 L
.4509 .34289 L
.45091 .34289 L
.45091 .34289 L
.45092 .34289 L
.45093 .34289 L
.45094 .34289 L
.45095 .34289 L
.45095 .34289 L
.45096 .34288 L
.45097 .34288 L
.45098 .34288 L
.45098 .34288 L
.45099 .34288 L
.451 .34288 L
.45101 .34288 L
.45102 .34288 L
.45102 .34287 L
.45103 .34287 L
.45104 .34287 L
.45105 .34287 L
.45106 .34287 L
.45106 .34287 L
.45107 .34287 L
Mistroke
.45108 .34287 L
.45109 .34287 L
.45109 .34286 L
.4511 .34286 L
.45111 .34286 L
.45112 .34286 L
.45113 .34286 L
.45113 .34286 L
.45114 .34286 L
.45115 .34286 L
.45116 .34286 L
.45116 .34286 L
.45117 .34285 L
.45118 .34285 L
.45119 .34285 L
.45119 .34285 L
.4512 .34285 L
.45121 .34285 L
.45122 .34285 L
.45123 .34285 L
.45123 .34285 L
.45124 .34285 L
.45125 .34284 L
.45126 .34284 L
.45126 .34284 L
.45127 .34284 L
.45128 .34284 L
.45129 .34284 L
.45129 .34284 L
.4513 .34284 L
.45131 .34284 L
.45132 .34284 L
.45132 .34284 L
.45133 .34284 L
.45134 .34283 L
.45135 .34283 L
.45135 .34283 L
.45136 .34283 L
.45137 .34283 L
.45138 .34283 L
.45138 .34283 L
.45139 .34283 L
.4514 .34283 L
.45141 .34283 L
.45141 .34283 L
.45142 .34283 L
.45143 .34282 L
.45144 .34282 L
.45144 .34282 L
.45145 .34282 L
Mistroke
.45146 .34282 L
.45147 .34282 L
.45147 .34282 L
.45148 .34282 L
.45149 .34282 L
.4515 .34282 L
.4515 .34282 L
.45151 .34282 L
.45152 .34282 L
.45153 .34282 L
.45153 .34282 L
.45154 .34281 L
.45155 .34281 L
.45156 .34281 L
.45156 .34281 L
.45157 .34281 L
.45158 .34281 L
.45159 .34281 L
.45159 .34281 L
.4516 .34281 L
.45161 .34281 L
.45162 .34281 L
.45162 .34281 L
.45163 .34281 L
.45164 .34281 L
.45164 .34281 L
.45165 .34281 L
.45166 .34281 L
.45167 .3428 L
.45167 .3428 L
.45168 .3428 L
.45169 .3428 L
.4517 .3428 L
.4517 .3428 L
.45171 .3428 L
.45172 .3428 L
.45172 .3428 L
.45173 .3428 L
.45174 .3428 L
.45175 .3428 L
.45175 .3428 L
.45176 .3428 L
.45177 .3428 L
.45177 .3428 L
.45178 .3428 L
.45179 .3428 L
.4518 .3428 L
.4518 .3428 L
.45181 .3428 L
.45182 .3428 L
Mistroke
.45182 .34279 L
.45183 .34279 L
.45184 .34279 L
.45185 .34279 L
.45185 .34279 L
.45186 .34279 L
.45187 .34279 L
.45187 .34279 L
.45188 .34279 L
.45189 .34279 L
.4519 .34279 L
.4519 .34279 L
.45191 .34279 L
.45192 .34279 L
.45192 .34279 L
.45193 .34279 L
.45194 .34279 L
.45195 .34279 L
.45195 .34279 L
.45196 .34279 L
.45197 .34279 L
.45197 .34279 L
.45198 .34279 L
.45199 .34279 L
.45199 .34279 L
.452 .34279 L
.45201 .34279 L
.45202 .34279 L
.45202 .34279 L
.45203 .34279 L
.45204 .34279 L
.45204 .34279 L
.45205 .34279 L
.45206 .34279 L
.45206 .34279 L
.45207 .34279 L
.45208 .34279 L
.45208 .34279 L
.45209 .34279 L
.4521 .34279 L
.45211 .34279 L
.45211 .34279 L
.45212 .34279 L
.45213 .34279 L
.45213 .34279 L
.45214 .34279 L
.45215 .34279 L
.45215 .34279 L
.45216 .34279 L
.45217 .34279 L
Mistroke
.45217 .34279 L
.45218 .34279 L
.45219 .34278 L
.45219 .34278 L
.4522 .34278 L
.45221 .34278 L
.45221 .34278 L
.45222 .34278 L
.45223 .34279 L
.45223 .34279 L
.45224 .34279 L
.45225 .34279 L
.45226 .34279 L
.45226 .34279 L
.45227 .34279 L
.45228 .34279 L
.45228 .34279 L
.45229 .34279 L
.4523 .34279 L
.4523 .34279 L
.45231 .34279 L
.45232 .34279 L
.45232 .34279 L
.45233 .34279 L
.45234 .34279 L
.45234 .34279 L
.45235 .34279 L
.45236 .34279 L
.45236 .34279 L
.45237 .34279 L
.45238 .34279 L
.45238 .34279 L
.45239 .34279 L
.4524 .34279 L
.4524 .34279 L
.45241 .34279 L
.45241 .34279 L
.45242 .34279 L
.45243 .34279 L
.45243 .34279 L
.45244 .34279 L
.45245 .34279 L
.45245 .34279 L
.45246 .34279 L
.45247 .34279 L
.45247 .34279 L
.45248 .34279 L
.45249 .34279 L
.45249 .34279 L
.4525 .34279 L
Mistroke
.45251 .34279 L
.45251 .34279 L
.45252 .34279 L
.45253 .34279 L
.45253 .34279 L
.45254 .34279 L
.45255 .34279 L
.45255 .34279 L
.45256 .34279 L
.45256 .34279 L
.45257 .34279 L
.45258 .3428 L
.45258 .3428 L
.45259 .3428 L
.4526 .3428 L
.4526 .3428 L
.45261 .3428 L
.45262 .3428 L
.45262 .3428 L
.45263 .3428 L
.45263 .3428 L
.45264 .3428 L
.45265 .3428 L
.45265 .3428 L
.45266 .3428 L
.45267 .3428 L
.45267 .3428 L
.45268 .3428 L
.45269 .3428 L
.45269 .3428 L
.4527 .3428 L
.4527 .3428 L
.45271 .3428 L
.45272 .3428 L
.45272 .34281 L
.45273 .34281 L
.45274 .34281 L
.45274 .34281 L
.45275 .34281 L
.45275 .34281 L
.45276 .34281 L
.45277 .34281 L
.45277 .34281 L
.45278 .34281 L
.45279 .34281 L
.45279 .34281 L
.4528 .34281 L
.4528 .34281 L
.45281 .34281 L
.45282 .34281 L
Mistroke
.45282 .34281 L
.45283 .34281 L
.45283 .34282 L
.45284 .34282 L
.45285 .34282 L
.45285 .34282 L
.45286 .34282 L
.45287 .34282 L
.45287 .34282 L
.45288 .34282 L
.45288 .34282 L
.45289 .34282 L
.4529 .34282 L
.4529 .34282 L
.45291 .34282 L
.45291 .34282 L
.45292 .34282 L
.45293 .34282 L
.45293 .34283 L
.45294 .34283 L
.45294 .34283 L
.45295 .34283 L
.45296 .34283 L
.45296 .34283 L
.45297 .34283 L
.45297 .34283 L
.45298 .34283 L
.45299 .34283 L
.45299 .34283 L
.453 .34283 L
.453 .34283 L
.45301 .34284 L
.45302 .34284 L
.45302 .34284 L
.45303 .34284 L
.45303 .34284 L
.45304 .34284 L
.45305 .34284 L
.45305 .34284 L
.45306 .34284 L
.45306 .34284 L
.45307 .34284 L
.45307 .34284 L
.45308 .34284 L
.45309 .34285 L
.45309 .34285 L
.4531 .34285 L
.4531 .34285 L
.45311 .34285 L
.45312 .34285 L
Mistroke
.45312 .34285 L
.45313 .34285 L
.45313 .34285 L
.45314 .34285 L
.45314 .34285 L
.45315 .34286 L
.45316 .34286 L
.45316 .34286 L
.45317 .34286 L
.45317 .34286 L
.45318 .34286 L
.45318 .34286 L
.45319 .34286 L
.4532 .34286 L
.4532 .34286 L
.45321 .34286 L
.45321 .34287 L
.45322 .34287 L
.45322 .34287 L
.45323 .34287 L
.45324 .34287 L
.45324 .34287 L
.45325 .34287 L
.45325 .34287 L
.45326 .34287 L
.45326 .34287 L
.45327 .34288 L
.45328 .34288 L
.45328 .34288 L
.45329 .34288 L
.45329 .34288 L
.4533 .34288 L
.4533 .34288 L
.45331 .34288 L
.45332 .34288 L
.45332 .34289 L
.45333 .34289 L
.45333 .34289 L
.45334 .34289 L
.45334 .34289 L
.45335 .34289 L
.45335 .34289 L
.45336 .34289 L
.45337 .34289 L
.45337 .3429 L
.45338 .3429 L
.45338 .3429 L
.45339 .3429 L
.45339 .3429 L
.4534 .3429 L
Mistroke
.4534 .3429 L
.45341 .3429 L
.45341 .3429 L
.45342 .34291 L
.45343 .34291 L
.45343 .34291 L
.45344 .34291 L
.45344 .34291 L
.45345 .34291 L
.45345 .34291 L
.45346 .34291 L
.45346 .34291 L
.45347 .34292 L
.45347 .34292 L
.45348 .34292 L
.45349 .34292 L
.45349 .34292 L
.4535 .34292 L
.4535 .34292 L
.45351 .34292 L
.45351 .34293 L
.45352 .34293 L
.45352 .34293 L
.45353 .34293 L
.45353 .34293 L
.45354 .34293 L
.45354 .34293 L
.45355 .34294 L
.45355 .34294 L
.45356 .34294 L
.45356 .34294 L
.45357 .34294 L
.45358 .34294 L
.45358 .34294 L
.45359 .34294 L
.45359 .34295 L
.4536 .34295 L
.4536 .34295 L
.45361 .34295 L
.45361 .34295 L
.45362 .34295 L
.45362 .34295 L
.45363 .34296 L
.45363 .34296 L
.45364 .34296 L
.45364 .34296 L
.45365 .34296 L
.45365 .34296 L
.45366 .34296 L
.45366 .34296 L
Mistroke
.45367 .34297 L
.45367 .34297 L
.45368 .34297 L
.45368 .34297 L
.45369 .34297 L
.45369 .34297 L
.4537 .34297 L
.4537 .34298 L
.45371 .34298 L
.45372 .34298 L
.45372 .34298 L
.45373 .34298 L
.45373 .34298 L
.45374 .34298 L
.45374 .34299 L
.45375 .34299 L
.45375 .34299 L
.45376 .34299 L
.45376 .34299 L
.45377 .34299 L
.45377 .343 L
.45378 .343 L
.45378 .343 L
.45379 .343 L
.45379 .343 L
.4538 .343 L
.4538 .343 L
.45381 .34301 L
.45381 .34301 L
.45382 .34301 L
.45382 .34301 L
.45383 .34301 L
.45383 .34301 L
.45384 .34302 L
.45384 .34302 L
.45384 .34302 L
.45385 .34302 L
.45385 .34302 L
.45386 .34302 L
.45386 .34302 L
.45387 .34303 L
.45387 .34303 L
.45388 .34303 L
.45388 .34303 L
.45389 .34303 L
.45389 .34303 L
.4539 .34304 L
.4539 .34304 L
.45391 .34304 L
.45391 .34304 L
Mistroke
.45392 .34304 L
.45392 .34304 L
.45393 .34305 L
.45393 .34305 L
.45394 .34305 L
.45394 .34305 L
.45395 .34305 L
.45395 .34305 L
.45396 .34306 L
.45396 .34306 L
.45397 .34306 L
.45397 .34306 L
.45397 .34306 L
.45398 .34306 L
.45398 .34307 L
.45399 .34307 L
.45399 .34307 L
.454 .34307 L
.454 .34307 L
.45401 .34308 L
.45401 .34308 L
.45402 .34308 L
.45402 .34308 L
.45403 .34308 L
.45403 .34308 L
.45404 .34309 L
.45404 .34309 L
.45405 .34309 L
.45405 .34309 L
.45405 .34309 L
.45406 .34309 L
.45406 .3431 L
.45407 .3431 L
.45407 .3431 L
.45408 .3431 L
.45408 .3431 L
.45409 .34311 L
.45409 .34311 L
.4541 .34311 L
.4541 .34311 L
.4541 .34311 L
.45411 .34311 L
.45411 .34312 L
.45412 .34312 L
.45412 .34312 L
.45413 .34312 L
.45413 .34312 L
.45414 .34313 L
.45414 .34313 L
.45415 .34313 L
Mistroke
.45415 .34313 L
.45415 .34313 L
.45416 .34313 L
.45416 .34314 L
.45417 .34314 L
.45417 .34314 L
.45418 .34314 L
.45418 .34314 L
.45419 .34315 L
.45419 .34315 L
.45419 .34315 L
.4542 .34315 L
.4542 .34315 L
.45421 .34316 L
.45421 .34316 L
.45422 .34316 L
.45422 .34316 L
.45422 .34316 L
.45423 .34317 L
.45423 .34317 L
.45424 .34317 L
.45424 .34317 L
.45425 .34317 L
.45425 .34318 L
.45426 .34318 L
.45426 .34318 L
.45426 .34318 L
.45427 .34318 L
.45427 .34319 L
.45428 .34319 L
.45428 .34319 L
.45429 .34319 L
.45429 .34319 L
.45429 .3432 L
.4543 .3432 L
.4543 .3432 L
.45431 .3432 L
.45431 .3432 L
.45431 .34321 L
.45432 .34321 L
.45432 .34321 L
.45433 .34321 L
.45433 .34321 L
.45434 .34322 L
.45434 .34322 L
.45434 .34322 L
.45435 .34322 L
.45435 .34322 L
.45436 .34323 L
.45436 .34323 L
Mistroke
.45437 .34323 L
.45437 .34323 L
.45437 .34323 L
.45438 .34324 L
.45438 .34324 L
.45439 .34324 L
.45439 .34324 L
.45439 .34324 L
.4544 .34325 L
.4544 .34325 L
.45441 .34325 L
.45441 .34325 L
.45441 .34326 L
.45442 .34326 L
.45442 .34326 L
.45443 .34326 L
.45443 .34326 L
.45443 .34327 L
.45444 .34327 L
.45444 .34327 L
.45445 .34327 L
.45445 .34327 L
.45445 .34328 L
.45446 .34328 L
.45446 .34328 L
.45447 .34328 L
.45447 .34329 L
.45447 .34329 L
.45448 .34329 L
.45448 .34329 L
.45449 .34329 L
.45449 .3433 L
.45449 .3433 L
.4545 .3433 L
.4545 .3433 L
.45451 .34331 L
.45451 .34331 L
.45451 .34331 L
.45452 .34331 L
.45452 .34331 L
.45453 .34332 L
.45453 .34332 L
.45453 .34332 L
.45454 .34332 L
.45454 .34333 L
.45454 .34333 L
.45455 .34333 L
.45455 .34333 L
.45456 .34333 L
.45456 .34334 L
Mistroke
.45456 .34334 L
.45457 .34334 L
.45457 .34334 L
.45458 .34335 L
.45458 .34335 L
.45458 .34335 L
.45459 .34335 L
.45459 .34336 L
.45459 .34336 L
.4546 .34336 L
.4546 .34336 L
.45461 .34336 L
.45461 .34337 L
.45461 .34337 L
.45462 .34337 L
.45462 .34337 L
.45462 .34338 L
.45463 .34338 L
.45463 .34338 L
.45464 .34338 L
.45464 .34339 L
.45464 .34339 L
.45465 .34339 L
.45465 .34339 L
.45465 .34339 L
.45466 .3434 L
.45466 .3434 L
.45466 .3434 L
.45467 .3434 L
.45467 .34341 L
.45468 .34341 L
.45468 .34341 L
.45468 .34341 L
.45469 .34342 L
.45469 .34342 L
.45469 .34342 L
.4547 .34342 L
.4547 .34343 L
.4547 .34343 L
.45471 .34343 L
.45471 .34343 L
.45472 .34344 L
.45472 .34344 L
.45472 .34344 L
.45473 .34344 L
.45473 .34345 L
.45473 .34345 L
.45474 .34345 L
.45474 .34345 L
.45474 .34346 L
Mistroke
.45475 .34346 L
.45475 .34346 L
.45475 .34346 L
.45476 .34346 L
.45476 .34347 L
.45476 .34347 L
.45477 .34347 L
.45477 .34347 L
.45477 .34348 L
.45478 .34348 L
.45478 .34348 L
.45478 .34348 L
.45479 .34349 L
.45479 .34349 L
.45479 .34349 L
.4548 .34349 L
.4548 .3435 L
.45481 .3435 L
.45481 .3435 L
.45481 .3435 L
.45482 .34351 L
.45482 .34351 L
.45482 .34351 L
.45483 .34351 L
.45483 .34352 L
.45483 .34352 L
.45484 .34352 L
.45484 .34353 L
.45484 .34353 L
.45485 .34353 L
.45485 .34353 L
.45485 .34354 L
.45486 .34354 L
.45486 .34354 L
.45486 .34354 L
.45487 .34355 L
.45487 .34355 L
.45487 .34355 L
.45487 .34355 L
.45488 .34356 L
.45488 .34356 L
.45488 .34356 L
.45489 .34356 L
.45489 .34357 L
.45489 .34357 L
.4549 .34357 L
.4549 .34357 L
.4549 .34358 L
.45491 .34358 L
.45491 .34358 L
Mistroke
.45491 .34358 L
.45492 .34359 L
.45492 .34359 L
.45492 .34359 L
.45493 .34359 L
.45493 .3436 L
.45493 .3436 L
.45494 .3436 L
.45494 .34361 L
.45494 .34361 L
.45494 .34361 L
.45495 .34361 L
.45495 .34362 L
.45495 .34362 L
.45496 .34362 L
.45496 .34362 L
.45496 .34363 L
.45497 .34363 L
.45497 .34363 L
.45497 .34363 L
.45498 .34364 L
.45498 .34364 L
.45498 .34364 L
.45498 .34365 L
.45499 .34365 L
.45499 .34365 L
.45499 .34365 L
.455 .34366 L
.455 .34366 L
.455 .34366 L
.45501 .34366 L
.45501 .34367 L
.45501 .34367 L
.45501 .34367 L
.45502 .34368 L
.45502 .34368 L
.45502 .34368 L
.45503 .34368 L
.45503 .34369 L
.45503 .34369 L
.45504 .34369 L
.45504 .34369 L
.45504 .3437 L
.45504 .3437 L
.45505 .3437 L
.45505 .34371 L
.45505 .34371 L
.45506 .34371 L
.45506 .34371 L
.45506 .34372 L
Mistroke
.45506 .34372 L
.45507 .34372 L
.45507 .34372 L
.45507 .34373 L
.45508 .34373 L
.45508 .34373 L
.45508 .34374 L
.45508 .34374 L
.45509 .34374 L
.45509 .34374 L
.45509 .34375 L
.4551 .34375 L
.4551 .34375 L
.4551 .34376 L
.4551 .34376 L
.45511 .34376 L
.45511 .34376 L
.45511 .34377 L
.45511 .34377 L
.45512 .34377 L
.45512 .34377 L
.45512 .34378 L
.45513 .34378 L
.45513 .34378 L
.45513 .34379 L
.45513 .34379 L
.45514 .34379 L
.45514 .34379 L
.45514 .3438 L
.45514 .3438 L
.45515 .3438 L
.45515 .34381 L
.45515 .34381 L
.45516 .34381 L
.45516 .34381 L
.45516 .34382 L
.45516 .34382 L
.45517 .34382 L
.45517 .34383 L
.45517 .34383 L
.45517 .34383 L
.45518 .34383 L
.45518 .34384 L
.45518 .34384 L
.45518 .34384 L
.45519 .34385 L
.45519 .34385 L
.45519 .34385 L
.45519 .34385 L
.4552 .34386 L
Mistroke
.4552 .34386 L
.4552 .34386 L
.4552 .34387 L
.45521 .34387 L
.45521 .34387 L
.45521 .34387 L
.45522 .34388 L
.45522 .34388 L
.45522 .34388 L
.45522 .34389 L
.45523 .34389 L
.45523 .34389 L
.45523 .3439 L
.45523 .3439 L
.45524 .3439 L
.45524 .3439 L
.45524 .34391 L
.45524 .34391 L
.45524 .34391 L
.45525 .34392 L
.45525 .34392 L
.45525 .34392 L
.45525 .34392 L
.45526 .34393 L
.45526 .34393 L
.45526 .34393 L
.45526 .34394 L
.45527 .34394 L
.45527 .34394 L
.45527 .34395 L
.45527 .34395 L
.45528 .34395 L
.45528 .34395 L
.45528 .34396 L
.45528 .34396 L
.45529 .34396 L
.45529 .34397 L
.45529 .34397 L
.45529 .34397 L
.4553 .34398 L
.4553 .34398 L
.4553 .34398 L
.4553 .34398 L
.4553 .34399 L
.45531 .34399 L
.45531 .34399 L
.45531 .344 L
.45531 .344 L
.45532 .344 L
.45532 .34401 L
Mistroke
.45532 .34401 L
.45532 .34401 L
.45532 .34401 L
.45533 .34402 L
.45533 .34402 L
.45533 .34402 L
.45533 .34403 L
.45534 .34403 L
.45534 .34403 L
.45534 .34404 L
.45534 .34404 L
.45534 .34404 L
.45535 .34404 L
.45535 .34405 L
.45535 .34405 L
.45535 .34405 L
.45536 .34406 L
.45536 .34406 L
.45536 .34406 L
.45536 .34407 L
.45536 .34407 L
.45537 .34407 L
.45537 .34407 L
.45537 .34408 L
.45537 .34408 L
.45537 .34408 L
.45538 .34409 L
.45538 .34409 L
.45538 .34409 L
.45538 .3441 L
.45539 .3441 L
.45539 .3441 L
.45539 .34411 L
.45539 .34411 L
.45539 .34411 L
.4554 .34411 L
.4554 .34412 L
.4554 .34412 L
.4554 .34412 L
.4554 .34413 L
.45541 .34413 L
.45541 .34413 L
.45541 .34414 L
.45541 .34414 L
.45541 .34414 L
.45542 .34415 L
.45542 .34415 L
.45542 .34415 L
.45542 .34416 L
.45542 .34416 L
Mistroke
.45543 .34416 L
.45543 .34416 L
.45543 .34417 L
.45543 .34417 L
.45543 .34417 L
.45544 .34418 L
.45544 .34418 L
.45544 .34418 L
.45544 .34419 L
.45544 .34419 L
.45545 .34419 L
.45545 .3442 L
.45545 .3442 L
.45545 .3442 L
.45545 .34421 L
.45545 .34421 L
.45546 .34421 L
.45546 .34421 L
.45546 .34422 L
.45546 .34422 L
.45546 .34422 L
.45547 .34423 L
.45547 .34423 L
.45547 .34423 L
.45547 .34424 L
.45547 .34424 L
.45548 .34424 L
.45548 .34425 L
.45548 .34425 L
.45548 .34425 L
.45548 .34426 L
.45548 .34426 L
.45549 .34426 L
.45549 .34427 L
.45549 .34427 L
.45549 .34427 L
.45549 .34427 L
.45549 .34428 L
.4555 .34428 L
.4555 .34428 L
.4555 .34429 L
.4555 .34429 L
.4555 .34429 L
.45551 .3443 L
.45551 .3443 L
.45551 .3443 L
.45551 .34431 L
.45551 .34431 L
.45551 .34431 L
.45552 .34432 L
Mistroke
.45552 .34432 L
.45552 .34432 L
.45552 .34433 L
.45552 .34433 L
.45552 .34433 L
.45553 .34434 L
.45553 .34434 L
.45553 .34434 L
.45553 .34435 L
.45553 .34435 L
.45553 .34435 L
.45554 .34435 L
.45554 .34436 L
.45554 .34436 L
.45554 .34436 L
.45554 .34437 L
.45554 .34437 L
.45555 .34437 L
.45555 .34438 L
.45555 .34438 L
.45555 .34438 L
.45555 .34439 L
.45555 .34439 L
.45555 .34439 L
.45556 .3444 L
.45556 .3444 L
.45556 .3444 L
.45556 .34441 L
.45556 .34441 L
.45556 .34441 L
.45557 .34442 L
.45557 .34442 L
.45557 .34442 L
.45557 .34443 L
.45557 .34443 L
.45557 .34443 L
.45557 .34444 L
.45558 .34444 L
.45558 .34444 L
.45558 .34445 L
.45558 .34445 L
.45558 .34445 L
.45558 .34446 L
.45558 .34446 L
.45559 .34446 L
.45559 .34447 L
.45559 .34447 L
.45559 .34447 L
.45559 .34448 L
.45559 .34448 L
Mistroke
.45559 .34448 L
.4556 .34448 L
.4556 .34449 L
.4556 .34449 L
.4556 .34449 L
.4556 .3445 L
.4556 .3445 L
.4556 .3445 L
.45561 .34451 L
.45561 .34451 L
.45561 .34451 L
.45561 .34452 L
.45561 .34452 L
.45561 .34452 L
.45561 .34453 L
.45562 .34453 L
.45562 .34453 L
.45562 .34454 L
.45562 .34454 L
.45562 .34454 L
.45562 .34455 L
.45562 .34455 L
.45562 .34455 L
.45563 .34456 L
.45563 .34456 L
.45563 .34456 L
.45563 .34457 L
.45563 .34457 L
.45563 .34457 L
.45563 .34458 L
.45563 .34458 L
.45564 .34458 L
.45564 .34459 L
.45564 .34459 L
.45564 .34459 L
.45564 .3446 L
.45564 .3446 L
.45564 .3446 L
.45564 .34461 L
.45565 .34461 L
.45565 .34461 L
.45565 .34462 L
.45565 .34462 L
.45565 .34462 L
.45565 .34463 L
.45565 .34463 L
.45565 .34463 L
.45566 .34464 L
.45566 .34464 L
.45566 .34464 L
Mistroke
.45566 .34465 L
.45566 .34465 L
.45566 .34465 L
.45566 .34466 L
.45566 .34466 L
.45566 .34466 L
.45567 .34467 L
.45567 .34467 L
.45567 .34467 L
.45567 .34468 L
.45567 .34468 L
.45567 .34468 L
.45567 .34469 L
.45567 .34469 L
.45567 .34469 L
.45568 .3447 L
.45568 .3447 L
.45568 .3447 L
.45568 .34471 L
.45568 .34471 L
.45568 .34471 L
.45568 .34472 L
.45568 .34472 L
.45568 .34472 L
.45568 .34473 L
.45569 .34473 L
.45569 .34473 L
.45569 .34474 L
.45569 .34474 L
.45569 .34474 L
.45569 .34475 L
.45569 .34475 L
.45569 .34475 L
.45569 .34476 L
.45569 .34476 L
.4557 .34477 L
.4557 .34477 L
.4557 .34477 L
.4557 .34478 L
.4557 .34478 L
.4557 .34478 L
.4557 .34479 L
.4557 .34479 L
.4557 .34479 L
.4557 .3448 L
.4557 .3448 L
.45571 .3448 L
.45571 .34481 L
.45571 .34481 L
.45571 .34481 L
Mistroke
.45571 .34482 L
.45571 .34482 L
.45571 .34482 L
.45571 .34483 L
.45571 .34483 L
.45571 .34483 L
.45571 .34484 L
.45572 .34484 L
.45572 .34484 L
.45572 .34485 L
.45572 .34485 L
.45572 .34485 L
.45572 .34486 L
.45572 .34486 L
.45572 .34486 L
.45572 .34487 L
.45572 .34487 L
.45572 .34487 L
.45572 .34488 L
.45573 .34488 L
.45573 .34488 L
.45573 .34489 L
.45573 .34489 L
.45573 .34489 L
.45573 .3449 L
.45573 .3449 L
.45573 .3449 L
.45573 .34491 L
.45573 .34491 L
.45573 .34491 L
.45573 .34492 L
.45573 .34492 L
.45574 .34493 L
.45574 .34493 L
.45574 .34493 L
.45574 .34494 L
.45574 .34494 L
.45574 .34494 L
.45574 .34495 L
.45574 .34495 L
.45574 .34495 L
.45574 .34496 L
.45574 .34496 L
.45574 .34496 L
.45574 .34497 L
.45574 .34497 L
.45575 .34497 L
.45575 .34498 L
.45575 .34498 L
.45575 .34498 L
Mistroke
.45575 .34499 L
.45575 .34499 L
.45575 .34499 L
.45575 .345 L
.45575 .345 L
.45575 .345 L
.45575 .34501 L
.45575 .34501 L
.45575 .34501 L
.45575 .34502 L
.45575 .34502 L
.45575 .34502 L
.45576 .34503 L
.45576 .34503 L
.45576 .34503 L
.45576 .34504 L
.45576 .34504 L
.45576 .34505 L
.45576 .34505 L
.45576 .34505 L
.45576 .34506 L
.45576 .34506 L
.45576 .34506 L
.45576 .34507 L
.45576 .34507 L
.45576 .34507 L
.45576 .34508 L
.45576 .34508 L
.45576 .34508 L
.45576 .34509 L
.45576 .34509 L
.45577 .34509 L
.45577 .3451 L
.45577 .3451 L
.45577 .3451 L
.45577 .34511 L
.45577 .34511 L
.45577 .34511 L
.45577 .34512 L
.45577 .34512 L
.45577 .34512 L
.45577 .34513 L
.45577 .34513 L
.45577 .34513 L
.45577 .34514 L
.45577 .34514 L
.45577 .34515 L
.45577 .34515 L
.45577 .34515 L
.45577 .34516 L
Mistroke
.45577 .34516 L
.45577 .34516 L
.45577 .34517 L
.45578 .34517 L
.45578 .34517 L
.45578 .34518 L
.45578 .34518 L
.45578 .34518 L
.45578 .34519 L
.45578 .34519 L
.45578 .34519 L
.45578 .3452 L
.45578 .3452 L
.45578 .3452 L
.45578 .34521 L
.45578 .34521 L
.45578 .34521 L
.45578 .34522 L
.45578 .34522 L
.45578 .34523 L
.45578 .34523 L
.45578 .34523 L
.45578 .34524 L
.45578 .34524 L
.45578 .34524 L
.45578 .34525 L
.45578 .34525 L
.45578 .34525 L
.45578 .34526 L
.45578 .34526 L
.45578 .34526 L
.45578 .34527 L
.45578 .34527 L
.45578 .34527 L
.45579 .34528 L
.45579 .34528 L
.45579 .34528 L
.45579 .34529 L
.45579 .34529 L
.45579 .34529 L
.45579 .3453 L
.45579 .3453 L
.45579 .3453 L
.45579 .34531 L
.45579 .34531 L
.45579 .34532 L
.45579 .34532 L
.45579 .34532 L
.45579 .34533 L
.45579 .34533 L
Mistroke
.45579 .34533 L
.45579 .34534 L
.45579 .34534 L
.45579 .34534 L
.45579 .34535 L
.45579 .34535 L
.45579 .34535 L
.45579 .34536 L
.45579 .34536 L
.45579 .34536 L
.45579 .34537 L
.45579 .34537 L
.45579 .34537 L
.45579 .34538 L
.45579 .34538 L
.45579 .34538 L
.45579 .34539 L
.45579 .34539 L
.45579 .3454 L
.45579 .3454 L
.45579 .3454 L
.45579 .34541 L
.45579 .34541 L
.45579 .34541 L
.45579 .34542 L
.45579 .34542 L
.45579 .34542 L
.45579 .34543 L
.45579 .34543 L
.45579 .34543 L
.45579 .34544 L
.45579 .34544 L
.45579 .34544 L
.45579 .34545 L
.45579 .34545 L
.45579 .34545 L
.45579 .34546 L
.45579 .34546 L
.45579 .34547 L
.45579 .34547 L
.45579 .34547 L
.45579 .34548 L
.45579 .34548 L
.45579 .34548 L
.45579 .34549 L
.45579 .34549 L
.45579 .34549 L
.45579 .3455 L
.45579 .3455 L
.45579 .3455 L
Mistroke
.45579 .34551 L
.45579 .34551 L
.45579 .34551 L
.45579 .34552 L
.45579 .34552 L
.45579 .34552 L
.45579 .34553 L
.45579 .34553 L
.45579 .34553 L
.45579 .34554 L
.45579 .34554 L
.45579 .34555 L
.45579 .34555 L
.45579 .34555 L
.45579 .34556 L
.45579 .34556 L
.45579 .34556 L
.45579 .34557 L
.45579 .34557 L
.45579 .34557 L
.45579 .34558 L
.45579 .34558 L
.45579 .34558 L
.45579 .34559 L
.45579 .34559 L
.45579 .34559 L
.45579 .3456 L
.45579 .3456 L
.45579 .3456 L
.45579 .34561 L
.45579 .34561 L
.45579 .34561 L
.45579 .34562 L
.45579 .34562 L
.45579 .34563 L
.45579 .34563 L
.45579 .34563 L
.45579 .34564 L
.45579 .34564 L
.45579 .34564 L
.45579 .34565 L
.45579 .34565 L
.45579 .34565 L
.45579 .34566 L
.45579 .34566 L
.45579 .34566 L
.45579 .34567 L
.45579 .34567 L
.45579 .34567 L
.45579 .34568 L
Mistroke
.45578 .34568 L
.45578 .34568 L
.45578 .34569 L
.45578 .34569 L
.45578 .34569 L
.45578 .3457 L
.45578 .3457 L
.45578 .34571 L
.45578 .34571 L
.45578 .34571 L
.45578 .34572 L
.45578 .34572 L
.45578 .34572 L
.45578 .34573 L
.45578 .34573 L
.45578 .34573 L
.45578 .34574 L
.45578 .34574 L
.45578 .34574 L
.45578 .34575 L
.45578 .34575 L
.45578 .34575 L
.45578 .34576 L
.45578 .34576 L
.45578 .34576 L
.45578 .34577 L
.45578 .34577 L
.45578 .34577 L
.45578 .34578 L
.45578 .34578 L
.45578 .34579 L
.45578 .34579 L
.45578 .34579 L
.45577 .3458 L
.45577 .3458 L
.45577 .3458 L
.45577 .34581 L
.45577 .34581 L
.45577 .34581 L
.45577 .34582 L
.45577 .34582 L
.45577 .34582 L
.45577 .34583 L
.45577 .34583 L
.45577 .34583 L
.45577 .34584 L
.45577 .34584 L
.45577 .34584 L
.45577 .34585 L
.45577 .34585 L
Mistroke
.45577 .34585 L
.45577 .34586 L
.45577 .34586 L
.45577 .34586 L
.45577 .34587 L
.45577 .34587 L
.45576 .34588 L
.45576 .34588 L
.45576 .34588 L
.45576 .34589 L
.45576 .34589 L
.45576 .34589 L
.45576 .3459 L
.45576 .3459 L
.45576 .3459 L
.45576 .34591 L
.45576 .34591 L
.45576 .34591 L
.45576 .34592 L
.45576 .34592 L
.45576 .34592 L
.45576 .34593 L
.45576 .34593 L
.45576 .34593 L
.45576 .34594 L
.45576 .34594 L
.45575 .34594 L
.45575 .34595 L
.45575 .34595 L
.45575 .34595 L
.45575 .34596 L
.45575 .34596 L
.45575 .34596 L
.45575 .34597 L
.45575 .34597 L
.45575 .34598 L
.45575 .34598 L
.45575 .34598 L
.45575 .34599 L
.45575 .34599 L
.45575 .34599 L
.45575 .346 L
.45575 .346 L
.45575 .346 L
.45574 .34601 L
.45574 .34601 L
.45574 .34601 L
.45574 .34602 L
.45574 .34602 L
.45574 .34602 L
Mistroke
.45574 .34603 L
.45574 .34603 L
.45574 .34603 L
.45574 .34604 L
.45574 .34604 L
.45574 .34604 L
.45574 .34605 L
.45574 .34605 L
.45574 .34605 L
.45574 .34606 L
.45573 .34606 L
.45573 .34606 L
.45573 .34607 L
.45573 .34607 L
.45573 .34608 L
.45573 .34608 L
.45573 .34608 L
.45573 .34609 L
.45573 .34609 L
.45573 .34609 L
.45573 .3461 L
.45573 .3461 L
.45573 .3461 L
.45573 .34611 L
.45572 .34611 L
.45572 .34611 L
.45572 .34612 L
.45572 .34612 L
.45572 .34612 L
.45572 .34613 L
.45572 .34613 L
.45572 .34613 L
.45572 .34614 L
.45572 .34614 L
.45572 .34614 L
.45572 .34615 L
.45572 .34615 L
.45572 .34615 L
.45571 .34616 L
.45571 .34616 L
.45571 .34616 L
.45571 .34617 L
.45571 .34617 L
.45571 .34617 L
.45571 .34618 L
.45571 .34618 L
.45571 .34618 L
.45571 .34619 L
.45571 .34619 L
.45571 .34619 L
Mistroke
.45571 .3462 L
.4557 .3462 L
.4557 .3462 L
.4557 .34621 L
.4557 .34621 L
.4557 .34622 L
.4557 .34622 L
.4557 .34622 L
.4557 .34623 L
.4557 .34623 L
.4557 .34623 L
.4557 .34624 L
.4557 .34624 L
.45569 .34624 L
.45569 .34625 L
.45569 .34625 L
.45569 .34625 L
.45569 .34626 L
.45569 .34626 L
.45569 .34626 L
.45569 .34627 L
.45569 .34627 L
.45569 .34627 L
.45569 .34628 L
.45569 .34628 L
.45568 .34628 L
.45568 .34629 L
.45568 .34629 L
.45568 .34629 L
.45568 .3463 L
.45568 .3463 L
.45568 .3463 L
.45568 .34631 L
.45568 .34631 L
.45568 .34631 L
.45568 .34632 L
.45567 .34632 L
.45567 .34632 L
.45567 .34633 L
.45567 .34633 L
.45567 .34633 L
.45567 .34634 L
.45567 .34634 L
.45567 .34634 L
.45567 .34635 L
.45567 .34635 L
.45566 .34635 L
.45566 .34636 L
.45566 .34636 L
.45566 .34636 L
Mistroke
.45566 .34637 L
.45566 .34637 L
.45566 .34637 L
.45566 .34638 L
.45566 .34638 L
.45566 .34638 L
.45566 .34639 L
.45565 .34639 L
.45565 .34639 L
.45565 .3464 L
.45565 .3464 L
.45565 .3464 L
.45565 .34641 L
.45565 .34641 L
.45565 .34641 L
.45565 .34642 L
.45565 .34642 L
.45564 .34642 L
.45564 .34643 L
.45564 .34643 L
.45564 .34643 L
.45564 .34644 L
.45564 .34644 L
.45564 .34644 L
.45564 .34645 L
.45564 .34645 L
.45563 .34645 L
.45563 .34646 L
.45563 .34646 L
.45563 .34646 L
.45563 .34647 L
.45563 .34647 L
.45563 .34647 L
.45563 .34648 L
.45563 .34648 L
.45563 .34648 L
.45562 .34649 L
.45562 .34649 L
.45562 .34649 L
.45562 .3465 L
.45562 .3465 L
.45562 .3465 L
.45562 .34651 L
.45562 .34651 L
.45562 .34651 L
.45561 .34652 L
.45561 .34652 L
.45561 .34652 L
.45561 .34653 L
.45561 .34653 L
Mistroke
.45561 .34653 L
.45561 .34654 L
.45561 .34654 L
.45561 .34654 L
.4556 .34655 L
.4556 .34655 L
.4556 .34655 L
.4556 .34656 L
.4556 .34656 L
.4556 .34656 L
.4556 .34657 L
.4556 .34657 L
.4556 .34657 L
.45559 .34658 L
.45559 .34658 L
.45559 .34658 L
.45559 .34659 L
.45559 .34659 L
.45559 .34659 L
.45559 .3466 L
.45559 .3466 L
.45558 .3466 L
.45558 .34661 L
.45558 .34661 L
.45558 .34661 L
.45558 .34662 L
.45558 .34662 L
.45558 .34662 L
.45558 .34663 L
.45558 .34663 L
.45557 .34663 L
.45557 .34664 L
.45557 .34664 L
.45557 .34664 L
.45557 .34665 L
.45557 .34665 L
.45557 .34665 L
.45557 .34666 L
.45556 .34666 L
.45556 .34666 L
.45556 .34667 L
.45556 .34667 L
.45556 .34667 L
.45556 .34668 L
.45556 .34668 L
.45556 .34668 L
.45555 .34669 L
.45555 .34669 L
.45555 .34669 L
.45555 .3467 L
Mistroke
.45555 .3467 L
.45555 .3467 L
.45555 .34671 L
.45555 .34671 L
.45554 .34671 L
.45554 .34672 L
.45554 .34672 L
.45554 .34672 L
.45554 .34672 L
.45554 .34673 L
.45554 .34673 L
.45554 .34673 L
.45553 .34674 L
.45553 .34674 L
.45553 .34674 L
.45553 .34675 L
.45553 .34675 L
.45553 .34675 L
.45553 .34676 L
.45552 .34676 L
.45552 .34676 L
.45552 .34677 L
.45552 .34677 L
.45552 .34677 L
.45552 .34678 L
.45552 .34678 L
.45552 .34678 L
.45551 .34679 L
.45551 .34679 L
.45551 .34679 L
.45551 .3468 L
.45551 .3468 L
.45551 .3468 L
.45551 .34681 L
.4555 .34681 L
.4555 .34681 L
.4555 .34682 L
.4555 .34682 L
.4555 .34682 L
.4555 .34682 L
.4555 .34683 L
.4555 .34683 L
.45549 .34683 L
.45549 .34684 L
.45549 .34684 L
.45549 .34684 L
.45549 .34685 L
.45549 .34685 L
.45549 .34685 L
.45548 .34686 L
Mistroke
.45548 .34686 L
.45548 .34686 L
.45548 .34687 L
.45548 .34687 L
.45548 .34687 L
.45548 .34688 L
.45547 .34688 L
.45547 .34688 L
.45547 .34689 L
.45547 .34689 L
.45547 .34689 L
.45547 .3469 L
.45547 .3469 L
.45546 .3469 L
.45546 .3469 L
.45546 .34691 L
.45546 .34691 L
.45546 .34691 L
.45546 .34692 L
.45546 .34692 L
.45545 .34692 L
.45545 .34693 L
.45545 .34693 L
.45545 .34693 L
.45545 .34694 L
.45545 .34694 L
.45545 .34694 L
.45544 .34695 L
.45544 .34695 L
.45544 .34695 L
.45544 .34696 L
.45544 .34696 L
.45544 .34696 L
.45544 .34696 L
.45543 .34697 L
.45543 .34697 L
.45543 .34697 L
.45543 .34698 L
.45543 .34698 L
.45543 .34698 L
.45543 .34699 L
.45542 .34699 L
.45542 .34699 L
.45542 .347 L
.45542 .347 L
.45542 .347 L
.45542 .34701 L
.45541 .34701 L
.45541 .34701 L
.45541 .34702 L
Mistroke
.45541 .34702 L
.45541 .34702 L
.45541 .34702 L
.45541 .34703 L
.4554 .34703 L
.4554 .34703 L
.4554 .34704 L
.4554 .34704 L
.4554 .34704 L
.4554 .34705 L
.45539 .34705 L
.45539 .34705 L
.45539 .34706 L
.45539 .34706 L
.45539 .34706 L
.45539 .34706 L
.45539 .34707 L
.45538 .34707 L
.45538 .34707 L
.45538 .34708 L
.45538 .34708 L
.45538 .34708 L
.45538 .34709 L
.45537 .34709 L
.45537 .34709 L
.45537 .3471 L
.45537 .3471 L
.45537 .3471 L
.45537 .34711 L
.45537 .34711 L
.45536 .34711 L
.45536 .34711 L
.45536 .34712 L
.45536 .34712 L
.45536 .34712 L
.45536 .34713 L
.45535 .34713 L
.45535 .34713 L
.45535 .34714 L
.45535 .34714 L
.45535 .34714 L
.45535 .34715 L
.45534 .34715 L
.45534 .34715 L
.45534 .34715 L
.45534 .34716 L
.45534 .34716 L
.45534 .34716 L
.45533 .34717 L
.45533 .34717 L
Mistroke
.45533 .34717 L
.45533 .34718 L
.45533 .34718 L
.45533 .34718 L
.45532 .34718 L
.45532 .34719 L
.45532 .34719 L
.45532 .34719 L
.45532 .3472 L
.45532 .3472 L
.45531 .3472 L
.45531 .34721 L
.45531 .34721 L
.45531 .34721 L
.45531 .34722 L
.45531 .34722 L
.4553 .34722 L
.4553 .34722 L
.4553 .34723 L
.4553 .34723 L
.4553 .34723 L
.4553 .34724 L
.45529 .34724 L
.45529 .34724 L
.45529 .34725 L
.45529 .34725 L
.45529 .34725 L
.45529 .34725 L
.45528 .34726 L
.45528 .34726 L
.45528 .34726 L
.45528 .34727 L
.45528 .34727 L
.45528 .34727 L
.45527 .34728 L
.45527 .34728 L
.45527 .34728 L
.45527 .34728 L
.45527 .34729 L
.45527 .34729 L
.45526 .34729 L
.45526 .3473 L
.45526 .3473 L
.45526 .3473 L
.45526 .34731 L
.45526 .34731 L
.45525 .34731 L
.45525 .34731 L
.45525 .34732 L
.45525 .34732 L
Mistroke
.45525 .34732 L
.45525 .34733 L
.45524 .34733 L
.45524 .34733 L
.45524 .34734 L
.45524 .34734 L
.45524 .34734 L
.45524 .34734 L
.45523 .34735 L
.45523 .34735 L
.45523 .34735 L
.45523 .34736 L
.45523 .34736 L
.45522 .34736 L
.45522 .34736 L
.45522 .34737 L
.45522 .34737 L
.45522 .34737 L
.45522 .34738 L
.45521 .34738 L
.45521 .34738 L
.45521 .34739 L
.45521 .34739 L
.45521 .34739 L
.45521 .34739 L
.4552 .3474 L
.4552 .3474 L
.4552 .3474 L
.4552 .34741 L
.4552 .34741 L
.45519 .34741 L
.45519 .34741 L
.45519 .34742 L
.45519 .34742 L
.45519 .34742 L
.45519 .34743 L
.45518 .34743 L
.45518 .34743 L
.45518 .34743 L
.45518 .34744 L
.45518 .34744 L
.45517 .34744 L
.45517 .34745 L
.45517 .34745 L
.45517 .34745 L
.45517 .34746 L
.45517 .34746 L
.45516 .34746 L
.45516 .34746 L
.45516 .34747 L
Mistroke
.45516 .34747 L
.45516 .34747 L
.45515 .34748 L
.45515 .34748 L
.45515 .34748 L
.45515 .34748 L
.45515 .34749 L
.45515 .34749 L
.45514 .34749 L
.45514 .3475 L
.45514 .3475 L
.45514 .3475 L
.45514 .3475 L
.45513 .34751 L
.45513 .34751 L
.45513 .34751 L
.45513 .34752 L
.45513 .34752 L
.45513 .34752 L
.45512 .34752 L
.45512 .34753 L
.45512 .34753 L
.45512 .34753 L
.45512 .34754 L
.45511 .34754 L
.45511 .34754 L
.45511 .34754 L
.45511 .34755 L
.45511 .34755 L
.4551 .34755 L
.4551 .34756 L
.4551 .34756 L
.4551 .34756 L
.4551 .34756 L
.4551 .34757 L
.45509 .34757 L
.45509 .34757 L
.45509 .34758 L
.45509 .34758 L
.45509 .34758 L
.45508 .34758 L
.45508 .34759 L
.45508 .34759 L
.45508 .34759 L
.45508 .34759 L
.45507 .3476 L
.45507 .3476 L
.45507 .3476 L
.45507 .34761 L
.45507 .34761 L
Mistroke
.45507 .34761 L
.45506 .34761 L
.45506 .34762 L
.45506 .34762 L
.45506 .34762 L
.45506 .34763 L
.45505 .34763 L
.45505 .34763 L
.45505 .34763 L
.45505 .34764 L
.45505 .34764 L
.45504 .34764 L
.45504 .34764 L
.45504 .34765 L
.45504 .34765 L
.45504 .34765 L
.45503 .34766 L
.45503 .34766 L
.45503 .34766 L
.45503 .34766 L
.45503 .34767 L
.45502 .34767 L
.45502 .34767 L
.45502 .34768 L
.45502 .34768 L
.45502 .34768 L
.45502 .34768 L
.45501 .34769 L
.45501 .34769 L
.45501 .34769 L
.45501 .34769 L
.45501 .3477 L
.455 .3477 L
.455 .3477 L
.455 .34771 L
.455 .34771 L
.455 .34771 L
.45499 .34771 L
.45499 .34772 L
.45499 .34772 L
.45499 .34772 L
.45499 .34772 L
.45498 .34773 L
.45498 .34773 L
.45498 .34773 L
.45498 .34774 L
.45498 .34774 L
.45497 .34774 L
.45497 .34774 L
.45497 .34775 L
Mistroke
.45497 .34775 L
.45497 .34775 L
.45496 .34775 L
.45496 .34776 L
.45496 .34776 L
.45496 .34776 L
.45496 .34777 L
.45495 .34777 L
.45495 .34777 L
.45495 .34777 L
.45495 .34778 L
.45495 .34778 L
.45494 .34778 L
.45494 .34778 L
.45494 .34779 L
.45494 .34779 L
.45494 .34779 L
.45493 .34779 L
.45493 .3478 L
.45493 .3478 L
.45493 .3478 L
.45493 .34781 L
.45492 .34781 L
.45492 .34781 L
.45492 .34781 L
.45492 .34782 L
.45492 .34782 L
.45491 .34782 L
.45491 .34782 L
.45491 .34783 L
.45491 .34783 L
.45491 .34783 L
.4549 .34783 L
.4549 .34784 L
.4549 .34784 L
.4549 .34784 L
.4549 .34784 L
.45489 .34785 L
.45489 .34785 L
.45489 .34785 L
.45489 .34786 L
.45489 .34786 L
.45488 .34786 L
.45488 .34786 L
.45488 .34787 L
.45488 .34787 L
.45488 .34787 L
.45487 .34787 L
.45487 .34788 L
.45487 .34788 L
Mistroke
.45487 .34788 L
.45487 .34788 L
.45486 .34789 L
.45486 .34789 L
.45486 .34789 L
.45486 .34789 L
.45486 .3479 L
.45485 .3479 L
.45485 .3479 L
.45485 .3479 L
.45485 .34791 L
.45485 .34791 L
.45484 .34791 L
.45484 .34792 L
.45484 .34792 L
.45484 .34792 L
.45483 .34792 L
.45483 .34793 L
.45483 .34793 L
.45483 .34793 L
.45483 .34793 L
.45482 .34794 L
.45482 .34794 L
.45482 .34794 L
.45482 .34794 L
.45482 .34795 L
.45481 .34795 L
.45481 .34795 L
.45481 .34795 L
.45481 .34796 L
.45481 .34796 L
.4548 .34796 L
.4548 .34796 L
.4548 .34797 L
.4548 .34797 L
.4548 .34797 L
.45479 .34797 L
.45479 .34798 L
.45479 .34798 L
.45479 .34798 L
.45479 .34798 L
.45478 .34799 L
.45478 .34799 L
.45478 .34799 L
.45478 .34799 L
.45477 .348 L
.45477 .348 L
.45477 .348 L
.45477 .348 L
.45477 .34801 L
Mistroke
.45476 .34801 L
.45476 .34801 L
.45476 .34801 L
.45476 .34802 L
.45476 .34802 L
.45475 .34802 L
.45475 .34802 L
.45475 .34803 L
.45475 .34803 L
.45475 .34803 L
.45474 .34803 L
.45474 .34804 L
.45474 .34804 L
.45474 .34804 L
.45473 .34804 L
.45473 .34805 L
.45473 .34805 L
.45473 .34805 L
.45473 .34805 L
.45472 .34806 L
.45472 .34806 L
.45472 .34806 L
.45472 .34806 L
.45472 .34807 L
.45471 .34807 L
.45471 .34807 L
.45471 .34807 L
.45471 .34808 L
.45471 .34808 L
.4547 .34808 L
.4547 .34808 L
.4547 .34809 L
.4547 .34809 L
.45469 .34809 L
.45469 .34809 L
.45469 .3481 L
.45469 .3481 L
.45469 .3481 L
.45468 .3481 L
.45468 .34811 L
.45468 .34811 L
.45468 .34811 L
.45468 .34811 L
.45467 .34812 L
.45467 .34812 L
.45467 .34812 L
.45467 .34812 L
.45466 .34812 L
.45466 .34813 L
.45466 .34813 L
Mistroke
.45466 .34813 L
.45466 .34813 L
.45465 .34814 L
.45465 .34814 L
.45465 .34814 L
.45465 .34814 L
.45465 .34815 L
.45464 .34815 L
.45464 .34815 L
.45464 .34815 L
.45464 .34816 L
.45463 .34816 L
.45463 .34816 L
.45463 .34816 L
.45463 .34817 L
.45463 .34817 L
.45462 .34817 L
.45462 .34817 L
.45462 .34817 L
.45462 .34818 L
.45462 .34818 L
.45461 .34818 L
.45461 .34818 L
.45461 .34819 L
.45461 .34819 L
.4546 .34819 L
.4546 .34819 L
.4546 .3482 L
.4546 .3482 L
.4546 .3482 L
.45459 .3482 L
.45459 .34821 L
.45459 .34821 L
.45459 .34821 L
.45458 .34821 L
.45458 .34821 L
.45458 .34822 L
.45458 .34822 L
.45458 .34822 L
.45457 .34822 L
.45457 .34823 L
.45457 .34823 L
.45457 .34823 L
.45457 .34823 L
.45456 .34824 L
.45456 .34824 L
.45456 .34824 L
.45456 .34824 L
.45455 .34824 L
.45455 .34825 L
Mistroke
.45455 .34825 L
.45455 .34825 L
.45455 .34825 L
.45454 .34826 L
.45454 .34826 L
.45454 .34826 L
.45454 .34826 L
.45453 .34827 L
.45453 .34827 L
.45453 .34827 L
.45453 .34827 L
.45453 .34827 L
.45452 .34828 L
.45452 .34828 L
.45452 .34828 L
.45452 .34828 L
.45452 .34829 L
.45451 .34829 L
.45451 .34829 L
.45451 .34829 L
.45451 .34829 L
.4545 .3483 L
.4545 .3483 L
.4545 .3483 L
.4545 .3483 L
.4545 .34831 L
.45449 .34831 L
.45449 .34831 L
.45449 .34831 L
.45449 .34832 L
.45448 .34832 L
.45448 .34832 L
.45448 .34832 L
.45448 .34832 L
.45448 .34833 L
.45447 .34833 L
.45447 .34833 L
.45447 .34833 L
.45447 .34834 L
.45446 .34834 L
.45446 .34834 L
.45446 .34834 L
.45446 .34834 L
.45446 .34835 L
.45445 .34835 L
.45445 .34835 L
.45445 .34835 L
.45445 .34835 L
.45444 .34836 L
.45444 .34836 L
Mistroke
.45444 .34836 L
.45444 .34836 L
.45444 .34837 L
.45443 .34837 L
.45443 .34837 L
.45443 .34837 L
.45443 .34837 L
.45443 .34838 L
.45442 .34838 L
.45442 .34838 L
.45442 .34838 L
.45442 .34839 L
.45441 .34839 L
.45441 .34839 L
.45441 .34839 L
.45441 .34839 L
.45441 .3484 L
.4544 .3484 L
.4544 .3484 L
.4544 .3484 L
.4544 .3484 L
.45439 .34841 L
.45439 .34841 L
.45439 .34841 L
.45439 .34841 L
.45439 .34842 L
.45438 .34842 L
.45438 .34842 L
.45438 .34842 L
.45438 .34842 L
.45437 .34843 L
.45437 .34843 L
.45437 .34843 L
.45437 .34843 L
.45437 .34843 L
.45436 .34844 L
.45436 .34844 L
.45436 .34844 L
.45436 .34844 L
.45435 .34845 L
.45435 .34845 L
.45435 .34845 L
.45435 .34845 L
.45435 .34845 L
.45434 .34846 L
.45434 .34846 L
.45434 .34846 L
.45434 .34846 L
.45433 .34846 L
.45433 .34847 L
Mistroke
.45433 .34847 L
.45433 .34847 L
.45433 .34847 L
.45432 .34847 L
.45432 .34848 L
.45432 .34848 L
.45432 .34848 L
.45431 .34848 L
.45431 .34848 L
.45431 .34849 L
.45431 .34849 L
.45431 .34849 L
.4543 .34849 L
.4543 .3485 L
.4543 .3485 L
.4543 .3485 L
.45429 .3485 L
.45429 .3485 L
.45429 .34851 L
.45429 .34851 L
.45428 .34851 L
.45428 .34851 L
.45428 .34851 L
.45428 .34852 L
.45428 .34852 L
.45427 .34852 L
.45427 .34852 L
.45427 .34852 L
.45427 .34853 L
.45426 .34853 L
.45426 .34853 L
.45426 .34853 L
.45426 .34853 L
.45426 .34854 L
.45425 .34854 L
.45425 .34854 L
.45425 .34854 L
.45425 .34854 L
.45424 .34855 L
.45424 .34855 L
.45424 .34855 L
.45424 .34855 L
.45424 .34855 L
.45423 .34856 L
.45423 .34856 L
.45423 .34856 L
.45423 .34856 L
.45422 .34856 L
.45422 .34857 L
.45422 .34857 L
Mistroke
.45422 .34857 L
.45422 .34857 L
.45421 .34857 L
.45421 .34858 L
.45421 .34858 L
.45421 .34858 L
.4542 .34858 L
.4542 .34858 L
.4542 .34859 L
.4542 .34859 L
.4542 .34859 L
.45419 .34859 L
.45419 .34859 L
.45419 .3486 L
.45419 .3486 L
.45418 .3486 L
.45418 .3486 L
.45418 .3486 L
.45418 .3486 L
.45418 .34861 L
.45417 .34861 L
.45417 .34861 L
.45417 .34861 L
.45417 .34861 L
.45416 .34862 L
.45416 .34862 L
.45416 .34862 L
.45416 .34862 L
.45415 .34862 L
.45415 .34863 L
.45415 .34863 L
.45415 .34863 L
.45415 .34863 L
.45414 .34863 L
.45414 .34864 L
.45414 .34864 L
.45414 .34864 L
.45413 .34864 L
.45413 .34864 L
.45413 .34865 L
.45413 .34865 L
.45413 .34865 L
.45412 .34865 L
.45412 .34865 L
.45412 .34865 L
.45412 .34866 L
.45411 .34866 L
.45411 .34866 L
.45411 .34866 L
.45411 .34866 L
Mistroke
.45411 .34867 L
.4541 .34867 L
.4541 .34867 L
.4541 .34867 L
.4541 .34867 L
.45409 .34867 L
.45409 .34868 L
.45409 .34868 L
.45409 .34868 L
.45409 .34868 L
.45408 .34868 L
.45408 .34869 L
.45408 .34869 L
.45408 .34869 L
.45407 .34869 L
.45407 .34869 L
.45407 .3487 L
.45407 .3487 L
.45407 .3487 L
.45406 .3487 L
.45406 .3487 L
.45406 .3487 L
.45406 .34871 L
.45405 .34871 L
.45405 .34871 L
.45405 .34871 L
.45405 .34871 L
.45404 .34872 L
.45404 .34872 L
.45404 .34872 L
.45404 .34872 L
.45404 .34872 L
.45403 .34872 L
.45403 .34873 L
.45403 .34873 L
.45403 .34873 L
.45402 .34873 L
.45402 .34873 L
.45402 .34873 L
.45402 .34874 L
.45402 .34874 L
.45401 .34874 L
.45401 .34874 L
.45401 .34874 L
.45401 .34875 L
.454 .34875 L
.454 .34875 L
.454 .34875 L
.454 .34875 L
.454 .34875 L
Mistroke
.45399 .34876 L
.45399 .34876 L
.45399 .34876 L
.45399 .34876 L
.45398 .34876 L
.45398 .34876 L
.45398 .34877 L
.45398 .34877 L
.45398 .34877 L
.45397 .34877 L
.45397 .34877 L
.45397 .34878 L
.45397 .34878 L
.45396 .34878 L
.45396 .34878 L
.45396 .34878 L
.45396 .34878 L
.45395 .34879 L
.45395 .34879 L
.45395 .34879 L
.45395 .34879 L
.45395 .34879 L
.45394 .34879 L
.45394 .3488 L
.45394 .3488 L
.45394 .3488 L
.45393 .3488 L
.45393 .3488 L
.45393 .3488 L
.45393 .34881 L
.45393 .34881 L
.45392 .34881 L
.45392 .34881 L
.45392 .34881 L
.45392 .34881 L
.45391 .34882 L
.45391 .34882 L
.45391 .34882 L
.45391 .34882 L
.45391 .34882 L
.4539 .34882 L
.4539 .34883 L
.4539 .34883 L
.4539 .34883 L
.45389 .34883 L
.45389 .34883 L
.45389 .34883 L
.45389 .34884 L
.45389 .34884 L
.45388 .34884 L
Mistroke
.45388 .34884 L
.45388 .34884 L
.45388 .34884 L
.45387 .34885 L
.45387 .34885 L
.45387 .34885 L
.45387 .34885 L
.45387 .34885 L
.45386 .34885 L
.45386 .34886 L
.45386 .34886 L
.45386 .34886 L
.45385 .34886 L
.45385 .34886 L
.45385 .34886 L
.45385 .34887 L
.45384 .34887 L
.45384 .34887 L
.45384 .34887 L
.45384 .34887 L
.45384 .34887 L
.45383 .34888 L
.45383 .34888 L
.45383 .34888 L
.45383 .34888 L
.45382 .34888 L
.45382 .34888 L
.45382 .34888 L
.45382 .34889 L
.45382 .34889 L
.45381 .34889 L
.45381 .34889 L
.45381 .34889 L
.45381 .34889 L
.4538 .3489 L
.4538 .3489 L
.4538 .3489 L
.4538 .3489 L
.4538 .3489 L
.45379 .3489 L
.45379 .34891 L
.45379 .34891 L
.45379 .34891 L
.45378 .34891 L
.45378 .34891 L
.45378 .34891 L
.45378 .34891 L
.45378 .34892 L
.45377 .34892 L
.45377 .34892 L
Mistroke
.45377 .34892 L
.45377 .34892 L
.45376 .34892 L
.45376 .34893 L
.45376 .34893 L
.45376 .34893 L
.45376 .34893 L
.45375 .34893 L
.45375 .34893 L
.45375 .34893 L
.45375 .34894 L
.45374 .34894 L
.45374 .34894 L
.45374 .34894 L
.45374 .34894 L
.45374 .34894 L
.45373 .34894 L
.45373 .34895 L
.45373 .34895 L
.45373 .34895 L
.45372 .34895 L
.45372 .34895 L
.45372 .34895 L
.45372 .34896 L
.45372 .34896 L
.45371 .34896 L
.45371 .34896 L
.45371 .34896 L
.45371 .34896 L
.4537 .34896 L
.4537 .34897 L
.4537 .34897 L
.4537 .34897 L
.4537 .34897 L
.45369 .34897 L
.45369 .34897 L
.45369 .34897 L
.45369 .34898 L
.45368 .34898 L
.45368 .34898 L
.45368 .34898 L
.45368 .34898 L
.45368 .34898 L
.45367 .34898 L
.45367 .34899 L
.45367 .34899 L
.45367 .34899 L
.45366 .34899 L
.45366 .34899 L
.45366 .34899 L
Mistroke
.45366 .34899 L
.45366 .349 L
.45365 .349 L
.45365 .349 L
.45365 .349 L
.45365 .349 L
.45364 .349 L
.45364 .349 L
.45364 .34901 L
.45364 .34901 L
.45364 .34901 L
.45363 .34901 L
.45363 .34901 L
.45363 .34901 L
.45363 .34901 L
.45363 .34902 L
.45362 .34902 L
.45362 .34902 L
.45362 .34902 L
.45362 .34902 L
.45361 .34902 L
.45361 .34902 L
.45361 .34903 L
.45361 .34903 L
.45361 .34903 L
.4536 .34903 L
.4536 .34903 L
.4536 .34903 L
.4536 .34903 L
.45359 .34904 L
.45359 .34904 L
.45359 .34904 L
.45359 .34904 L
.45359 .34904 L
.45358 .34904 L
.45358 .34904 L
.45358 .34904 L
.45358 .34905 L
.45357 .34905 L
.45357 .34905 L
.45357 .34905 L
.45357 .34905 L
.45357 .34905 L
.45356 .34905 L
.45356 .34906 L
.45356 .34906 L
.45356 .34906 L
.45355 .34906 L
.45355 .34906 L
.45355 .34906 L
Mistroke
.45355 .34906 L
.45355 .34906 L
.45354 .34907 L
.45354 .34907 L
.45354 .34907 L
.45354 .34907 L
.45354 .34907 L
.45353 .34907 L
.45353 .34907 L
.45353 .34908 L
.45353 .34908 L
.45352 .34908 L
.45352 .34908 L
.45352 .34908 L
.45352 .34908 L
.45352 .34908 L
.45351 .34908 L
.45351 .34909 L
.45351 .34909 L
.45351 .34909 L
.4535 .34909 L
.4535 .34909 L
.4535 .34909 L
.4535 .34909 L
.4535 .34909 L
.45349 .3491 L
.45349 .3491 L
.45349 .3491 L
.45349 .3491 L
.45349 .3491 L
.45348 .3491 L
.45348 .3491 L
.45348 .3491 L
.45348 .34911 L
.45347 .34911 L
.45347 .34911 L
.45347 .34911 L
.45347 .34911 L
.45347 .34911 L
.45346 .34911 L
.45346 .34911 L
.45346 .34912 L
.45346 .34912 L
.45345 .34912 L
.45345 .34912 L
.45345 .34912 L
.45345 .34912 L
.45345 .34912 L
.45344 .34912 L
.45344 .34913 L
Mistroke
.45344 .34913 L
.45344 .34913 L
.45344 .34913 L
.45343 .34913 L
.45343 .34913 L
.45343 .34913 L
.45343 .34913 L
.45342 .34914 L
.45342 .34914 L
.45342 .34914 L
.45342 .34914 L
.45342 .34914 L
.45341 .34914 L
.45341 .34914 L
.45341 .34914 L
.45341 .34914 L
.45341 .34915 L
.4534 .34915 L
.4534 .34915 L
.4534 .34915 L
.4534 .34915 L
.45339 .34915 L
.45339 .34915 L
.45339 .34915 L
.45339 .34916 L
.45339 .34916 L
.45338 .34916 L
.45338 .34916 L
.45338 .34916 L
.45338 .34916 L
.45338 .34916 L
.45337 .34916 L
.45337 .34916 L
.45337 .34917 L
.45337 .34917 L
.45336 .34917 L
.45336 .34917 L
.45336 .34917 L
.45336 .34917 L
.45336 .34917 L
.45335 .34917 L
.45335 .34917 L
.45335 .34918 L
.45335 .34918 L
.45335 .34918 L
.45334 .34918 L
.45334 .34918 L
.45334 .34918 L
.45334 .34918 L
.45334 .34918 L
Mistroke
.45333 .34918 L
.45333 .34919 L
.45333 .34919 L
.45333 .34919 L
.45332 .34919 L
.45332 .34919 L
.45332 .34919 L
.45332 .34919 L
.45332 .34919 L
.45331 .34919 L
.45331 .3492 L
.45331 .3492 L
.45331 .3492 L
.45331 .3492 L
.4533 .3492 L
.4533 .3492 L
.4533 .3492 L
.4533 .3492 L
.45329 .3492 L
.45329 .34921 L
.45329 .34921 L
.45329 .34921 L
.45329 .34921 L
.45328 .34921 L
.45328 .34921 L
.45328 .34921 L
.45328 .34921 L
.45328 .34921 L
.45327 .34922 L
.45327 .34922 L
.45327 .34922 L
.45327 .34922 L
.45327 .34922 L
.45326 .34922 L
.45326 .34922 L
.45326 .34922 L
.45326 .34922 L
.45325 .34922 L
.45325 .34923 L
.45325 .34923 L
.45325 .34923 L
.45325 .34923 L
.45324 .34923 L
.45324 .34923 L
.45324 .34923 L
.45324 .34923 L
.45324 .34923 L
.45323 .34923 L
.45323 .34924 L
.45323 .34924 L
Mistroke
.45323 .34924 L
.45323 .34924 L
.45322 .34924 L
.45322 .34924 L
.45322 .34924 L
.45322 .34924 L
.45322 .34924 L
.45321 .34924 L
.45321 .34925 L
.45321 .34925 L
.45321 .34925 L
.45321 .34925 L
.4532 .34925 L
.4532 .34925 L
.4532 .34925 L
.4532 .34925 L
.45319 .34925 L
.45319 .34925 L
.45319 .34926 L
.45319 .34926 L
.45319 .34926 L
.45318 .34926 L
.45318 .34926 L
.45318 .34926 L
.45318 .34926 L
.45318 .34926 L
.45317 .34926 L
.45317 .34926 L
.45317 .34927 L
.45317 .34927 L
.45317 .34927 L
.45316 .34927 L
.45316 .34927 L
.45316 .34927 L
.45316 .34927 L
.45316 .34927 L
.45315 .34927 L
.45315 .34927 L
.45315 .34927 L
.45315 .34928 L
.45315 .34928 L
.45314 .34928 L
.45314 .34928 L
.45314 .34928 L
.45314 .34928 L
.45314 .34928 L
.45313 .34928 L
.45313 .34928 L
.45313 .34928 L
.45313 .34928 L
Mistroke
.45312 .34929 L
.45312 .34929 L
.45312 .34929 L
.45312 .34929 L
.45312 .34929 L
.45311 .34929 L
.45311 .34929 L
.45311 .34929 L
.45311 .34929 L
.45311 .34929 L
.4531 .34929 L
.4531 .3493 L
.4531 .3493 L
.4531 .3493 L
.4531 .3493 L
.45309 .3493 L
.45309 .3493 L
.45309 .3493 L
.45309 .3493 L
.45309 .3493 L
.45308 .3493 L
.45308 .3493 L
.45308 .34931 L
.45308 .34931 L
.45308 .34931 L
.45307 .34931 L
.45307 .34931 L
.45307 .34931 L
.45307 .34931 L
.45307 .34931 L
.45306 .34931 L
.45306 .34931 L
.45306 .34931 L
.45306 .34931 L
.45306 .34932 L
.45305 .34932 L
.45305 .34932 L
.45305 .34932 L
.45305 .34932 L
.45305 .34932 L
.45304 .34932 L
.45304 .34932 L
.45304 .34932 L
.45304 .34932 L
.45304 .34932 L
.45303 .34932 L
.45303 .34933 L
.45303 .34933 L
.45303 .34933 L
.45303 .34933 L
Mistroke
.45302 .34933 L
.45302 .34933 L
.45302 .34933 L
.45302 .34933 L
.45302 .34933 L
.45301 .34933 L
.45301 .34933 L
.45301 .34933 L
.45301 .34933 L
.45301 .34934 L
.453 .34934 L
.453 .34934 L
.453 .34934 L
.453 .34934 L
.453 .34934 L
.45299 .34934 L
.45299 .34934 L
.45299 .34934 L
.45299 .34934 L
.45299 .34934 L
.45298 .34934 L
.45298 .34935 L
.45298 .34935 L
.45298 .34935 L
.45298 .34935 L
.45297 .34935 L
.45297 .34935 L
.45297 .34935 L
.45297 .34935 L
.45297 .34935 L
.45296 .34935 L
.45296 .34935 L
.45296 .34935 L
.45296 .34935 L
.45296 .34935 L
.45296 .34936 L
.45295 .34936 L
.45295 .34936 L
.45295 .34936 L
.45295 .34936 L
.45295 .34936 L
.45294 .34936 L
.45294 .34936 L
.45294 .34936 L
.45294 .34936 L
.45294 .34936 L
.45293 .34936 L
.45293 .34936 L
.45293 .34937 L
.45293 .34937 L
Mistroke
.45293 .34937 L
.45292 .34937 L
.45292 .34937 L
.45292 .34937 L
.45292 .34937 L
.45292 .34937 L
.45291 .34937 L
.45291 .34937 L
.45291 .34937 L
.45291 .34937 L
.45291 .34937 L
.4529 .34937 L
.4529 .34937 L
.4529 .34938 L
.4529 .34938 L
.4529 .34938 L
.4529 .34938 L
.45289 .34938 L
.45289 .34938 L
.45289 .34938 L
.45289 .34938 L
.45289 .34938 L
.45288 .34938 L
.45288 .34938 L
.45288 .34938 L
.45288 .34938 L
.45288 .34938 L
.45287 .34939 L
.45287 .34939 L
.45287 .34939 L
.45287 .34939 L
.45287 .34939 L
.45286 .34939 L
.45286 .34939 L
.45286 .34939 L
.45286 .34939 L
.45286 .34939 L
.45286 .34939 L
.45285 .34939 L
.45285 .34939 L
.45285 .34939 L
.45285 .34939 L
.45285 .34939 L
.45284 .3494 L
.45284 .3494 L
.45284 .3494 L
.45284 .3494 L
.45284 .3494 L
.45283 .3494 L
.45283 .3494 L
Mistroke
.45283 .3494 L
.45283 .3494 L
.45283 .3494 L
.45282 .3494 L
.45282 .3494 L
.45282 .3494 L
.45282 .3494 L
.45282 .3494 L
.45282 .3494 L
.45281 .34941 L
.45281 .34941 L
.45281 .34941 L
.45281 .34941 L
.45281 .34941 L
.4528 .34941 L
.4528 .34941 L
.4528 .34941 L
.4528 .34941 L
.4528 .34941 L
.45279 .34941 L
.45279 .34941 L
.45279 .34941 L
.45279 .34941 L
.45279 .34941 L
.45279 .34941 L
.45278 .34941 L
.45278 .34942 L
.45278 .34942 L
.45278 .34942 L
.45278 .34942 L
.45277 .34942 L
.45277 .34942 L
.45277 .34942 L
.45277 .34942 L
.45277 .34942 L
.45277 .34942 L
.45276 .34942 L
.45276 .34942 L
.45276 .34942 L
.45276 .34942 L
.45276 .34942 L
.45275 .34942 L
.45275 .34942 L
.45275 .34942 L
.45275 .34943 L
.45275 .34943 L
.45274 .34943 L
.45274 .34943 L
.45274 .34943 L
.45274 .34943 L
Mistroke
.45274 .34943 L
.45274 .34943 L
.45273 .34943 L
.45273 .34943 L
.45273 .34943 L
.45273 .34943 L
.45273 .34943 L
.45272 .34943 L
.45272 .34943 L
.45272 .34943 L
.45272 .34943 L
.45272 .34943 L
.45272 .34943 L
.45271 .34944 L
.45271 .34944 L
.45271 .34944 L
.45271 .34944 L
.45271 .34944 L
.4527 .34944 L
.4527 .34944 L
.4527 .34944 L
.4527 .34944 L
.4527 .34944 L
.4527 .34944 L
.45269 .34944 L
.45269 .34944 L
.45269 .34944 L
.45269 .34944 L
.45269 .34944 L
.45269 .34944 L
.45268 .34944 L
.45268 .34944 L
.45268 .34944 L
.45268 .34944 L
.45268 .34945 L
.45267 .34945 L
.45267 .34945 L
.45267 .34945 L
.45267 .34945 L
.45267 .34945 L
.45267 .34945 L
.45266 .34945 L
.45266 .34945 L
.45266 .34945 L
.45266 .34945 L
.45266 .34945 L
.45265 .34945 L
.45265 .34945 L
.45265 .34945 L
.45265 .34945 L
Mistroke
.45265 .34945 L
.45265 .34945 L
.45264 .34945 L
.45264 .34945 L
.45264 .34945 L
.45264 .34945 L
.45264 .34946 L
.45264 .34946 L
.45263 .34946 L
.45263 .34946 L
.45263 .34946 L
.45263 .34946 L
.45263 .34946 L
.45262 .34946 L
.45262 .34946 L
.45262 .34946 L
.45262 .34946 L
.45262 .34946 L
.45262 .34946 L
.45261 .34946 L
.45261 .34946 L
.45261 .34946 L
.45261 .34946 L
.45261 .34946 L
.45261 .34946 L
.4526 .34946 L
.4526 .34946 L
.4526 .34946 L
.4526 .34946 L
.4526 .34946 L
.4526 .34946 L
.45259 .34947 L
.45259 .34947 L
.45259 .34947 L
.45259 .34947 L
.45259 .34947 L
.45258 .34947 L
.45258 .34947 L
.45258 .34947 L
.45258 .34947 L
.45258 .34947 L
.45258 .34947 L
.45257 .34947 L
.45257 .34947 L
.45257 .34947 L
.45257 .34947 L
.45257 .34947 L
.45257 .34947 L
.45256 .34947 L
.45256 .34947 L
Mistroke
.45256 .34947 L
.45256 .34947 L
.45256 .34947 L
.45256 .34947 L
.45255 .34947 L
.45255 .34947 L
.45255 .34947 L
.45255 .34947 L
.45255 .34948 L
.45255 .34948 L
.45254 .34948 L
.45254 .34948 L
.45254 .34948 L
.45254 .34948 L
.45254 .34948 L
.45254 .34948 L
.45253 .34948 L
.45253 .34948 L
.45253 .34948 L
.45253 .34948 L
.45253 .34948 L
.45253 .34948 L
.45252 .34948 L
.45252 .34948 L
.45252 .34948 L
.45252 .34948 L
.45252 .34948 L
.45252 .34948 L
.45251 .34948 L
.45251 .34948 L
.45251 .34948 L
.45251 .34948 L
.45251 .34948 L
.45251 .34948 L
.4525 .34948 L
.4525 .34948 L
.4525 .34948 L
.4525 .34948 L
.4525 .34948 L
.4525 .34948 L
.45249 .34949 L
.45249 .34949 L
.45249 .34949 L
.45249 .34949 L
.45249 .34949 L
.45249 .34949 L
.45248 .34949 L
.45248 .34949 L
.45248 .34949 L
.45248 .34949 L
Mistroke
.45248 .34949 L
.45248 .34949 L
.45247 .34949 L
.45247 .34949 L
.45247 .34949 L
.45247 .34949 L
.45247 .34949 L
.45247 .34949 L
.45246 .34949 L
.45246 .34949 L
.45246 .34949 L
.45246 .34949 L
.45246 .34949 L
.45246 .34949 L
.45245 .34949 L
.45245 .34949 L
.45245 .34949 L
.45245 .34949 L
.45245 .34949 L
.45245 .34949 L
.45244 .34949 L
.45244 .34949 L
.45244 .34949 L
.45244 .34949 L
.45244 .34949 L
.45244 .34949 L
.45243 .34949 L
.45243 .34949 L
.45243 .34949 L
.45243 .3495 L
.45243 .3495 L
.45243 .3495 L
.45243 .3495 L
.45242 .3495 L
.45242 .3495 L
.45242 .3495 L
.45242 .3495 L
.45242 .3495 L
.45242 .3495 L
.45241 .3495 L
.45241 .3495 L
.45241 .3495 L
.45241 .3495 L
.45241 .3495 L
.45241 .3495 L
.4524 .3495 L
.4524 .3495 L
.4524 .3495 L
.4524 .3495 L
.4524 .3495 L
Mistroke
.4524 .3495 L
.45239 .3495 L
.45239 .3495 L
.45239 .3495 L
.45239 .3495 L
.45239 .3495 L
.45239 .3495 L
.45239 .3495 L
.45238 .3495 L
.45238 .3495 L
.45238 .3495 L
.45238 .3495 L
.45238 .3495 L
.45238 .3495 L
.45237 .3495 L
.45237 .3495 L
.45237 .3495 L
.45237 .3495 L
.45237 .3495 L
.45237 .3495 L
.45237 .3495 L
.45236 .3495 L
.45236 .3495 L
.45236 .3495 L
.45236 .3495 L
.45236 .3495 L
.45236 .3495 L
.45235 .3495 L
.45235 .3495 L
.45235 .3495 L
.45235 .3495 L
.45235 .3495 L
.45235 .3495 L
.45235 .34951 L
.45234 .34951 L
.45234 .34951 L
.45234 .34951 L
.45234 .34951 L
.45234 .34951 L
.45234 .34951 L
.45233 .34951 L
.45233 .34951 L
.45233 .34951 L
.45233 .34951 L
.45233 .34951 L
.45233 .34951 L
.45233 .34951 L
.45232 .34951 L
.45232 .34951 L
.45232 .34951 L
Mistroke
.45232 .34951 L
.45232 .34951 L
.45232 .34951 L
.45231 .34951 L
.45231 .34951 L
.45231 .34951 L
.45231 .34951 L
.45231 .34951 L
.45231 .34951 L
.45231 .34951 L
.4523 .34951 L
.4523 .34951 L
.4523 .34951 L
.4523 .34951 L
.4523 .34951 L
.4523 .34951 L
.4523 .34951 L
.45229 .34951 L
.45229 .34951 L
.45229 .34951 L
.45229 .34951 L
.45229 .34951 L
.45229 .34951 L
.45228 .34951 L
.45228 .34951 L
.45228 .34951 L
.45228 .34951 L
.45228 .34951 L
.45228 .34951 L
.45228 .34951 L
.45227 .34951 L
.45227 .34951 L
.45227 .34951 L
.45227 .34951 L
.45227 .34951 L
.45227 .34951 L
.45227 .34951 L
.45226 .34951 L
.45226 .34951 L
.45226 .34951 L
.45226 .34951 L
.45226 .34951 L
.45226 .34951 L
.45226 .34951 L
.45225 .34951 L
.45225 .34951 L
.45225 .34951 L
.45225 .34951 L
.45225 .34951 L
.45225 .34951 L
Mistroke
.45225 .34951 L
.45224 .34951 L
.45224 .34951 L
.45224 .34951 L
.45224 .34951 L
.45224 .34951 L
.45224 .34951 L
.45224 .34951 L
.45223 .34951 L
.45223 .34951 L
.45223 .34951 L
.45223 .34951 L
.45223 .34951 L
.45223 .34951 L
.45223 .34951 L
.45222 .34951 L
.45222 .34951 L
.45222 .34951 L
.45222 .34951 L
.45222 .34951 L
.45222 .34951 L
.45222 .34951 L
.45221 .34951 L
.45221 .34951 L
.45221 .34951 L
.45221 .34951 L
.45221 .34951 L
.45221 .34951 L
.45221 .34951 L
.4522 .34951 L
.4522 .34951 L
.4522 .34951 L
.4522 .34951 L
.4522 .34951 L
.4522 .34951 L
.4522 .34951 L
.45219 .34951 L
.45219 .34951 L
.45219 .34951 L
.45219 .34951 L
.45219 .34951 L
.45219 .34951 L
.45219 .34951 L
.45218 .34951 L
.45218 .34951 L
.45218 .34951 L
.45218 .34951 L
.45218 .34951 L
.45218 .34951 L
.45218 .34951 L
Mistroke
.45218 .34951 L
.45217 .34951 L
.45217 .34951 L
.45217 .34951 L
.45217 .34951 L
.45217 .34951 L
.45217 .34951 L
.45217 .34951 L
.45216 .34951 L
.45216 .34951 L
.45216 .34951 L
.45216 .34951 L
.45216 .34951 L
.45216 .34951 L
.45216 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45215 .34951 L
.45214 .34951 L
.45214 .34951 L
.45214 .34951 L
.45214 .34951 L
.45214 .34951 L
.45214 .34951 L
.45214 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45213 .34951 L
.45212 .34951 L
.45212 .34951 L
.45212 .34951 L
.45212 .34951 L
.45212 .34951 L
.45212 .34951 L
.45212 .34951 L
.45211 .34951 L
.45211 .34951 L
.45211 .34951 L
.45211 .34951 L
.45211 .34951 L
Mistroke
.45211 .34951 L
.45211 .34951 L
.45211 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.4521 .34951 L
.45209 .34951 L
.45209 .34951 L
.45209 .34951 L
.45209 .34951 L
.45209 .34951 L
.45209 .34951 L
.45209 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45208 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45207 .34951 L
.45206 .34951 L
.45206 .3495 L
.45206 .3495 L
.45206 .3495 L
.45206 .3495 L
.45206 .3495 L
.45206 .3495 L
.45206 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
.45205 .3495 L
Mistroke
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45204 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45203 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45202 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.45201 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.452 .3495 L
.45199 .3495 L
.45199 .3495 L
.45199 .34949 L
.45199 .34949 L
.45199 .34949 L
.45199 .34949 L
.45199 .34949 L
.45199 .34949 L
Mistroke
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45198 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45197 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45196 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45195 .34949 L
.45194 .34949 L
.45194 .34949 L
.45194 .34948 L
.45194 .34948 L
.45194 .34948 L
.45194 .34948 L
.45194 .34948 L
.45194 .34948 L
.45194 .34948 L
.45193 .34948 L
.45193 .34948 L
.45193 .34948 L
.45193 .34948 L
.45193 .34948 L
Mistroke
.45193 .34948 L
.45193 .34948 L
.45193 .34948 L
.45193 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45192 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.45191 .34948 L
.4519 .34948 L
.4519 .34948 L
.4519 .34948 L
.4519 .34947 L
.4519 .34947 L
.4519 .34947 L
.4519 .34947 L
.4519 .34947 L
.4519 .34947 L
.4519 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45189 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
.45188 .34947 L
Mistroke
.45188 .34947 L
.45187 .34947 L
.45187 .34947 L
.45187 .34947 L
.45187 .34947 L
.45187 .34947 L
.45187 .34947 L
.45187 .34946 L
.45187 .34946 L
.45187 .34946 L
.45187 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45186 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45185 .34946 L
.45184 .34946 L
.45184 .34946 L
.45184 .34946 L
.45184 .34946 L
.45184 .34946 L
.45184 .34946 L
.45184 .34945 L
.45184 .34945 L
.45184 .34945 L
.45184 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
.45183 .34945 L
Mistroke
.45183 .34945 L
.45183 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45182 .34945 L
.45181 .34945 L
.45181 .34945 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.45181 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.4518 .34944 L
.45179 .34944 L
.45179 .34944 L
.45179 .34944 L
.45179 .34944 L
.45179 .34944 L
.45179 .34943 L
.45179 .34943 L
.45179 .34943 L
.45179 .34943 L
.45179 .34943 L
.45179 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
Mistroke
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45178 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34943 L
.45177 .34942 L
.45177 .34942 L
.45177 .34942 L
.45177 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45176 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34942 L
.45175 .34941 L
.45175 .34941 L
.45175 .34941 L
.45175 .34941 L
.45175 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
Mistroke
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45174 .34941 L
.45173 .34941 L
.45173 .34941 L
.45173 .34941 L
.45173 .34941 L
.45173 .34941 L
.45173 .3494 L
.45173 .3494 L
.45173 .3494 L
.45173 .3494 L
.45173 .3494 L
.45173 .3494 L
.45173 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45172 .3494 L
.45171 .3494 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.45171 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
.4517 .34939 L
Mistroke
.4517 .34939 L
.4517 .34938 L
.4517 .34938 L
.4517 .34938 L
.4517 .34938 L
.4517 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45169 .34938 L
.45168 .34938 L
.45168 .34938 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45168 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34937 L
.45167 .34936 L
.45167 .34936 L
.45167 .34936 L
.45167 .34936 L
.45167 .34936 L
.45167 .34936 L
.45167 .34936 L
.45166 .34936 L
.45166 .34936 L
Mistroke
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34936 L
.45166 .34935 L
.45166 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45165 .34935 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45164 .34934 L
.45163 .34934 L
.45163 .34934 L
.45163 .34934 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
Mistroke
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45163 .34933 L
.45162 .34933 L
.45162 .34933 L
.45162 .34933 L
.45162 .34933 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45162 .34932 L
.45161 .34932 L
.45161 .34932 L
.45161 .34932 L
.45161 .34932 L
.45161 .34932 L
.45161 .34932 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.45161 .34931 L
.4516 .34931 L
.4516 .34931 L
.4516 .34931 L
.4516 .34931 L
.4516 .34931 L
.4516 .3493 L
Mistroke
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.4516 .3493 L
.45159 .3493 L
.45159 .3493 L
.45159 .3493 L
.45159 .3493 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45159 .34929 L
.45158 .34929 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34928 L
.45158 .34927 L
Mistroke
.45158 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34927 L
.45157 .34926 L
.45157 .34926 L
.45157 .34926 L
.45157 .34926 L
.45157 .34926 L
.45157 .34926 L
.45157 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34926 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45156 .34925 L
.45155 .34925 L
.45155 .34925 L
.45155 .34925 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
Mistroke
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34924 L
.45155 .34923 L
.45155 .34923 L
.45155 .34923 L
.45155 .34923 L
.45155 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34923 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45154 .34922 L
.45153 .34922 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
Mistroke
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .34921 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45153 .3492 L
.45152 .3492 L
.45152 .3492 L
.45152 .3492 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34919 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
.45152 .34918 L
Mistroke
.45152 .34918 L
.45151 .34918 L
.45151 .34918 L
.45151 .34918 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34917 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34916 L
.45151 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34915 L
.4515 .34914 L
.4515 .34914 L
Mistroke
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34914 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.4515 .34913 L
.45149 .34913 L
.45149 .34913 L
.45149 .34913 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34912 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
Mistroke
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .34911 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .3491 L
.45149 .34909 L
.45149 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34909 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34908 L
.45148 .34907 L
Mistroke
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34907 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34906 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45148 .34905 L
.45147 .34905 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
Mistroke
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34904 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34903 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34902 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .34901 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
Mistroke
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .349 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34899 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34898 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
Mistroke
.45147 .34897 L
.45147 .34897 L
.45147 .34897 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34896 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34895 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34894 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
Mistroke
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34893 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34892 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .34891 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
.45147 .3489 L
Mistroke
.45147 .3489 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34889 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34888 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45147 .34887 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
Mistroke
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34886 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34885 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34884 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
.45148 .34883 L
Mistroke
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34882 L
.45148 .34881 L
.45148 .34881 L
.45148 .34881 L
.45148 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .34881 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .3488 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
Mistroke
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34879 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34878 L
.45149 .34877 L
.45149 .34877 L
.45149 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34877 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
.4515 .34876 L
Mistroke
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34875 L
.4515 .34874 L
.4515 .34874 L
.4515 .34874 L
.4515 .34874 L
.4515 .34874 L
.4515 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34874 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34873 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
Mistroke
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34872 L
.45151 .34871 L
.45151 .34871 L
.45151 .34871 L
.45151 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .34871 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .3487 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
.45152 .34869 L
Mistroke
.45152 .34869 L
.45153 .34869 L
.45153 .34869 L
.45153 .34869 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34868 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34867 L
.45153 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
.45154 .34866 L
Mistroke
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34865 L
.45154 .34864 L
.45154 .34864 L
.45154 .34864 L
.45154 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34864 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34863 L
.45155 .34862 L
.45155 .34862 L
.45155 .34862 L
Mistroke
.45155 .34862 L
.45155 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34862 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .34861 L
.45156 .3486 L
.45156 .3486 L
.45156 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .3486 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
Mistroke
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45157 .34859 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34858 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45158 .34857 L
.45159 .34857 L
.45159 .34857 L
.45159 .34857 L
.45159 .34857 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
Mistroke
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34856 L
.45159 .34855 L
.45159 .34855 L
.45159 .34855 L
.45159 .34855 L
.45159 .34855 L
.45159 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34855 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.4516 .34854 L
.45161 .34854 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
Mistroke
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34853 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45161 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34852 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45162 .34851 L
.45163 .34851 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
Mistroke
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .3485 L
.45163 .34849 L
.45163 .34849 L
.45163 .34849 L
.45163 .34849 L
.45163 .34849 L
.45163 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34849 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45164 .34848 L
.45165 .34848 L
.45165 .34848 L
.45165 .34848 L
.45165 .34848 L
Mistroke
.45165 .34848 L
.45165 .34848 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45165 .34847 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34846 L
.45166 .34845 L
.45166 .34845 L
.45166 .34845 L
.45166 .34845 L
.45166 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
Mistroke
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34845 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45167 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34844 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45168 .34843 L
.45169 .34843 L
.45169 .34843 L
.45169 .34843 L
.45169 .34843 L
.45169 .34843 L
.45169 .34843 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
Mistroke
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.45169 .34842 L
.4517 .34842 L
.4517 .34842 L
.4517 .34842 L
.4517 .34842 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.4517 .34841 L
.45171 .34841 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
Mistroke
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .3484 L
.45171 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34839 L
.45172 .34838 L
.45172 .34838 L
.45172 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
.45173 .34838 L
Mistroke
.45173 .34838 L
.45173 .34838 L
.45173 .34837 L
.45173 .34837 L
.45173 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34837 L
.45174 .34836 L
.45174 .34836 L
.45174 .34836 L
.45174 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34836 L
.45175 .34835 L
.45175 .34835 L
.45175 .34835 L
.45175 .34835 L
Mistroke
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34835 L
.45176 .34834 L
.45176 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34834 L
.45177 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
Mistroke
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45178 .34833 L
.45179 .34833 L
.45179 .34833 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.45179 .34832 L
.4518 .34832 L
.4518 .34832 L
.4518 .34832 L
.4518 .34832 L
.4518 .34832 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
Mistroke
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.4518 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .34831 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45181 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .3483 L
.45182 .34829 L
.45182 .34829 L
.45182 .34829 L
.45182 .34829 L
.45182 .34829 L
Mistroke
.45182 .34829 L
.45182 .34829 L
.45182 .34829 L
.45182 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34829 L
.45183 .34828 L
.45183 .34828 L
.45183 .34828 L
.45183 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45184 .34828 L
.45185 .34828 L
.45185 .34828 L
.45185 .34828 L
Mistroke
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45185 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34827 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45186 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
Mistroke
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34826 L
.45187 .34825 L
.45187 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45188 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34825 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
Mistroke
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.45189 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34824 L
.4519 .34823 L
.4519 .34823 L
.4519 .34823 L
.4519 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
.45191 .34823 L
Mistroke
.45191 .34823 L
.45191 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34823 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45192 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45193 .34822 L
.45194 .34822 L
.45194 .34822 L
.45194 .34821 L
Mistroke
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45194 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .34821 L
.45195 .3482 L
.45195 .3482 L
.45195 .3482 L
.45195 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
Mistroke
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45196 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .3482 L
.45197 .34819 L
.45197 .34819 L
.45197 .34819 L
.45197 .34819 L
.45197 .34819 L
.45197 .34819 L
.45197 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
Mistroke
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45198 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34819 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.45199 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
Mistroke
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.452 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34818 L
.45201 .34817 L
.45201 .34817 L
.45201 .34817 L
.45201 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
Mistroke
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45202 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45203 .34817 L
.45204 .34817 L
.45204 .34817 L
.45204 .34817 L
.45204 .34817 L
.45204 .34817 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
Mistroke
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45204 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45205 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
Mistroke
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34816 L
.45206 .34815 L
.45206 .34815 L
.45206 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45207 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
Mistroke
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45208 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.45209 .34815 L
.4521 .34815 L
.4521 .34815 L
.4521 .34815 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
Mistroke
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.4521 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45211 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
Mistroke
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45212 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
.45213 .34814 L
Mistroke
.45213 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34814 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45214 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
Mistroke
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45215 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45216 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
Mistroke
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45217 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
Mistroke
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45218 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.45219 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
Mistroke
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.4522 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
Mistroke
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45221 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
.45222 .34813 L
Mistroke
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45223 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
Mistroke
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45224 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
Mistroke
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34813 L
.45225 .34814 L
.45225 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
Mistroke
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45226 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
Mistroke
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45227 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
Mistroke
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34814 L
.45228 .34815 L
.45228 .34815 L
.45228 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
Mistroke
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.45229 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
Mistroke
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34815 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.4523 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
Mistroke
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
Mistroke
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45231 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34816 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
Mistroke
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
.45232 .34817 L
Mistroke
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34817 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
Mistroke
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34818 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
Mistroke
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45233 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
Mistroke
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .34819 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
Mistroke
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .3482 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
Mistroke
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45234 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
Mistroke
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34821 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
Mistroke
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34822 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
Mistroke
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34823 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
Mistroke
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
Mistroke
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34824 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
Mistroke
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34825 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
Mistroke
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
Mistroke
.45235 .34826 L
.45235 .34826 L
.45235 .34826 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
Mistroke
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34827 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45235 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
Mistroke
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34828 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
Mistroke
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
Mistroke
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .34829 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
Mistroke
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45234 .3483 L
.45233 .3483 L
.45233 .3483 L
.45233 .3483 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
Mistroke
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
Mistroke
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34831 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
Mistroke
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45233 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
.45232 .34832 L
Mistroke
.45232 .34832 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
Mistroke
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34833 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
Mistroke
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45232 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
Mistroke
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34834 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
Mistroke
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.45231 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
Mistroke
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34835 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
Mistroke
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.4523 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
Mistroke
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34836 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
Mistroke
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
.45229 .34837 L
Mistroke
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
Mistroke
.45228 .34837 L
.45228 .34837 L
.45228 .34837 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
Mistroke
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45228 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
Mistroke
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34838 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
Mistroke
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45227 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
Mistroke
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
Mistroke
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45226 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
Mistroke
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .34839 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
Mistroke
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45225 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
Mistroke
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
Mistroke
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
Mistroke
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45224 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
Mistroke
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .3484 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
Mistroke
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45223 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
Mistroke
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45222 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
Mistroke
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.45221 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
Mistroke
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.4522 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
Mistroke
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45219 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
Mistroke
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .34841 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
.45218 .3484 L
Mistroke
.45218 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
Mistroke
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .3484 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
Mistroke
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34839 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
Mistroke
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
Mistroke
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
Mistroke
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
Mistroke
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34835 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
.45221 .34836 L
Mistroke
.45221 .34836 L
Mfstroke
1 0 .85 r
.18454 .02432 m
.18497 .02429 L
.1854 .02426 L
.18583 .02422 L
.18626 .02419 L
.18668 .02415 L
.18711 .02412 L
.18754 .02409 L
.18797 .02406 L
.1884 .02402 L
.18882 .02399 L
.18925 .02396 L
.18968 .02392 L
.19011 .02389 L
.19053 .02386 L
.19096 .02383 L
.19139 .02379 L
.19182 .02376 L
.19225 .02373 L
.19267 .0237 L
.1931 .02366 L
.19353 .02363 L
.19396 .0236 L
.19438 .02357 L
.19481 .02354 L
.19524 .0235 L
.19566 .02347 L
.19609 .02344 L
.19652 .02341 L
.19695 .02338 L
.19737 .02335 L
.1978 .02331 L
.19823 .02328 L
.19865 .02325 L
.19908 .02322 L
.19951 .02319 L
.19994 .02316 L
.20036 .02313 L
.20079 .0231 L
.20122 .02307 L
.20164 .02303 L
.20207 .023 L
.2025 .02297 L
.20292 .02294 L
.20335 .02291 L
.20378 .02288 L
.2042 .02285 L
.20463 .02282 L
.20506 .02279 L
.20548 .02276 L
Mistroke
.20591 .02273 L
.20633 .0227 L
.20676 .02267 L
.20719 .02264 L
.20761 .02261 L
.20804 .02258 L
.20847 .02255 L
.20889 .02252 L
.20932 .02249 L
.20974 .02246 L
.21017 .02243 L
.2106 .02241 L
.21102 .02238 L
.21145 .02235 L
.21187 .02232 L
.2123 .02229 L
.21273 .02226 L
.21315 .02223 L
.21358 .0222 L
.214 .02217 L
.21443 .02215 L
.21485 .02212 L
.21528 .02209 L
.21571 .02206 L
.21613 .02203 L
.21656 .022 L
.21698 .02198 L
.21741 .02195 L
.21783 .02192 L
.21826 .02189 L
.21868 .02186 L
.21911 .02184 L
.21953 .02181 L
.21996 .02178 L
.22039 .02175 L
.22081 .02172 L
.22124 .0217 L
.22166 .02167 L
.22209 .02164 L
.22251 .02161 L
.22294 .02159 L
.22336 .02156 L
.22379 .02153 L
.22421 .02151 L
.22464 .02148 L
.22506 .02145 L
.22549 .02143 L
.22591 .0214 L
.22633 .02137 L
.22676 .02135 L
Mistroke
.22718 .02132 L
.22761 .02129 L
.22803 .02127 L
.22846 .02124 L
.22888 .02121 L
.22931 .02119 L
.22973 .02116 L
.23016 .02113 L
.23058 .02111 L
.231 .02108 L
.23143 .02106 L
.23185 .02103 L
.23228 .021 L
.2327 .02098 L
.23313 .02095 L
.23355 .02093 L
.23397 .0209 L
.2344 .02088 L
.23482 .02085 L
.23525 .02083 L
.23567 .0208 L
.23609 .02078 L
.23652 .02075 L
.23694 .02072 L
.23737 .0207 L
.23779 .02067 L
.23821 .02065 L
.23864 .02063 L
.23906 .0206 L
.23949 .02058 L
.23991 .02055 L
.24033 .02053 L
.24076 .0205 L
.24118 .02048 L
.2416 .02045 L
.24203 .02043 L
.24245 .0204 L
.24287 .02038 L
.2433 .02036 L
.24372 .02033 L
.24414 .02031 L
.24457 .02028 L
.24499 .02026 L
.24541 .02024 L
.24584 .02021 L
.24626 .02019 L
.24668 .02016 L
.24711 .02014 L
.24753 .02012 L
.24795 .02009 L
Mistroke
.24838 .02007 L
.2488 .02005 L
.24922 .02002 L
.24964 .02 L
.25007 .01998 L
.25049 .01995 L
.25091 .01993 L
.25134 .01991 L
.25176 .01989 L
.25218 .01986 L
.2526 .01984 L
.25303 .01982 L
.25345 .01979 L
.25387 .01977 L
.25429 .01975 L
.25472 .01973 L
.25514 .0197 L
.25556 .01968 L
.25598 .01966 L
.25641 .01964 L
.25683 .01962 L
.25725 .01959 L
.25767 .01957 L
.25809 .01955 L
.25852 .01953 L
.25894 .0195 L
.25936 .01948 L
.25978 .01946 L
.26021 .01944 L
.26063 .01942 L
.26105 .0194 L
.26147 .01937 L
.26189 .01935 L
.26232 .01933 L
.26274 .01931 L
.26316 .01929 L
.26358 .01927 L
.264 .01925 L
.26442 .01923 L
.26485 .0192 L
.26527 .01918 L
.26569 .01916 L
.26611 .01914 L
.26653 .01912 L
.26695 .0191 L
.26738 .01908 L
.2678 .01906 L
.26822 .01904 L
.26864 .01902 L
.26906 .019 L
Mistroke
.26948 .01898 L
.2699 .01896 L
.27033 .01893 L
.27075 .01891 L
.27117 .01889 L
.27159 .01887 L
.27201 .01885 L
.27243 .01883 L
.27285 .01881 L
.27327 .01879 L
.27369 .01877 L
.27412 .01875 L
.27454 .01873 L
.27496 .01871 L
.27538 .01869 L
.2758 .01868 L
.27622 .01866 L
.27664 .01864 L
.27706 .01862 L
.27748 .0186 L
.2779 .01858 L
.27832 .01856 L
.27874 .01854 L
.27917 .01852 L
.27959 .0185 L
.28001 .01848 L
.28043 .01846 L
.28085 .01844 L
.28127 .01843 L
.28169 .01841 L
.28211 .01839 L
.28253 .01837 L
.28295 .01835 L
.28337 .01833 L
.28379 .01831 L
.28421 .01829 L
.28463 .01828 L
.28505 .01826 L
.28547 .01824 L
.28589 .01822 L
.28631 .0182 L
.28673 .01818 L
.28715 .01817 L
.28757 .01815 L
.28799 .01813 L
.28841 .01811 L
.28883 .01809 L
.28925 .01808 L
.28967 .01806 L
.29009 .01804 L
Mistroke
.29051 .01802 L
.29093 .01801 L
.29135 .01799 L
.29177 .01797 L
.29219 .01795 L
.29261 .01794 L
.29303 .01792 L
.29345 .0179 L
.29387 .01788 L
.29429 .01787 L
.2947 .01785 L
.29512 .01783 L
.29554 .01781 L
.29596 .0178 L
.29638 .01778 L
.2968 .01776 L
.29722 .01775 L
.29764 .01773 L
.29806 .01771 L
.29848 .0177 L
.2989 .01768 L
.29932 .01766 L
.29974 .01765 L
.30015 .01763 L
.30057 .01761 L
.30099 .0176 L
.30141 .01758 L
.30183 .01756 L
.30225 .01755 L
.30267 .01753 L
.30309 .01752 L
.3035 .0175 L
.30392 .01748 L
.30434 .01747 L
.30476 .01745 L
.30518 .01744 L
.3056 .01742 L
.30602 .0174 L
.30644 .01739 L
.30685 .01737 L
.30727 .01736 L
.30769 .01734 L
.30811 .01733 L
.30853 .01731 L
.30895 .0173 L
.30936 .01728 L
.30978 .01726 L
.3102 .01725 L
.31062 .01723 L
.31104 .01722 L
Mistroke
.31145 .0172 L
.31187 .01719 L
.31229 .01717 L
.31271 .01716 L
.31313 .01714 L
.31354 .01713 L
.31396 .01711 L
.31438 .0171 L
.3148 .01708 L
.31522 .01707 L
.31563 .01706 L
.31605 .01704 L
.31647 .01703 L
.31689 .01701 L
.3173 .017 L
.31772 .01698 L
.31814 .01697 L
.31856 .01695 L
.31898 .01694 L
.31939 .01693 L
.31981 .01691 L
.32023 .0169 L
.32065 .01688 L
.32106 .01687 L
.32148 .01686 L
.3219 .01684 L
.32231 .01683 L
.32273 .01681 L
.32315 .0168 L
.32357 .01679 L
.32398 .01677 L
.3244 .01676 L
.32482 .01675 L
.32523 .01673 L
.32565 .01672 L
.32607 .01671 L
.32649 .01669 L
.3269 .01668 L
.32732 .01667 L
.32774 .01665 L
.32815 .01664 L
.32857 .01663 L
.32899 .01661 L
.3294 .0166 L
.32982 .01659 L
.33024 .01657 L
.33065 .01656 L
.33107 .01655 L
.33149 .01654 L
.3319 .01652 L
Mistroke
.33232 .01651 L
.33274 .0165 L
.33315 .01649 L
.33357 .01647 L
.33398 .01646 L
.3344 .01645 L
.33482 .01644 L
.33523 .01642 L
.33565 .01641 L
.33607 .0164 L
.33648 .01639 L
.3369 .01637 L
.33731 .01636 L
.33773 .01635 L
.33815 .01634 L
.33856 .01633 L
.33898 .01631 L
.33939 .0163 L
.33981 .01629 L
.34023 .01628 L
.34064 .01627 L
.34106 .01626 L
.34147 .01624 L
.34189 .01623 L
.3423 .01622 L
.34272 .01621 L
.34314 .0162 L
.34355 .01619 L
.34397 .01618 L
.34438 .01616 L
.3448 .01615 L
.34521 .01614 L
.34563 .01613 L
.34604 .01612 L
.34646 .01611 L
.34688 .0161 L
.34729 .01609 L
.34771 .01608 L
.34812 .01606 L
.34854 .01605 L
.34895 .01604 L
.34937 .01603 L
.34978 .01602 L
.3502 .01601 L
.35061 .016 L
.35103 .01599 L
.35144 .01598 L
.35186 .01597 L
.35227 .01596 L
.35269 .01595 L
Mistroke
.3531 .01594 L
.35352 .01593 L
.35393 .01592 L
.35435 .01591 L
.35476 .0159 L
.35517 .01589 L
.35559 .01588 L
.356 .01587 L
.35642 .01586 L
.35683 .01585 L
.35725 .01584 L
.35766 .01583 L
.35808 .01582 L
.35849 .01581 L
.3589 .0158 L
.35932 .01579 L
.35973 .01578 L
.36015 .01577 L
.36056 .01576 L
.36098 .01575 L
.36139 .01574 L
.3618 .01573 L
.36222 .01572 L
.36263 .01571 L
.36305 .0157 L
.36346 .01569 L
.36387 .01569 L
.36429 .01568 L
.3647 .01567 L
.36512 .01566 L
.36553 .01565 L
.36594 .01564 L
.36636 .01563 L
.36677 .01562 L
.36718 .01561 L
.3676 .0156 L
.36801 .0156 L
.36843 .01559 L
.36884 .01558 L
.36925 .01557 L
.36967 .01556 L
.37008 .01555 L
.37049 .01554 L
.37091 .01554 L
.37132 .01553 L
.37173 .01552 L
.37215 .01551 L
.37256 .0155 L
.37297 .0155 L
.37339 .01549 L
Mistroke
.3738 .01548 L
.37421 .01547 L
.37463 .01546 L
.37504 .01545 L
.37545 .01545 L
.37586 .01544 L
.37628 .01543 L
.37669 .01542 L
.3771 .01542 L
.37752 .01541 L
.37793 .0154 L
.37834 .01539 L
.37875 .01539 L
.37917 .01538 L
.37958 .01537 L
.37999 .01536 L
.3804 .01536 L
.38082 .01535 L
.38123 .01534 L
.38164 .01533 L
.38205 .01533 L
.38247 .01532 L
.38288 .01531 L
.38329 .0153 L
.3837 .0153 L
.38412 .01529 L
.38453 .01528 L
.38494 .01528 L
.38535 .01527 L
.38576 .01526 L
.38618 .01526 L
.38659 .01525 L
.387 .01524 L
.38741 .01524 L
.38782 .01523 L
.38824 .01522 L
.38865 .01522 L
.38906 .01521 L
.38947 .0152 L
.38988 .0152 L
.3903 .01519 L
.39071 .01518 L
.39112 .01518 L
.39153 .01517 L
.39194 .01517 L
.39235 .01516 L
.39276 .01515 L
.39318 .01515 L
.39359 .01514 L
.394 .01514 L
Mistroke
.39441 .01513 L
.39482 .01512 L
.39523 .01512 L
.39564 .01511 L
.39606 .01511 L
.39647 .0151 L
.39688 .0151 L
.39729 .01509 L
.3977 .01508 L
.39811 .01508 L
.39852 .01507 L
.39893 .01507 L
.39934 .01506 L
.39975 .01506 L
.40017 .01505 L
.40058 .01505 L
.40099 .01504 L
.4014 .01504 L
.40181 .01503 L
.40222 .01503 L
.40263 .01502 L
.40304 .01502 L
.40345 .01501 L
.40386 .01501 L
.40427 .015 L
.40468 .015 L
.40509 .01499 L
.4055 .01499 L
.40591 .01498 L
.40632 .01498 L
.40673 .01497 L
.40714 .01497 L
.40755 .01496 L
.40796 .01496 L
.40838 .01495 L
.40879 .01495 L
.4092 .01495 L
.40961 .01494 L
.41002 .01494 L
.41043 .01493 L
.41083 .01493 L
.41124 .01492 L
.41165 .01492 L
.41206 .01492 L
.41247 .01491 L
.41288 .01491 L
.41329 .0149 L
.4137 .0149 L
.41411 .0149 L
.41452 .01489 L
Mistroke
.41493 .01489 L
.41534 .01488 L
.41575 .01488 L
.41616 .01488 L
.41657 .01487 L
.41698 .01487 L
.41739 .01487 L
.4178 .01486 L
.41821 .01486 L
.41862 .01486 L
.41903 .01485 L
.41943 .01485 L
.41984 .01485 L
.42025 .01484 L
.42066 .01484 L
.42107 .01484 L
.42148 .01483 L
.42189 .01483 L
.4223 .01483 L
.42271 .01482 L
.42311 .01482 L
.42352 .01482 L
.42393 .01482 L
.42434 .01481 L
.42475 .01481 L
.42516 .01481 L
.42557 .0148 L
.42597 .0148 L
.42638 .0148 L
.42679 .0148 L
.4272 .01479 L
.42761 .01479 L
.42802 .01479 L
.42843 .01479 L
.42883 .01478 L
.42924 .01478 L
.42965 .01478 L
.43006 .01478 L
.43047 .01477 L
.43087 .01477 L
.43128 .01477 L
.43169 .01477 L
.4321 .01477 L
.43251 .01476 L
.43291 .01476 L
.43332 .01476 L
.43373 .01476 L
.43414 .01476 L
.43454 .01475 L
.43495 .01475 L
Mistroke
.43536 .01475 L
.43577 .01475 L
.43617 .01475 L
.43658 .01475 L
.43699 .01474 L
.4374 .01474 L
.4378 .01474 L
.43821 .01474 L
.43862 .01474 L
.43903 .01474 L
.43943 .01474 L
.43984 .01473 L
.44025 .01473 L
.44065 .01473 L
.44106 .01473 L
.44147 .01473 L
.44188 .01473 L
.44228 .01473 L
.44269 .01473 L
.4431 .01473 L
.4435 .01472 L
.44391 .01472 L
.44432 .01472 L
.44472 .01472 L
.44513 .01472 L
.44554 .01472 L
.44594 .01472 L
.44635 .01472 L
.44676 .01472 L
.44716 .01472 L
.44757 .01472 L
.44798 .01472 L
.44838 .01472 L
.44879 .01472 L
.44919 .01472 L
.4496 .01472 L
.45001 .01472 L
.45041 .01472 L
.45082 .01472 L
.45123 .01472 L
.45163 .01472 L
.45204 .01472 L
.45244 .01472 L
.45285 .01472 L
.45325 .01472 L
.45366 .01472 L
.45407 .01472 L
.45447 .01472 L
.45488 .01472 L
.45528 .01472 L
Mistroke
.45569 .01472 L
.45609 .01472 L
.4565 .01472 L
.45691 .01472 L
.45731 .01472 L
.45772 .01472 L
.45812 .01472 L
.45853 .01472 L
.45893 .01472 L
.45934 .01472 L
.45974 .01472 L
.46015 .01472 L
.46055 .01472 L
.46096 .01472 L
.46136 .01473 L
.46177 .01473 L
.46217 .01473 L
.46258 .01473 L
.46298 .01473 L
.46339 .01473 L
.46379 .01473 L
.4642 .01473 L
.4646 .01473 L
.46501 .01473 L
.46541 .01474 L
.46581 .01474 L
.46622 .01474 L
.46662 .01474 L
.46703 .01474 L
.46743 .01474 L
.46784 .01474 L
.46824 .01475 L
.46865 .01475 L
.46905 .01475 L
.46945 .01475 L
.46986 .01475 L
.47026 .01475 L
.47067 .01476 L
.47107 .01476 L
.47147 .01476 L
.47188 .01476 L
.47228 .01476 L
.47269 .01477 L
.47309 .01477 L
.47349 .01477 L
.4739 .01477 L
.4743 .01477 L
.4747 .01478 L
.47511 .01478 L
.47551 .01478 L
Mistroke
.47591 .01478 L
.47632 .01479 L
.47672 .01479 L
.47712 .01479 L
.47753 .01479 L
.47793 .0148 L
.47833 .0148 L
.47874 .0148 L
.47914 .0148 L
.47954 .01481 L
.47995 .01481 L
.48035 .01481 L
.48075 .01482 L
.48116 .01482 L
.48156 .01482 L
.48196 .01482 L
.48236 .01483 L
.48277 .01483 L
.48317 .01483 L
.48357 .01484 L
.48397 .01484 L
.48438 .01484 L
.48478 .01485 L
.48518 .01485 L
.48558 .01485 L
.48599 .01486 L
.48639 .01486 L
.48679 .01486 L
.48719 .01487 L
.4876 .01487 L
.488 .01487 L
.4884 .01488 L
.4888 .01488 L
.4892 .01488 L
.48961 .01489 L
.49001 .01489 L
.49041 .0149 L
.49081 .0149 L
.49121 .0149 L
.49161 .01491 L
.49202 .01491 L
.49242 .01492 L
.49282 .01492 L
.49322 .01492 L
.49362 .01493 L
.49402 .01493 L
.49442 .01494 L
.49483 .01494 L
.49523 .01494 L
.49563 .01495 L
Mistroke
.49603 .01495 L
.49643 .01496 L
.49683 .01496 L
.49723 .01497 L
.49763 .01497 L
.49803 .01498 L
.49844 .01498 L
.49884 .01499 L
.49924 .01499 L
.49964 .01499 L
.50004 .015 L
.50044 .015 L
.50084 .01501 L
.50124 .01501 L
.50164 .01502 L
.50204 .01502 L
.50244 .01503 L
.50284 .01503 L
.50324 .01504 L
.50364 .01504 L
.50404 .01505 L
.50444 .01506 L
.50484 .01506 L
.50524 .01507 L
.50564 .01507 L
.50604 .01508 L
.50644 .01508 L
.50684 .01509 L
.50724 .01509 L
.50764 .0151 L
.50804 .0151 L
.50844 .01511 L
.50884 .01512 L
.50924 .01512 L
.50964 .01513 L
.51004 .01513 L
.51044 .01514 L
.51084 .01514 L
.51124 .01515 L
.51164 .01516 L
.51204 .01516 L
.51244 .01517 L
.51284 .01518 L
.51324 .01518 L
.51363 .01519 L
.51403 .01519 L
.51443 .0152 L
.51483 .01521 L
.51523 .01521 L
.51563 .01522 L
Mistroke
.51603 .01523 L
.51643 .01523 L
.51683 .01524 L
.51722 .01525 L
.51762 .01525 L
.51802 .01526 L
.51842 .01527 L
.51882 .01527 L
.51922 .01528 L
.51961 .01529 L
.52001 .01529 L
.52041 .0153 L
.52081 .01531 L
.52121 .01531 L
.52161 .01532 L
.522 .01533 L
.5224 .01533 L
.5228 .01534 L
.5232 .01535 L
.52359 .01536 L
.52399 .01536 L
.52439 .01537 L
.52479 .01538 L
.52519 .01539 L
.52558 .01539 L
.52598 .0154 L
.52638 .01541 L
.52678 .01542 L
.52717 .01542 L
.52757 .01543 L
.52797 .01544 L
.52836 .01545 L
.52876 .01545 L
.52916 .01546 L
.52956 .01547 L
.52995 .01548 L
.53035 .01549 L
.53075 .01549 L
.53114 .0155 L
.53154 .01551 L
.53194 .01552 L
.53233 .01553 L
.53273 .01553 L
.53313 .01554 L
.53352 .01555 L
.53392 .01556 L
.53432 .01557 L
.53471 .01558 L
.53511 .01559 L
.5355 .01559 L
Mistroke
.5359 .0156 L
.5363 .01561 L
.53669 .01562 L
.53709 .01563 L
.53749 .01564 L
.53788 .01565 L
.53828 .01565 L
.53867 .01566 L
.53907 .01567 L
.53946 .01568 L
.53986 .01569 L
.54026 .0157 L
.54065 .01571 L
.54105 .01572 L
.54144 .01573 L
.54184 .01574 L
.54223 .01575 L
.54263 .01575 L
.54302 .01576 L
.54342 .01577 L
.54381 .01578 L
.54421 .01579 L
.5446 .0158 L
.545 .01581 L
.54539 .01582 L
.54579 .01583 L
.54618 .01584 L
.54658 .01585 L
.54697 .01586 L
.54737 .01587 L
.54776 .01588 L
.54816 .01589 L
.54855 .0159 L
.54894 .01591 L
.54934 .01592 L
.54973 .01593 L
.55013 .01594 L
.55052 .01595 L
.55092 .01596 L
.55131 .01597 L
.5517 .01598 L
.5521 .01599 L
.55249 .016 L
.55289 .01601 L
.55328 .01602 L
.55367 .01603 L
.55407 .01604 L
.55446 .01605 L
.55485 .01606 L
.55525 .01607 L
Mistroke
.55564 .01609 L
.55603 .0161 L
.55643 .01611 L
.55682 .01612 L
.55721 .01613 L
.55761 .01614 L
.558 .01615 L
.55839 .01616 L
.55879 .01617 L
.55918 .01618 L
.55957 .0162 L
.55996 .01621 L
.56036 .01622 L
.56075 .01623 L
.56114 .01624 L
.56153 .01625 L
.56193 .01626 L
.56232 .01627 L
.56271 .01629 L
.5631 .0163 L
.5635 .01631 L
.56389 .01632 L
.56428 .01633 L
.56467 .01634 L
.56507 .01636 L
.56546 .01637 L
.56585 .01638 L
.56624 .01639 L
.56663 .0164 L
.56702 .01642 L
.56742 .01643 L
.56781 .01644 L
.5682 .01645 L
.56859 .01646 L
.56898 .01648 L
.56937 .01649 L
.56976 .0165 L
.57016 .01651 L
.57055 .01653 L
.57094 .01654 L
.57133 .01655 L
.57172 .01656 L
.57211 .01658 L
.5725 .01659 L
.57289 .0166 L
.57328 .01661 L
.57367 .01663 L
.57407 .01664 L
.57446 .01665 L
.57485 .01667 L
Mistroke
.57524 .01668 L
.57563 .01669 L
.57602 .0167 L
.57641 .01672 L
.5768 .01673 L
.57719 .01674 L
.57758 .01676 L
.57797 .01677 L
.57836 .01678 L
.57875 .0168 L
.57914 .01681 L
.57953 .01682 L
.57992 .01684 L
.58031 .01685 L
.5807 .01686 L
.58109 .01688 L
.58148 .01689 L
.58186 .01691 L
.58225 .01692 L
.58264 .01693 L
.58303 .01695 L
.58342 .01696 L
.58381 .01698 L
.5842 .01699 L
.58459 .017 L
.58498 .01702 L
.58537 .01703 L
.58576 .01705 L
.58614 .01706 L
.58653 .01707 L
.58692 .01709 L
.58731 .0171 L
.5877 .01712 L
.58809 .01713 L
.58847 .01715 L
.58886 .01716 L
.58925 .01718 L
.58964 .01719 L
.59003 .01721 L
.59042 .01722 L
.5908 .01723 L
.59119 .01725 L
.59158 .01726 L
.59197 .01728 L
.59235 .01729 L
.59274 .01731 L
.59313 .01732 L
.59352 .01734 L
.5939 .01735 L
.59429 .01737 L
Mistroke
.59468 .01739 L
.59507 .0174 L
.59545 .01742 L
.59584 .01743 L
.59623 .01745 L
.59661 .01746 L
.597 .01748 L
.59739 .01749 L
.59777 .01751 L
.59816 .01752 L
.59855 .01754 L
.59893 .01756 L
.59932 .01757 L
.59971 .01759 L
.60009 .0176 L
.60048 .01762 L
.60087 .01764 L
.60125 .01765 L
.60164 .01767 L
.60202 .01768 L
.60241 .0177 L
.6028 .01772 L
.60318 .01773 L
.60357 .01775 L
.60395 .01777 L
.60434 .01778 L
.60472 .0178 L
.60511 .01782 L
.60549 .01783 L
.60588 .01785 L
.60626 .01787 L
.60665 .01788 L
.60703 .0179 L
.60742 .01792 L
.6078 .01793 L
.60819 .01795 L
.60857 .01797 L
.60896 .01798 L
.60934 .018 L
.60973 .01802 L
.61011 .01804 L
.6105 .01805 L
.61088 .01807 L
.61127 .01809 L
.61165 .01811 L
.61203 .01812 L
.61242 .01814 L
.6128 .01816 L
.61319 .01818 L
.61357 .01819 L
Mistroke
.61395 .01821 L
.61434 .01823 L
.61472 .01825 L
.61511 .01826 L
.61549 .01828 L
.61587 .0183 L
.61626 .01832 L
.61664 .01834 L
.61702 .01835 L
.61741 .01837 L
.61779 .01839 L
.61817 .01841 L
.61855 .01843 L
.61894 .01845 L
.61932 .01846 L
.6197 .01848 L
.62009 .0185 L
.62047 .01852 L
.62085 .01854 L
.62123 .01856 L
.62162 .01857 L
.622 .01859 L
.62238 .01861 L
.62276 .01863 L
.62314 .01865 L
.62353 .01867 L
.62391 .01869 L
.62429 .01871 L
.62467 .01873 L
.62505 .01875 L
.62543 .01876 L
.62582 .01878 L
.6262 .0188 L
.62658 .01882 L
.62696 .01884 L
.62734 .01886 L
.62772 .01888 L
.6281 .0189 L
.62848 .01892 L
.62887 .01894 L
.62925 .01896 L
.62963 .01898 L
.63001 .019 L
.63039 .01902 L
.63077 .01904 L
.63115 .01906 L
.63153 .01908 L
.63191 .0191 L
.63229 .01912 L
.63267 .01914 L
Mistroke
.63305 .01916 L
.63343 .01918 L
.63381 .0192 L
.63419 .01922 L
.63457 .01924 L
.63495 .01926 L
.63533 .01928 L
.63571 .0193 L
.63609 .01932 L
.63647 .01934 L
.63685 .01937 L
.63723 .01939 L
.63761 .01941 L
.63799 .01943 L
.63836 .01945 L
.63874 .01947 L
.63912 .01949 L
.6395 .01951 L
.63988 .01953 L
.64026 .01955 L
.64064 .01958 L
.64101 .0196 L
.64139 .01962 L
.64177 .01964 L
.64215 .01966 L
.64253 .01968 L
.64291 .0197 L
.64328 .01973 L
.64366 .01975 L
.64404 .01977 L
.64442 .01979 L
.64479 .01981 L
.64517 .01984 L
.64555 .01986 L
.64593 .01988 L
.6463 .0199 L
.64668 .01992 L
.64706 .01995 L
.64744 .01997 L
.64781 .01999 L
.64819 .02001 L
.64857 .02004 L
.64894 .02006 L
.64932 .02008 L
.6497 .0201 L
.65007 .02013 L
.65045 .02015 L
.65083 .02017 L
.6512 .02019 L
.65158 .02022 L
Mistroke
.65195 .02024 L
.65233 .02026 L
.65271 .02029 L
.65308 .02031 L
.65346 .02033 L
.65383 .02036 L
.65421 .02038 L
.65458 .0204 L
.65496 .02043 L
.65534 .02045 L
.65571 .02047 L
.65609 .0205 L
.65646 .02052 L
.65684 .02054 L
.65721 .02057 L
.65759 .02059 L
.65796 .02061 L
.65833 .02064 L
.65871 .02066 L
.65908 .02069 L
.65946 .02071 L
.65983 .02073 L
.66021 .02076 L
.66058 .02078 L
.66095 .02081 L
.66133 .02083 L
.6617 .02086 L
.66208 .02088 L
.66245 .0209 L
.66282 .02093 L
.6632 .02095 L
.66357 .02098 L
.66394 .021 L
.66432 .02103 L
.66469 .02105 L
.66506 .02108 L
.66544 .0211 L
.66581 .02113 L
.66618 .02115 L
.66655 .02118 L
.66693 .0212 L
.6673 .02123 L
.66767 .02125 L
.66804 .02128 L
.66842 .0213 L
.66879 .02133 L
.66916 .02136 L
.66953 .02138 L
.6699 .02141 L
.67028 .02143 L
Mistroke
.67065 .02146 L
.67102 .02148 L
.67139 .02151 L
.67176 .02154 L
.67213 .02156 L
.67251 .02159 L
.67288 .02161 L
.67325 .02164 L
.67362 .02167 L
.67399 .02169 L
.67436 .02172 L
.67473 .02175 L
.6751 .02177 L
.67547 .0218 L
.67584 .02183 L
.67621 .02185 L
.67658 .02188 L
.67695 .02191 L
.67732 .02193 L
.67769 .02196 L
.67806 .02199 L
.67843 .02201 L
.6788 .02204 L
.67917 .02207 L
.67954 .02209 L
.67991 .02212 L
.68028 .02215 L
.68065 .02218 L
.68102 .0222 L
.68139 .02223 L
.68176 .02226 L
.68213 .02229 L
.68249 .02231 L
.68286 .02234 L
.68323 .02237 L
.6836 .0224 L
.68397 .02243 L
.68434 .02245 L
.6847 .02248 L
.68507 .02251 L
.68544 .02254 L
.68581 .02257 L
.68618 .02259 L
.68654 .02262 L
.68691 .02265 L
.68728 .02268 L
.68765 .02271 L
.68801 .02274 L
.68838 .02277 L
.68875 .02279 L
Mistroke
.68912 .02282 L
.68948 .02285 L
.68985 .02288 L
.69022 .02291 L
.69058 .02294 L
.69095 .02297 L
.69132 .023 L
.69168 .02303 L
.69205 .02306 L
.69241 .02309 L
.69278 .02311 L
.69315 .02314 L
.69351 .02317 L
.69388 .0232 L
.69424 .02323 L
.69461 .02326 L
.69497 .02329 L
.69534 .02332 L
.6957 .02335 L
.69607 .02338 L
.69643 .02341 L
.6968 .02344 L
.69716 .02347 L
.69753 .0235 L
.69789 .02353 L
.69826 .02356 L
.69862 .02359 L
.69899 .02363 L
.69935 .02366 L
.69971 .02369 L
.70008 .02372 L
.70044 .02375 L
.70081 .02378 L
.70117 .02381 L
.70153 .02384 L
.7019 .02387 L
.70226 .0239 L
.70262 .02393 L
.70299 .02397 L
.70335 .024 L
.70371 .02403 L
.70408 .02406 L
.70444 .02409 L
.7048 .02412 L
.70516 .02415 L
.70553 .02419 L
.70589 .02422 L
.70625 .02425 L
.70661 .02428 L
.70697 .02431 L
Mistroke
.70734 .02435 L
.7077 .02438 L
.70806 .02441 L
.70842 .02444 L
.70878 .02447 L
.70914 .02451 L
.70951 .02454 L
.70987 .02457 L
.71023 .0246 L
.71059 .02464 L
.71095 .02467 L
.71131 .0247 L
.71167 .02474 L
.71203 .02477 L
.71239 .0248 L
.71275 .02483 L
.71311 .02487 L
.71347 .0249 L
.71383 .02493 L
.71419 .02497 L
.71455 .025 L
.71491 .02503 L
.71527 .02507 L
.71563 .0251 L
.71599 .02513 L
.71635 .02517 L
.71671 .0252 L
.71707 .02524 L
.71743 .02527 L
.71778 .0253 L
.71814 .02534 L
.7185 .02537 L
.71886 .02541 L
.71922 .02544 L
.71958 .02548 L
.71993 .02551 L
.72029 .02554 L
.72065 .02558 L
.72101 .02561 L
.72137 .02565 L
.72172 .02568 L
.72208 .02572 L
.72244 .02575 L
.72279 .02579 L
.72315 .02582 L
.72351 .02586 L
.72387 .02589 L
.72422 .02593 L
.72458 .02596 L
.72493 .026 L
Mistroke
.72529 .02603 L
.72565 .02607 L
.726 .02611 L
.72636 .02614 L
.72672 .02618 L
.72707 .02621 L
.72743 .02625 L
.72778 .02629 L
.72814 .02632 L
.72849 .02636 L
.72885 .02639 L
.7292 .02643 L
.72956 .02647 L
.72991 .0265 L
.73027 .02654 L
.73062 .02658 L
.73098 .02661 L
.73133 .02665 L
.73169 .02669 L
.73204 .02672 L
.73239 .02676 L
.73275 .0268 L
.7331 .02683 L
.73345 .02687 L
.73381 .02691 L
.73416 .02695 L
.73451 .02698 L
.73487 .02702 L
.73522 .02706 L
.73557 .0271 L
.73593 .02713 L
.73628 .02717 L
.73663 .02721 L
.73698 .02725 L
.73734 .02729 L
.73769 .02732 L
.73804 .02736 L
.73839 .0274 L
.73874 .02744 L
.7391 .02748 L
.73945 .02752 L
.7398 .02755 L
.74015 .02759 L
.7405 .02763 L
.74085 .02767 L
.7412 .02771 L
.74155 .02775 L
.74191 .02779 L
.74226 .02783 L
.74261 .02787 L
Mistroke
.74296 .0279 L
.74331 .02794 L
.74366 .02798 L
.74401 .02802 L
.74436 .02806 L
.74471 .0281 L
.74506 .02814 L
.74541 .02818 L
.74575 .02822 L
.7461 .02826 L
.74645 .0283 L
.7468 .02834 L
.74715 .02838 L
.7475 .02842 L
.74785 .02846 L
.7482 .0285 L
.74854 .02854 L
.74889 .02858 L
.74924 .02862 L
.74959 .02866 L
.74994 .02871 L
.75028 .02875 L
.75063 .02879 L
.75098 .02883 L
.75133 .02887 L
.75167 .02891 L
.75202 .02895 L
.75237 .02899 L
.75271 .02903 L
.75306 .02908 L
.75341 .02912 L
.75375 .02916 L
.7541 .0292 L
.75444 .02924 L
.75479 .02929 L
.75514 .02933 L
.75548 .02937 L
.75583 .02941 L
.75617 .02945 L
.75652 .0295 L
.75686 .02954 L
.75721 .02958 L
.75755 .02962 L
.7579 .02967 L
.75824 .02971 L
.75859 .02975 L
.75893 .02979 L
.75928 .02984 L
.75962 .02988 L
.75996 .02992 L
Mistroke
.76031 .02997 L
.76065 .03001 L
.76099 .03005 L
.76134 .0301 L
.76168 .03014 L
.76202 .03018 L
.76237 .03023 L
.76271 .03027 L
.76305 .03032 L
.76339 .03036 L
.76374 .0304 L
.76408 .03045 L
.76442 .03049 L
.76476 .03054 L
.76511 .03058 L
.76545 .03063 L
.76579 .03067 L
.76613 .03072 L
.76647 .03076 L
.76681 .0308 L
.76715 .03085 L
.76749 .03089 L
.76783 .03094 L
.76818 .03098 L
.76852 .03103 L
.76886 .03108 L
.7692 .03112 L
.76954 .03117 L
.76988 .03121 L
.77022 .03126 L
.77056 .0313 L
.77089 .03135 L
.77123 .0314 L
.77157 .03144 L
.77191 .03149 L
.77225 .03153 L
.77259 .03158 L
.77293 .03163 L
.77327 .03167 L
.7736 .03172 L
.77394 .03177 L
.77428 .03181 L
.77462 .03186 L
.77496 .03191 L
.77529 .03195 L
.77563 .032 L
.77597 .03205 L
.77631 .0321 L
.77664 .03214 L
.77698 .03219 L
Mistroke
.77732 .03224 L
.77765 .03229 L
.77799 .03233 L
.77832 .03238 L
.77866 .03243 L
.779 .03248 L
.77933 .03253 L
.77967 .03257 L
.78 .03262 L
.78034 .03267 L
.78067 .03272 L
.78101 .03277 L
.78134 .03282 L
.78168 .03286 L
.78201 .03291 L
.78235 .03296 L
.78268 .03301 L
.78302 .03306 L
.78335 .03311 L
.78368 .03316 L
.78402 .03321 L
.78435 .03326 L
.78468 .03331 L
.78502 .03336 L
.78535 .03341 L
.78568 .03346 L
.78602 .03351 L
.78635 .03356 L
.78668 .03361 L
.78701 .03366 L
.78734 .03371 L
.78768 .03376 L
.78801 .03381 L
.78834 .03386 L
.78867 .03391 L
.789 .03396 L
.78933 .03401 L
.78966 .03406 L
.79 .03411 L
.79033 .03417 L
.79066 .03422 L
.79099 .03427 L
.79132 .03432 L
.79165 .03437 L
.79198 .03442 L
.79231 .03447 L
.79264 .03453 L
.79297 .03458 L
.79329 .03463 L
.79362 .03468 L
Mistroke
.79395 .03473 L
.79428 .03479 L
.79461 .03484 L
.79494 .03489 L
.79527 .03494 L
.79559 .035 L
.79592 .03505 L
.79625 .0351 L
.79658 .03516 L
.79691 .03521 L
.79723 .03526 L
.79756 .03532 L
.79789 .03537 L
.79821 .03542 L
.79854 .03548 L
.79887 .03553 L
.79919 .03558 L
.79952 .03564 L
.79984 .03569 L
.80017 .03575 L
.8005 .0358 L
.80082 .03585 L
.80115 .03591 L
.80147 .03596 L
.8018 .03602 L
.80212 .03607 L
.80245 .03613 L
.80277 .03618 L
.80309 .03624 L
.80342 .03629 L
.80374 .03635 L
.80407 .0364 L
.80439 .03646 L
.80471 .03651 L
.80504 .03657 L
.80536 .03663 L
.80568 .03668 L
.80601 .03674 L
.80633 .03679 L
.80665 .03685 L
.80697 .03691 L
.80729 .03696 L
.80762 .03702 L
.80794 .03707 L
.80826 .03713 L
.80858 .03719 L
.8089 .03725 L
.80922 .0373 L
.80954 .03736 L
.80986 .03742 L
Mistroke
.81018 .03747 L
.81051 .03753 L
.81083 .03759 L
.81115 .03765 L
.81146 .0377 L
.81178 .03776 L
.8121 .03782 L
.81242 .03788 L
.81274 .03794 L
.81306 .03799 L
.81338 .03805 L
.8137 .03811 L
.81402 .03817 L
.81433 .03823 L
.81465 .03829 L
.81497 .03835 L
.81529 .03841 L
.81561 .03846 L
.81592 .03852 L
.81624 .03858 L
.81656 .03864 L
.81687 .0387 L
.81719 .03876 L
.81751 .03882 L
.81782 .03888 L
.81814 .03894 L
.81845 .039 L
.81877 .03906 L
.81909 .03912 L
.8194 .03918 L
.81972 .03924 L
.82003 .0393 L
.82035 .03936 L
.82066 .03942 L
.82097 .03949 L
.82129 .03955 L
.8216 .03961 L
.82192 .03967 L
.82223 .03973 L
.82254 .03979 L
.82286 .03985 L
.82317 .03992 L
.82348 .03998 L
.82379 .04004 L
.82411 .0401 L
.82442 .04016 L
.82473 .04023 L
.82504 .04029 L
.82535 .04035 L
.82567 .04041 L
Mistroke
.82598 .04048 L
.82629 .04054 L
.8266 .0406 L
.82691 .04067 L
.82722 .04073 L
.82753 .04079 L
.82784 .04086 L
.82815 .04092 L
.82846 .04098 L
.82877 .04105 L
.82908 .04111 L
.82939 .04117 L
.8297 .04124 L
.83001 .0413 L
.83031 .04137 L
.83062 .04143 L
.83093 .0415 L
.83124 .04156 L
.83155 .04163 L
.83185 .04169 L
.83216 .04176 L
.83247 .04182 L
.83278 .04189 L
.83308 .04195 L
.83339 .04202 L
.8337 .04208 L
.834 .04215 L
.83431 .04222 L
.83461 .04228 L
.83492 .04235 L
.83523 .04241 L
.83553 .04248 L
.83584 .04255 L
.83614 .04261 L
.83644 .04268 L
.83675 .04275 L
.83705 .04281 L
.83736 .04288 L
.83766 .04295 L
.83796 .04302 L
.83827 .04308 L
.83857 .04315 L
.83887 .04322 L
.83918 .04329 L
.83948 .04335 L
.83978 .04342 L
.84008 .04349 L
.84039 .04356 L
.84069 .04363 L
.84099 .0437 L
Mistroke
.84129 .04376 L
.84159 .04383 L
.84189 .0439 L
.84219 .04397 L
.84249 .04404 L
.84279 .04411 L
.84309 .04418 L
.84339 .04425 L
.84369 .04432 L
.84399 .04439 L
.84429 .04446 L
.84459 .04453 L
.84489 .0446 L
.84519 .04467 L
.84549 .04474 L
.84579 .04481 L
.84608 .04488 L
.84638 .04495 L
.84668 .04502 L
.84698 .04509 L
.84727 .04516 L
.84757 .04524 L
.84787 .04531 L
.84816 .04538 L
.84846 .04545 L
.84875 .04552 L
.84905 .04559 L
.84935 .04567 L
.84964 .04574 L
.84994 .04581 L
.85023 .04588 L
.85053 .04596 L
.85082 .04603 L
.85112 .0461 L
.85141 .04617 L
.8517 .04625 L
.852 .04632 L
.85229 .04639 L
.85258 .04647 L
.85288 .04654 L
.85317 .04662 L
.85346 .04669 L
.85375 .04676 L
.85405 .04684 L
.85434 .04691 L
.85463 .04699 L
.85492 .04706 L
.85521 .04714 L
.8555 .04721 L
.85579 .04729 L
Mistroke
.85608 .04736 L
.85637 .04744 L
.85666 .04751 L
.85695 .04759 L
.85724 .04766 L
.85753 .04774 L
.85782 .04781 L
.85811 .04789 L
.8584 .04797 L
.85869 .04804 L
.85898 .04812 L
.85926 .0482 L
.85955 .04827 L
.85984 .04835 L
.86013 .04843 L
.86041 .0485 L
.8607 .04858 L
.86099 .04866 L
.86127 .04874 L
.86156 .04881 L
.86184 .04889 L
.86213 .04897 L
.86242 .04905 L
.8627 .04913 L
.86299 .0492 L
.86327 .04928 L
.86355 .04936 L
.86384 .04944 L
.86412 .04952 L
.86441 .0496 L
.86469 .04968 L
.86497 .04976 L
.86526 .04984 L
.86554 .04992 L
.86582 .05 L
.8661 .05008 L
.86639 .05016 L
.86667 .05024 L
.86695 .05032 L
.86723 .0504 L
.86751 .05048 L
.86779 .05056 L
.86807 .05064 L
.86835 .05072 L
.86863 .0508 L
.86891 .05088 L
.86919 .05096 L
.86947 .05105 L
.86975 .05113 L
.87003 .05121 L
Mistroke
.87031 .05129 L
.87059 .05137 L
.87087 .05146 L
.87114 .05154 L
.87142 .05162 L
.8717 .0517 L
.87198 .05179 L
.87225 .05187 L
.87253 .05195 L
.87281 .05204 L
.87308 .05212 L
.87336 .0522 L
.87363 .05229 L
.87391 .05237 L
.87419 .05246 L
.87446 .05254 L
.87473 .05263 L
.87501 .05271 L
.87528 .05279 L
.87556 .05288 L
.87583 .05296 L
.8761 .05305 L
.87638 .05314 L
.87665 .05322 L
.87692 .05331 L
.8772 .05339 L
.87747 .05348 L
.87774 .05356 L
.87801 .05365 L
.87828 .05374 L
.87855 .05382 L
.87882 .05391 L
.87909 .054 L
.87937 .05408 L
.87964 .05417 L
.87991 .05426 L
.88017 .05435 L
.88044 .05443 L
.88071 .05452 L
.88098 .05461 L
.88125 .0547 L
.88152 .05479 L
.88179 .05487 L
.88205 .05496 L
.88232 .05505 L
.88259 .05514 L
.88286 .05523 L
.88312 .05532 L
.88339 .05541 L
.88365 .0555 L
Mistroke
.88392 .05559 L
.88419 .05568 L
.88445 .05577 L
.88472 .05586 L
.88498 .05595 L
.88525 .05604 L
.88551 .05613 L
.88577 .05622 L
.88604 .05631 L
.8863 .0564 L
.88656 .05649 L
.88683 .05658 L
.88709 .05667 L
.88735 .05677 L
.88761 .05686 L
.88788 .05695 L
.88814 .05704 L
.8884 .05713 L
.88866 .05723 L
.88892 .05732 L
.88918 .05741 L
.88944 .0575 L
.8897 .0576 L
.88996 .05769 L
.89022 .05778 L
.89048 .05788 L
.89074 .05797 L
.891 .05807 L
.89125 .05816 L
.89151 .05825 L
.89177 .05835 L
.89203 .05844 L
.89228 .05854 L
.89254 .05863 L
.8928 .05873 L
.89305 .05882 L
.89331 .05892 L
.89357 .05901 L
.89382 .05911 L
.89408 .05921 L
.89433 .0593 L
.89458 .0594 L
.89484 .05949 L
.89509 .05959 L
.89535 .05969 L
.8956 .05979 L
.89585 .05988 L
.89611 .05998 L
.89636 .06008 L
.89661 .06017 L
Mistroke
.89686 .06027 L
.89711 .06037 L
.89737 .06047 L
.89762 .06057 L
.89787 .06067 L
.89812 .06076 L
.89837 .06086 L
.89862 .06096 L
.89887 .06106 L
.89912 .06116 L
.89937 .06126 L
.89961 .06136 L
.89986 .06146 L
.90011 .06156 L
.90036 .06166 L
.90061 .06176 L
.90085 .06186 L
.9011 .06196 L
.90135 .06206 L
.90159 .06216 L
.90184 .06226 L
.90209 .06237 L
.90233 .06247 L
.90258 .06257 L
.90282 .06267 L
.90307 .06277 L
.90331 .06287 L
.90355 .06298 L
.9038 .06308 L
.90404 .06318 L
.90428 .06329 L
.90453 .06339 L
.90477 .06349 L
.90501 .0636 L
.90525 .0637 L
.90549 .0638 L
.90573 .06391 L
.90598 .06401 L
.90622 .06412 L
.90646 .06422 L
.9067 .06433 L
.90694 .06443 L
.90718 .06454 L
.90741 .06464 L
.90765 .06475 L
.90789 .06485 L
.90813 .06496 L
.90837 .06506 L
.9086 .06517 L
.90884 .06528 L
Mistroke
.90908 .06538 L
.90932 .06549 L
.90955 .0656 L
.90979 .0657 L
.91002 .06581 L
.91026 .06592 L
.91049 .06603 L
.91073 .06613 L
.91096 .06624 L
.9112 .06635 L
.91143 .06646 L
.91166 .06657 L
.9119 .06668 L
.91213 .06679 L
.91236 .06689 L
.91259 .067 L
.91282 .06711 L
.91306 .06722 L
.91329 .06733 L
.91352 .06744 L
.91375 .06755 L
.91398 .06766 L
.91421 .06777 L
.91444 .06789 L
.91467 .068 L
.9149 .06811 L
.91512 .06822 L
.91535 .06833 L
.91558 .06844 L
.91581 .06855 L
.91604 .06867 L
.91626 .06878 L
.91649 .06889 L
.91671 .069 L
.91694 .06912 L
.91717 .06923 L
.91739 .06934 L
.91762 .06946 L
.91784 .06957 L
.91806 .06969 L
.91829 .0698 L
.91851 .06991 L
.91874 .07003 L
.91896 .07014 L
.91918 .07026 L
.9194 .07037 L
.91962 .07049 L
.91985 .0706 L
.92007 .07072 L
.92029 .07084 L
Mistroke
.92051 .07095 L
.92073 .07107 L
.92095 .07118 L
.92117 .0713 L
.92139 .07142 L
.92161 .07154 L
.92182 .07165 L
.92204 .07177 L
.92226 .07189 L
.92248 .07201 L
.92269 .07212 L
.92291 .07224 L
.92313 .07236 L
.92334 .07248 L
.92356 .0726 L
.92377 .07272 L
.92399 .07284 L
.9242 .07296 L
.92442 .07308 L
.92463 .0732 L
.92485 .07332 L
.92506 .07344 L
.92527 .07356 L
.92548 .07368 L
.9257 .0738 L
.92591 .07392 L
.92612 .07404 L
.92633 .07416 L
.92654 .07428 L
.92675 .07441 L
.92696 .07453 L
.92717 .07465 L
.92738 .07477 L
.92759 .0749 L
.9278 .07502 L
.92801 .07514 L
.92821 .07527 L
.92842 .07539 L
.92863 .07551 L
.92884 .07564 L
.92904 .07576 L
.92925 .07589 L
.92945 .07601 L
.92966 .07613 L
.92986 .07626 L
.93007 .07639 L
.93027 .07651 L
.93048 .07664 L
.93068 .07676 L
.93088 .07689 L
Mistroke
.93109 .07701 L
.93129 .07714 L
.93149 .07727 L
.93169 .0774 L
.93189 .07752 L
.93209 .07765 L
.93229 .07778 L
.93249 .07791 L
.93269 .07803 L
.93289 .07816 L
.93309 .07829 L
.93329 .07842 L
.93349 .07855 L
.93369 .07868 L
.93389 .07881 L
.93408 .07894 L
.93428 .07907 L
.93448 .0792 L
.93467 .07933 L
.93487 .07946 L
.93506 .07959 L
.93526 .07972 L
.93545 .07985 L
.93565 .07998 L
.93584 .08011 L
.93603 .08024 L
.93623 .08037 L
.93642 .08051 L
.93661 .08064 L
.9368 .08077 L
.937 .08091 L
.93719 .08104 L
.93738 .08117 L
.93757 .0813 L
.93776 .08144 L
.93795 .08157 L
.93814 .08171 L
.93832 .08184 L
.93851 .08198 L
.9387 .08211 L
.93889 .08225 L
.93908 .08238 L
.93926 .08252 L
.93945 .08265 L
.93963 .08279 L
.93982 .08292 L
.94001 .08306 L
.94019 .0832 L
.94038 .08333 L
.94056 .08347 L
Mistroke
.94074 .08361 L
.94093 .08375 L
.94111 .08388 L
.94129 .08402 L
.94147 .08416 L
.94166 .0843 L
.94184 .08444 L
.94202 .08458 L
.9422 .08472 L
.94238 .08486 L
.94256 .08499 L
.94274 .08513 L
.94292 .08527 L
.94309 .08542 L
.94327 .08556 L
.94345 .0857 L
.94363 .08584 L
.9438 .08598 L
.94398 .08612 L
.94416 .08626 L
.94433 .0864 L
.94451 .08655 L
.94468 .08669 L
.94486 .08683 L
.94503 .08697 L
.9452 .08712 L
.94538 .08726 L
.94555 .0874 L
.94572 .08755 L
.94589 .08769 L
.94607 .08784 L
.94624 .08798 L
.94641 .08813 L
.94658 .08827 L
.94675 .08842 L
.94692 .08856 L
.94709 .08871 L
.94725 .08885 L
.94742 .089 L
.94759 .08915 L
.94776 .08929 L
.94792 .08944 L
.94809 .08959 L
.94826 .08973 L
.94842 .08988 L
.94859 .09003 L
.94875 .09018 L
.94892 .09033 L
.94908 .09048 L
.94924 .09062 L
Mistroke
.94941 .09077 L
.94957 .09092 L
.94973 .09107 L
.94989 .09122 L
.95005 .09137 L
.95022 .09152 L
.95038 .09167 L
.95054 .09182 L
.9507 .09197 L
.95085 .09213 L
.95101 .09228 L
.95117 .09243 L
.95133 .09258 L
.95149 .09273 L
.95164 .09289 L
.9518 .09304 L
.95196 .09319 L
.95211 .09335 L
.95227 .0935 L
.95242 .09365 L
.95258 .09381 L
.95273 .09396 L
.95288 .09412 L
.95304 .09427 L
.95319 .09443 L
.95334 .09458 L
.95349 .09474 L
.95365 .09489 L
.9538 .09505 L
.95395 .09521 L
.9541 .09536 L
.95425 .09552 L
.9544 .09568 L
.95454 .09583 L
.95469 .09599 L
.95484 .09615 L
.95499 .09631 L
.95513 .09646 L
.95528 .09662 L
.95543 .09678 L
.95557 .09694 L
.95572 .0971 L
.95586 .09726 L
.95601 .09742 L
.95615 .09758 L
.95629 .09774 L
.95644 .0979 L
.95658 .09806 L
.95672 .09822 L
.95686 .09839 L
Mistroke
.957 .09855 L
.95714 .09871 L
.95728 .09887 L
.95742 .09903 L
.95756 .0992 L
.9577 .09936 L
.95784 .09952 L
.95798 .09969 L
.95811 .09985 L
.95825 .10001 L
.95839 .10018 L
.95852 .10034 L
.95866 .10051 L
.95879 .10067 L
.95893 .10084 L
.95906 .101 L
.95919 .10117 L
.95933 .10134 L
.95946 .1015 L
.95959 .10167 L
.95972 .10184 L
.95985 .102 L
.95998 .10217 L
.96011 .10234 L
.96024 .10251 L
.96037 .10267 L
.9605 .10284 L
.96063 .10301 L
.96076 .10318 L
.96089 .10335 L
.96101 .10352 L
.96114 .10369 L
.96127 .10386 L
.96139 .10403 L
.96152 .1042 L
.96164 .10437 L
.96176 .10454 L
.96189 .10472 L
.96201 .10489 L
.96213 .10506 L
.96226 .10523 L
.96238 .1054 L
.9625 .10558 L
.96262 .10575 L
.96274 .10592 L
.96286 .1061 L
.96298 .10627 L
.9631 .10645 L
.96321 .10662 L
.96333 .10679 L
Mistroke
.96345 .10697 L
.96357 .10714 L
.96368 .10732 L
.9638 .1075 L
.96391 .10767 L
.96403 .10785 L
.96414 .10803 L
.96426 .1082 L
.96437 .10838 L
.96448 .10856 L
.96459 .10874 L
.96471 .10891 L
.96482 .10909 L
.96493 .10927 L
.96504 .10945 L
.96515 .10963 L
.96526 .10981 L
.96537 .10999 L
.96547 .11017 L
.96558 .11035 L
.96569 .11053 L
.9658 .11071 L
.9659 .11089 L
.96601 .11107 L
.96611 .11125 L
.96622 .11144 L
.96632 .11162 L
.96643 .1118 L
.96653 .11198 L
.96663 .11217 L
.96673 .11235 L
.96684 .11253 L
.96694 .11272 L
.96704 .1129 L
.96714 .11309 L
.96724 .11327 L
.96734 .11346 L
.96744 .11364 L
.96753 .11383 L
.96763 .11402 L
.96773 .1142 L
.96782 .11439 L
.96792 .11458 L
.96802 .11476 L
.96811 .11495 L
.96821 .11514 L
.9683 .11533 L
.96839 .11551 L
.96849 .1157 L
.96858 .11589 L
Mistroke
.96867 .11608 L
.96876 .11627 L
.96885 .11646 L
.96894 .11665 L
.96903 .11684 L
.96912 .11703 L
.96921 .11722 L
.9693 .11741 L
.96939 .1176 L
.96947 .1178 L
.96956 .11799 L
.96965 .11818 L
.96973 .11837 L
.96982 .11857 L
.9699 .11876 L
.96998 .11895 L
.97007 .11915 L
.97015 .11934 L
.97023 .11954 L
.97032 .11973 L
.9704 .11993 L
.97048 .12012 L
.97056 .12032 L
.97064 .12051 L
.97072 .12071 L
.9708 .12091 L
.97087 .1211 L
.97095 .1213 L
.97103 .1215 L
.9711 .1217 L
.97118 .12189 L
.97126 .12209 L
.97133 .12229 L
.9714 .12249 L
.97148 .12269 L
.97155 .12289 L
.97162 .12309 L
.9717 .12329 L
.97177 .12349 L
.97184 .12369 L
.97191 .12389 L
.97198 .12409 L
.97205 .12429 L
.97212 .1245 L
.97218 .1247 L
.97225 .1249 L
.97232 .1251 L
.97239 .12531 L
.97245 .12551 L
.97252 .12571 L
Mistroke
.97258 .12592 L
.97265 .12612 L
.97271 .12633 L
.97277 .12653 L
.97284 .12674 L
.9729 .12694 L
.97296 .12715 L
.97302 .12735 L
.97308 .12756 L
.97314 .12777 L
.9732 .12798 L
.97326 .12818 L
.97332 .12839 L
.97338 .1286 L
.97343 .12881 L
.97349 .12902 L
.97355 .12922 L
.9736 .12943 L
.97366 .12964 L
.97371 .12985 L
.97376 .13006 L
.97382 .13027 L
.97387 .13049 L
.97392 .1307 L
.97397 .13091 L
.97402 .13112 L
.97407 .13133 L
.97412 .13154 L
.97417 .13176 L
.97422 .13197 L
.97427 .13218 L
.97432 .1324 L
.97436 .13261 L
.97441 .13282 L
.97445 .13304 L
.9745 .13325 L
.97454 .13347 L
.97459 .13369 L
.97463 .1339 L
.97467 .13412 L
.97472 .13433 L
.97476 .13455 L
.9748 .13477 L
.97484 .13498 L
.97488 .1352 L
.97492 .13542 L
.97496 .13564 L
.975 .13586 L
.97503 .13608 L
.97507 .1363 L
Mistroke
.97511 .13652 L
.97514 .13674 L
.97518 .13696 L
.97521 .13718 L
.97525 .1374 L
.97528 .13762 L
.97531 .13784 L
.97534 .13806 L
.97538 .13828 L
.97541 .13851 L
.97544 .13873 L
.97547 .13895 L
.9755 .13918 L
.97552 .1394 L
.97555 .13962 L
.97558 .13985 L
.97561 .14007 L
.97563 .1403 L
.97566 .14052 L
.97568 .14075 L
.97571 .14098 L
.97573 .1412 L
.97576 .14143 L
.97578 .14166 L
.9758 .14188 L
.97582 .14211 L
.97584 .14234 L
.97586 .14257 L
.97588 .14279 L
.9759 .14302 L
.97592 .14325 L
.97594 .14348 L
.97596 .14371 L
.97597 .14394 L
.97599 .14417 L
.976 .1444 L
.97602 .14464 L
.97603 .14487 L
.97605 .1451 L
.97606 .14533 L
.97607 .14556 L
.97608 .1458 L
.97609 .14603 L
.97611 .14626 L
.97612 .1465 L
.97612 .14673 L
.97613 .14696 L
.97614 .1472 L
.97615 .14743 L
.97616 .14767 L
Mistroke
.97616 .14791 L
.97617 .14814 L
.97617 .14838 L
.97618 .14862 L
.97618 .14885 L
.97618 .14909 L
.97619 .14933 L
.97619 .14957 L
.97619 .1498 L
.97619 .15004 L
.97619 .15028 L
.97619 .15052 L
.97619 .15076 L
.97619 .151 L
.97618 .15124 L
.97618 .15148 L
.97618 .15172 L
.97617 .15196 L
.97617 .15221 L
.97616 .15245 L
.97616 .15269 L
.97615 .15293 L
.97614 .15318 L
.97613 .15342 L
.97613 .15366 L
.97612 .15391 L
.97611 .15415 L
.9761 .1544 L
.97608 .15464 L
.97607 .15489 L
.97606 .15513 L
.97605 .15538 L
.97603 .15562 L
.97602 .15587 L
.976 .15612 L
.97599 .15636 L
.97597 .15661 L
.97595 .15686 L
.97594 .15711 L
.97592 .15736 L
.9759 .15761 L
.97588 .15786 L
.97586 .1581 L
.97584 .15835 L
.97582 .15861 L
.9758 .15886 L
.97577 .15911 L
.97575 .15936 L
.97573 .15961 L
.9757 .15986 L
Mistroke
.97568 .16011 L
.97565 .16037 L
.97562 .16062 L
.9756 .16087 L
.97557 .16113 L
.97554 .16138 L
.97551 .16163 L
.97548 .16189 L
.97545 .16214 L
.97542 .1624 L
.97539 .16266 L
.97535 .16291 L
.97532 .16317 L
.97529 .16342 L
.97525 .16368 L
.97522 .16394 L
.97518 .1642 L
.97515 .16445 L
.97511 .16471 L
.97507 .16497 L
.97503 .16523 L
.97499 .16549 L
.97495 .16575 L
.97491 .16601 L
.97487 .16627 L
.97483 .16653 L
.97479 .16679 L
.97475 .16705 L
.9747 .16732 L
.97466 .16758 L
.97461 .16784 L
.97457 .1681 L
.97452 .16837 L
.97448 .16863 L
.97443 .16889 L
.97438 .16916 L
.97433 .16942 L
.97428 .16969 L
.97423 .16995 L
.97418 .17022 L
.97413 .17048 L
.97408 .17075 L
.97402 .17101 L
.97397 .17128 L
.97392 .17155 L
.97386 .17182 L
.97381 .17208 L
.97375 .17235 L
.97369 .17262 L
.97364 .17289 L
Mistroke
.97358 .17316 L
.97352 .17343 L
.97346 .1737 L
.9734 .17397 L
.97334 .17424 L
.97328 .17451 L
.97321 .17478 L
.97315 .17505 L
.97309 .17532 L
.97302 .1756 L
.97296 .17587 L
.97289 .17614 L
.97283 .17641 L
.97276 .17669 L
.97269 .17696 L
.97262 .17724 L
.97256 .17751 L
.97249 .17779 L
.97242 .17806 L
.97234 .17834 L
.97227 .17861 L
.9722 .17889 L
.97213 .17917 L
.97205 .17944 L
.97198 .17972 L
.9719 .18 L
.97183 .18028 L
.97175 .18055 L
.97168 .18083 L
.9716 .18111 L
.97152 .18139 L
.97144 .18167 L
.97136 .18195 L
.97128 .18223 L
.9712 .18251 L
.97112 .18279 L
.97103 .18307 L
.97095 .18336 L
.97087 .18364 L
.97078 .18392 L
.9707 .1842 L
.97061 .18449 L
.97052 .18477 L
.97044 .18505 L
.97035 .18534 L
.97026 .18562 L
.97017 .18591 L
.97008 .18619 L
.96999 .18648 L
.9699 .18676 L
Mistroke
.96981 .18705 L
.96971 .18734 L
.96962 .18762 L
.96953 .18791 L
.96943 .1882 L
.96934 .18848 L
.96924 .18877 L
.96914 .18906 L
.96904 .18935 L
.96895 .18964 L
.96885 .18993 L
.96875 .19022 L
.96865 .19051 L
.96855 .1908 L
.96844 .19109 L
.96834 .19138 L
.96824 .19167 L
.96813 .19196 L
.96803 .19226 L
.96792 .19255 L
.96782 .19284 L
.96771 .19314 L
.9676 .19343 L
.9675 .19372 L
.96739 .19402 L
.96728 .19431 L
.96717 .19461 L
.96706 .1949 L
.96695 .1952 L
.96683 .19549 L
.96672 .19579 L
.96661 .19609 L
.96649 .19638 L
.96638 .19668 L
.96626 .19698 L
.96614 .19728 L
.96603 .19757 L
.96591 .19787 L
.96579 .19817 L
.96567 .19847 L
.96555 .19877 L
.96543 .19907 L
.96531 .19937 L
.96519 .19967 L
.96507 .19997 L
.96494 .20027 L
.96482 .20057 L
.96469 .20088 L
.96457 .20118 L
.96444 .20148 L
Mistroke
.96431 .20178 L
.96419 .20209 L
.96406 .20239 L
.96393 .20269 L
.9638 .203 L
.96367 .2033 L
.96354 .20361 L
.9634 .20391 L
.96327 .20422 L
.96314 .20453 L
.963 .20483 L
.96287 .20514 L
.96273 .20544 L
.9626 .20575 L
.96246 .20606 L
.96232 .20637 L
.96219 .20668 L
.96205 .20698 L
.96191 .20729 L
.96177 .2076 L
.96163 .20791 L
.96148 .20822 L
.96134 .20853 L
.9612 .20884 L
.96105 .20915 L
.96091 .20946 L
.96076 .20978 L
.96062 .21009 L
.96047 .2104 L
.96032 .21071 L
.96018 .21103 L
.96003 .21134 L
.95988 .21165 L
.95973 .21197 L
.95958 .21228 L
.95942 .21259 L
.95927 .21291 L
.95912 .21322 L
.95896 .21354 L
.95881 .21386 L
.95865 .21417 L
.9585 .21449 L
.95834 .2148 L
.95818 .21512 L
.95803 .21544 L
.95787 .21576 L
.95771 .21607 L
.95755 .21639 L
.95739 .21671 L
.95722 .21703 L
Mistroke
.95706 .21735 L
.9569 .21767 L
.95673 .21799 L
.95657 .21831 L
.9564 .21863 L
.95624 .21895 L
.95607 .21927 L
.9559 .21959 L
.95574 .21992 L
.95557 .22024 L
.9554 .22056 L
.95523 .22088 L
.95506 .22121 L
.95489 .22153 L
.95471 .22185 L
.95454 .22218 L
.95437 .2225 L
.95419 .22283 L
.95402 .22315 L
.95384 .22348 L
.95366 .2238 L
.95349 .22413 L
.95331 .22445 L
.95313 .22478 L
.95295 .22511 L
.95277 .22543 L
.95259 .22576 L
.95241 .22609 L
.95222 .22642 L
.95204 .22675 L
.95186 .22708 L
.95167 .2274 L
.95149 .22773 L
.9513 .22806 L
.95111 .22839 L
.95093 .22872 L
.95074 .22905 L
.95055 .22939 L
.95036 .22972 L
.95017 .23005 L
.94998 .23038 L
.94979 .23071 L
.9496 .23104 L
.9494 .23138 L
.94921 .23171 L
.94901 .23204 L
.94882 .23238 L
.94862 .23271 L
.94843 .23305 L
.94823 .23338 L
Mistroke
.94803 .23372 L
.94783 .23405 L
.94763 .23439 L
.94743 .23472 L
.94723 .23506 L
.94703 .23539 L
.94683 .23573 L
.94662 .23607 L
.94642 .23641 L
.94622 .23674 L
.94601 .23708 L
.9458 .23742 L
.9456 .23776 L
.94539 .2381 L
.94518 .23844 L
.94497 .23877 L
.94476 .23911 L
.94455 .23945 L
.94434 .23979 L
.94413 .24014 L
.94392 .24048 L
.94371 .24082 L
.94349 .24116 L
.94328 .2415 L
.94306 .24184 L
.94285 .24219 L
.94263 .24253 L
.94241 .24287 L
.94219 .24321 L
.94198 .24356 L
.94176 .2439 L
.94154 .24425 L
.94132 .24459 L
.94109 .24493 L
.94087 .24528 L
.94065 .24562 L
.94043 .24597 L
.9402 .24632 L
.93998 .24666 L
.93975 .24701 L
.93952 .24735 L
.9393 .2477 L
.93907 .24805 L
.93884 .2484 L
.93861 .24874 L
.93838 .24909 L
.93815 .24944 L
.93792 .24979 L
.93769 .25014 L
.93745 .25049 L
Mistroke
.93722 .25084 L
.93699 .25119 L
.93675 .25154 L
.93651 .25189 L
.93628 .25224 L
.93604 .25259 L
.9358 .25294 L
.93556 .25329 L
.93533 .25364 L
.93509 .25399 L
.93484 .25435 L
.9346 .2547 L
.93436 .25505 L
.93412 .2554 L
.93388 .25576 L
.93363 .25611 L
.93339 .25646 L
.93314 .25682 L
.93289 .25717 L
.93265 .25753 L
.9324 .25788 L
.93215 .25824 L
.9319 .25859 L
.93165 .25895 L
.9314 .2593 L
.93115 .25966 L
.9309 .26002 L
.93065 .26037 L
.93039 .26073 L
.93014 .26109 L
.92989 .26145 L
.92963 .2618 L
.92937 .26216 L
.92912 .26252 L
.92886 .26288 L
.9286 .26324 L
.92834 .2636 L
.92808 .26396 L
.92782 .26431 L
.92756 .26467 L
.9273 .26503 L
.92704 .2654 L
.92678 .26576 L
.92651 .26612 L
.92625 .26648 L
.92598 .26684 L
.92572 .2672 L
.92545 .26756 L
.92518 .26792 L
.92492 .26829 L
Mistroke
.92465 .26865 L
.92438 .26901 L
.92411 .26937 L
.92384 .26974 L
.92357 .2701 L
.9233 .27047 L
.92302 .27083 L
.92275 .27119 L
.92248 .27156 L
.9222 .27192 L
.92193 .27229 L
.92165 .27265 L
.92137 .27302 L
.9211 .27338 L
.92082 .27375 L
.92054 .27412 L
.92026 .27448 L
.91998 .27485 L
.9197 .27522 L
.91942 .27558 L
.91914 .27595 L
.91885 .27632 L
.91857 .27668 L
.91829 .27705 L
.918 .27742 L
.91771 .27779 L
.91743 .27816 L
.91714 .27853 L
.91685 .2789 L
.91657 .27927 L
.91628 .27963 L
.91599 .28 L
.9157 .28037 L
.91541 .28074 L
.91512 .28111 L
.91482 .28149 L
.91453 .28186 L
.91424 .28223 L
.91394 .2826 L
.91365 .28297 L
.91335 .28334 L
.91306 .28371 L
.91276 .28409 L
.91246 .28446 L
.91216 .28483 L
.91186 .2852 L
.91156 .28558 L
.91126 .28595 L
.91096 .28632 L
.91066 .2867 L
Mistroke
.91036 .28707 L
.91006 .28744 L
.90975 .28782 L
.90945 .28819 L
.90914 .28857 L
.90884 .28894 L
.90853 .28932 L
.90823 .28969 L
.90792 .29007 L
.90761 .29044 L
.9073 .29082 L
.90699 .2912 L
.90668 .29157 L
.90637 .29195 L
.90606 .29232 L
.90575 .2927 L
.90544 .29308 L
.90512 .29345 L
.90481 .29383 L
.90449 .29421 L
.90418 .29459 L
.90386 .29497 L
.90355 .29534 L
.90323 .29572 L
.90291 .2961 L
.90259 .29648 L
.90227 .29686 L
.90195 .29724 L
.90163 .29762 L
.90131 .29799 L
.90099 .29837 L
.90067 .29875 L
.90035 .29913 L
.90002 .29951 L
.8997 .29989 L
.89937 .30027 L
.89905 .30065 L
.89872 .30104 L
.89839 .30142 L
.89807 .3018 L
.89774 .30218 L
.89741 .30256 L
.89708 .30294 L
.89675 .30332 L
.89642 .3037 L
.89609 .30409 L
.89576 .30447 L
.89542 .30485 L
.89509 .30523 L
.89476 .30562 L
Mistroke
.89442 .306 L
.89409 .30638 L
.89375 .30677 L
.89342 .30715 L
.89308 .30753 L
.89274 .30792 L
.8924 .3083 L
.89207 .30868 L
.89173 .30907 L
.89139 .30945 L
.89105 .30984 L
.89071 .31022 L
.89036 .3106 L
.89002 .31099 L
.88968 .31137 L
.88933 .31176 L
.88899 .31214 L
.88865 .31253 L
.8883 .31292 L
.88795 .3133 L
.88761 .31369 L
.88726 .31407 L
.88691 .31446 L
.88656 .31484 L
.88621 .31523 L
.88587 .31562 L
.88552 .316 L
.88516 .31639 L
.88481 .31678 L
.88446 .31716 L
.88411 .31755 L
.88375 .31794 L
.8834 .31833 L
.88305 .31871 L
.88269 .3191 L
.88234 .31949 L
.88198 .31988 L
.88162 .32026 L
.88127 .32065 L
.88091 .32104 L
.88055 .32143 L
.88019 .32182 L
.87983 .3222 L
.87947 .32259 L
.87911 .32298 L
.87875 .32337 L
.87839 .32376 L
.87802 .32415 L
.87766 .32454 L
.8773 .32493 L
Mistroke
.87693 .32532 L
.87657 .32571 L
.8762 .32609 L
.87584 .32648 L
.87547 .32687 L
.8751 .32726 L
.87473 .32765 L
.87437 .32804 L
.874 .32843 L
.87363 .32882 L
.87326 .32921 L
.87289 .3296 L
.87252 .32999 L
.87214 .33039 L
.87177 .33078 L
.8714 .33117 L
.87103 .33156 L
.87065 .33195 L
.87028 .33234 L
.8699 .33273 L
.86953 .33312 L
.86915 .33351 L
.86877 .3339 L
.8684 .33429 L
.86802 .33469 L
.86764 .33508 L
.86726 .33547 L
.86688 .33586 L
.8665 .33625 L
.86612 .33664 L
.86574 .33704 L
.86536 .33743 L
.86498 .33782 L
.86459 .33821 L
.86421 .3386 L
.86383 .339 L
.86344 .33939 L
.86306 .33978 L
.86267 .34017 L
.86228 .34056 L
.8619 .34096 L
.86151 .34135 L
.86112 .34174 L
.86074 .34213 L
.86035 .34253 L
.85996 .34292 L
.85957 .34331 L
.85918 .34371 L
.85879 .3441 L
.8584 .34449 L
Mistroke
.858 .34488 L
.85761 .34528 L
.85722 .34567 L
.85683 .34606 L
.85643 .34646 L
.85604 .34685 L
.85564 .34724 L
.85525 .34763 L
.85485 .34803 L
.85446 .34842 L
.85406 .34881 L
.85366 .34921 L
.85326 .3496 L
.85286 .34999 L
.85247 .35039 L
.85207 .35078 L
.85167 .35117 L
.85127 .35157 L
.85087 .35196 L
.85046 .35235 L
.85006 .35275 L
.84966 .35314 L
.84926 .35353 L
.84885 .35393 L
.84845 .35432 L
.84805 .35471 L
.84764 .35511 L
.84724 .3555 L
.84683 .35589 L
.84642 .35629 L
.84602 .35668 L
.84561 .35708 L
.8452 .35747 L
.84479 .35786 L
.84438 .35826 L
.84398 .35865 L
.84357 .35904 L
.84316 .35944 L
.84275 .35983 L
.84233 .36022 L
.84192 .36062 L
.84151 .36101 L
.8411 .3614 L
.84069 .3618 L
.84027 .36219 L
.83986 .36258 L
.83944 .36298 L
.83903 .36337 L
.83861 .36376 L
.8382 .36416 L
Mistroke
.83778 .36455 L
.83737 .36494 L
.83695 .36534 L
.83653 .36573 L
.83611 .36612 L
.8357 .36652 L
.83528 .36691 L
.83486 .3673 L
.83444 .3677 L
.83402 .36809 L
.8336 .36848 L
.83318 .36887 L
.83275 .36927 L
.83233 .36966 L
.83191 .37005 L
.83149 .37045 L
.83106 .37084 L
.83064 .37123 L
.83022 .37162 L
.82979 .37202 L
.82937 .37241 L
.82894 .3728 L
.82852 .37319 L
.82809 .37359 L
.82766 .37398 L
.82724 .37437 L
.82681 .37476 L
.82638 .37515 L
.82595 .37555 L
.82552 .37594 L
.8251 .37633 L
.82467 .37672 L
.82424 .37711 L
.82381 .37751 L
.82338 .3779 L
.82294 .37829 L
.82251 .37868 L
.82208 .37907 L
.82165 .37946 L
.82122 .37985 L
.82078 .38025 L
.82035 .38064 L
.81992 .38103 L
.81948 .38142 L
.81905 .38181 L
.81861 .3822 L
.81818 .38259 L
.81774 .38298 L
.8173 .38337 L
.81687 .38376 L
Mistroke
.81643 .38415 L
.81599 .38454 L
.81556 .38493 L
.81512 .38532 L
.81468 .38571 L
.81424 .3861 L
.8138 .38649 L
.81336 .38688 L
.81292 .38727 L
.81248 .38766 L
.81204 .38805 L
.8116 .38844 L
.81116 .38883 L
.81072 .38922 L
.81027 .38961 L
.80983 .39 L
.80939 .39038 L
.80894 .39077 L
.8085 .39116 L
.80806 .39155 L
.80761 .39194 L
.80717 .39233 L
.80672 .39271 L
.80628 .3931 L
.80583 .39349 L
.80539 .39388 L
.80494 .39426 L
.80449 .39465 L
.80405 .39504 L
.8036 .39543 L
.80315 .39581 L
.8027 .3962 L
.80225 .39659 L
.80181 .39697 L
.80136 .39736 L
.80091 .39774 L
.80046 .39813 L
.80001 .39852 L
.79956 .3989 L
.79911 .39929 L
.79866 .39967 L
.79821 .40006 L
.79775 .40044 L
.7973 .40083 L
.79685 .40121 L
.7964 .4016 L
.79594 .40198 L
.79549 .40237 L
.79504 .40275 L
.79458 .40314 L
Mistroke
.79413 .40352 L
.79368 .4039 L
.79322 .40429 L
.79277 .40467 L
.79231 .40505 L
.79185 .40544 L
.7914 .40582 L
.79094 .4062 L
.79049 .40658 L
.79003 .40697 L
.78957 .40735 L
.78912 .40773 L
.78866 .40811 L
.7882 .40849 L
.78774 .40888 L
.78728 .40926 L
.78682 .40964 L
.78637 .41002 L
.78591 .4104 L
.78545 .41078 L
.78499 .41116 L
.78453 .41154 L
.78407 .41192 L
.78361 .4123 L
.78315 .41268 L
.78268 .41306 L
.78222 .41344 L
.78176 .41382 L
.7813 .4142 L
.78084 .41458 L
.78037 .41495 L
.77991 .41533 L
.77945 .41571 L
.77899 .41609 L
.77852 .41647 L
.77806 .41684 L
.7776 .41722 L
.77713 .4176 L
.77667 .41797 L
.7762 .41835 L
.77574 .41873 L
.77527 .4191 L
.77481 .41948 L
.77434 .41985 L
.77388 .42023 L
.77341 .4206 L
.77294 .42098 L
.77248 .42135 L
.77201 .42173 L
.77154 .4221 L
Mistroke
.77108 .42248 L
.77061 .42285 L
.77014 .42322 L
.76967 .4236 L
.76921 .42397 L
.76874 .42434 L
.76827 .42472 L
.7678 .42509 L
.76733 .42546 L
.76686 .42583 L
.76639 .4262 L
.76592 .42657 L
.76545 .42695 L
.76498 .42732 L
.76451 .42769 L
.76404 .42806 L
.76357 .42843 L
.7631 .4288 L
.76263 .42917 L
.76216 .42954 L
.76169 .4299 L
.76122 .43027 L
.76075 .43064 L
.76028 .43101 L
.7598 .43138 L
.75933 .43175 L
.75886 .43211 L
.75839 .43248 L
.75791 .43285 L
.75744 .43321 L
.75697 .43358 L
.75649 .43395 L
.75602 .43431 L
.75555 .43468 L
.75507 .43504 L
.7546 .43541 L
.75413 .43577 L
.75365 .43614 L
.75318 .4365 L
.7527 .43687 L
.75223 .43723 L
.75175 .43759 L
.75128 .43796 L
.7508 .43832 L
.75033 .43868 L
.74985 .43904 L
.74938 .4394 L
.7489 .43977 L
.74843 .44013 L
.74795 .44049 L
Mistroke
.74748 .44085 L
.747 .44121 L
.74652 .44157 L
.74605 .44193 L
.74557 .44229 L
.74509 .44265 L
.74462 .44301 L
.74414 .44337 L
.74366 .44372 L
.74319 .44408 L
.74271 .44444 L
.74223 .4448 L
.74175 .44515 L
.74128 .44551 L
.7408 .44587 L
.74032 .44622 L
.73984 .44658 L
.73936 .44693 L
.73889 .44729 L
.73841 .44764 L
.73793 .448 L
.73745 .44835 L
.73697 .4487 L
.73649 .44906 L
.73601 .44941 L
.73553 .44976 L
.73506 .45012 L
.73458 .45047 L
.7341 .45082 L
.73362 .45117 L
.73314 .45152 L
.73266 .45187 L
.73218 .45222 L
.7317 .45257 L
.73122 .45292 L
.73074 .45327 L
.73026 .45362 L
.72978 .45397 L
.7293 .45432 L
.72882 .45467 L
.72834 .45501 L
.72786 .45536 L
.72738 .45571 L
.7269 .45606 L
.72642 .4564 L
.72594 .45675 L
.72546 .45709 L
.72498 .45744 L
.7245 .45778 L
.72402 .45813 L
Mistroke
.72354 .45847 L
.72306 .45881 L
.72257 .45916 L
.72209 .4595 L
.72161 .45984 L
.72113 .46019 L
.72065 .46053 L
.72017 .46087 L
.71969 .46121 L
.71921 .46155 L
.71873 .46189 L
.71824 .46223 L
.71776 .46257 L
.71728 .46291 L
.7168 .46325 L
.71632 .46359 L
.71584 .46393 L
.71536 .46426 L
.71488 .4646 L
.71439 .46494 L
.71391 .46527 L
.71343 .46561 L
.71295 .46595 L
.71247 .46628 L
.71199 .46662 L
.7115 .46695 L
.71102 .46729 L
.71054 .46762 L
.71006 .46795 L
.70958 .46829 L
.7091 .46862 L
.70862 .46895 L
.70813 .46928 L
.70765 .46961 L
.70717 .46995 L
.70669 .47028 L
.70621 .47061 L
.70573 .47094 L
.70524 .47127 L
.70476 .47159 L
.70428 .47192 L
.7038 .47225 L
.70332 .47258 L
.70284 .47291 L
.70235 .47323 L
.70187 .47356 L
.70139 .47389 L
.70091 .47421 L
.70043 .47454 L
.69995 .47486 L
Mistroke
.69947 .47519 L
.69898 .47551 L
.6985 .47583 L
.69802 .47616 L
.69754 .47648 L
.69706 .4768 L
.69658 .47712 L
.6961 .47745 L
.69562 .47777 L
.69514 .47809 L
.69465 .47841 L
.69417 .47873 L
.69369 .47905 L
.69321 .47937 L
.69273 .47968 L
.69225 .48 L
.69177 .48032 L
.69129 .48064 L
.69081 .48095 L
.69033 .48127 L
.68985 .48159 L
.68937 .4819 L
.68889 .48222 L
.68841 .48253 L
.68793 .48285 L
.68745 .48316 L
.68697 .48347 L
.68649 .48379 L
.68601 .4841 L
.68553 .48441 L
.68505 .48472 L
.68457 .48503 L
.68409 .48534 L
.68361 .48565 L
.68313 .48596 L
.68265 .48627 L
.68217 .48658 L
.68169 .48689 L
.68121 .4872 L
.68073 .4875 L
.68025 .48781 L
.67977 .48812 L
.67929 .48842 L
.67882 .48873 L
.67834 .48903 L
.67786 .48934 L
.67738 .48964 L
.6769 .48995 L
.67642 .49025 L
.67595 .49055 L
Mistroke
.67547 .49085 L
.67499 .49116 L
.67451 .49146 L
.67403 .49176 L
.67356 .49206 L
.67308 .49236 L
.6726 .49266 L
.67212 .49296 L
.67165 .49326 L
.67117 .49355 L
.67069 .49385 L
.67022 .49415 L
.66974 .49445 L
.66926 .49474 L
.66879 .49504 L
.66831 .49533 L
.66783 .49563 L
.66736 .49592 L
.66688 .49621 L
.66641 .49651 L
.66593 .4968 L
.66545 .49709 L
.66498 .49738 L
.6645 .49768 L
.66403 .49797 L
.66355 .49826 L
.66308 .49855 L
.6626 .49884 L
.66213 .49913 L
.66166 .49941 L
.66118 .4997 L
.66071 .49999 L
.66023 .50028 L
.65976 .50056 L
.65929 .50085 L
.65881 .50113 L
.65834 .50142 L
.65787 .5017 L
.65739 .50199 L
.65692 .50227 L
.65645 .50255 L
.65597 .50283 L
.6555 .50312 L
.65503 .5034 L
.65456 .50368 L
.65409 .50396 L
.65361 .50424 L
.65314 .50452 L
.65267 .5048 L
.6522 .50508 L
Mistroke
.65173 .50535 L
.65126 .50563 L
.65079 .50591 L
.65032 .50618 L
.64985 .50646 L
.64938 .50673 L
.64891 .50701 L
.64844 .50728 L
.64797 .50756 L
.6475 .50783 L
.64703 .5081 L
.64656 .50838 L
.64609 .50865 L
.64562 .50892 L
.64515 .50919 L
.64469 .50946 L
.64422 .50973 L
.64375 .51 L
.64328 .51027 L
.64281 .51053 L
.64235 .5108 L
.64188 .51107 L
.64141 .51134 L
.64095 .5116 L
.64048 .51187 L
.64001 .51213 L
.63955 .5124 L
.63908 .51266 L
.63862 .51292 L
.63815 .51319 L
.63769 .51345 L
.63722 .51371 L
.63676 .51397 L
.63629 .51423 L
.63583 .51449 L
.63536 .51475 L
.6349 .51501 L
.63444 .51527 L
.63397 .51553 L
.63351 .51579 L
.63305 .51604 L
.63258 .5163 L
.63212 .51655 L
.63166 .51681 L
.6312 .51706 L
.63073 .51732 L
.63027 .51757 L
.62981 .51783 L
.62935 .51808 L
.62889 .51833 L
Mistroke
.62843 .51858 L
.62797 .51883 L
.62751 .51908 L
.62705 .51933 L
.62659 .51958 L
.62613 .51983 L
.62567 .52008 L
.62521 .52033 L
.62475 .52058 L
.62429 .52082 L
.62384 .52107 L
.62338 .52131 L
.62292 .52156 L
.62246 .5218 L
.622 .52205 L
.62155 .52229 L
.62109 .52253 L
.62063 .52278 L
.62018 .52302 L
.61972 .52326 L
.61927 .5235 L
.61881 .52374 L
.61836 .52398 L
.6179 .52422 L
.61745 .52446 L
.61699 .5247 L
.61654 .52493 L
.61608 .52517 L
.61563 .52541 L
.61518 .52564 L
.61472 .52588 L
.61427 .52611 L
.61382 .52635 L
.61337 .52658 L
.61291 .52681 L
.61246 .52705 L
.61201 .52728 L
.61156 .52751 L
.61111 .52774 L
.61066 .52797 L
.61021 .5282 L
.60976 .52843 L
.60931 .52866 L
.60886 .52888 L
.60841 .52911 L
.60796 .52934 L
.60751 .52957 L
.60706 .52979 L
.60662 .53002 L
.60617 .53024 L
Mistroke
.60572 .53046 L
.60527 .53069 L
.60483 .53091 L
.60438 .53113 L
.60394 .53136 L
.60349 .53158 L
.60304 .5318 L
.6026 .53202 L
.60215 .53224 L
.60171 .53246 L
.60126 .53267 L
.60082 .53289 L
.60038 .53311 L
.59993 .53333 L
.59949 .53354 L
.59905 .53376 L
.5986 .53397 L
.59816 .53419 L
.59772 .5344 L
.59728 .53462 L
.59684 .53483 L
.5964 .53504 L
.59596 .53525 L
.59551 .53546 L
.59507 .53567 L
.59464 .53588 L
.5942 .53609 L
.59376 .5363 L
.59332 .53651 L
.59288 .53672 L
.59244 .53692 L
.592 .53713 L
.59157 .53734 L
.59113 .53754 L
.59069 .53775 L
.59026 .53795 L
.58982 .53816 L
.58938 .53836 L
.58895 .53856 L
.58851 .53876 L
.58808 .53896 L
.58764 .53917 L
.58721 .53937 L
.58677 .53957 L
.58634 .53976 L
.58591 .53996 L
.58547 .54016 L
.58504 .54036 L
.58461 .54056 L
.58418 .54075 L
Mistroke
.58375 .54095 L
.58332 .54114 L
.58288 .54134 L
.58245 .54153 L
.58202 .54172 L
.58159 .54192 L
.58116 .54211 L
.58074 .5423 L
.58031 .54249 L
.57988 .54268 L
.57945 .54287 L
.57902 .54306 L
.57859 .54325 L
.57817 .54344 L
.57774 .54363 L
.57731 .54381 L
.57689 .544 L
.57646 .54419 L
.57604 .54437 L
.57561 .54456 L
.57519 .54474 L
.57476 .54492 L
.57434 .54511 L
.57392 .54529 L
.57349 .54547 L
.57307 .54565 L
.57265 .54583 L
.57223 .54601 L
.5718 .54619 L
.57138 .54637 L
.57096 .54655 L
.57054 .54673 L
.57012 .54691 L
.5697 .54708 L
.56928 .54726 L
.56886 .54744 L
.56844 .54761 L
.56802 .54779 L
.56761 .54796 L
.56719 .54813 L
.56677 .54831 L
.56635 .54848 L
.56594 .54865 L
.56552 .54882 L
.56511 .54899 L
.56469 .54916 L
.56427 .54933 L
.56386 .5495 L
.56345 .54967 L
.56303 .54983 L
Mistroke
.56262 .55 L
.5622 .55017 L
.56179 .55033 L
.56138 .5505 L
.56097 .55066 L
.56056 .55083 L
.56014 .55099 L
.55973 .55115 L
.55932 .55132 L
.55891 .55148 L
.5585 .55164 L
.55809 .5518 L
.55768 .55196 L
.55728 .55212 L
.55687 .55228 L
.55646 .55244 L
.55605 .55259 L
.55564 .55275 L
.55524 .55291 L
.55483 .55306 L
.55443 .55322 L
.55402 .55338 L
.55361 .55353 L
.55321 .55368 L
.55281 .55384 L
.5524 .55399 L
.552 .55414 L
.55159 .55429 L
.55119 .55444 L
.55079 .55459 L
.55039 .55474 L
.54999 .55489 L
.54958 .55504 L
.54918 .55519 L
.54878 .55534 L
.54838 .55548 L
.54798 .55563 L
.54758 .55578 L
.54719 .55592 L
.54679 .55607 L
.54639 .55621 L
.54599 .55635 L
.54559 .5565 L
.5452 .55664 L
.5448 .55678 L
.5444 .55692 L
.54401 .55706 L
.54361 .5572 L
.54322 .55734 L
.54282 .55748 L
Mistroke
.54243 .55762 L
.54204 .55776 L
.54164 .55789 L
.54125 .55803 L
.54086 .55817 L
.54047 .5583 L
.54007 .55844 L
.53968 .55857 L
.53929 .55871 L
.5389 .55884 L
.53851 .55897 L
.53812 .5591 L
.53773 .55924 L
.53734 .55937 L
.53696 .5595 L
.53657 .55963 L
.53618 .55976 L
.53579 .55989 L
.53541 .56001 L
.53502 .56014 L
.53463 .56027 L
.53425 .56039 L
.53386 .56052 L
.53348 .56065 L
.5331 .56077 L
.53271 .56089 L
.53233 .56102 L
.53195 .56114 L
.53156 .56126 L
.53118 .56139 L
.5308 .56151 L
.53042 .56163 L
.53004 .56175 L
.52966 .56187 L
.52928 .56199 L
.5289 .56211 L
.52852 .56222 L
.52814 .56234 L
.52776 .56246 L
.52738 .56257 L
.52701 .56269 L
.52663 .56281 L
.52625 .56292 L
.52588 .56303 L
.5255 .56315 L
.52512 .56326 L
.52475 .56337 L
.52438 .56349 L
.524 .5636 L
.52363 .56371 L
Mistroke
.52325 .56382 L
.52288 .56393 L
.52251 .56404 L
.52214 .56415 L
.52177 .56425 L
.52139 .56436 L
.52102 .56447 L
.52065 .56457 L
.52028 .56468 L
.51991 .56478 L
.51955 .56489 L
.51918 .56499 L
.51881 .5651 L
.51844 .5652 L
.51807 .5653 L
.51771 .5654 L
.51734 .56551 L
.51698 .56561 L
.51661 .56571 L
.51624 .56581 L
.51588 .56591 L
.51552 .566 L
.51515 .5661 L
.51479 .5662 L
.51443 .5663 L
.51406 .56639 L
.5137 .56649 L
.51334 .56659 L
.51298 .56668 L
.51262 .56677 L
.51226 .56687 L
.5119 .56696 L
.51154 .56705 L
.51118 .56715 L
.51082 .56724 L
.51046 .56733 L
.5101 .56742 L
.50975 .56751 L
.50939 .5676 L
.50903 .56769 L
.50868 .56778 L
.50832 .56786 L
.50797 .56795 L
.50761 .56804 L
.50726 .56812 L
.50691 .56821 L
.50655 .56829 L
.5062 .56838 L
.50585 .56846 L
.50549 .56855 L
Mistroke
.50514 .56863 L
.50479 .56871 L
.50444 .56879 L
.50409 .56887 L
.50374 .56895 L
.50339 .56904 L
.50304 .56911 L
.50269 .56919 L
.50235 .56927 L
.502 .56935 L
.50165 .56943 L
.50131 .56951 L
.50096 .56958 L
.50061 .56966 L
.50027 .56973 L
.49992 .56981 L
.49958 .56988 L
.49923 .56996 L
.49889 .57003 L
.49855 .5701 L
.4982 .57018 L
.49786 .57025 L
.49752 .57032 L
.49718 .57039 L
.49684 .57046 L
.4965 .57053 L
.49616 .5706 L
.49582 .57067 L
.49548 .57073 L
.49514 .5708 L
.4948 .57087 L
.49446 .57094 L
.49413 .571 L
.49379 .57107 L
.49345 .57113 L
.49312 .5712 L
.49278 .57126 L
.49245 .57132 L
.49211 .57139 L
.49178 .57145 L
.49144 .57151 L
.49111 .57157 L
.49078 .57163 L
.49044 .57169 L
.49011 .57175 L
.48978 .57181 L
.48945 .57187 L
.48912 .57193 L
.48879 .57199 L
.48846 .57205 L
Mistroke
.48813 .5721 L
.4878 .57216 L
.48747 .57221 L
.48714 .57227 L
.48682 .57232 L
.48649 .57238 L
.48616 .57243 L
.48584 .57249 L
.48551 .57254 L
.48519 .57259 L
.48486 .57264 L
.48454 .57269 L
.48421 .57274 L
.48389 .57279 L
.48356 .57284 L
.48324 .57289 L
.48292 .57294 L
.4826 .57299 L
.48228 .57304 L
.48196 .57308 L
.48164 .57313 L
.48132 .57318 L
.481 .57322 L
.48068 .57327 L
.48036 .57331 L
.48004 .57336 L
.47972 .5734 L
.4794 .57344 L
.47909 .57349 L
.47877 .57353 L
.47846 .57357 L
.47814 .57361 L
.47782 .57365 L
.47751 .57369 L
.4772 .57373 L
.47688 .57377 L
.47657 .57381 L
.47626 .57385 L
.47594 .57389 L
.47563 .57392 L
.47532 .57396 L
.47501 .574 L
.4747 .57403 L
.47439 .57407 L
.47408 .5741 L
.47377 .57414 L
.47346 .57417 L
.47315 .5742 L
.47284 .57424 L
.47254 .57427 L
Mistroke
.47223 .5743 L
.47192 .57433 L
.47162 .57436 L
.47131 .57439 L
.47101 .57442 L
.4707 .57445 L
.4704 .57448 L
.47009 .57451 L
.46979 .57454 L
.46949 .57457 L
.46918 .57459 L
.46888 .57462 L
.46858 .57465 L
.46828 .57467 L
.46798 .5747 L
.46768 .57472 L
.46738 .57475 L
.46708 .57477 L
.46678 .57479 L
.46648 .57482 L
.46618 .57484 L
.46588 .57486 L
.46559 .57488 L
.46529 .5749 L
.46499 .57492 L
.4647 .57494 L
.4644 .57496 L
.46411 .57498 L
.46381 .575 L
.46352 .57502 L
.46322 .57504 L
.46293 .57506 L
.46264 .57507 L
.46235 .57509 L
.46205 .57511 L
.46176 .57512 L
.46147 .57514 L
.46118 .57515 L
.46089 .57516 L
.4606 .57518 L
.46031 .57519 L
.46002 .5752 L
.45973 .57522 L
.45945 .57523 L
.45916 .57524 L
.45887 .57525 L
.45859 .57526 L
.4583 .57527 L
.45801 .57528 L
.45773 .57529 L
Mistroke
.45744 .5753 L
.45716 .57531 L
.45688 .57531 L
.45659 .57532 L
.45631 .57533 L
.45603 .57534 L
.45574 .57534 L
.45546 .57535 L
.45518 .57535 L
.4549 .57536 L
.45462 .57536 L
.45434 .57536 L
.45406 .57537 L
.45378 .57537 L
.4535 .57537 L
.45322 .57538 L
.45295 .57538 L
.45267 .57538 L
.45239 .57538 L
.45212 .57538 L
.45184 .57538 L
.45156 .57538 L
.45129 .57538 L
.45101 .57538 L
.45074 .57537 L
.45047 .57537 L
.45019 .57537 L
.44992 .57537 L
.44965 .57536 L
.44937 .57536 L
.4491 .57535 L
.44883 .57535 L
.44856 .57534 L
.44829 .57534 L
.44802 .57533 L
.44775 .57533 L
.44748 .57532 L
.44721 .57531 L
.44695 .5753 L
.44668 .5753 L
.44641 .57529 L
.44614 .57528 L
.44588 .57527 L
.44561 .57526 L
.44535 .57525 L
.44508 .57524 L
.44482 .57523 L
.44455 .57521 L
.44429 .5752 L
.44402 .57519 L
Mistroke
.44376 .57518 L
.4435 .57516 L
.44324 .57515 L
.44297 .57514 L
.44271 .57512 L
.44245 .57511 L
.44219 .57509 L
.44193 .57507 L
.44167 .57506 L
.44141 .57504 L
.44116 .57503 L
.4409 .57501 L
.44064 .57499 L
.44038 .57497 L
.44012 .57495 L
.43987 .57493 L
.43961 .57491 L
.43936 .57489 L
.4391 .57487 L
.43885 .57485 L
.43859 .57483 L
.43834 .57481 L
.43808 .57479 L
.43783 .57477 L
.43758 .57475 L
.43733 .57472 L
.43708 .5747 L
.43682 .57468 L
.43657 .57465 L
.43632 .57463 L
.43607 .5746 L
.43582 .57458 L
.43557 .57455 L
.43532 .57452 L
.43508 .5745 L
.43483 .57447 L
.43458 .57444 L
.43433 .57442 L
.43409 .57439 L
.43384 .57436 L
.43359 .57433 L
.43335 .5743 L
.4331 .57427 L
.43286 .57424 L
.43262 .57421 L
.43237 .57418 L
.43213 .57415 L
.43189 .57412 L
.43164 .57409 L
.4314 .57405 L
Mistroke
.43116 .57402 L
.43092 .57399 L
.43068 .57395 L
.43044 .57392 L
.4302 .57389 L
.42996 .57385 L
.42972 .57382 L
.42948 .57378 L
.42924 .57375 L
.429 .57371 L
.42877 .57367 L
.42853 .57364 L
.42829 .5736 L
.42806 .57356 L
.42782 .57352 L
.42759 .57349 L
.42735 .57345 L
.42712 .57341 L
.42688 .57337 L
.42665 .57333 L
.42642 .57329 L
.42618 .57325 L
.42595 .57321 L
.42572 .57317 L
.42549 .57313 L
.42526 .57308 L
.42503 .57304 L
.42479 .573 L
.42456 .57296 L
.42434 .57291 L
.42411 .57287 L
.42388 .57282 L
.42365 .57278 L
.42342 .57274 L
.42319 .57269 L
.42297 .57264 L
.42274 .5726 L
.42251 .57255 L
.42229 .57251 L
.42206 .57246 L
.42184 .57241 L
.42161 .57236 L
.42139 .57232 L
.42117 .57227 L
.42094 .57222 L
.42072 .57217 L
.4205 .57212 L
.42027 .57207 L
.42005 .57202 L
.41983 .57197 L
Mistroke
.41961 .57192 L
.41939 .57187 L
.41917 .57182 L
.41895 .57177 L
.41873 .57172 L
.41851 .57166 L
.41829 .57161 L
.41808 .57156 L
.41786 .5715 L
.41764 .57145 L
.41742 .5714 L
.41721 .57134 L
.41699 .57129 L
.41678 .57123 L
.41656 .57118 L
.41635 .57112 L
.41613 .57106 L
.41592 .57101 L
.4157 .57095 L
.41549 .57089 L
.41528 .57084 L
.41506 .57078 L
.41485 .57072 L
.41464 .57066 L
.41443 .5706 L
.41422 .57055 L
.41401 .57049 L
.4138 .57043 L
.41359 .57037 L
.41338 .57031 L
.41317 .57025 L
.41296 .57019 L
.41275 .57012 L
.41255 .57006 L
.41234 .57 L
.41213 .56994 L
.41193 .56988 L
.41172 .56981 L
.41151 .56975 L
.41131 .56969 L
.4111 .56962 L
.4109 .56956 L
.41069 .56949 L
.41049 .56943 L
.41029 .56936 L
.41008 .5693 L
.40988 .56923 L
.40968 .56917 L
.40948 .5691 L
.40928 .56904 L
Mistroke
.40908 .56897 L
.40888 .5689 L
.40868 .56883 L
.40848 .56877 L
.40828 .5687 L
.40808 .56863 L
.40788 .56856 L
.40768 .56849 L
.40748 .56842 L
.40728 .56835 L
.40709 .56828 L
.40689 .56821 L
.40669 .56814 L
.4065 .56807 L
.4063 .568 L
.40611 .56793 L
.40591 .56786 L
.40572 .56779 L
.40552 .56771 L
.40533 .56764 L
.40514 .56757 L
.40494 .5675 L
.40475 .56742 L
.40456 .56735 L
.40437 .56727 L
.40418 .5672 L
.40399 .56713 L
.4038 .56705 L
.4036 .56698 L
.40341 .5669 L
.40323 .56682 L
.40304 .56675 L
.40285 .56667 L
.40266 .5666 L
.40247 .56652 L
.40228 .56644 L
.4021 .56636 L
.40191 .56629 L
.40172 .56621 L
.40154 .56613 L
.40135 .56605 L
.40117 .56597 L
.40098 .56589 L
.4008 .56581 L
.40061 .56573 L
.40043 .56566 L
.40025 .56557 L
.40006 .56549 L
.39988 .56541 L
.3997 .56533 L
Mistroke
.39952 .56525 L
.39933 .56517 L
.39915 .56509 L
.39897 .56501 L
.39879 .56492 L
.39861 .56484 L
.39843 .56476 L
.39825 .56468 L
.39807 .56459 L
.39789 .56451 L
.39772 .56442 L
.39754 .56434 L
.39736 .56426 L
.39718 .56417 L
.39701 .56409 L
.39683 .564 L
.39665 .56392 L
.39648 .56383 L
.3963 .56374 L
.39613 .56366 L
.39595 .56357 L
.39578 .56348 L
.39561 .5634 L
.39543 .56331 L
.39526 .56322 L
.39509 .56313 L
.39491 .56305 L
.39474 .56296 L
.39457 .56287 L
.3944 .56278 L
.39423 .56269 L
.39406 .5626 L
.39389 .56251 L
.39372 .56242 L
.39355 .56233 L
.39338 .56224 L
.39321 .56215 L
.39304 .56206 L
.39287 .56197 L
.3927 .56188 L
.39254 .56179 L
.39237 .5617 L
.3922 .5616 L
.39204 .56151 L
.39187 .56142 L
.39171 .56133 L
.39154 .56123 L
.39138 .56114 L
.39121 .56105 L
.39105 .56095 L
Mistroke
.39088 .56086 L
.39072 .56076 L
.39056 .56067 L
.39039 .56058 L
.39023 .56048 L
.39007 .56039 L
.38991 .56029 L
.38975 .56019 L
.38959 .5601 L
.38942 .56 L
.38926 .55991 L
.3891 .55981 L
.38894 .55971 L
.38879 .55962 L
.38863 .55952 L
.38847 .55942 L
.38831 .55932 L
.38815 .55923 L
.38799 .55913 L
.38784 .55903 L
.38768 .55893 L
.38752 .55883 L
.38737 .55873 L
.38721 .55863 L
.38706 .55853 L
.3869 .55844 L
.38675 .55834 L
.38659 .55824 L
.38644 .55813 L
.38628 .55803 L
.38613 .55793 L
.38598 .55783 L
.38582 .55773 L
.38567 .55763 L
.38552 .55753 L
.38537 .55743 L
.38522 .55732 L
.38507 .55722 L
.38492 .55712 L
.38477 .55702 L
.38462 .55691 L
.38447 .55681 L
.38432 .55671 L
.38417 .5566 L
.38402 .5565 L
.38387 .5564 L
.38372 .55629 L
.38357 .55619 L
.38343 .55608 L
.38328 .55598 L
Mistroke
.38313 .55587 L
.38299 .55577 L
.38284 .55566 L
.3827 .55556 L
.38255 .55545 L
.38241 .55535 L
.38226 .55524 L
.38212 .55513 L
.38197 .55503 L
.38183 .55492 L
.38169 .55481 L
.38154 .55471 L
.3814 .5546 L
.38126 .55449 L
.38112 .55438 L
.38097 .55428 L
.38083 .55417 L
.38069 .55406 L
.38055 .55395 L
.38041 .55384 L
.38027 .55373 L
.38013 .55362 L
.37999 .55351 L
.37985 .5534 L
.37971 .5533 L
.37957 .55319 L
.37944 .55308 L
.3793 .55297 L
.37916 .55285 L
.37902 .55274 L
.37889 .55263 L
.37875 .55252 L
.37861 .55241 L
.37848 .5523 L
.37834 .55219 L
.37821 .55208 L
.37807 .55196 L
.37794 .55185 L
.3778 .55174 L
.37767 .55163 L
.37754 .55151 L
.3774 .5514 L
.37727 .55129 L
.37714 .55118 L
.37701 .55106 L
.37687 .55095 L
.37674 .55084 L
.37661 .55072 L
.37648 .55061 L
.37635 .55049 L
Mistroke
.37622 .55038 L
.37609 .55026 L
.37596 .55015 L
.37583 .55003 L
.3757 .54992 L
.37557 .5498 L
.37544 .54969 L
.37531 .54957 L
.37519 .54946 L
.37506 .54934 L
.37493 .54922 L
.3748 .54911 L
.37468 .54899 L
.37455 .54888 L
.37443 .54876 L
.3743 .54864 L
.37417 .54852 L
.37405 .54841 L
.37392 .54829 L
.3738 .54817 L
.37368 .54805 L
.37355 .54794 L
.37343 .54782 L
.3733 .5477 L
.37318 .54758 L
.37306 .54746 L
.37294 .54734 L
.37281 .54723 L
.37269 .54711 L
.37257 .54699 L
.37245 .54687 L
.37233 .54675 L
.37221 .54663 L
.37209 .54651 L
.37197 .54639 L
.37185 .54627 L
.37173 .54615 L
.37161 .54603 L
.37149 .54591 L
.37137 .54579 L
.37126 .54567 L
.37114 .54554 L
.37102 .54542 L
.3709 .5453 L
.37079 .54518 L
.37067 .54506 L
.37055 .54494 L
.37044 .54481 L
.37032 .54469 L
.37021 .54457 L
Mistroke
.37009 .54445 L
.36998 .54433 L
.36986 .5442 L
.36975 .54408 L
.36963 .54396 L
.36952 .54383 L
.36941 .54371 L
.36929 .54359 L
.36918 .54346 L
.36907 .54334 L
.36896 .54322 L
.36884 .54309 L
.36873 .54297 L
.36862 .54284 L
.36851 .54272 L
.3684 .54259 L
.36829 .54247 L
.36818 .54234 L
.36807 .54222 L
.36796 .54209 L
.36785 .54197 L
.36774 .54184 L
.36763 .54172 L
.36752 .54159 L
.36741 .54147 L
.36731 .54134 L
.3672 .54122 L
.36709 .54109 L
.36698 .54096 L
.36688 .54084 L
.36677 .54071 L
.36667 .54058 L
.36656 .54046 L
.36645 .54033 L
.36635 .5402 L
.36624 .54008 L
.36614 .53995 L
.36603 .53982 L
.36593 .53969 L
.36583 .53957 L
.36572 .53944 L
.36562 .53931 L
.36552 .53918 L
.36541 .53905 L
.36531 .53893 L
.36521 .5388 L
.36511 .53867 L
.36501 .53854 L
.3649 .53841 L
.3648 .53828 L
Mistroke
.3647 .53815 L
.3646 .53802 L
.3645 .53789 L
.3644 .53777 L
.3643 .53764 L
.3642 .53751 L
.3641 .53738 L
.364 .53725 L
.36391 .53712 L
.36381 .53699 L
.36371 .53686 L
.36361 .53673 L
.36351 .5366 L
.36342 .53646 L
.36332 .53633 L
.36322 .5362 L
.36313 .53607 L
.36303 .53594 L
.36293 .53581 L
.36284 .53568 L
.36274 .53555 L
.36265 .53542 L
.36255 .53528 L
.36246 .53515 L
.36236 .53502 L
.36227 .53489 L
.36218 .53476 L
.36208 .53463 L
.36199 .53449 L
.3619 .53436 L
.3618 .53423 L
.36171 .5341 L
.36162 .53396 L
.36153 .53383 L
.36144 .5337 L
.36135 .53357 L
.36125 .53343 L
.36116 .5333 L
.36107 .53317 L
.36098 .53303 L
.36089 .5329 L
.3608 .53277 L
.36071 .53263 L
.36062 .5325 L
.36053 .53236 L
.36045 .53223 L
.36036 .5321 L
.36027 .53196 L
.36018 .53183 L
.36009 .53169 L
Mistroke
.36001 .53156 L
.35992 .53142 L
.35983 .53129 L
.35975 .53116 L
.35966 .53102 L
.35957 .53089 L
.35949 .53075 L
.3594 .53062 L
.35932 .53048 L
.35923 .53035 L
.35915 .53021 L
.35906 .53007 L
.35898 .52994 L
.35889 .5298 L
.35881 .52967 L
.35873 .52953 L
.35864 .5294 L
.35856 .52926 L
.35848 .52912 L
.35839 .52899 L
.35831 .52885 L
.35823 .52872 L
.35815 .52858 L
.35807 .52844 L
.35799 .52831 L
.3579 .52817 L
.35782 .52803 L
.35774 .5279 L
.35766 .52776 L
.35758 .52762 L
.3575 .52749 L
.35742 .52735 L
.35734 .52721 L
.35727 .52707 L
.35719 .52694 L
.35711 .5268 L
.35703 .52666 L
.35695 .52652 L
.35687 .52639 L
.3568 .52625 L
.35672 .52611 L
.35664 .52597 L
.35657 .52583 L
.35649 .5257 L
.35641 .52556 L
.35634 .52542 L
.35626 .52528 L
.35618 .52514 L
.35611 .52501 L
.35603 .52487 L
Mistroke
.35596 .52473 L
.35589 .52459 L
.35581 .52445 L
.35574 .52431 L
.35566 .52417 L
.35559 .52403 L
.35552 .5239 L
.35544 .52376 L
.35537 .52362 L
.3553 .52348 L
.35522 .52334 L
.35515 .5232 L
.35508 .52306 L
.35501 .52292 L
.35494 .52278 L
.35487 .52264 L
.35479 .5225 L
.35472 .52236 L
.35465 .52222 L
.35458 .52208 L
.35451 .52194 L
.35444 .5218 L
.35437 .52166 L
.3543 .52152 L
.35423 .52138 L
.35417 .52124 L
.3541 .5211 L
.35403 .52096 L
.35396 .52082 L
.35389 .52068 L
.35382 .52054 L
.35376 .5204 L
.35369 .52026 L
.35362 .52012 L
.35356 .51998 L
.35349 .51983 L
.35342 .51969 L
.35336 .51955 L
.35329 .51941 L
.35323 .51927 L
.35316 .51913 L
.35309 .51899 L
.35303 .51885 L
.35297 .51871 L
.3529 .51856 L
.35284 .51842 L
.35277 .51828 L
.35271 .51814 L
.35264 .518 L
.35258 .51786 L
Mistroke
.35252 .51771 L
.35246 .51757 L
.35239 .51743 L
.35233 .51729 L
.35227 .51715 L
.35221 .517 L
.35214 .51686 L
.35208 .51672 L
.35202 .51658 L
.35196 .51644 L
.3519 .51629 L
.35184 .51615 L
.35178 .51601 L
.35172 .51587 L
.35166 .51572 L
.3516 .51558 L
.35154 .51544 L
.35148 .5153 L
.35142 .51515 L
.35136 .51501 L
.3513 .51487 L
.35124 .51473 L
.35119 .51458 L
.35113 .51444 L
.35107 .5143 L
.35101 .51415 L
.35095 .51401 L
.3509 .51387 L
.35084 .51373 L
.35078 .51358 L
.35073 .51344 L
.35067 .5133 L
.35061 .51315 L
.35056 .51301 L
.3505 .51287 L
.35045 .51272 L
.35039 .51258 L
.35034 .51244 L
.35028 .51229 L
.35023 .51215 L
.35017 .51201 L
.35012 .51186 L
.35007 .51172 L
.35001 .51158 L
.34996 .51143 L
.3499 .51129 L
.34985 .51114 L
.3498 .511 L
.34975 .51086 L
.34969 .51071 L
Mistroke
.34964 .51057 L
.34959 .51042 L
.34954 .51028 L
.34949 .51014 L
.34943 .50999 L
.34938 .50985 L
.34933 .5097 L
.34928 .50956 L
.34923 .50942 L
.34918 .50927 L
.34913 .50913 L
.34908 .50898 L
.34903 .50884 L
.34898 .50869 L
.34893 .50855 L
.34888 .50841 L
.34883 .50826 L
.34878 .50812 L
.34874 .50797 L
.34869 .50783 L
.34864 .50768 L
.34859 .50754 L
.34854 .50739 L
.3485 .50725 L
.34845 .5071 L
.3484 .50696 L
.34835 .50682 L
.34831 .50667 L
.34826 .50653 L
.34822 .50638 L
.34817 .50624 L
.34812 .50609 L
.34808 .50595 L
.34803 .5058 L
.34799 .50566 L
.34794 .50551 L
.3479 .50537 L
.34785 .50522 L
.34781 .50508 L
.34776 .50493 L
.34772 .50479 L
.34768 .50464 L
.34763 .5045 L
.34759 .50435 L
.34754 .50421 L
.3475 .50406 L
.34746 .50392 L
.34742 .50377 L
.34737 .50363 L
.34733 .50348 L
Mistroke
.34729 .50334 L
.34725 .50319 L
.34721 .50304 L
.34716 .5029 L
.34712 .50275 L
.34708 .50261 L
.34704 .50246 L
.347 .50232 L
.34696 .50217 L
.34692 .50203 L
.34688 .50188 L
.34684 .50174 L
.3468 .50159 L
.34676 .50145 L
.34672 .5013 L
.34668 .50115 L
.34664 .50101 L
.3466 .50086 L
.34656 .50072 L
.34653 .50057 L
.34649 .50043 L
.34645 .50028 L
.34641 .50014 L
.34637 .49999 L
.34634 .49984 L
.3463 .4997 L
.34626 .49955 L
.34622 .49941 L
.34619 .49926 L
.34615 .49912 L
.34611 .49897 L
.34608 .49883 L
.34604 .49868 L
.34601 .49853 L
.34597 .49839 L
.34594 .49824 L
.3459 .4981 L
.34586 .49795 L
.34583 .49781 L
.3458 .49766 L
.34576 .49751 L
.34573 .49737 L
.34569 .49722 L
.34566 .49708 L
.34562 .49693 L
.34559 .49679 L
.34556 .49664 L
.34552 .49649 L
.34549 .49635 L
.34546 .4962 L
Mistroke
.34543 .49606 L
.34539 .49591 L
.34536 .49576 L
.34533 .49562 L
.3453 .49547 L
.34526 .49533 L
.34523 .49518 L
.3452 .49504 L
.34517 .49489 L
.34514 .49474 L
.34511 .4946 L
.34508 .49445 L
.34505 .49431 L
.34502 .49416 L
.34499 .49402 L
.34496 .49387 L
.34493 .49372 L
.3449 .49358 L
.34487 .49343 L
.34484 .49329 L
.34481 .49314 L
.34478 .49299 L
.34475 .49285 L
.34472 .4927 L
.34469 .49256 L
.34467 .49241 L
.34464 .49227 L
.34461 .49212 L
.34458 .49197 L
.34455 .49183 L
.34453 .49168 L
.3445 .49154 L
.34447 .49139 L
.34445 .49124 L
.34442 .4911 L
.34439 .49095 L
.34437 .49081 L
.34434 .49066 L
.34431 .49052 L
.34429 .49037 L
.34426 .49022 L
.34424 .49008 L
.34421 .48993 L
.34419 .48979 L
.34416 .48964 L
.34414 .4895 L
.34411 .48935 L
.34409 .4892 L
.34406 .48906 L
.34404 .48891 L
Mistroke
.34401 .48877 L
.34399 .48862 L
.34397 .48848 L
.34394 .48833 L
.34392 .48818 L
.3439 .48804 L
.34387 .48789 L
.34385 .48775 L
.34383 .4876 L
.34381 .48746 L
.34378 .48731 L
.34376 .48717 L
.34374 .48702 L
.34372 .48687 L
.3437 .48673 L
.34367 .48658 L
.34365 .48644 L
.34363 .48629 L
.34361 .48615 L
.34359 .486 L
.34357 .48586 L
.34355 .48571 L
.34353 .48557 L
.34351 .48542 L
.34349 .48527 L
.34347 .48513 L
.34345 .48498 L
.34343 .48484 L
.34341 .48469 L
.34339 .48455 L
.34337 .4844 L
.34335 .48426 L
.34333 .48411 L
.34332 .48397 L
.3433 .48382 L
.34328 .48368 L
.34326 .48353 L
.34324 .48339 L
.34323 .48324 L
.34321 .4831 L
.34319 .48295 L
.34317 .48281 L
.34316 .48266 L
.34314 .48252 L
.34312 .48237 L
.3431 .48223 L
.34309 .48208 L
.34307 .48194 L
.34306 .48179 L
.34304 .48165 L
Mistroke
.34302 .4815 L
.34301 .48136 L
.34299 .48121 L
.34298 .48107 L
.34296 .48092 L
.34295 .48078 L
.34293 .48063 L
.34292 .48049 L
.3429 .48034 L
.34289 .4802 L
.34287 .48005 L
.34286 .47991 L
.34285 .47976 L
.34283 .47962 L
.34282 .47947 L
.3428 .47933 L
.34279 .47919 L
.34278 .47904 L
.34276 .4789 L
.34275 .47875 L
.34274 .47861 L
.34273 .47846 L
.34271 .47832 L
.3427 .47817 L
.34269 .47803 L
.34268 .47789 L
.34266 .47774 L
.34265 .4776 L
.34264 .47745 L
.34263 .47731 L
.34262 .47716 L
.34261 .47702 L
.3426 .47688 L
.34259 .47673 L
.34257 .47659 L
.34256 .47644 L
.34255 .4763 L
.34254 .47616 L
.34253 .47601 L
.34252 .47587 L
.34251 .47572 L
.3425 .47558 L
.34249 .47544 L
.34248 .47529 L
.34248 .47515 L
.34247 .475 L
.34246 .47486 L
.34245 .47472 L
.34244 .47457 L
.34243 .47443 L
Mistroke
.34242 .47429 L
.34241 .47414 L
.34241 .474 L
.3424 .47385 L
.34239 .47371 L
.34238 .47357 L
.34238 .47342 L
.34237 .47328 L
.34236 .47314 L
.34235 .47299 L
.34235 .47285 L
.34234 .47271 L
.34233 .47256 L
.34233 .47242 L
.34232 .47228 L
.34231 .47213 L
.34231 .47199 L
.3423 .47185 L
.3423 .47171 L
.34229 .47156 L
.34228 .47142 L
.34228 .47128 L
.34227 .47113 L
.34227 .47099 L
.34226 .47085 L
.34226 .4707 L
.34225 .47056 L
.34225 .47042 L
.34225 .47028 L
.34224 .47013 L
.34224 .46999 L
.34223 .46985 L
.34223 .46971 L
.34222 .46956 L
.34222 .46942 L
.34222 .46928 L
.34221 .46914 L
.34221 .46899 L
.34221 .46885 L
.34221 .46871 L
.3422 .46857 L
.3422 .46842 L
.3422 .46828 L
.34219 .46814 L
.34219 .468 L
.34219 .46786 L
.34219 .46771 L
.34219 .46757 L
.34218 .46743 L
.34218 .46729 L
Mistroke
.34218 .46715 L
.34218 .467 L
.34218 .46686 L
.34218 .46672 L
.34218 .46658 L
.34218 .46644 L
.34218 .4663 L
.34218 .46615 L
.34217 .46601 L
.34217 .46587 L
.34217 .46573 L
.34217 .46559 L
.34217 .46545 L
.34217 .4653 L
.34217 .46516 L
.34218 .46502 L
.34218 .46488 L
.34218 .46474 L
.34218 .4646 L
.34218 .46446 L
.34218 .46432 L
.34218 .46418 L
.34218 .46403 L
.34218 .46389 L
.34219 .46375 L
.34219 .46361 L
.34219 .46347 L
.34219 .46333 L
.34219 .46319 L
.3422 .46305 L
.3422 .46291 L
.3422 .46277 L
.3422 .46263 L
.34221 .46249 L
.34221 .46235 L
.34221 .4622 L
.34222 .46206 L
.34222 .46192 L
.34222 .46178 L
.34223 .46164 L
.34223 .4615 L
.34223 .46136 L
.34224 .46122 L
.34224 .46108 L
.34225 .46094 L
.34225 .4608 L
.34225 .46066 L
.34226 .46052 L
.34226 .46038 L
.34227 .46024 L
Mistroke
.34227 .4601 L
.34228 .45996 L
.34228 .45982 L
.34229 .45968 L
.34229 .45955 L
.3423 .45941 L
.34231 .45927 L
.34231 .45913 L
.34232 .45899 L
.34232 .45885 L
.34233 .45871 L
.34234 .45857 L
.34234 .45843 L
.34235 .45829 L
.34236 .45815 L
.34236 .45801 L
.34237 .45787 L
.34238 .45774 L
.34238 .4576 L
.34239 .45746 L
.3424 .45732 L
.34241 .45718 L
.34241 .45704 L
.34242 .4569 L
.34243 .45676 L
.34244 .45663 L
.34244 .45649 L
.34245 .45635 L
.34246 .45621 L
.34247 .45607 L
.34248 .45593 L
.34249 .45579 L
.3425 .45566 L
.3425 .45552 L
.34251 .45538 L
.34252 .45524 L
.34253 .4551 L
.34254 .45497 L
.34255 .45483 L
.34256 .45469 L
.34257 .45455 L
.34258 .45442 L
.34259 .45428 L
.3426 .45414 L
.34261 .454 L
.34262 .45386 L
.34263 .45373 L
.34264 .45359 L
.34265 .45345 L
.34266 .45332 L
Mistroke
.34267 .45318 L
.34268 .45304 L
.3427 .4529 L
.34271 .45277 L
.34272 .45263 L
.34273 .45249 L
.34274 .45236 L
.34275 .45222 L
.34276 .45208 L
.34278 .45194 L
.34279 .45181 L
.3428 .45167 L
.34281 .45153 L
.34282 .4514 L
.34284 .45126 L
.34285 .45113 L
.34286 .45099 L
.34287 .45085 L
.34289 .45072 L
.3429 .45058 L
.34291 .45044 L
.34293 .45031 L
.34294 .45017 L
.34295 .45004 L
.34297 .4499 L
.34298 .44976 L
.34299 .44963 L
.34301 .44949 L
.34302 .44936 L
.34304 .44922 L
.34305 .44909 L
.34306 .44895 L
.34308 .44881 L
.34309 .44868 L
.34311 .44854 L
.34312 .44841 L
.34314 .44827 L
.34315 .44814 L
.34317 .448 L
.34318 .44787 L
.3432 .44773 L
.34321 .4476 L
.34323 .44746 L
.34324 .44733 L
.34326 .44719 L
.34328 .44706 L
.34329 .44692 L
.34331 .44679 L
.34332 .44665 L
.34334 .44652 L
Mistroke
.34336 .44638 L
.34337 .44625 L
.34339 .44612 L
.34341 .44598 L
.34342 .44585 L
.34344 .44571 L
.34346 .44558 L
.34347 .44545 L
.34349 .44531 L
.34351 .44518 L
.34352 .44504 L
.34354 .44491 L
.34356 .44478 L
.34358 .44464 L
.3436 .44451 L
.34361 .44437 L
.34363 .44424 L
.34365 .44411 L
.34367 .44397 L
.34369 .44384 L
.3437 .44371 L
.34372 .44357 L
.34374 .44344 L
.34376 .44331 L
.34378 .44318 L
.3438 .44304 L
.34382 .44291 L
.34383 .44278 L
.34385 .44264 L
.34387 .44251 L
.34389 .44238 L
.34391 .44225 L
.34393 .44211 L
.34395 .44198 L
.34397 .44185 L
.34399 .44172 L
.34401 .44158 L
.34403 .44145 L
.34405 .44132 L
.34407 .44119 L
.34409 .44106 L
.34411 .44092 L
.34413 .44079 L
.34415 .44066 L
.34417 .44053 L
.34419 .4404 L
.34422 .44026 L
.34424 .44013 L
.34426 .44 L
.34428 .43987 L
Mistroke
.3443 .43974 L
.34432 .43961 L
.34434 .43948 L
.34436 .43934 L
.34439 .43921 L
.34441 .43908 L
.34443 .43895 L
.34445 .43882 L
.34447 .43869 L
.3445 .43856 L
.34452 .43843 L
.34454 .4383 L
.34456 .43817 L
.34459 .43804 L
.34461 .4379 L
.34463 .43777 L
.34465 .43764 L
.34468 .43751 L
.3447 .43738 L
.34472 .43725 L
.34475 .43712 L
.34477 .43699 L
.34479 .43686 L
.34482 .43673 L
.34484 .4366 L
.34486 .43647 L
.34489 .43634 L
.34491 .43621 L
.34494 .43608 L
.34496 .43595 L
.34498 .43582 L
.34501 .4357 L
.34503 .43557 L
.34506 .43544 L
.34508 .43531 L
.34511 .43518 L
.34513 .43505 L
.34516 .43492 L
.34518 .43479 L
.3452 .43466 L
.34523 .43453 L
.34526 .4344 L
.34528 .43428 L
.34531 .43415 L
.34533 .43402 L
.34536 .43389 L
.34538 .43376 L
.34541 .43363 L
.34543 .43351 L
.34546 .43338 L
Mistroke
.34549 .43325 L
.34551 .43312 L
.34554 .43299 L
.34556 .43286 L
.34559 .43274 L
.34562 .43261 L
.34564 .43248 L
.34567 .43235 L
.3457 .43223 L
.34572 .4321 L
.34575 .43197 L
.34578 .43184 L
.3458 .43172 L
.34583 .43159 L
.34586 .43146 L
.34588 .43133 L
.34591 .43121 L
.34594 .43108 L
.34597 .43095 L
.34599 .43083 L
.34602 .4307 L
.34605 .43057 L
.34608 .43045 L
.34611 .43032 L
.34613 .43019 L
.34616 .43007 L
.34619 .42994 L
.34622 .42981 L
.34625 .42969 L
.34627 .42956 L
.3463 .42944 L
.34633 .42931 L
.34636 .42918 L
.34639 .42906 L
.34642 .42893 L
.34645 .42881 L
.34648 .42868 L
.34651 .42855 L
.34653 .42843 L
.34656 .4283 L
.34659 .42818 L
.34662 .42805 L
.34665 .42793 L
.34668 .4278 L
.34671 .42768 L
.34674 .42755 L
.34677 .42743 L
.3468 .4273 L
.34683 .42718 L
.34686 .42705 L
Mistroke
.34689 .42693 L
.34692 .4268 L
.34695 .42668 L
.34698 .42655 L
.34701 .42643 L
.34704 .4263 L
.34707 .42618 L
.3471 .42606 L
.34713 .42593 L
.34717 .42581 L
.3472 .42568 L
.34723 .42556 L
.34726 .42544 L
.34729 .42531 L
.34732 .42519 L
.34735 .42506 L
.34738 .42494 L
.34742 .42482 L
.34745 .42469 L
.34748 .42457 L
.34751 .42445 L
.34754 .42432 L
.34757 .4242 L
.34761 .42408 L
.34764 .42396 L
.34767 .42383 L
.3477 .42371 L
.34773 .42359 L
.34777 .42346 L
.3478 .42334 L
.34783 .42322 L
.34786 .4231 L
.3479 .42297 L
.34793 .42285 L
.34796 .42273 L
.348 .42261 L
.34803 .42248 L
.34806 .42236 L
.34809 .42224 L
.34813 .42212 L
.34816 .422 L
.34819 .42187 L
.34823 .42175 L
.34826 .42163 L
.3483 .42151 L
.34833 .42139 L
.34836 .42127 L
.3484 .42115 L
.34843 .42102 L
.34846 .4209 L
Mistroke
.3485 .42078 L
.34853 .42066 L
.34857 .42054 L
.3486 .42042 L
.34864 .4203 L
.34867 .42018 L
.3487 .42006 L
.34874 .41994 L
.34877 .41981 L
.34881 .41969 L
.34884 .41957 L
.34888 .41945 L
.34891 .41933 L
.34895 .41921 L
.34898 .41909 L
.34902 .41897 L
.34905 .41885 L
.34909 .41873 L
.34912 .41861 L
.34916 .41849 L
.34919 .41837 L
.34923 .41825 L
.34927 .41813 L
.3493 .41801 L
.34934 .4179 L
.34937 .41778 L
.34941 .41766 L
.34944 .41754 L
.34948 .41742 L
.34952 .4173 L
.34955 .41718 L
.34959 .41706 L
.34963 .41694 L
.34966 .41682 L
.3497 .41671 L
.34973 .41659 L
.34977 .41647 L
.34981 .41635 L
.34984 .41623 L
.34988 .41611 L
.34992 .416 L
.34996 .41588 L
.34999 .41576 L
.35003 .41564 L
.35007 .41552 L
.3501 .41541 L
.35014 .41529 L
.35018 .41517 L
.35022 .41505 L
.35025 .41493 L
Mistroke
.35029 .41482 L
.35033 .4147 L
.35037 .41458 L
.3504 .41447 L
.35044 .41435 L
.35048 .41423 L
.35052 .41411 L
.35056 .414 L
.35059 .41388 L
.35063 .41376 L
.35067 .41365 L
.35071 .41353 L
.35075 .41341 L
.35079 .4133 L
.35082 .41318 L
.35086 .41306 L
.3509 .41295 L
.35094 .41283 L
.35098 .41272 L
.35102 .4126 L
.35106 .41248 L
.3511 .41237 L
.35113 .41225 L
.35117 .41214 L
.35121 .41202 L
.35125 .4119 L
.35129 .41179 L
.35133 .41167 L
.35137 .41156 L
.35141 .41144 L
.35145 .41133 L
.35149 .41121 L
.35153 .4111 L
.35157 .41098 L
.35161 .41087 L
.35165 .41075 L
.35169 .41064 L
.35173 .41052 L
.35177 .41041 L
.35181 .41029 L
.35185 .41018 L
.35189 .41007 L
.35193 .40995 L
.35197 .40984 L
.35201 .40972 L
.35205 .40961 L
.35209 .40949 L
.35213 .40938 L
.35217 .40927 L
.35221 .40915 L
Mistroke
.35225 .40904 L
.35229 .40893 L
.35233 .40881 L
.35238 .4087 L
.35242 .40859 L
.35246 .40847 L
.3525 .40836 L
.35254 .40825 L
.35258 .40813 L
.35262 .40802 L
.35266 .40791 L
.35271 .40779 L
.35275 .40768 L
.35279 .40757 L
.35283 .40746 L
.35287 .40734 L
.35291 .40723 L
.35296 .40712 L
.353 .40701 L
.35304 .40689 L
.35308 .40678 L
.35312 .40667 L
.35317 .40656 L
.35321 .40645 L
.35325 .40633 L
.35329 .40622 L
.35333 .40611 L
.35338 .406 L
.35342 .40589 L
.35346 .40578 L
.3535 .40566 L
.35355 .40555 L
.35359 .40544 L
.35363 .40533 L
.35367 .40522 L
.35372 .40511 L
.35376 .405 L
.3538 .40489 L
.35385 .40478 L
.35389 .40467 L
.35393 .40455 L
.35398 .40444 L
.35402 .40433 L
.35406 .40422 L
.35411 .40411 L
.35415 .404 L
.35419 .40389 L
.35424 .40378 L
.35428 .40367 L
.35432 .40356 L
Mistroke
.35437 .40345 L
.35441 .40334 L
.35446 .40323 L
.3545 .40312 L
.35454 .40301 L
.35459 .4029 L
.35463 .4028 L
.35468 .40269 L
.35472 .40258 L
.35476 .40247 L
.35481 .40236 L
.35485 .40225 L
.3549 .40214 L
.35494 .40203 L
.35499 .40192 L
.35503 .40181 L
.35507 .40171 L
.35512 .4016 L
.35516 .40149 L
.35521 .40138 L
.35525 .40127 L
.3553 .40116 L
.35534 .40106 L
.35539 .40095 L
.35543 .40084 L
.35548 .40073 L
.35552 .40062 L
.35557 .40052 L
.35561 .40041 L
.35566 .4003 L
.3557 .40019 L
.35575 .40009 L
.3558 .39998 L
.35584 .39987 L
.35589 .39976 L
.35593 .39966 L
.35598 .39955 L
.35602 .39944 L
.35607 .39934 L
.35611 .39923 L
.35616 .39912 L
.35621 .39902 L
.35625 .39891 L
.3563 .3988 L
.35634 .3987 L
.35639 .39859 L
.35644 .39848 L
.35648 .39838 L
.35653 .39827 L
.35658 .39816 L
Mistroke
.35662 .39806 L
.35667 .39795 L
.35671 .39785 L
.35676 .39774 L
.35681 .39764 L
.35685 .39753 L
.3569 .39742 L
.35695 .39732 L
.35699 .39721 L
.35704 .39711 L
.35709 .397 L
.35714 .3969 L
.35718 .39679 L
.35723 .39669 L
.35728 .39658 L
.35732 .39648 L
.35737 .39637 L
.35742 .39627 L
.35746 .39616 L
.35751 .39606 L
.35756 .39596 L
.35761 .39585 L
.35765 .39575 L
.3577 .39564 L
.35775 .39554 L
.3578 .39543 L
.35784 .39533 L
.35789 .39523 L
.35794 .39512 L
.35799 .39502 L
.35804 .39492 L
.35808 .39481 L
.35813 .39471 L
.35818 .39461 L
.35823 .3945 L
.35828 .3944 L
.35832 .3943 L
.35837 .39419 L
.35842 .39409 L
.35847 .39399 L
.35852 .39388 L
.35856 .39378 L
.35861 .39368 L
.35866 .39358 L
.35871 .39347 L
.35876 .39337 L
.35881 .39327 L
.35886 .39317 L
.3589 .39306 L
.35895 .39296 L
Mistroke
.359 .39286 L
.35905 .39276 L
.3591 .39266 L
.35915 .39255 L
.3592 .39245 L
.35925 .39235 L
.35929 .39225 L
.35934 .39215 L
.35939 .39205 L
.35944 .39194 L
.35949 .39184 L
.35954 .39174 L
.35959 .39164 L
.35964 .39154 L
.35969 .39144 L
.35974 .39134 L
.35979 .39124 L
.35984 .39114 L
.35989 .39104 L
.35994 .39094 L
.35999 .39083 L
.36004 .39073 L
.36009 .39063 L
.36013 .39053 L
.36018 .39043 L
.36023 .39033 L
.36028 .39023 L
.36033 .39013 L
.36038 .39003 L
.36043 .38993 L
.36048 .38983 L
.36053 .38973 L
.36058 .38964 L
.36063 .38954 L
.36068 .38944 L
.36074 .38934 L
.36079 .38924 L
.36084 .38914 L
.36089 .38904 L
.36094 .38894 L
.36099 .38884 L
.36104 .38874 L
.36109 .38864 L
.36114 .38855 L
.36119 .38845 L
.36124 .38835 L
.36129 .38825 L
.36134 .38815 L
.36139 .38805 L
.36144 .38795 L
Mistroke
.36149 .38786 L
.36155 .38776 L
.3616 .38766 L
.36165 .38756 L
.3617 .38746 L
.36175 .38737 L
.3618 .38727 L
.36185 .38717 L
.3619 .38707 L
.36195 .38698 L
.36201 .38688 L
.36206 .38678 L
.36211 .38668 L
.36216 .38659 L
.36221 .38649 L
.36226 .38639 L
.36231 .3863 L
.36237 .3862 L
.36242 .3861 L
.36247 .38601 L
.36252 .38591 L
.36257 .38581 L
.36262 .38572 L
.36268 .38562 L
.36273 .38552 L
.36278 .38543 L
.36283 .38533 L
.36288 .38524 L
.36293 .38514 L
.36299 .38504 L
.36304 .38495 L
.36309 .38485 L
.36314 .38476 L
.3632 .38466 L
.36325 .38457 L
.3633 .38447 L
.36335 .38438 L
.3634 .38428 L
.36346 .38419 L
.36351 .38409 L
.36356 .384 L
.36361 .3839 L
.36367 .38381 L
.36372 .38371 L
.36377 .38362 L
.36382 .38352 L
.36388 .38343 L
.36393 .38333 L
.36398 .38324 L
.36403 .38314 L
Mistroke
.36409 .38305 L
.36414 .38296 L
.36419 .38286 L
.36425 .38277 L
.3643 .38267 L
.36435 .38258 L
.3644 .38249 L
.36446 .38239 L
.36451 .3823 L
.36456 .3822 L
.36462 .38211 L
.36467 .38202 L
.36472 .38192 L
.36478 .38183 L
.36483 .38174 L
.36488 .38165 L
.36494 .38155 L
.36499 .38146 L
.36504 .38137 L
.3651 .38127 L
.36515 .38118 L
.3652 .38109 L
.36526 .381 L
.36531 .3809 L
.36536 .38081 L
.36542 .38072 L
.36547 .38063 L
.36553 .38053 L
.36558 .38044 L
.36563 .38035 L
.36569 .38026 L
.36574 .38017 L
.36579 .38008 L
.36585 .37998 L
.3659 .37989 L
.36596 .3798 L
.36601 .37971 L
.36606 .37962 L
.36612 .37953 L
.36617 .37944 L
.36623 .37934 L
.36628 .37925 L
.36634 .37916 L
.36639 .37907 L
.36644 .37898 L
.3665 .37889 L
.36655 .3788 L
.36661 .37871 L
.36666 .37862 L
.36672 .37853 L
Mistroke
.36677 .37844 L
.36682 .37835 L
.36688 .37826 L
.36693 .37817 L
.36699 .37808 L
.36704 .37799 L
.3671 .3779 L
.36715 .37781 L
.36721 .37772 L
.36726 .37763 L
.36732 .37754 L
.36737 .37745 L
.36743 .37736 L
.36748 .37727 L
.36754 .37718 L
.36759 .37709 L
.36765 .377 L
.3677 .37691 L
.36776 .37683 L
.36781 .37674 L
.36787 .37665 L
.36792 .37656 L
.36798 .37647 L
.36803 .37638 L
.36809 .37629 L
.36814 .3762 L
.3682 .37612 L
.36825 .37603 L
.36831 .37594 L
.36836 .37585 L
.36842 .37576 L
.36847 .37568 L
.36853 .37559 L
.36858 .3755 L
.36864 .37541 L
.3687 .37533 L
.36875 .37524 L
.36881 .37515 L
.36886 .37506 L
.36892 .37498 L
.36897 .37489 L
.36903 .3748 L
.36908 .37471 L
.36914 .37463 L
.3692 .37454 L
.36925 .37445 L
.36931 .37437 L
.36936 .37428 L
.36942 .37419 L
.36948 .37411 L
Mistroke
.36953 .37402 L
.36959 .37393 L
.36964 .37385 L
.3697 .37376 L
.36975 .37368 L
.36981 .37359 L
.36987 .3735 L
.36992 .37342 L
.36998 .37333 L
.37004 .37325 L
.37009 .37316 L
.37015 .37307 L
.3702 .37299 L
.37026 .3729 L
.37032 .37282 L
.37037 .37273 L
.37043 .37265 L
.37049 .37256 L
.37054 .37248 L
.3706 .37239 L
.37066 .37231 L
.37071 .37222 L
.37077 .37214 L
.37082 .37205 L
.37088 .37197 L
.37094 .37188 L
.37099 .3718 L
.37105 .37172 L
.37111 .37163 L
.37116 .37155 L
.37122 .37146 L
.37128 .37138 L
.37133 .37129 L
.37139 .37121 L
.37145 .37113 L
.3715 .37104 L
.37156 .37096 L
.37162 .37088 L
.37168 .37079 L
.37173 .37071 L
.37179 .37063 L
.37185 .37054 L
.3719 .37046 L
.37196 .37038 L
.37202 .37029 L
.37207 .37021 L
.37213 .37013 L
.37219 .37004 L
.37225 .36996 L
.3723 .36988 L
Mistroke
.37236 .3698 L
.37242 .36971 L
.37247 .36963 L
.37253 .36955 L
.37259 .36947 L
.37265 .36938 L
.3727 .3693 L
.37276 .36922 L
.37282 .36914 L
.37288 .36906 L
.37293 .36897 L
.37299 .36889 L
.37305 .36881 L
.37311 .36873 L
.37316 .36865 L
.37322 .36857 L
.37328 .36849 L
.37334 .3684 L
.37339 .36832 L
.37345 .36824 L
.37351 .36816 L
.37357 .36808 L
.37362 .368 L
.37368 .36792 L
.37374 .36784 L
.3738 .36776 L
.37385 .36768 L
.37391 .36759 L
.37397 .36751 L
.37403 .36743 L
.37409 .36735 L
.37414 .36727 L
.3742 .36719 L
.37426 .36711 L
.37432 .36703 L
.37438 .36695 L
.37443 .36687 L
.37449 .36679 L
.37455 .36671 L
.37461 .36663 L
.37467 .36655 L
.37472 .36648 L
.37478 .3664 L
.37484 .36632 L
.3749 .36624 L
.37496 .36616 L
.37501 .36608 L
.37507 .366 L
.37513 .36592 L
.37519 .36584 L
Mistroke
.37525 .36576 L
.37531 .36568 L
.37536 .36561 L
.37542 .36553 L
.37548 .36545 L
.37554 .36537 L
.3756 .36529 L
.37566 .36521 L
.37571 .36514 L
.37577 .36506 L
.37583 .36498 L
.37589 .3649 L
.37595 .36482 L
.37601 .36475 L
.37607 .36467 L
.37612 .36459 L
.37618 .36451 L
.37624 .36444 L
.3763 .36436 L
.37636 .36428 L
.37642 .3642 L
.37648 .36413 L
.37653 .36405 L
.37659 .36397 L
.37665 .36389 L
.37671 .36382 L
.37677 .36374 L
.37683 .36366 L
.37689 .36359 L
.37695 .36351 L
.377 .36343 L
.37706 .36336 L
.37712 .36328 L
.37718 .36321 L
.37724 .36313 L
.3773 .36305 L
.37736 .36298 L
.37742 .3629 L
.37748 .36282 L
.37753 .36275 L
.37759 .36267 L
.37765 .3626 L
.37771 .36252 L
.37777 .36245 L
.37783 .36237 L
.37789 .3623 L
.37795 .36222 L
.37801 .36214 L
.37807 .36207 L
.37813 .36199 L
Mistroke
.37818 .36192 L
.37824 .36184 L
.3783 .36177 L
.37836 .36169 L
.37842 .36162 L
.37848 .36155 L
.37854 .36147 L
.3786 .3614 L
.37866 .36132 L
.37872 .36125 L
.37878 .36117 L
.37884 .3611 L
.3789 .36102 L
.37895 .36095 L
.37901 .36088 L
.37907 .3608 L
.37913 .36073 L
.37919 .36065 L
.37925 .36058 L
.37931 .36051 L
.37937 .36043 L
.37943 .36036 L
.37949 .36029 L
.37955 .36021 L
.37961 .36014 L
.37967 .36007 L
.37973 .35999 L
.37979 .35992 L
.37985 .35985 L
.37991 .35978 L
.37997 .3597 L
.38003 .35963 L
.38009 .35956 L
.38015 .35948 L
.3802 .35941 L
.38026 .35934 L
.38032 .35927 L
.38038 .35919 L
.38044 .35912 L
.3805 .35905 L
.38056 .35898 L
.38062 .35891 L
.38068 .35883 L
.38074 .35876 L
.3808 .35869 L
.38086 .35862 L
.38092 .35855 L
.38098 .35848 L
.38104 .3584 L
.3811 .35833 L
Mistroke
.38116 .35826 L
.38122 .35819 L
.38128 .35812 L
.38134 .35805 L
.3814 .35798 L
.38146 .35791 L
.38152 .35783 L
.38158 .35776 L
.38164 .35769 L
.3817 .35762 L
.38176 .35755 L
.38182 .35748 L
.38188 .35741 L
.38194 .35734 L
.382 .35727 L
.38206 .3572 L
.38212 .35713 L
.38218 .35706 L
.38224 .35699 L
.3823 .35692 L
.38236 .35685 L
.38242 .35678 L
.38248 .35671 L
.38254 .35664 L
.3826 .35657 L
.38266 .3565 L
.38272 .35643 L
.38278 .35636 L
.38284 .35629 L
.3829 .35622 L
.38296 .35615 L
.38302 .35609 L
.38308 .35602 L
.38314 .35595 L
.3832 .35588 L
.38326 .35581 L
.38332 .35574 L
.38338 .35567 L
.38345 .3556 L
.38351 .35554 L
.38357 .35547 L
.38363 .3554 L
.38369 .35533 L
.38375 .35526 L
.38381 .35519 L
.38387 .35513 L
.38393 .35506 L
.38399 .35499 L
.38405 .35492 L
.38411 .35485 L
Mistroke
.38417 .35479 L
.38423 .35472 L
.38429 .35465 L
.38435 .35458 L
.38441 .35452 L
.38447 .35445 L
.38453 .35438 L
.38459 .35431 L
.38465 .35425 L
.38471 .35418 L
.38477 .35411 L
.38484 .35405 L
.3849 .35398 L
.38496 .35391 L
.38502 .35385 L
.38508 .35378 L
.38514 .35371 L
.3852 .35365 L
.38526 .35358 L
.38532 .35351 L
.38538 .35345 L
.38544 .35338 L
.3855 .35332 L
.38556 .35325 L
.38562 .35318 L
.38568 .35312 L
.38574 .35305 L
.3858 .35299 L
.38587 .35292 L
.38593 .35285 L
.38599 .35279 L
.38605 .35272 L
.38611 .35266 L
.38617 .35259 L
.38623 .35253 L
.38629 .35246 L
.38635 .3524 L
.38641 .35233 L
.38647 .35227 L
.38653 .3522 L
.38659 .35214 L
.38666 .35207 L
.38672 .35201 L
.38678 .35194 L
.38684 .35188 L
.3869 .35181 L
.38696 .35175 L
.38702 .35169 L
.38708 .35162 L
.38714 .35156 L
Mistroke
.3872 .35149 L
.38726 .35143 L
.38732 .35136 L
.38738 .3513 L
.38745 .35124 L
.38751 .35117 L
.38757 .35111 L
.38763 .35105 L
.38769 .35098 L
.38775 .35092 L
.38781 .35086 L
.38787 .35079 L
.38793 .35073 L
.38799 .35067 L
.38805 .3506 L
.38812 .35054 L
.38818 .35048 L
.38824 .35041 L
.3883 .35035 L
.38836 .35029 L
.38842 .35023 L
.38848 .35016 L
.38854 .3501 L
.3886 .35004 L
.38866 .34998 L
.38873 .34991 L
.38879 .34985 L
.38885 .34979 L
.38891 .34973 L
.38897 .34966 L
.38903 .3496 L
.38909 .34954 L
.38915 .34948 L
.38921 .34942 L
.38927 .34935 L
.38934 .34929 L
.3894 .34923 L
.38946 .34917 L
.38952 .34911 L
.38958 .34905 L
.38964 .34899 L
.3897 .34892 L
.38976 .34886 L
.38982 .3488 L
.38988 .34874 L
.38995 .34868 L
.39001 .34862 L
.39007 .34856 L
.39013 .3485 L
.39019 .34844 L
Mistroke
.39025 .34838 L
.39031 .34832 L
.39037 .34826 L
.39043 .34819 L
.3905 .34813 L
.39056 .34807 L
.39062 .34801 L
.39068 .34795 L
.39074 .34789 L
.3908 .34783 L
.39086 .34777 L
.39092 .34771 L
.39098 .34765 L
.39105 .34759 L
.39111 .34753 L
.39117 .34748 L
.39123 .34742 L
.39129 .34736 L
.39135 .3473 L
.39141 .34724 L
.39147 .34718 L
.39153 .34712 L
.3916 .34706 L
.39166 .347 L
.39172 .34694 L
.39178 .34688 L
.39184 .34682 L
.3919 .34677 L
.39196 .34671 L
.39202 .34665 L
.39208 .34659 L
.39215 .34653 L
.39221 .34647 L
.39227 .34641 L
.39233 .34636 L
.39239 .3463 L
.39245 .34624 L
.39251 .34618 L
.39257 .34612 L
.39264 .34607 L
.3927 .34601 L
.39276 .34595 L
.39282 .34589 L
.39288 .34584 L
.39294 .34578 L
.393 .34572 L
.39306 .34566 L
.39312 .34561 L
.39319 .34555 L
.39325 .34549 L
Mistroke
.39331 .34543 L
.39337 .34538 L
.39343 .34532 L
.39349 .34526 L
.39355 .34521 L
.39361 .34515 L
.39368 .34509 L
.39374 .34504 L
.3938 .34498 L
.39386 .34492 L
.39392 .34487 L
.39398 .34481 L
.39404 .34475 L
.3941 .3447 L
.39417 .34464 L
.39423 .34458 L
.39429 .34453 L
.39435 .34447 L
.39441 .34442 L
.39447 .34436 L
.39453 .3443 L
.39459 .34425 L
.39465 .34419 L
.39472 .34414 L
.39478 .34408 L
.39484 .34403 L
.3949 .34397 L
.39496 .34392 L
.39502 .34386 L
.39508 .34381 L
.39514 .34375 L
.39521 .34369 L
.39527 .34364 L
.39533 .34359 L
.39539 .34353 L
.39545 .34348 L
.39551 .34342 L
.39557 .34337 L
.39563 .34331 L
.39569 .34326 L
.39576 .3432 L
.39582 .34315 L
.39588 .34309 L
.39594 .34304 L
.396 .34299 L
.39606 .34293 L
.39612 .34288 L
.39618 .34282 L
.39625 .34277 L
.39631 .34272 L
Mistroke
.39637 .34266 L
.39643 .34261 L
.39649 .34255 L
.39655 .3425 L
.39661 .34245 L
.39667 .34239 L
.39673 .34234 L
.3968 .34229 L
.39686 .34223 L
.39692 .34218 L
.39698 .34213 L
.39704 .34207 L
.3971 .34202 L
.39716 .34197 L
.39722 .34192 L
.39728 .34186 L
.39735 .34181 L
.39741 .34176 L
.39747 .3417 L
.39753 .34165 L
.39759 .3416 L
.39765 .34155 L
.39771 .34149 L
.39777 .34144 L
.39784 .34139 L
.3979 .34134 L
.39796 .34129 L
.39802 .34123 L
.39808 .34118 L
.39814 .34113 L
.3982 .34108 L
.39826 .34103 L
.39832 .34097 L
.39838 .34092 L
.39845 .34087 L
.39851 .34082 L
.39857 .34077 L
.39863 .34072 L
.39869 .34067 L
.39875 .34062 L
.39881 .34056 L
.39887 .34051 L
.39893 .34046 L
.399 .34041 L
.39906 .34036 L
.39912 .34031 L
.39918 .34026 L
.39924 .34021 L
.3993 .34016 L
.39936 .34011 L
Mistroke
.39942 .34006 L
.39948 .34001 L
.39954 .33996 L
.39961 .3399 L
.39967 .33985 L
.39973 .3398 L
.39979 .33975 L
.39985 .3397 L
.39991 .33965 L
.39997 .3396 L
.40003 .33955 L
.40009 .3395 L
.40015 .33946 L
.40022 .33941 L
.40028 .33936 L
.40034 .33931 L
.4004 .33926 L
.40046 .33921 L
.40052 .33916 L
.40058 .33911 L
.40064 .33906 L
.4007 .33901 L
.40076 .33896 L
.40082 .33891 L
.40089 .33886 L
.40095 .33881 L
.40101 .33877 L
.40107 .33872 L
.40113 .33867 L
.40119 .33862 L
.40125 .33857 L
.40131 .33852 L
.40137 .33847 L
.40143 .33843 L
.40149 .33838 L
.40155 .33833 L
.40162 .33828 L
.40168 .33823 L
.40174 .33819 L
.4018 .33814 L
.40186 .33809 L
.40192 .33804 L
.40198 .33799 L
.40204 .33795 L
.4021 .3379 L
.40216 .33785 L
.40222 .3378 L
.40228 .33776 L
.40234 .33771 L
.40241 .33766 L
Mistroke
.40247 .33761 L
.40253 .33757 L
.40259 .33752 L
.40265 .33747 L
.40271 .33743 L
.40277 .33738 L
.40283 .33733 L
.40289 .33728 L
.40295 .33724 L
.40301 .33719 L
.40307 .33714 L
.40313 .3371 L
.40319 .33705 L
.40325 .33701 L
.40332 .33696 L
.40338 .33691 L
.40344 .33687 L
.4035 .33682 L
.40356 .33677 L
.40362 .33673 L
.40368 .33668 L
.40374 .33664 L
.4038 .33659 L
.40386 .33654 L
.40392 .3365 L
.40398 .33645 L
.40404 .33641 L
.4041 .33636 L
.40416 .33632 L
.40422 .33627 L
.40428 .33623 L
.40434 .33618 L
.4044 .33613 L
.40447 .33609 L
.40453 .33604 L
.40459 .336 L
.40465 .33595 L
.40471 .33591 L
.40477 .33586 L
.40483 .33582 L
.40489 .33578 L
.40495 .33573 L
.40501 .33569 L
.40507 .33564 L
.40513 .3356 L
.40519 .33555 L
.40525 .33551 L
.40531 .33546 L
.40537 .33542 L
.40543 .33538 L
Mistroke
.40549 .33533 L
.40555 .33529 L
.40561 .33524 L
.40567 .3352 L
.40573 .33516 L
.40579 .33511 L
.40585 .33507 L
.40591 .33502 L
.40597 .33498 L
.40603 .33494 L
.40609 .33489 L
.40615 .33485 L
.40622 .33481 L
.40628 .33476 L
.40634 .33472 L
.4064 .33468 L
.40646 .33463 L
.40652 .33459 L
.40658 .33455 L
.40664 .33451 L
.4067 .33446 L
.40676 .33442 L
.40682 .33438 L
.40688 .33433 L
.40694 .33429 L
.407 .33425 L
.40706 .33421 L
.40712 .33416 L
.40718 .33412 L
.40724 .33408 L
.4073 .33404 L
.40736 .33399 L
.40742 .33395 L
.40748 .33391 L
.40754 .33387 L
.4076 .33383 L
.40766 .33378 L
.40772 .33374 L
.40778 .3337 L
.40784 .33366 L
.4079 .33362 L
.40796 .33358 L
.40802 .33353 L
.40808 .33349 L
.40814 .33345 L
.4082 .33341 L
.40826 .33337 L
.40832 .33333 L
.40838 .33329 L
.40844 .33325 L
Mistroke
.4085 .3332 L
.40855 .33316 L
.40861 .33312 L
.40867 .33308 L
.40873 .33304 L
.40879 .333 L
.40885 .33296 L
.40891 .33292 L
.40897 .33288 L
.40903 .33284 L
.40909 .3328 L
.40915 .33276 L
.40921 .33272 L
.40927 .33268 L
.40933 .33264 L
.40939 .3326 L
.40945 .33256 L
.40951 .33252 L
.40957 .33248 L
.40963 .33244 L
.40969 .3324 L
.40975 .33236 L
.40981 .33232 L
.40987 .33228 L
.40993 .33224 L
.40999 .3322 L
.41005 .33216 L
.41011 .33212 L
.41016 .33208 L
.41022 .33204 L
.41028 .332 L
.41034 .33196 L
.4104 .33192 L
.41046 .33188 L
.41052 .33185 L
.41058 .33181 L
.41064 .33177 L
.4107 .33173 L
.41076 .33169 L
.41082 .33165 L
.41088 .33161 L
.41094 .33157 L
.411 .33154 L
.41106 .3315 L
.41111 .33146 L
.41117 .33142 L
.41123 .33138 L
.41129 .33134 L
.41135 .33131 L
.41141 .33127 L
Mistroke
.41147 .33123 L
.41153 .33119 L
.41159 .33115 L
.41165 .33112 L
.41171 .33108 L
.41177 .33104 L
.41182 .331 L
.41188 .33097 L
.41194 .33093 L
.412 .33089 L
.41206 .33085 L
.41212 .33082 L
.41218 .33078 L
.41224 .33074 L
.4123 .3307 L
.41236 .33067 L
.41241 .33063 L
.41247 .33059 L
.41253 .33056 L
.41259 .33052 L
.41265 .33048 L
.41271 .33044 L
.41277 .33041 L
.41283 .33037 L
.41289 .33033 L
.41294 .3303 L
.413 .33026 L
.41306 .33023 L
.41312 .33019 L
.41318 .33015 L
.41324 .33012 L
.4133 .33008 L
.41336 .33004 L
.41341 .33001 L
.41347 .32997 L
.41353 .32994 L
.41359 .3299 L
.41365 .32986 L
.41371 .32983 L
.41377 .32979 L
.41383 .32976 L
.41388 .32972 L
.41394 .32969 L
.414 .32965 L
.41406 .32961 L
.41412 .32958 L
.41418 .32954 L
.41424 .32951 L
.41429 .32947 L
.41435 .32944 L
Mistroke
.41441 .3294 L
.41447 .32937 L
.41453 .32933 L
.41459 .3293 L
.41464 .32926 L
.4147 .32923 L
.41476 .32919 L
.41482 .32916 L
.41488 .32912 L
.41494 .32909 L
.41499 .32906 L
.41505 .32902 L
.41511 .32899 L
.41517 .32895 L
.41523 .32892 L
.41529 .32888 L
.41534 .32885 L
.4154 .32881 L
.41546 .32878 L
.41552 .32875 L
.41558 .32871 L
.41563 .32868 L
.41569 .32865 L
.41575 .32861 L
.41581 .32858 L
.41587 .32854 L
.41592 .32851 L
.41598 .32848 L
.41604 .32844 L
.4161 .32841 L
.41616 .32838 L
.41621 .32834 L
.41627 .32831 L
.41633 .32828 L
.41639 .32824 L
.41645 .32821 L
.4165 .32818 L
.41656 .32814 L
.41662 .32811 L
.41668 .32808 L
.41674 .32805 L
.41679 .32801 L
.41685 .32798 L
.41691 .32795 L
.41697 .32791 L
.41702 .32788 L
.41708 .32785 L
.41714 .32782 L
.4172 .32779 L
.41726 .32775 L
Mistroke
.41731 .32772 L
.41737 .32769 L
.41743 .32766 L
.41749 .32762 L
.41754 .32759 L
.4176 .32756 L
.41766 .32753 L
.41772 .3275 L
.41777 .32746 L
.41783 .32743 L
.41789 .3274 L
.41795 .32737 L
.418 .32734 L
.41806 .32731 L
.41812 .32727 L
.41818 .32724 L
.41823 .32721 L
.41829 .32718 L
.41835 .32715 L
.4184 .32712 L
.41846 .32709 L
.41852 .32706 L
.41858 .32702 L
.41863 .32699 L
.41869 .32696 L
.41875 .32693 L
.4188 .3269 L
.41886 .32687 L
.41892 .32684 L
.41898 .32681 L
.41903 .32678 L
.41909 .32675 L
.41915 .32672 L
.4192 .32669 L
.41926 .32666 L
.41932 .32663 L
.41938 .3266 L
.41943 .32657 L
.41949 .32654 L
.41955 .32651 L
.4196 .32648 L
.41966 .32645 L
.41972 .32642 L
.41977 .32639 L
.41983 .32636 L
.41989 .32633 L
.41994 .3263 L
.42 .32627 L
.42006 .32624 L
.42011 .32621 L
Mistroke
.42017 .32618 L
.42023 .32615 L
.42028 .32612 L
.42034 .32609 L
.4204 .32606 L
.42045 .32603 L
.42051 .326 L
.42057 .32597 L
.42062 .32594 L
.42068 .32592 L
.42074 .32589 L
.42079 .32586 L
.42085 .32583 L
.42091 .3258 L
.42096 .32577 L
.42102 .32574 L
.42108 .32571 L
.42113 .32569 L
.42119 .32566 L
.42125 .32563 L
.4213 .3256 L
.42136 .32557 L
.42141 .32554 L
.42147 .32552 L
.42153 .32549 L
.42158 .32546 L
.42164 .32543 L
.4217 .3254 L
.42175 .32537 L
.42181 .32535 L
.42186 .32532 L
.42192 .32529 L
.42198 .32526 L
.42203 .32524 L
.42209 .32521 L
.42214 .32518 L
.4222 .32515 L
.42226 .32513 L
.42231 .3251 L
.42237 .32507 L
.42242 .32504 L
.42248 .32502 L
.42254 .32499 L
.42259 .32496 L
.42265 .32493 L
.4227 .32491 L
.42276 .32488 L
.42281 .32485 L
.42287 .32483 L
.42293 .3248 L
Mistroke
.42298 .32477 L
.42304 .32475 L
.42309 .32472 L
.42315 .32469 L
.4232 .32467 L
.42326 .32464 L
.42332 .32461 L
.42337 .32459 L
.42343 .32456 L
.42348 .32453 L
.42354 .32451 L
.42359 .32448 L
.42365 .32446 L
.4237 .32443 L
.42376 .3244 L
.42381 .32438 L
.42387 .32435 L
.42393 .32433 L
.42398 .3243 L
.42404 .32427 L
.42409 .32425 L
.42415 .32422 L
.4242 .3242 L
.42426 .32417 L
.42431 .32415 L
.42437 .32412 L
.42442 .32409 L
.42448 .32407 L
.42453 .32404 L
.42459 .32402 L
.42464 .32399 L
.4247 .32397 L
.42475 .32394 L
.42481 .32392 L
.42486 .32389 L
.42492 .32387 L
.42497 .32384 L
.42503 .32382 L
.42508 .32379 L
.42514 .32377 L
.42519 .32374 L
.42525 .32372 L
.4253 .32369 L
.42536 .32367 L
.42541 .32365 L
.42547 .32362 L
.42552 .3236 L
.42558 .32357 L
.42563 .32355 L
.42569 .32352 L
Mistroke
.42574 .3235 L
.42579 .32348 L
.42585 .32345 L
.4259 .32343 L
.42596 .3234 L
.42601 .32338 L
.42607 .32336 L
.42612 .32333 L
.42618 .32331 L
.42623 .32328 L
.42628 .32326 L
.42634 .32324 L
.42639 .32321 L
.42645 .32319 L
.4265 .32317 L
.42656 .32314 L
.42661 .32312 L
.42667 .3231 L
.42672 .32307 L
.42677 .32305 L
.42683 .32303 L
.42688 .323 L
.42694 .32298 L
.42699 .32296 L
.42704 .32293 L
.4271 .32291 L
.42715 .32289 L
.42721 .32287 L
.42726 .32284 L
.42731 .32282 L
.42737 .3228 L
.42742 .32278 L
.42748 .32275 L
.42753 .32273 L
.42758 .32271 L
.42764 .32269 L
.42769 .32266 L
.42774 .32264 L
.4278 .32262 L
.42785 .3226 L
.42791 .32257 L
.42796 .32255 L
.42801 .32253 L
.42807 .32251 L
.42812 .32249 L
.42817 .32246 L
.42823 .32244 L
.42828 .32242 L
.42833 .3224 L
.42839 .32238 L
Mistroke
.42844 .32236 L
.4285 .32233 L
.42855 .32231 L
.4286 .32229 L
.42866 .32227 L
.42871 .32225 L
.42876 .32223 L
.42882 .32221 L
.42887 .32218 L
.42892 .32216 L
.42897 .32214 L
.42903 .32212 L
.42908 .3221 L
.42913 .32208 L
.42919 .32206 L
.42924 .32204 L
.42929 .32202 L
.42935 .322 L
.4294 .32197 L
.42945 .32195 L
.42951 .32193 L
.42956 .32191 L
.42961 .32189 L
.42966 .32187 L
.42972 .32185 L
.42977 .32183 L
.42982 .32181 L
.42988 .32179 L
.42993 .32177 L
.42998 .32175 L
.43003 .32173 L
.43009 .32171 L
.43014 .32169 L
.43019 .32167 L
.43024 .32165 L
.4303 .32163 L
.43035 .32161 L
.4304 .32159 L
.43045 .32157 L
.43051 .32155 L
.43056 .32153 L
.43061 .32151 L
.43066 .32149 L
.43072 .32147 L
.43077 .32145 L
.43082 .32143 L
.43087 .32141 L
.43093 .32139 L
.43098 .32137 L
.43103 .32136 L
Mistroke
.43108 .32134 L
.43114 .32132 L
.43119 .3213 L
.43124 .32128 L
.43129 .32126 L
.43134 .32124 L
.4314 .32122 L
.43145 .3212 L
.4315 .32118 L
.43155 .32117 L
.4316 .32115 L
.43166 .32113 L
.43171 .32111 L
.43176 .32109 L
.43181 .32107 L
.43186 .32105 L
.43192 .32104 L
.43197 .32102 L
.43202 .321 L
.43207 .32098 L
.43212 .32096 L
.43217 .32094 L
.43223 .32093 L
.43228 .32091 L
.43233 .32089 L
.43238 .32087 L
.43243 .32085 L
.43248 .32084 L
.43253 .32082 L
.43259 .3208 L
.43264 .32078 L
.43269 .32077 L
.43274 .32075 L
.43279 .32073 L
.43284 .32071 L
.43289 .3207 L
.43295 .32068 L
.433 .32066 L
.43305 .32064 L
.4331 .32063 L
.43315 .32061 L
.4332 .32059 L
.43325 .32057 L
.4333 .32056 L
.43336 .32054 L
.43341 .32052 L
.43346 .32051 L
.43351 .32049 L
.43356 .32047 L
.43361 .32046 L
Mistroke
.43366 .32044 L
.43371 .32042 L
.43376 .3204 L
.43381 .32039 L
.43386 .32037 L
.43392 .32035 L
.43397 .32034 L
.43402 .32032 L
.43407 .32031 L
.43412 .32029 L
.43417 .32027 L
.43422 .32026 L
.43427 .32024 L
.43432 .32022 L
.43437 .32021 L
.43442 .32019 L
.43447 .32018 L
.43452 .32016 L
.43457 .32014 L
.43462 .32013 L
.43467 .32011 L
.43472 .3201 L
.43477 .32008 L
.43482 .32006 L
.43487 .32005 L
.43493 .32003 L
.43498 .32002 L
.43503 .32 L
.43508 .31999 L
.43513 .31997 L
.43518 .31996 L
.43523 .31994 L
.43528 .31993 L
.43533 .31991 L
.43538 .31989 L
.43543 .31988 L
.43548 .31986 L
.43553 .31985 L
.43558 .31983 L
.43563 .31982 L
.43568 .3198 L
.43573 .31979 L
.43577 .31977 L
.43582 .31976 L
.43587 .31974 L
.43592 .31973 L
.43597 .31972 L
.43602 .3197 L
.43607 .31969 L
.43612 .31967 L
Mistroke
.43617 .31966 L
.43622 .31964 L
.43627 .31963 L
.43632 .31961 L
.43637 .3196 L
.43642 .31959 L
.43647 .31957 L
.43652 .31956 L
.43657 .31954 L
.43662 .31953 L
.43667 .31951 L
.43672 .3195 L
.43676 .31949 L
.43681 .31947 L
.43686 .31946 L
.43691 .31944 L
.43696 .31943 L
.43701 .31942 L
.43706 .3194 L
.43711 .31939 L
.43716 .31938 L
.43721 .31936 L
.43725 .31935 L
.4373 .31934 L
.43735 .31932 L
.4374 .31931 L
.43745 .3193 L
.4375 .31928 L
.43755 .31927 L
.4376 .31926 L
.43764 .31924 L
.43769 .31923 L
.43774 .31922 L
.43779 .3192 L
.43784 .31919 L
.43789 .31918 L
.43794 .31916 L
.43798 .31915 L
.43803 .31914 L
.43808 .31913 L
.43813 .31911 L
.43818 .3191 L
.43823 .31909 L
.43828 .31908 L
.43832 .31906 L
.43837 .31905 L
.43842 .31904 L
.43847 .31903 L
.43852 .31901 L
.43856 .319 L
Mistroke
.43861 .31899 L
.43866 .31898 L
.43871 .31896 L
.43876 .31895 L
.4388 .31894 L
.43885 .31893 L
.4389 .31892 L
.43895 .3189 L
.439 .31889 L
.43904 .31888 L
.43909 .31887 L
.43914 .31886 L
.43919 .31885 L
.43924 .31883 L
.43928 .31882 L
.43933 .31881 L
.43938 .3188 L
.43943 .31879 L
.43947 .31878 L
.43952 .31876 L
.43957 .31875 L
.43962 .31874 L
.43966 .31873 L
.43971 .31872 L
.43976 .31871 L
.43981 .3187 L
.43985 .31869 L
.4399 .31867 L
.43995 .31866 L
.43999 .31865 L
.44004 .31864 L
.44009 .31863 L
.44014 .31862 L
.44018 .31861 L
.44023 .3186 L
.44028 .31859 L
.44032 .31858 L
.44037 .31857 L
.44042 .31855 L
.44047 .31854 L
.44051 .31853 L
.44056 .31852 L
.44061 .31851 L
.44065 .3185 L
.4407 .31849 L
.44075 .31848 L
.44079 .31847 L
.44084 .31846 L
.44089 .31845 L
.44093 .31844 L
Mistroke
.44098 .31843 L
.44103 .31842 L
.44107 .31841 L
.44112 .3184 L
.44117 .31839 L
.44121 .31838 L
.44126 .31837 L
.44131 .31836 L
.44135 .31835 L
.4414 .31834 L
.44144 .31833 L
.44149 .31832 L
.44154 .31831 L
.44158 .3183 L
.44163 .31829 L
.44168 .31828 L
.44172 .31827 L
.44177 .31826 L
.44181 .31826 L
.44186 .31825 L
.44191 .31824 L
.44195 .31823 L
.442 .31822 L
.44204 .31821 L
.44209 .3182 L
.44214 .31819 L
.44218 .31818 L
.44223 .31817 L
.44227 .31816 L
.44232 .31816 L
.44236 .31815 L
.44241 .31814 L
.44246 .31813 L
.4425 .31812 L
.44255 .31811 L
.44259 .3181 L
.44264 .31809 L
.44268 .31809 L
.44273 .31808 L
.44277 .31807 L
.44282 .31806 L
.44287 .31805 L
.44291 .31804 L
.44296 .31803 L
.443 .31803 L
.44305 .31802 L
.44309 .31801 L
.44314 .318 L
.44318 .31799 L
.44323 .31799 L
Mistroke
.44327 .31798 L
.44332 .31797 L
.44336 .31796 L
.44341 .31795 L
.44345 .31795 L
.4435 .31794 L
.44354 .31793 L
.44359 .31792 L
.44363 .31791 L
.44368 .31791 L
.44372 .3179 L
.44377 .31789 L
.44381 .31788 L
.44386 .31788 L
.4439 .31787 L
.44394 .31786 L
.44399 .31785 L
.44403 .31785 L
.44408 .31784 L
.44412 .31783 L
.44417 .31782 L
.44421 .31782 L
.44426 .31781 L
.4443 .3178 L
.44434 .3178 L
.44439 .31779 L
.44443 .31778 L
.44448 .31778 L
.44452 .31777 L
.44457 .31776 L
.44461 .31775 L
.44465 .31775 L
.4447 .31774 L
.44474 .31773 L
.44479 .31773 L
.44483 .31772 L
.44487 .31771 L
.44492 .31771 L
.44496 .3177 L
.44501 .31769 L
.44505 .31769 L
.44509 .31768 L
.44514 .31768 L
.44518 .31767 L
.44522 .31766 L
.44527 .31766 L
.44531 .31765 L
.44536 .31764 L
.4454 .31764 L
.44544 .31763 L
Mistroke
.44549 .31763 L
.44553 .31762 L
.44557 .31761 L
.44562 .31761 L
.44566 .3176 L
.4457 .3176 L
.44575 .31759 L
.44579 .31758 L
.44583 .31758 L
.44588 .31757 L
.44592 .31757 L
.44596 .31756 L
.44601 .31756 L
.44605 .31755 L
.44609 .31755 L
.44614 .31754 L
.44618 .31753 L
.44622 .31753 L
.44626 .31752 L
.44631 .31752 L
.44635 .31751 L
.44639 .31751 L
.44644 .3175 L
.44648 .3175 L
.44652 .31749 L
.44656 .31749 L
.44661 .31748 L
.44665 .31748 L
.44669 .31747 L
.44673 .31747 L
.44678 .31746 L
.44682 .31746 L
.44686 .31745 L
.4469 .31745 L
.44695 .31744 L
.44699 .31744 L
.44703 .31743 L
.44707 .31743 L
.44712 .31742 L
.44716 .31742 L
.4472 .31742 L
.44724 .31741 L
.44728 .31741 L
.44733 .3174 L
.44737 .3174 L
.44741 .31739 L
.44745 .31739 L
.44749 .31738 L
.44754 .31738 L
.44758 .31738 L
Mistroke
.44762 .31737 L
.44766 .31737 L
.4477 .31736 L
.44775 .31736 L
.44779 .31736 L
.44783 .31735 L
.44787 .31735 L
.44791 .31734 L
.44795 .31734 L
.448 .31734 L
.44804 .31733 L
.44808 .31733 L
.44812 .31733 L
.44816 .31732 L
.4482 .31732 L
.44824 .31731 L
.44829 .31731 L
.44833 .31731 L
.44837 .3173 L
.44841 .3173 L
.44845 .3173 L
.44849 .31729 L
.44853 .31729 L
.44857 .31729 L
.44862 .31728 L
.44866 .31728 L
.4487 .31728 L
.44874 .31727 L
.44878 .31727 L
.44882 .31727 L
.44886 .31727 L
.4489 .31726 L
.44894 .31726 L
.44898 .31726 L
.44902 .31725 L
.44906 .31725 L
.44911 .31725 L
.44915 .31725 L
.44919 .31724 L
.44923 .31724 L
.44927 .31724 L
.44931 .31723 L
.44935 .31723 L
.44939 .31723 L
.44943 .31723 L
.44947 .31722 L
.44951 .31722 L
.44955 .31722 L
.44959 .31722 L
.44963 .31721 L
Mistroke
.44967 .31721 L
.44971 .31721 L
.44975 .31721 L
.44979 .31721 L
.44983 .3172 L
.44987 .3172 L
.44991 .3172 L
.44995 .3172 L
.44999 .3172 L
.45003 .31719 L
.45007 .31719 L
.45011 .31719 L
.45015 .31719 L
.45019 .31719 L
.45023 .31718 L
.45027 .31718 L
.45031 .31718 L
.45035 .31718 L
.45039 .31718 L
.45043 .31718 L
.45047 .31717 L
.45051 .31717 L
.45055 .31717 L
.45059 .31717 L
.45063 .31717 L
.45067 .31717 L
.45071 .31717 L
.45074 .31716 L
.45078 .31716 L
.45082 .31716 L
.45086 .31716 L
.4509 .31716 L
.45094 .31716 L
.45098 .31716 L
.45102 .31716 L
.45106 .31715 L
.4511 .31715 L
.45114 .31715 L
.45117 .31715 L
.45121 .31715 L
.45125 .31715 L
.45129 .31715 L
.45133 .31715 L
.45137 .31715 L
.45141 .31715 L
.45145 .31715 L
.45149 .31714 L
.45152 .31714 L
.45156 .31714 L
.4516 .31714 L
Mistroke
.45164 .31714 L
.45168 .31714 L
.45172 .31714 L
.45175 .31714 L
.45179 .31714 L
.45183 .31714 L
.45187 .31714 L
.45191 .31714 L
.45195 .31714 L
.45198 .31714 L
.45202 .31714 L
.45206 .31714 L
.4521 .31714 L
.45214 .31714 L
.45218 .31714 L
.45221 .31714 L
.45225 .31714 L
.45229 .31714 L
.45233 .31714 L
.45236 .31714 L
.4524 .31714 L
.45244 .31714 L
.45248 .31714 L
.45252 .31714 L
.45255 .31714 L
.45259 .31714 L
.45263 .31714 L
.45267 .31714 L
.4527 .31714 L
.45274 .31714 L
.45278 .31714 L
.45282 .31714 L
.45285 .31714 L
.45289 .31714 L
.45293 .31714 L
.45297 .31715 L
.453 .31715 L
.45304 .31715 L
.45308 .31715 L
.45312 .31715 L
.45315 .31715 L
.45319 .31715 L
.45323 .31715 L
.45326 .31715 L
.4533 .31715 L
.45334 .31715 L
.45337 .31715 L
.45341 .31716 L
.45345 .31716 L
.45348 .31716 L
Mistroke
.45352 .31716 L
.45356 .31716 L
.4536 .31716 L
.45363 .31716 L
.45367 .31716 L
.45371 .31717 L
.45374 .31717 L
.45378 .31717 L
.45381 .31717 L
.45385 .31717 L
.45389 .31717 L
.45392 .31717 L
.45396 .31718 L
.454 .31718 L
.45403 .31718 L
.45407 .31718 L
.45411 .31718 L
.45414 .31718 L
.45418 .31719 L
.45421 .31719 L
.45425 .31719 L
.45429 .31719 L
.45432 .31719 L
.45436 .31719 L
.45439 .3172 L
.45443 .3172 L
.45447 .3172 L
.4545 .3172 L
.45454 .3172 L
.45457 .31721 L
.45461 .31721 L
.45465 .31721 L
.45468 .31721 L
.45472 .31722 L
.45475 .31722 L
.45479 .31722 L
.45482 .31722 L
.45486 .31722 L
.45489 .31723 L
.45493 .31723 L
.45497 .31723 L
.455 .31723 L
.45504 .31724 L
.45507 .31724 L
.45511 .31724 L
.45514 .31724 L
.45518 .31725 L
.45521 .31725 L
.45525 .31725 L
.45528 .31726 L
Mistroke
.45532 .31726 L
.45535 .31726 L
.45539 .31726 L
.45542 .31727 L
.45546 .31727 L
.45549 .31727 L
.45553 .31728 L
.45556 .31728 L
.4556 .31728 L
.45563 .31728 L
.45567 .31729 L
.4557 .31729 L
.45574 .31729 L
.45577 .3173 L
.4558 .3173 L
.45584 .3173 L
.45587 .31731 L
.45591 .31731 L
.45594 .31731 L
.45598 .31732 L
.45601 .31732 L
.45605 .31732 L
.45608 .31733 L
.45611 .31733 L
.45615 .31733 L
.45618 .31734 L
.45622 .31734 L
.45625 .31734 L
.45628 .31735 L
.45632 .31735 L
.45635 .31736 L
.45639 .31736 L
.45642 .31736 L
.45645 .31737 L
.45649 .31737 L
.45652 .31737 L
.45656 .31738 L
.45659 .31738 L
.45662 .31739 L
.45666 .31739 L
.45669 .31739 L
.45672 .3174 L
.45676 .3174 L
.45679 .31741 L
.45683 .31741 L
.45686 .31741 L
.45689 .31742 L
.45693 .31742 L
.45696 .31743 L
.45699 .31743 L
Mistroke
.45703 .31744 L
.45706 .31744 L
.45709 .31744 L
.45713 .31745 L
.45716 .31745 L
.45719 .31746 L
.45722 .31746 L
.45726 .31747 L
.45729 .31747 L
.45732 .31748 L
.45736 .31748 L
.45739 .31748 L
.45742 .31749 L
.45746 .31749 L
.45749 .3175 L
.45752 .3175 L
.45755 .31751 L
.45759 .31751 L
.45762 .31752 L
.45765 .31752 L
.45768 .31753 L
.45772 .31753 L
.45775 .31754 L
.45778 .31754 L
.45781 .31755 L
.45785 .31755 L
.45788 .31756 L
.45791 .31756 L
.45794 .31757 L
.45798 .31757 L
.45801 .31758 L
.45804 .31758 L
.45807 .31759 L
.4581 .31759 L
.45814 .3176 L
.45817 .3176 L
.4582 .31761 L
.45823 .31761 L
.45826 .31762 L
.4583 .31763 L
.45833 .31763 L
.45836 .31764 L
.45839 .31764 L
.45842 .31765 L
.45846 .31765 L
.45849 .31766 L
.45852 .31766 L
.45855 .31767 L
.45858 .31768 L
.45861 .31768 L
Mistroke
.45865 .31769 L
.45868 .31769 L
.45871 .3177 L
.45874 .3177 L
.45877 .31771 L
.4588 .31772 L
.45883 .31772 L
.45886 .31773 L
.4589 .31773 L
.45893 .31774 L
.45896 .31775 L
.45899 .31775 L
.45902 .31776 L
.45905 .31776 L
.45908 .31777 L
.45911 .31778 L
.45914 .31778 L
.45918 .31779 L
.45921 .3178 L
.45924 .3178 L
.45927 .31781 L
.4593 .31781 L
.45933 .31782 L
.45936 .31783 L
.45939 .31783 L
.45942 .31784 L
.45945 .31785 L
.45948 .31785 L
.45951 .31786 L
.45954 .31787 L
.45957 .31787 L
.4596 .31788 L
.45964 .31789 L
.45967 .31789 L
.4597 .3179 L
.45973 .31791 L
.45976 .31791 L
.45979 .31792 L
.45982 .31793 L
.45985 .31793 L
.45988 .31794 L
.45991 .31795 L
.45994 .31795 L
.45997 .31796 L
.46 .31797 L
.46003 .31798 L
.46006 .31798 L
.46009 .31799 L
.46012 .318 L
.46015 .318 L
Mistroke
.46018 .31801 L
.46021 .31802 L
.46024 .31802 L
.46026 .31803 L
.46029 .31804 L
.46032 .31805 L
.46035 .31805 L
.46038 .31806 L
.46041 .31807 L
.46044 .31808 L
.46047 .31808 L
.4605 .31809 L
.46053 .3181 L
.46056 .31811 L
.46059 .31811 L
.46062 .31812 L
.46065 .31813 L
.46068 .31814 L
.46071 .31814 L
.46073 .31815 L
.46076 .31816 L
.46079 .31817 L
.46082 .31817 L
.46085 .31818 L
.46088 .31819 L
.46091 .3182 L
.46094 .31821 L
.46097 .31821 L
.46099 .31822 L
.46102 .31823 L
.46105 .31824 L
.46108 .31824 L
.46111 .31825 L
.46114 .31826 L
.46117 .31827 L
.46119 .31828 L
.46122 .31828 L
.46125 .31829 L
.46128 .3183 L
.46131 .31831 L
.46134 .31832 L
.46136 .31833 L
.46139 .31833 L
.46142 .31834 L
.46145 .31835 L
.46148 .31836 L
.46151 .31837 L
.46153 .31838 L
.46156 .31838 L
.46159 .31839 L
Mistroke
.46162 .3184 L
.46165 .31841 L
.46167 .31842 L
.4617 .31843 L
.46173 .31843 L
.46176 .31844 L
.46178 .31845 L
.46181 .31846 L
.46184 .31847 L
.46187 .31848 L
.46189 .31849 L
.46192 .3185 L
.46195 .3185 L
.46198 .31851 L
.462 .31852 L
.46203 .31853 L
.46206 .31854 L
.46209 .31855 L
.46211 .31856 L
.46214 .31857 L
.46217 .31857 L
.4622 .31858 L
.46222 .31859 L
.46225 .3186 L
.46228 .31861 L
.4623 .31862 L
.46233 .31863 L
.46236 .31864 L
.46239 .31865 L
.46241 .31866 L
.46244 .31867 L
.46247 .31867 L
.46249 .31868 L
.46252 .31869 L
.46255 .3187 L
.46257 .31871 L
.4626 .31872 L
.46263 .31873 L
.46265 .31874 L
.46268 .31875 L
.46271 .31876 L
.46273 .31877 L
.46276 .31878 L
.46278 .31879 L
.46281 .3188 L
.46284 .31881 L
.46286 .31882 L
.46289 .31883 L
.46292 .31883 L
.46294 .31884 L
Mistroke
.46297 .31885 L
.46299 .31886 L
.46302 .31887 L
.46305 .31888 L
.46307 .31889 L
.4631 .3189 L
.46312 .31891 L
.46315 .31892 L
.46318 .31893 L
.4632 .31894 L
.46323 .31895 L
.46325 .31896 L
.46328 .31897 L
.46331 .31898 L
.46333 .31899 L
.46336 .319 L
.46338 .31901 L
.46341 .31902 L
.46343 .31903 L
.46346 .31904 L
.46348 .31905 L
.46351 .31906 L
.46354 .31907 L
.46356 .31908 L
.46359 .31909 L
.46361 .3191 L
.46364 .31911 L
.46366 .31912 L
.46369 .31913 L
.46371 .31914 L
.46374 .31916 L
.46376 .31917 L
.46379 .31918 L
.46381 .31919 L
.46384 .3192 L
.46386 .31921 L
.46389 .31922 L
.46391 .31923 L
.46394 .31924 L
.46396 .31925 L
.46399 .31926 L
.46401 .31927 L
.46404 .31928 L
.46406 .31929 L
.46408 .3193 L
.46411 .31931 L
.46413 .31932 L
.46416 .31933 L
.46418 .31935 L
.46421 .31936 L
Mistroke
.46423 .31937 L
.46426 .31938 L
.46428 .31939 L
.4643 .3194 L
.46433 .31941 L
.46435 .31942 L
.46438 .31943 L
.4644 .31944 L
.46442 .31945 L
.46445 .31947 L
.46447 .31948 L
.4645 .31949 L
.46452 .3195 L
.46454 .31951 L
.46457 .31952 L
.46459 .31953 L
.46462 .31954 L
.46464 .31955 L
.46466 .31957 L
.46469 .31958 L
.46471 .31959 L
.46473 .3196 L
.46476 .31961 L
.46478 .31962 L
.46481 .31963 L
.46483 .31964 L
.46485 .31966 L
.46488 .31967 L
.4649 .31968 L
.46492 .31969 L
.46495 .3197 L
.46497 .31971 L
.46499 .31972 L
.46502 .31974 L
.46504 .31975 L
.46506 .31976 L
.46508 .31977 L
.46511 .31978 L
.46513 .31979 L
.46515 .31981 L
.46518 .31982 L
.4652 .31983 L
.46522 .31984 L
.46525 .31985 L
.46527 .31986 L
.46529 .31988 L
.46531 .31989 L
.46534 .3199 L
.46536 .31991 L
.46538 .31992 L
Mistroke
.4654 .31994 L
.46543 .31995 L
.46545 .31996 L
.46547 .31997 L
.46549 .31998 L
.46552 .32 L
.46554 .32001 L
.46556 .32002 L
.46558 .32003 L
.46561 .32004 L
.46563 .32006 L
.46565 .32007 L
.46567 .32008 L
.46569 .32009 L
.46572 .3201 L
.46574 .32012 L
.46576 .32013 L
.46578 .32014 L
.4658 .32015 L
.46583 .32017 L
.46585 .32018 L
.46587 .32019 L
.46589 .3202 L
.46591 .32022 L
.46594 .32023 L
.46596 .32024 L
.46598 .32025 L
.466 .32026 L
.46602 .32028 L
.46604 .32029 L
.46607 .3203 L
.46609 .32031 L
.46611 .32033 L
.46613 .32034 L
.46615 .32035 L
.46617 .32037 L
.46619 .32038 L
.46622 .32039 L
.46624 .3204 L
.46626 .32042 L
.46628 .32043 L
.4663 .32044 L
.46632 .32045 L
.46634 .32047 L
.46636 .32048 L
.46638 .32049 L
.46641 .32051 L
.46643 .32052 L
.46645 .32053 L
.46647 .32054 L
Mistroke
.46649 .32056 L
.46651 .32057 L
.46653 .32058 L
.46655 .3206 L
.46657 .32061 L
.46659 .32062 L
.46661 .32063 L
.46663 .32065 L
.46665 .32066 L
.46667 .32067 L
.46669 .32069 L
.46672 .3207 L
.46674 .32071 L
.46676 .32073 L
.46678 .32074 L
.4668 .32075 L
.46682 .32077 L
.46684 .32078 L
.46686 .32079 L
.46688 .32081 L
.4669 .32082 L
.46692 .32083 L
.46694 .32085 L
.46696 .32086 L
.46698 .32087 L
.467 .32089 L
.46702 .3209 L
.46704 .32091 L
.46706 .32093 L
.46708 .32094 L
.4671 .32095 L
.46712 .32097 L
.46714 .32098 L
.46716 .32099 L
.46718 .32101 L
.4672 .32102 L
.46721 .32103 L
.46723 .32105 L
.46725 .32106 L
.46727 .32107 L
.46729 .32109 L
.46731 .3211 L
.46733 .32112 L
.46735 .32113 L
.46737 .32114 L
.46739 .32116 L
.46741 .32117 L
.46743 .32118 L
.46745 .3212 L
.46747 .32121 L
Mistroke
.46749 .32123 L
.4675 .32124 L
.46752 .32125 L
.46754 .32127 L
.46756 .32128 L
.46758 .3213 L
.4676 .32131 L
.46762 .32132 L
.46764 .32134 L
.46766 .32135 L
.46767 .32136 L
.46769 .32138 L
.46771 .32139 L
.46773 .32141 L
.46775 .32142 L
.46777 .32144 L
.46779 .32145 L
.4678 .32146 L
.46782 .32148 L
.46784 .32149 L
.46786 .32151 L
.46788 .32152 L
.4679 .32153 L
.46791 .32155 L
.46793 .32156 L
.46795 .32158 L
.46797 .32159 L
.46799 .32161 L
.46801 .32162 L
.46802 .32163 L
.46804 .32165 L
.46806 .32166 L
.46808 .32168 L
.4681 .32169 L
.46811 .32171 L
.46813 .32172 L
.46815 .32174 L
.46817 .32175 L
.46818 .32176 L
.4682 .32178 L
.46822 .32179 L
.46824 .32181 L
.46825 .32182 L
.46827 .32184 L
.46829 .32185 L
.46831 .32187 L
.46832 .32188 L
.46834 .3219 L
.46836 .32191 L
.46838 .32192 L
Mistroke
.46839 .32194 L
.46841 .32195 L
.46843 .32197 L
.46845 .32198 L
.46846 .322 L
.46848 .32201 L
.4685 .32203 L
.46852 .32204 L
.46853 .32206 L
.46855 .32207 L
.46857 .32209 L
.46858 .3221 L
.4686 .32212 L
.46862 .32213 L
.46863 .32215 L
.46865 .32216 L
.46867 .32218 L
.46868 .32219 L
.4687 .32221 L
.46872 .32222 L
.46873 .32224 L
.46875 .32225 L
.46877 .32227 L
.46878 .32228 L
.4688 .3223 L
.46882 .32231 L
.46883 .32233 L
.46885 .32234 L
.46887 .32236 L
.46888 .32237 L
.4689 .32239 L
.46892 .3224 L
.46893 .32242 L
.46895 .32243 L
.46896 .32245 L
.46898 .32246 L
.469 .32248 L
.46901 .32249 L
.46903 .32251 L
.46904 .32252 L
.46906 .32254 L
.46908 .32256 L
.46909 .32257 L
.46911 .32259 L
.46912 .3226 L
.46914 .32262 L
.46916 .32263 L
.46917 .32265 L
.46919 .32266 L
.4692 .32268 L
Mistroke
.46922 .32269 L
.46923 .32271 L
.46925 .32272 L
.46926 .32274 L
.46928 .32276 L
.4693 .32277 L
.46931 .32279 L
.46933 .3228 L
.46934 .32282 L
.46936 .32283 L
.46937 .32285 L
.46939 .32286 L
.4694 .32288 L
.46942 .3229 L
.46943 .32291 L
.46945 .32293 L
.46946 .32294 L
.46948 .32296 L
.46949 .32297 L
.46951 .32299 L
.46952 .32301 L
.46954 .32302 L
.46955 .32304 L
.46957 .32305 L
.46958 .32307 L
.4696 .32309 L
.46961 .3231 L
.46963 .32312 L
.46964 .32313 L
.46966 .32315 L
.46967 .32316 L
.46969 .32318 L
.4697 .3232 L
.46972 .32321 L
.46973 .32323 L
.46974 .32324 L
.46976 .32326 L
.46977 .32328 L
.46979 .32329 L
.4698 .32331 L
.46982 .32332 L
.46983 .32334 L
.46984 .32336 L
.46986 .32337 L
.46987 .32339 L
.46989 .3234 L
.4699 .32342 L
.46991 .32344 L
.46993 .32345 L
.46994 .32347 L
Mistroke
.46996 .32349 L
.46997 .3235 L
.46998 .32352 L
.47 .32353 L
.47001 .32355 L
.47003 .32357 L
.47004 .32358 L
.47005 .3236 L
.47007 .32362 L
.47008 .32363 L
.47009 .32365 L
.47011 .32366 L
.47012 .32368 L
.47014 .3237 L
.47015 .32371 L
.47016 .32373 L
.47018 .32375 L
.47019 .32376 L
.4702 .32378 L
.47022 .3238 L
.47023 .32381 L
.47024 .32383 L
.47026 .32384 L
.47027 .32386 L
.47028 .32388 L
.4703 .32389 L
.47031 .32391 L
.47032 .32393 L
.47033 .32394 L
.47035 .32396 L
.47036 .32398 L
.47037 .32399 L
.47039 .32401 L
.4704 .32403 L
.47041 .32404 L
.47042 .32406 L
.47044 .32408 L
.47045 .32409 L
.47046 .32411 L
.47048 .32413 L
.47049 .32414 L
.4705 .32416 L
.47051 .32418 L
.47053 .32419 L
.47054 .32421 L
.47055 .32423 L
.47056 .32424 L
.47058 .32426 L
.47059 .32428 L
.4706 .32429 L
Mistroke
.47061 .32431 L
.47062 .32433 L
.47064 .32434 L
.47065 .32436 L
.47066 .32438 L
.47067 .3244 L
.47069 .32441 L
.4707 .32443 L
.47071 .32445 L
.47072 .32446 L
.47073 .32448 L
.47075 .3245 L
.47076 .32451 L
.47077 .32453 L
.47078 .32455 L
.47079 .32456 L
.47081 .32458 L
.47082 .3246 L
.47083 .32462 L
.47084 .32463 L
.47085 .32465 L
.47086 .32467 L
.47088 .32468 L
.47089 .3247 L
.4709 .32472 L
.47091 .32474 L
.47092 .32475 L
.47093 .32477 L
.47094 .32479 L
.47096 .3248 L
.47097 .32482 L
.47098 .32484 L
.47099 .32486 L
.471 .32487 L
.47101 .32489 L
.47102 .32491 L
.47103 .32492 L
.47105 .32494 L
.47106 .32496 L
.47107 .32498 L
.47108 .32499 L
.47109 .32501 L
.4711 .32503 L
.47111 .32505 L
.47112 .32506 L
.47113 .32508 L
.47114 .3251 L
.47115 .32511 L
.47117 .32513 L
.47118 .32515 L
Mistroke
.47119 .32517 L
.4712 .32518 L
.47121 .3252 L
.47122 .32522 L
.47123 .32524 L
.47124 .32525 L
.47125 .32527 L
.47126 .32529 L
.47127 .32531 L
.47128 .32532 L
.47129 .32534 L
.4713 .32536 L
.47131 .32538 L
.47132 .32539 L
.47133 .32541 L
.47134 .32543 L
.47135 .32545 L
.47136 .32546 L
.47137 .32548 L
.47138 .3255 L
.47139 .32552 L
.4714 .32553 L
.47141 .32555 L
.47142 .32557 L
.47143 .32559 L
.47144 .32561 L
.47145 .32562 L
.47146 .32564 L
.47147 .32566 L
.47148 .32568 L
.47149 .32569 L
.4715 .32571 L
.47151 .32573 L
.47152 .32575 L
.47153 .32576 L
.47154 .32578 L
.47155 .3258 L
.47156 .32582 L
.47157 .32584 L
.47158 .32585 L
.47159 .32587 L
.4716 .32589 L
.47161 .32591 L
.47162 .32592 L
.47163 .32594 L
.47163 .32596 L
.47164 .32598 L
.47165 .326 L
.47166 .32601 L
.47167 .32603 L
Mistroke
.47168 .32605 L
.47169 .32607 L
.4717 .32609 L
.47171 .3261 L
.47172 .32612 L
.47173 .32614 L
.47173 .32616 L
.47174 .32617 L
.47175 .32619 L
.47176 .32621 L
.47177 .32623 L
.47178 .32625 L
.47179 .32626 L
.4718 .32628 L
.47181 .3263 L
.47181 .32632 L
.47182 .32634 L
.47183 .32635 L
.47184 .32637 L
.47185 .32639 L
.47186 .32641 L
.47187 .32643 L
.47187 .32645 L
.47188 .32646 L
.47189 .32648 L
.4719 .3265 L
.47191 .32652 L
.47192 .32654 L
.47192 .32655 L
.47193 .32657 L
.47194 .32659 L
.47195 .32661 L
.47196 .32663 L
.47196 .32664 L
.47197 .32666 L
.47198 .32668 L
.47199 .3267 L
.472 .32672 L
.472 .32674 L
.47201 .32675 L
.47202 .32677 L
.47203 .32679 L
.47204 .32681 L
.47204 .32683 L
.47205 .32685 L
.47206 .32686 L
.47207 .32688 L
.47207 .3269 L
.47208 .32692 L
.47209 .32694 L
Mistroke
.4721 .32695 L
.4721 .32697 L
.47211 .32699 L
.47212 .32701 L
.47213 .32703 L
.47213 .32705 L
.47214 .32707 L
.47215 .32708 L
.47216 .3271 L
.47216 .32712 L
.47217 .32714 L
.47218 .32716 L
.47219 .32718 L
.47219 .32719 L
.4722 .32721 L
.47221 .32723 L
.47221 .32725 L
.47222 .32727 L
.47223 .32729 L
.47224 .3273 L
.47224 .32732 L
.47225 .32734 L
.47226 .32736 L
.47226 .32738 L
.47227 .3274 L
.47228 .32742 L
.47228 .32743 L
.47229 .32745 L
.4723 .32747 L
.4723 .32749 L
.47231 .32751 L
.47232 .32753 L
.47232 .32755 L
.47233 .32756 L
.47234 .32758 L
.47234 .3276 L
.47235 .32762 L
.47236 .32764 L
.47236 .32766 L
.47237 .32768 L
.47238 .32769 L
.47238 .32771 L
.47239 .32773 L
.47239 .32775 L
.4724 .32777 L
.47241 .32779 L
.47241 .32781 L
.47242 .32782 L
.47243 .32784 L
.47243 .32786 L
Mistroke
.47244 .32788 L
.47244 .3279 L
.47245 .32792 L
.47246 .32794 L
.47246 .32796 L
.47247 .32797 L
.47247 .32799 L
.47248 .32801 L
.47249 .32803 L
.47249 .32805 L
.4725 .32807 L
.4725 .32809 L
.47251 .32811 L
.47251 .32812 L
.47252 .32814 L
.47253 .32816 L
.47253 .32818 L
.47254 .3282 L
.47254 .32822 L
.47255 .32824 L
.47255 .32826 L
.47256 .32827 L
.47256 .32829 L
.47257 .32831 L
.47258 .32833 L
.47258 .32835 L
.47259 .32837 L
.47259 .32839 L
.4726 .32841 L
.4726 .32842 L
.47261 .32844 L
.47261 .32846 L
.47262 .32848 L
.47262 .3285 L
.47263 .32852 L
.47263 .32854 L
.47264 .32856 L
.47264 .32858 L
.47265 .3286 L
.47265 .32861 L
.47266 .32863 L
.47266 .32865 L
.47267 .32867 L
.47267 .32869 L
.47268 .32871 L
.47268 .32873 L
.47269 .32875 L
.47269 .32877 L
.4727 .32878 L
.4727 .3288 L
Mistroke
.47271 .32882 L
.47271 .32884 L
.47271 .32886 L
.47272 .32888 L
.47272 .3289 L
.47273 .32892 L
.47273 .32894 L
.47274 .32896 L
.47274 .32897 L
.47275 .32899 L
.47275 .32901 L
.47275 .32903 L
.47276 .32905 L
.47276 .32907 L
.47277 .32909 L
.47277 .32911 L
.47278 .32913 L
.47278 .32915 L
.47278 .32916 L
.47279 .32918 L
.47279 .3292 L
.4728 .32922 L
.4728 .32924 L
.4728 .32926 L
.47281 .32928 L
.47281 .3293 L
.47282 .32932 L
.47282 .32934 L
.47282 .32936 L
.47283 .32938 L
.47283 .32939 L
.47284 .32941 L
.47284 .32943 L
.47284 .32945 L
.47285 .32947 L
.47285 .32949 L
.47285 .32951 L
.47286 .32953 L
.47286 .32955 L
.47286 .32957 L
.47287 .32959 L
.47287 .3296 L
.47287 .32962 L
.47288 .32964 L
.47288 .32966 L
.47288 .32968 L
.47289 .3297 L
.47289 .32972 L
.47289 .32974 L
.4729 .32976 L
Mistroke
.4729 .32978 L
.4729 .3298 L
.47291 .32982 L
.47291 .32984 L
.47291 .32985 L
.47292 .32987 L
.47292 .32989 L
.47292 .32991 L
.47293 .32993 L
.47293 .32995 L
.47293 .32997 L
.47294 .32999 L
.47294 .33001 L
.47294 .33003 L
.47294 .33005 L
.47295 .33007 L
.47295 .33009 L
.47295 .33011 L
.47296 .33012 L
.47296 .33014 L
.47296 .33016 L
.47296 .33018 L
.47297 .3302 L
.47297 .33022 L
.47297 .33024 L
.47297 .33026 L
.47298 .33028 L
.47298 .3303 L
.47298 .33032 L
.47298 .33034 L
.47299 .33036 L
.47299 .33038 L
.47299 .33039 L
.47299 .33041 L
.473 .33043 L
.473 .33045 L
.473 .33047 L
.473 .33049 L
.473 .33051 L
.47301 .33053 L
.47301 .33055 L
.47301 .33057 L
.47301 .33059 L
.47302 .33061 L
.47302 .33063 L
.47302 .33065 L
.47302 .33067 L
.47302 .33069 L
.47302 .3307 L
.47303 .33072 L
Mistroke
.47303 .33074 L
.47303 .33076 L
.47303 .33078 L
.47303 .3308 L
.47304 .33082 L
.47304 .33084 L
.47304 .33086 L
.47304 .33088 L
.47304 .3309 L
.47304 .33092 L
.47305 .33094 L
.47305 .33096 L
.47305 .33098 L
.47305 .331 L
.47305 .33101 L
.47305 .33103 L
.47306 .33105 L
.47306 .33107 L
.47306 .33109 L
.47306 .33111 L
.47306 .33113 L
.47306 .33115 L
.47306 .33117 L
.47307 .33119 L
.47307 .33121 L
.47307 .33123 L
.47307 .33125 L
.47307 .33127 L
.47307 .33129 L
.47307 .33131 L
.47307 .33133 L
.47307 .33135 L
.47308 .33136 L
.47308 .33138 L
.47308 .3314 L
.47308 .33142 L
.47308 .33144 L
.47308 .33146 L
.47308 .33148 L
.47308 .3315 L
.47308 .33152 L
.47308 .33154 L
.47308 .33156 L
.47309 .33158 L
.47309 .3316 L
.47309 .33162 L
.47309 .33164 L
.47309 .33166 L
.47309 .33168 L
.47309 .3317 L
Mistroke
.47309 .33172 L
.47309 .33174 L
.47309 .33175 L
.47309 .33177 L
.47309 .33179 L
.47309 .33181 L
.47309 .33183 L
.47309 .33185 L
.47309 .33187 L
.47309 .33189 L
.47309 .33191 L
.4731 .33193 L
.4731 .33195 L
.4731 .33197 L
.4731 .33199 L
.4731 .33201 L
.4731 .33203 L
.4731 .33205 L
.4731 .33207 L
.4731 .33209 L
.4731 .33211 L
.4731 .33213 L
.4731 .33215 L
.4731 .33216 L
.4731 .33218 L
.4731 .3322 L
.4731 .33222 L
.4731 .33224 L
.4731 .33226 L
.4731 .33228 L
.4731 .3323 L
.4731 .33232 L
.4731 .33234 L
.4731 .33236 L
.4731 .33238 L
.4731 .3324 L
.47309 .33242 L
.47309 .33244 L
.47309 .33246 L
.47309 .33248 L
.47309 .3325 L
.47309 .33252 L
.47309 .33254 L
.47309 .33256 L
.47309 .33258 L
.47309 .33259 L
.47309 .33261 L
.47309 .33263 L
.47309 .33265 L
.47309 .33267 L
Mistroke
.47309 .33269 L
.47309 .33271 L
.47309 .33273 L
.47309 .33275 L
.47309 .33277 L
.47308 .33279 L
.47308 .33281 L
.47308 .33283 L
.47308 .33285 L
.47308 .33287 L
.47308 .33289 L
.47308 .33291 L
.47308 .33293 L
.47308 .33295 L
.47308 .33297 L
.47308 .33299 L
.47307 .33301 L
.47307 .33302 L
.47307 .33304 L
.47307 .33306 L
.47307 .33308 L
.47307 .3331 L
.47307 .33312 L
.47307 .33314 L
.47307 .33316 L
.47306 .33318 L
.47306 .3332 L
.47306 .33322 L
.47306 .33324 L
.47306 .33326 L
.47306 .33328 L
.47306 .3333 L
.47305 .33332 L
.47305 .33334 L
.47305 .33336 L
.47305 .33338 L
.47305 .3334 L
.47305 .33342 L
.47305 .33344 L
.47304 .33346 L
.47304 .33347 L
.47304 .33349 L
.47304 .33351 L
.47304 .33353 L
.47304 .33355 L
.47303 .33357 L
.47303 .33359 L
.47303 .33361 L
.47303 .33363 L
.47303 .33365 L
Mistroke
.47303 .33367 L
.47302 .33369 L
.47302 .33371 L
.47302 .33373 L
.47302 .33375 L
.47302 .33377 L
.47301 .33379 L
.47301 .33381 L
.47301 .33383 L
.47301 .33385 L
.47301 .33387 L
.473 .33389 L
.473 .3339 L
.473 .33392 L
.473 .33394 L
.473 .33396 L
.47299 .33398 L
.47299 .334 L
.47299 .33402 L
.47299 .33404 L
.47298 .33406 L
.47298 .33408 L
.47298 .3341 L
.47298 .33412 L
.47297 .33414 L
.47297 .33416 L
.47297 .33418 L
.47297 .3342 L
.47296 .33422 L
.47296 .33424 L
.47296 .33426 L
.47296 .33428 L
.47295 .3343 L
.47295 .33431 L
.47295 .33433 L
.47295 .33435 L
.47294 .33437 L
.47294 .33439 L
.47294 .33441 L
.47294 .33443 L
.47293 .33445 L
.47293 .33447 L
.47293 .33449 L
.47293 .33451 L
.47292 .33453 L
.47292 .33455 L
.47292 .33457 L
.47291 .33459 L
.47291 .33461 L
.47291 .33463 L
Mistroke
.4729 .33465 L
.4729 .33467 L
.4729 .33469 L
.4729 .3347 L
.47289 .33472 L
.47289 .33474 L
.47289 .33476 L
.47288 .33478 L
.47288 .3348 L
.47288 .33482 L
.47287 .33484 L
.47287 .33486 L
.47287 .33488 L
.47286 .3349 L
.47286 .33492 L
.47286 .33494 L
.47285 .33496 L
.47285 .33498 L
.47285 .335 L
.47284 .33502 L
.47284 .33504 L
.47284 .33506 L
.47283 .33507 L
.47283 .33509 L
.47283 .33511 L
.47282 .33513 L
.47282 .33515 L
.47282 .33517 L
.47281 .33519 L
.47281 .33521 L
.47281 .33523 L
.4728 .33525 L
.4728 .33527 L
.4728 .33529 L
.47279 .33531 L
.47279 .33533 L
.47278 .33535 L
.47278 .33537 L
.47278 .33539 L
.47277 .3354 L
.47277 .33542 L
.47276 .33544 L
.47276 .33546 L
.47276 .33548 L
.47275 .3355 L
.47275 .33552 L
.47275 .33554 L
.47274 .33556 L
.47274 .33558 L
.47273 .3356 L
Mistroke
.47273 .33562 L
.47273 .33564 L
.47272 .33566 L
.47272 .33568 L
.47271 .3357 L
.47271 .33571 L
.4727 .33573 L
.4727 .33575 L
.4727 .33577 L
.47269 .33579 L
.47269 .33581 L
.47268 .33583 L
.47268 .33585 L
.47268 .33587 L
.47267 .33589 L
.47267 .33591 L
.47266 .33593 L
.47266 .33595 L
.47265 .33597 L
.47265 .33599 L
.47264 .33601 L
.47264 .33602 L
.47264 .33604 L
.47263 .33606 L
.47263 .33608 L
.47262 .3361 L
.47262 .33612 L
.47261 .33614 L
.47261 .33616 L
.4726 .33618 L
.4726 .3362 L
.47259 .33622 L
.47259 .33624 L
.47258 .33626 L
.47258 .33628 L
.47258 .33629 L
.47257 .33631 L
.47257 .33633 L
.47256 .33635 L
.47256 .33637 L
.47255 .33639 L
.47255 .33641 L
.47254 .33643 L
.47254 .33645 L
.47253 .33647 L
.47253 .33649 L
.47252 .33651 L
.47252 .33653 L
.47251 .33654 L
.47251 .33656 L
Mistroke
.4725 .33658 L
.4725 .3366 L
.47249 .33662 L
.47249 .33664 L
.47248 .33666 L
.47248 .33668 L
.47247 .3367 L
.47247 .33672 L
.47246 .33674 L
.47246 .33676 L
.47245 .33678 L
.47245 .33679 L
.47244 .33681 L
.47243 .33683 L
.47243 .33685 L
.47242 .33687 L
.47242 .33689 L
.47241 .33691 L
.47241 .33693 L
.4724 .33695 L
.4724 .33697 L
.47239 .33699 L
.47239 .337 L
.47238 .33702 L
.47238 .33704 L
.47237 .33706 L
.47236 .33708 L
.47236 .3371 L
.47235 .33712 L
.47235 .33714 L
.47234 .33716 L
.47234 .33718 L
.47233 .3372 L
.47232 .33722 L
.47232 .33723 L
.47231 .33725 L
.47231 .33727 L
.4723 .33729 L
.4723 .33731 L
.47229 .33733 L
.47228 .33735 L
.47228 .33737 L
.47227 .33739 L
.47227 .33741 L
.47226 .33742 L
.47226 .33744 L
.47225 .33746 L
.47224 .33748 L
.47224 .3375 L
.47223 .33752 L
Mistroke
.47223 .33754 L
.47222 .33756 L
.47221 .33758 L
.47221 .3376 L
.4722 .33761 L
.4722 .33763 L
.47219 .33765 L
.47218 .33767 L
.47218 .33769 L
.47217 .33771 L
.47216 .33773 L
.47216 .33775 L
.47215 .33777 L
.47215 .33779 L
.47214 .3378 L
.47213 .33782 L
.47213 .33784 L
.47212 .33786 L
.47211 .33788 L
.47211 .3379 L
.4721 .33792 L
.4721 .33794 L
.47209 .33796 L
.47208 .33797 L
.47208 .33799 L
.47207 .33801 L
.47206 .33803 L
.47206 .33805 L
.47205 .33807 L
.47204 .33809 L
.47204 .33811 L
.47203 .33813 L
.47202 .33814 L
.47202 .33816 L
.47201 .33818 L
.472 .3382 L
.472 .33822 L
.47199 .33824 L
.47198 .33826 L
.47198 .33828 L
.47197 .33829 L
.47196 .33831 L
.47196 .33833 L
.47195 .33835 L
.47194 .33837 L
.47194 .33839 L
.47193 .33841 L
.47192 .33843 L
.47192 .33845 L
.47191 .33846 L
Mistroke
.4719 .33848 L
.4719 .3385 L
.47189 .33852 L
.47188 .33854 L
.47188 .33856 L
.47187 .33858 L
.47186 .3386 L
.47185 .33861 L
.47185 .33863 L
.47184 .33865 L
.47183 .33867 L
.47183 .33869 L
.47182 .33871 L
.47181 .33873 L
.47181 .33874 L
.4718 .33876 L
.47179 .33878 L
.47178 .3388 L
.47178 .33882 L
.47177 .33884 L
.47176 .33886 L
.47175 .33888 L
.47175 .33889 L
.47174 .33891 L
.47173 .33893 L
.47173 .33895 L
.47172 .33897 L
.47171 .33899 L
.4717 .33901 L
.4717 .33902 L
.47169 .33904 L
.47168 .33906 L
.47167 .33908 L
.47167 .3391 L
.47166 .33912 L
.47165 .33914 L
.47164 .33915 L
.47164 .33917 L
.47163 .33919 L
.47162 .33921 L
.47161 .33923 L
.47161 .33925 L
.4716 .33926 L
.47159 .33928 L
.47158 .3393 L
.47158 .33932 L
.47157 .33934 L
.47156 .33936 L
.47155 .33938 L
.47155 .33939 L
Mistroke
.47154 .33941 L
.47153 .33943 L
.47152 .33945 L
.47151 .33947 L
.47151 .33949 L
.4715 .3395 L
.47149 .33952 L
.47148 .33954 L
.47148 .33956 L
.47147 .33958 L
.47146 .3396 L
.47145 .33962 L
.47144 .33963 L
.47144 .33965 L
.47143 .33967 L
.47142 .33969 L
.47141 .33971 L
.4714 .33973 L
.4714 .33974 L
.47139 .33976 L
.47138 .33978 L
.47137 .3398 L
.47136 .33982 L
.47136 .33984 L
.47135 .33985 L
.47134 .33987 L
.47133 .33989 L
.47132 .33991 L
.47132 .33993 L
.47131 .33994 L
.4713 .33996 L
.47129 .33998 L
.47128 .34 L
.47127 .34002 L
.47127 .34004 L
.47126 .34005 L
.47125 .34007 L
.47124 .34009 L
.47123 .34011 L
.47122 .34013 L
.47122 .34015 L
.47121 .34016 L
.4712 .34018 L
.47119 .3402 L
.47118 .34022 L
.47117 .34024 L
.47117 .34025 L
.47116 .34027 L
.47115 .34029 L
.47114 .34031 L
Mistroke
.47113 .34033 L
.47112 .34034 L
.47112 .34036 L
.47111 .34038 L
.4711 .3404 L
.47109 .34042 L
.47108 .34044 L
.47107 .34045 L
.47106 .34047 L
.47106 .34049 L
.47105 .34051 L
.47104 .34053 L
.47103 .34054 L
.47102 .34056 L
.47101 .34058 L
.471 .3406 L
.47099 .34062 L
.47099 .34063 L
.47098 .34065 L
.47097 .34067 L
.47096 .34069 L
.47095 .34071 L
.47094 .34072 L
.47093 .34074 L
.47092 .34076 L
.47092 .34078 L
.47091 .34079 L
.4709 .34081 L
.47089 .34083 L
.47088 .34085 L
.47087 .34087 L
.47086 .34088 L
.47085 .3409 L
.47084 .34092 L
.47084 .34094 L
.47083 .34096 L
.47082 .34097 L
.47081 .34099 L
.4708 .34101 L
.47079 .34103 L
.47078 .34105 L
.47077 .34106 L
.47076 .34108 L
.47075 .3411 L
.47075 .34112 L
.47074 .34113 L
.47073 .34115 L
.47072 .34117 L
.47071 .34119 L
.4707 .3412 L
Mistroke
.47069 .34122 L
.47068 .34124 L
.47067 .34126 L
.47066 .34128 L
.47065 .34129 L
.47064 .34131 L
.47063 .34133 L
.47063 .34135 L
.47062 .34136 L
.47061 .34138 L
.4706 .3414 L
.47059 .34142 L
.47058 .34143 L
.47057 .34145 L
.47056 .34147 L
.47055 .34149 L
.47054 .34151 L
.47053 .34152 L
.47052 .34154 L
.47051 .34156 L
.4705 .34158 L
.47049 .34159 L
.47048 .34161 L
.47048 .34163 L
.47047 .34165 L
.47046 .34166 L
.47045 .34168 L
.47044 .3417 L
.47043 .34172 L
.47042 .34173 L
.47041 .34175 L
.4704 .34177 L
.47039 .34179 L
.47038 .3418 L
.47037 .34182 L
.47036 .34184 L
.47035 .34186 L
.47034 .34187 L
.47033 .34189 L
.47032 .34191 L
.47031 .34193 L
.4703 .34194 L
.47029 .34196 L
.47028 .34198 L
.47027 .34199 L
.47026 .34201 L
.47025 .34203 L
.47024 .34205 L
.47023 .34206 L
.47022 .34208 L
Mistroke
.47021 .3421 L
.4702 .34212 L
.47019 .34213 L
.47018 .34215 L
.47017 .34217 L
.47016 .34219 L
.47015 .3422 L
.47014 .34222 L
.47014 .34224 L
.47013 .34225 L
.47012 .34227 L
.47011 .34229 L
.4701 .34231 L
.47009 .34232 L
.47008 .34234 L
.47007 .34236 L
.47006 .34237 L
.47005 .34239 L
.47004 .34241 L
.47002 .34243 L
.47001 .34244 L
.47 .34246 L
.46999 .34248 L
.46998 .34249 L
.46997 .34251 L
.46996 .34253 L
.46995 .34255 L
.46994 .34256 L
.46993 .34258 L
.46992 .3426 L
.46991 .34261 L
.4699 .34263 L
.46989 .34265 L
.46988 .34267 L
.46987 .34268 L
.46986 .3427 L
.46985 .34272 L
.46984 .34273 L
.46983 .34275 L
.46982 .34277 L
.46981 .34278 L
.4698 .3428 L
.46979 .34282 L
.46978 .34284 L
.46977 .34285 L
.46976 .34287 L
.46975 .34289 L
.46974 .3429 L
.46973 .34292 L
.46972 .34294 L
Mistroke
.46971 .34295 L
.4697 .34297 L
.46969 .34299 L
.46968 .343 L
.46967 .34302 L
.46965 .34304 L
.46964 .34305 L
.46963 .34307 L
.46962 .34309 L
.46961 .3431 L
.4696 .34312 L
.46959 .34314 L
.46958 .34316 L
.46957 .34317 L
.46956 .34319 L
.46955 .34321 L
.46954 .34322 L
.46953 .34324 L
.46952 .34326 L
.46951 .34327 L
.4695 .34329 L
.46949 .34331 L
.46948 .34332 L
.46946 .34334 L
.46945 .34336 L
.46944 .34337 L
.46943 .34339 L
.46942 .34341 L
.46941 .34342 L
.4694 .34344 L
.46939 .34346 L
.46938 .34347 L
.46937 .34349 L
.46936 .3435 L
.46935 .34352 L
.46934 .34354 L
.46932 .34355 L
.46931 .34357 L
.4693 .34359 L
.46929 .3436 L
.46928 .34362 L
.46927 .34364 L
.46926 .34365 L
.46925 .34367 L
.46924 .34369 L
.46923 .3437 L
.46922 .34372 L
.46921 .34374 L
.46919 .34375 L
.46918 .34377 L
Mistroke
.46917 .34378 L
.46916 .3438 L
.46915 .34382 L
.46914 .34383 L
.46913 .34385 L
.46912 .34387 L
.46911 .34388 L
.4691 .3439 L
.46908 .34392 L
.46907 .34393 L
.46906 .34395 L
.46905 .34396 L
.46904 .34398 L
.46903 .344 L
.46902 .34401 L
.46901 .34403 L
.469 .34405 L
.46898 .34406 L
.46897 .34408 L
.46896 .34409 L
.46895 .34411 L
.46894 .34413 L
.46893 .34414 L
.46892 .34416 L
.46891 .34418 L
.4689 .34419 L
.46888 .34421 L
.46887 .34422 L
.46886 .34424 L
.46885 .34426 L
.46884 .34427 L
.46883 .34429 L
.46882 .3443 L
.46881 .34432 L
.46879 .34434 L
.46878 .34435 L
.46877 .34437 L
.46876 .34438 L
.46875 .3444 L
.46874 .34442 L
.46873 .34443 L
.46871 .34445 L
.4687 .34446 L
.46869 .34448 L
.46868 .3445 L
.46867 .34451 L
.46866 .34453 L
.46865 .34454 L
.46864 .34456 L
.46862 .34458 L
Mistroke
.46861 .34459 L
.4686 .34461 L
.46859 .34462 L
.46858 .34464 L
.46857 .34466 L
.46856 .34467 L
.46854 .34469 L
.46853 .3447 L
.46852 .34472 L
.46851 .34473 L
.4685 .34475 L
.46849 .34477 L
.46847 .34478 L
.46846 .3448 L
.46845 .34481 L
.46844 .34483 L
.46843 .34484 L
.46842 .34486 L
.46841 .34488 L
.46839 .34489 L
.46838 .34491 L
.46837 .34492 L
.46836 .34494 L
.46835 .34495 L
.46834 .34497 L
.46832 .34499 L
.46831 .345 L
.4683 .34502 L
.46829 .34503 L
.46828 .34505 L
.46827 .34506 L
.46825 .34508 L
.46824 .34509 L
.46823 .34511 L
.46822 .34513 L
.46821 .34514 L
.4682 .34516 L
.46818 .34517 L
.46817 .34519 L
.46816 .3452 L
.46815 .34522 L
.46814 .34523 L
.46812 .34525 L
.46811 .34526 L
.4681 .34528 L
.46809 .3453 L
.46808 .34531 L
.46807 .34533 L
.46805 .34534 L
.46804 .34536 L
Mistroke
.46803 .34537 L
.46802 .34539 L
.46801 .3454 L
.46799 .34542 L
.46798 .34543 L
.46797 .34545 L
.46796 .34546 L
.46795 .34548 L
.46794 .3455 L
.46792 .34551 L
.46791 .34553 L
.4679 .34554 L
.46789 .34556 L
.46788 .34557 L
.46786 .34559 L
.46785 .3456 L
.46784 .34562 L
.46783 .34563 L
.46782 .34565 L
.4678 .34566 L
.46779 .34568 L
.46778 .34569 L
.46777 .34571 L
.46776 .34572 L
.46774 .34574 L
.46773 .34575 L
.46772 .34577 L
.46771 .34578 L
.4677 .3458 L
.46768 .34581 L
.46767 .34583 L
.46766 .34584 L
.46765 .34586 L
.46764 .34587 L
.46762 .34589 L
.46761 .3459 L
.4676 .34592 L
.46759 .34593 L
.46757 .34595 L
.46756 .34596 L
.46755 .34598 L
.46754 .34599 L
.46753 .34601 L
.46751 .34602 L
.4675 .34604 L
.46749 .34605 L
.46748 .34607 L
.46747 .34608 L
.46745 .3461 L
.46744 .34611 L
Mistroke
.46743 .34613 L
.46742 .34614 L
.4674 .34616 L
.46739 .34617 L
.46738 .34619 L
.46737 .3462 L
.46736 .34622 L
.46734 .34623 L
.46733 .34624 L
.46732 .34626 L
.46731 .34627 L
.46729 .34629 L
.46728 .3463 L
.46727 .34632 L
.46726 .34633 L
.46724 .34635 L
.46723 .34636 L
.46722 .34638 L
.46721 .34639 L
.4672 .34641 L
.46718 .34642 L
.46717 .34643 L
.46716 .34645 L
.46715 .34646 L
.46713 .34648 L
.46712 .34649 L
.46711 .34651 L
.4671 .34652 L
.46708 .34654 L
.46707 .34655 L
.46706 .34657 L
.46705 .34658 L
.46703 .34659 L
.46702 .34661 L
.46701 .34662 L
.467 .34664 L
.46699 .34665 L
.46697 .34667 L
.46696 .34668 L
.46695 .34669 L
.46694 .34671 L
.46692 .34672 L
.46691 .34674 L
.4669 .34675 L
.46689 .34677 L
.46687 .34678 L
.46686 .3468 L
.46685 .34681 L
.46684 .34682 L
.46682 .34684 L
Mistroke
.46681 .34685 L
.4668 .34687 L
.46679 .34688 L
.46677 .34689 L
.46676 .34691 L
.46675 .34692 L
.46674 .34694 L
.46672 .34695 L
.46671 .34697 L
.4667 .34698 L
.46669 .34699 L
.46667 .34701 L
.46666 .34702 L
.46665 .34704 L
.46663 .34705 L
.46662 .34706 L
.46661 .34708 L
.4666 .34709 L
.46658 .34711 L
.46657 .34712 L
.46656 .34713 L
.46655 .34715 L
.46653 .34716 L
.46652 .34718 L
.46651 .34719 L
.4665 .3472 L
.46648 .34722 L
.46647 .34723 L
.46646 .34725 L
.46645 .34726 L
.46643 .34727 L
.46642 .34729 L
.46641 .3473 L
.46639 .34732 L
.46638 .34733 L
.46637 .34734 L
.46636 .34736 L
.46634 .34737 L
.46633 .34738 L
.46632 .3474 L
.46631 .34741 L
.46629 .34743 L
.46628 .34744 L
.46627 .34745 L
.46625 .34747 L
.46624 .34748 L
.46623 .34749 L
.46622 .34751 L
.4662 .34752 L
.46619 .34754 L
Mistroke
.46618 .34755 L
.46617 .34756 L
.46615 .34758 L
.46614 .34759 L
.46613 .3476 L
.46611 .34762 L
.4661 .34763 L
.46609 .34764 L
.46608 .34766 L
.46606 .34767 L
.46605 .34768 L
.46604 .3477 L
.46602 .34771 L
.46601 .34773 L
.466 .34774 L
.46599 .34775 L
.46597 .34777 L
.46596 .34778 L
.46595 .34779 L
.46594 .34781 L
.46592 .34782 L
.46591 .34783 L
.4659 .34785 L
.46588 .34786 L
.46587 .34787 L
.46586 .34789 L
.46585 .3479 L
.46583 .34791 L
.46582 .34793 L
.46581 .34794 L
.46579 .34795 L
.46578 .34797 L
.46577 .34798 L
.46575 .34799 L
.46574 .34801 L
.46573 .34802 L
.46572 .34803 L
.4657 .34805 L
.46569 .34806 L
.46568 .34807 L
.46566 .34808 L
.46565 .3481 L
.46564 .34811 L
.46563 .34812 L
.46561 .34814 L
.4656 .34815 L
.46559 .34816 L
.46557 .34818 L
.46556 .34819 L
.46555 .3482 L
Mistroke
.46554 .34822 L
.46552 .34823 L
.46551 .34824 L
.4655 .34825 L
.46548 .34827 L
.46547 .34828 L
.46546 .34829 L
.46544 .34831 L
.46543 .34832 L
.46542 .34833 L
.46541 .34835 L
.46539 .34836 L
.46538 .34837 L
.46537 .34838 L
.46535 .3484 L
.46534 .34841 L
.46533 .34842 L
.46531 .34844 L
.4653 .34845 L
.46529 .34846 L
.46528 .34847 L
.46526 .34849 L
.46525 .3485 L
.46524 .34851 L
.46522 .34852 L
.46521 .34854 L
.4652 .34855 L
.46518 .34856 L
.46517 .34858 L
.46516 .34859 L
.46514 .3486 L
.46513 .34861 L
.46512 .34863 L
.46511 .34864 L
.46509 .34865 L
.46508 .34866 L
.46507 .34868 L
.46505 .34869 L
.46504 .3487 L
.46503 .34871 L
.46501 .34873 L
.465 .34874 L
.46499 .34875 L
.46497 .34876 L
.46496 .34878 L
.46495 .34879 L
.46494 .3488 L
.46492 .34881 L
.46491 .34883 L
.4649 .34884 L
Mistroke
.46488 .34885 L
.46487 .34886 L
.46486 .34888 L
.46484 .34889 L
.46483 .3489 L
.46482 .34891 L
.4648 .34893 L
.46479 .34894 L
.46478 .34895 L
.46476 .34896 L
.46475 .34898 L
.46474 .34899 L
.46473 .349 L
.46471 .34901 L
.4647 .34902 L
.46469 .34904 L
.46467 .34905 L
.46466 .34906 L
.46465 .34907 L
.46463 .34909 L
.46462 .3491 L
.46461 .34911 L
.46459 .34912 L
.46458 .34913 L
.46457 .34915 L
.46455 .34916 L
.46454 .34917 L
.46453 .34918 L
.46451 .34919 L
.4645 .34921 L
.46449 .34922 L
.46447 .34923 L
.46446 .34924 L
.46445 .34925 L
.46444 .34927 L
.46442 .34928 L
.46441 .34929 L
.4644 .3493 L
.46438 .34931 L
.46437 .34933 L
.46436 .34934 L
.46434 .34935 L
.46433 .34936 L
.46432 .34937 L
.4643 .34939 L
.46429 .3494 L
.46428 .34941 L
.46426 .34942 L
.46425 .34943 L
.46424 .34945 L
Mistroke
.46422 .34946 L
.46421 .34947 L
.4642 .34948 L
.46418 .34949 L
.46417 .3495 L
.46416 .34952 L
.46414 .34953 L
.46413 .34954 L
.46412 .34955 L
.4641 .34956 L
.46409 .34957 L
.46408 .34959 L
.46407 .3496 L
.46405 .34961 L
.46404 .34962 L
.46403 .34963 L
.46401 .34964 L
.464 .34966 L
.46399 .34967 L
.46397 .34968 L
.46396 .34969 L
.46395 .3497 L
.46393 .34971 L
.46392 .34972 L
.46391 .34974 L
.46389 .34975 L
.46388 .34976 L
.46387 .34977 L
.46385 .34978 L
.46384 .34979 L
.46383 .34981 L
.46381 .34982 L
.4638 .34983 L
.46379 .34984 L
.46377 .34985 L
.46376 .34986 L
.46375 .34987 L
.46373 .34988 L
.46372 .3499 L
.46371 .34991 L
.46369 .34992 L
.46368 .34993 L
.46367 .34994 L
.46365 .34995 L
.46364 .34996 L
.46363 .34997 L
.46361 .34999 L
.4636 .35 L
.46359 .35001 L
.46357 .35002 L
Mistroke
.46356 .35003 L
.46355 .35004 L
.46353 .35005 L
.46352 .35006 L
.46351 .35008 L
.46349 .35009 L
.46348 .3501 L
.46347 .35011 L
.46345 .35012 L
.46344 .35013 L
.46343 .35014 L
.46341 .35015 L
.4634 .35016 L
.46339 .35017 L
.46338 .35019 L
.46336 .3502 L
.46335 .35021 L
.46334 .35022 L
.46332 .35023 L
.46331 .35024 L
.4633 .35025 L
.46328 .35026 L
.46327 .35027 L
.46326 .35028 L
.46324 .3503 L
.46323 .35031 L
.46322 .35032 L
.4632 .35033 L
.46319 .35034 L
.46318 .35035 L
.46316 .35036 L
.46315 .35037 L
.46314 .35038 L
.46312 .35039 L
.46311 .3504 L
.4631 .35041 L
.46308 .35042 L
.46307 .35044 L
.46306 .35045 L
.46304 .35046 L
.46303 .35047 L
.46302 .35048 L
.463 .35049 L
.46299 .3505 L
.46298 .35051 L
.46296 .35052 L
.46295 .35053 L
.46294 .35054 L
.46292 .35055 L
.46291 .35056 L
Mistroke
.4629 .35057 L
.46288 .35058 L
.46287 .35059 L
.46286 .3506 L
.46284 .35061 L
.46283 .35063 L
.46282 .35064 L
.4628 .35065 L
.46279 .35066 L
.46278 .35067 L
.46276 .35068 L
.46275 .35069 L
.46274 .3507 L
.46272 .35071 L
.46271 .35072 L
.4627 .35073 L
.46268 .35074 L
.46267 .35075 L
.46266 .35076 L
.46264 .35077 L
.46263 .35078 L
.46262 .35079 L
.4626 .3508 L
.46259 .35081 L
.46258 .35082 L
.46256 .35083 L
.46255 .35084 L
.46254 .35085 L
.46252 .35086 L
.46251 .35087 L
.4625 .35088 L
.46248 .35089 L
.46247 .3509 L
.46246 .35091 L
.46244 .35092 L
.46243 .35093 L
.46242 .35094 L
.4624 .35095 L
.46239 .35096 L
.46238 .35097 L
.46236 .35098 L
.46235 .35099 L
.46234 .351 L
.46232 .35101 L
.46231 .35102 L
.4623 .35103 L
.46228 .35104 L
.46227 .35105 L
.46226 .35106 L
.46225 .35107 L
Mistroke
.46223 .35108 L
.46222 .35109 L
.46221 .3511 L
.46219 .35111 L
.46218 .35112 L
.46217 .35113 L
.46215 .35114 L
.46214 .35115 L
.46213 .35116 L
.46211 .35117 L
.4621 .35118 L
.46209 .35119 L
.46207 .3512 L
.46206 .35121 L
.46205 .35122 L
.46203 .35123 L
.46202 .35124 L
.46201 .35125 L
.46199 .35126 L
.46198 .35127 L
.46197 .35128 L
.46195 .35129 L
.46194 .3513 L
.46193 .35131 L
.46191 .35132 L
.4619 .35133 L
.46189 .35134 L
.46187 .35135 L
.46186 .35135 L
.46185 .35136 L
.46183 .35137 L
.46182 .35138 L
.46181 .35139 L
.46179 .3514 L
.46178 .35141 L
.46177 .35142 L
.46175 .35143 L
.46174 .35144 L
.46173 .35145 L
.46171 .35146 L
.4617 .35147 L
.46169 .35148 L
.46168 .35149 L
.46166 .3515 L
.46165 .35151 L
.46164 .35151 L
.46162 .35152 L
.46161 .35153 L
.4616 .35154 L
.46158 .35155 L
Mistroke
.46157 .35156 L
.46156 .35157 L
.46154 .35158 L
.46153 .35159 L
.46152 .3516 L
.4615 .35161 L
.46149 .35162 L
.46148 .35163 L
.46146 .35163 L
.46145 .35164 L
.46144 .35165 L
.46142 .35166 L
.46141 .35167 L
.4614 .35168 L
.46138 .35169 L
.46137 .3517 L
.46136 .35171 L
.46135 .35172 L
.46133 .35173 L
.46132 .35173 L
.46131 .35174 L
.46129 .35175 L
.46128 .35176 L
.46127 .35177 L
.46125 .35178 L
.46124 .35179 L
.46123 .3518 L
.46121 .35181 L
.4612 .35181 L
.46119 .35182 L
.46117 .35183 L
.46116 .35184 L
.46115 .35185 L
.46113 .35186 L
.46112 .35187 L
.46111 .35188 L
.46109 .35189 L
.46108 .35189 L
.46107 .3519 L
.46106 .35191 L
.46104 .35192 L
.46103 .35193 L
.46102 .35194 L
.461 .35195 L
.46099 .35196 L
.46098 .35196 L
.46096 .35197 L
.46095 .35198 L
.46094 .35199 L
.46092 .352 L
Mistroke
.46091 .35201 L
.4609 .35202 L
.46088 .35202 L
.46087 .35203 L
.46086 .35204 L
.46085 .35205 L
.46083 .35206 L
.46082 .35207 L
.46081 .35208 L
.46079 .35208 L
.46078 .35209 L
.46077 .3521 L
.46075 .35211 L
.46074 .35212 L
.46073 .35213 L
.46071 .35213 L
.4607 .35214 L
.46069 .35215 L
.46068 .35216 L
.46066 .35217 L
.46065 .35218 L
.46064 .35219 L
.46062 .35219 L
.46061 .3522 L
.4606 .35221 L
.46058 .35222 L
.46057 .35223 L
.46056 .35223 L
.46055 .35224 L
.46053 .35225 L
.46052 .35226 L
.46051 .35227 L
.46049 .35228 L
.46048 .35228 L
.46047 .35229 L
.46045 .3523 L
.46044 .35231 L
.46043 .35232 L
.46041 .35232 L
.4604 .35233 L
.46039 .35234 L
.46038 .35235 L
.46036 .35236 L
.46035 .35237 L
.46034 .35237 L
.46032 .35238 L
.46031 .35239 L
.4603 .3524 L
.46028 .35241 L
.46027 .35241 L
Mistroke
.46026 .35242 L
.46025 .35243 L
.46023 .35244 L
.46022 .35245 L
.46021 .35245 L
.46019 .35246 L
.46018 .35247 L
.46017 .35248 L
.46016 .35248 L
.46014 .35249 L
.46013 .3525 L
.46012 .35251 L
.4601 .35252 L
.46009 .35252 L
.46008 .35253 L
.46006 .35254 L
.46005 .35255 L
.46004 .35256 L
.46003 .35256 L
.46001 .35257 L
.46 .35258 L
.45999 .35259 L
.45997 .35259 L
.45996 .3526 L
.45995 .35261 L
.45994 .35262 L
.45992 .35262 L
.45991 .35263 L
.4599 .35264 L
.45988 .35265 L
.45987 .35265 L
.45986 .35266 L
.45985 .35267 L
.45983 .35268 L
.45982 .35269 L
.45981 .35269 L
.45979 .3527 L
.45978 .35271 L
.45977 .35272 L
.45976 .35272 L
.45974 .35273 L
.45973 .35274 L
.45972 .35274 L
.4597 .35275 L
.45969 .35276 L
.45968 .35277 L
.45967 .35277 L
.45965 .35278 L
.45964 .35279 L
.45963 .3528 L
Mistroke
.45961 .3528 L
.4596 .35281 L
.45959 .35282 L
.45958 .35283 L
.45956 .35283 L
.45955 .35284 L
.45954 .35285 L
.45952 .35286 L
.45951 .35286 L
.4595 .35287 L
.45949 .35288 L
.45947 .35288 L
.45946 .35289 L
.45945 .3529 L
.45944 .35291 L
.45942 .35291 L
.45941 .35292 L
.4594 .35293 L
.45938 .35293 L
.45937 .35294 L
.45936 .35295 L
.45935 .35296 L
.45933 .35296 L
.45932 .35297 L
.45931 .35298 L
.4593 .35298 L
.45928 .35299 L
.45927 .353 L
.45926 .353 L
.45924 .35301 L
.45923 .35302 L
.45922 .35303 L
.45921 .35303 L
.45919 .35304 L
.45918 .35305 L
.45917 .35305 L
.45916 .35306 L
.45914 .35307 L
.45913 .35307 L
.45912 .35308 L
.45911 .35309 L
.45909 .35309 L
.45908 .3531 L
.45907 .35311 L
.45905 .35311 L
.45904 .35312 L
.45903 .35313 L
.45902 .35314 L
.459 .35314 L
.45899 .35315 L
Mistroke
.45898 .35316 L
.45897 .35316 L
.45895 .35317 L
.45894 .35318 L
.45893 .35318 L
.45892 .35319 L
.4589 .3532 L
.45889 .3532 L
.45888 .35321 L
.45887 .35322 L
.45885 .35322 L
.45884 .35323 L
.45883 .35324 L
.45882 .35324 L
.4588 .35325 L
.45879 .35325 L
.45878 .35326 L
.45877 .35327 L
.45875 .35327 L
.45874 .35328 L
.45873 .35329 L
.45872 .35329 L
.4587 .3533 L
.45869 .35331 L
.45868 .35331 L
.45867 .35332 L
.45865 .35333 L
.45864 .35333 L
.45863 .35334 L
.45862 .35334 L
.4586 .35335 L
.45859 .35336 L
.45858 .35336 L
.45857 .35337 L
.45855 .35338 L
.45854 .35338 L
.45853 .35339 L
.45852 .3534 L
.4585 .3534 L
.45849 .35341 L
.45848 .35341 L
.45847 .35342 L
.45845 .35343 L
.45844 .35343 L
.45843 .35344 L
.45842 .35345 L
.4584 .35345 L
.45839 .35346 L
.45838 .35346 L
.45837 .35347 L
Mistroke
.45835 .35348 L
.45834 .35348 L
.45833 .35349 L
.45832 .35349 L
.4583 .3535 L
.45829 .35351 L
.45828 .35351 L
.45827 .35352 L
.45826 .35352 L
.45824 .35353 L
.45823 .35354 L
.45822 .35354 L
.45821 .35355 L
.45819 .35355 L
.45818 .35356 L
.45817 .35357 L
.45816 .35357 L
.45814 .35358 L
.45813 .35358 L
.45812 .35359 L
.45811 .3536 L
.4581 .3536 L
.45808 .35361 L
.45807 .35361 L
.45806 .35362 L
.45805 .35362 L
.45803 .35363 L
.45802 .35364 L
.45801 .35364 L
.458 .35365 L
.45799 .35365 L
.45797 .35366 L
.45796 .35366 L
.45795 .35367 L
.45794 .35368 L
.45792 .35368 L
.45791 .35369 L
.4579 .35369 L
.45789 .3537 L
.45788 .3537 L
.45786 .35371 L
.45785 .35372 L
.45784 .35372 L
.45783 .35373 L
.45781 .35373 L
.4578 .35374 L
.45779 .35374 L
.45778 .35375 L
.45777 .35375 L
.45775 .35376 L
Mistroke
.45774 .35377 L
.45773 .35377 L
.45772 .35378 L
.45771 .35378 L
.45769 .35379 L
.45768 .35379 L
.45767 .3538 L
.45766 .3538 L
.45765 .35381 L
.45763 .35381 L
.45762 .35382 L
.45761 .35383 L
.4576 .35383 L
.45758 .35384 L
.45757 .35384 L
.45756 .35385 L
.45755 .35385 L
.45754 .35386 L
.45752 .35386 L
.45751 .35387 L
.4575 .35387 L
.45749 .35388 L
.45748 .35388 L
.45746 .35389 L
.45745 .35389 L
.45744 .3539 L
.45743 .3539 L
.45742 .35391 L
.4574 .35392 L
.45739 .35392 L
.45738 .35393 L
.45737 .35393 L
.45736 .35394 L
.45734 .35394 L
.45733 .35395 L
.45732 .35395 L
.45731 .35396 L
.4573 .35396 L
.45729 .35397 L
.45727 .35397 L
.45726 .35398 L
.45725 .35398 L
.45724 .35399 L
.45723 .35399 L
.45721 .354 L
.4572 .354 L
.45719 .35401 L
.45718 .35401 L
.45717 .35402 L
.45715 .35402 L
Mistroke
.45714 .35403 L
.45713 .35403 L
.45712 .35404 L
.45711 .35404 L
.4571 .35405 L
.45708 .35405 L
.45707 .35406 L
.45706 .35406 L
.45705 .35406 L
.45704 .35407 L
.45702 .35407 L
.45701 .35408 L
.457 .35408 L
.45699 .35409 L
.45698 .35409 L
.45697 .3541 L
.45695 .3541 L
.45694 .35411 L
.45693 .35411 L
.45692 .35412 L
.45691 .35412 L
.4569 .35413 L
.45688 .35413 L
.45687 .35414 L
.45686 .35414 L
.45685 .35415 L
.45684 .35415 L
.45683 .35415 L
.45681 .35416 L
.4568 .35416 L
.45679 .35417 L
.45678 .35417 L
.45677 .35418 L
.45676 .35418 L
.45674 .35419 L
.45673 .35419 L
.45672 .3542 L
.45671 .3542 L
.4567 .3542 L
.45669 .35421 L
.45667 .35421 L
.45666 .35422 L
.45665 .35422 L
.45664 .35423 L
.45663 .35423 L
.45662 .35424 L
.4566 .35424 L
.45659 .35424 L
.45658 .35425 L
.45657 .35425 L
Mistroke
.45656 .35426 L
.45655 .35426 L
.45654 .35427 L
.45652 .35427 L
.45651 .35427 L
.4565 .35428 L
.45649 .35428 L
.45648 .35429 L
.45647 .35429 L
.45645 .3543 L
.45644 .3543 L
.45643 .3543 L
.45642 .35431 L
.45641 .35431 L
.4564 .35432 L
.45639 .35432 L
.45637 .35432 L
.45636 .35433 L
.45635 .35433 L
.45634 .35434 L
.45633 .35434 L
.45632 .35435 L
.45631 .35435 L
.45629 .35435 L
.45628 .35436 L
.45627 .35436 L
.45626 .35437 L
.45625 .35437 L
.45624 .35437 L
.45623 .35438 L
.45621 .35438 L
.4562 .35439 L
.45619 .35439 L
.45618 .35439 L
.45617 .3544 L
.45616 .3544 L
.45615 .35441 L
.45614 .35441 L
.45612 .35441 L
.45611 .35442 L
.4561 .35442 L
.45609 .35443 L
.45608 .35443 L
.45607 .35443 L
.45606 .35444 L
.45605 .35444 L
.45603 .35444 L
.45602 .35445 L
.45601 .35445 L
.456 .35446 L
Mistroke
.45599 .35446 L
.45598 .35446 L
.45597 .35447 L
.45596 .35447 L
.45594 .35447 L
.45593 .35448 L
.45592 .35448 L
.45591 .35449 L
.4559 .35449 L
.45589 .35449 L
.45588 .3545 L
.45587 .3545 L
.45586 .3545 L
.45584 .35451 L
.45583 .35451 L
.45582 .35451 L
.45581 .35452 L
.4558 .35452 L
.45579 .35453 L
.45578 .35453 L
.45577 .35453 L
.45576 .35454 L
.45574 .35454 L
.45573 .35454 L
.45572 .35455 L
.45571 .35455 L
.4557 .35455 L
.45569 .35456 L
.45568 .35456 L
.45567 .35456 L
.45566 .35457 L
.45564 .35457 L
.45563 .35457 L
.45562 .35458 L
.45561 .35458 L
.4556 .35458 L
.45559 .35459 L
.45558 .35459 L
.45557 .35459 L
.45556 .3546 L
.45555 .3546 L
.45553 .3546 L
.45552 .35461 L
.45551 .35461 L
.4555 .35461 L
.45549 .35462 L
.45548 .35462 L
.45547 .35462 L
.45546 .35463 L
.45545 .35463 L
Mistroke
.45544 .35463 L
.45543 .35464 L
.45541 .35464 L
.4554 .35464 L
.45539 .35465 L
.45538 .35465 L
.45537 .35465 L
.45536 .35466 L
.45535 .35466 L
.45534 .35466 L
.45533 .35467 L
.45532 .35467 L
.45531 .35467 L
.4553 .35468 L
.45529 .35468 L
.45527 .35468 L
.45526 .35468 L
.45525 .35469 L
.45524 .35469 L
.45523 .35469 L
.45522 .3547 L
.45521 .3547 L
.4552 .3547 L
.45519 .35471 L
.45518 .35471 L
.45517 .35471 L
.45516 .35471 L
.45515 .35472 L
.45513 .35472 L
.45512 .35472 L
.45511 .35473 L
.4551 .35473 L
.45509 .35473 L
.45508 .35473 L
.45507 .35474 L
.45506 .35474 L
.45505 .35474 L
.45504 .35475 L
.45503 .35475 L
.45502 .35475 L
.45501 .35475 L
.455 .35476 L
.45499 .35476 L
.45498 .35476 L
.45496 .35477 L
.45495 .35477 L
.45494 .35477 L
.45493 .35477 L
.45492 .35478 L
.45491 .35478 L
Mistroke
.4549 .35478 L
.45489 .35478 L
.45488 .35479 L
.45487 .35479 L
.45486 .35479 L
.45485 .3548 L
.45484 .3548 L
.45483 .3548 L
.45482 .3548 L
.45481 .35481 L
.4548 .35481 L
.45479 .35481 L
.45478 .35481 L
.45477 .35482 L
.45476 .35482 L
.45474 .35482 L
.45473 .35482 L
.45472 .35483 L
.45471 .35483 L
.4547 .35483 L
.45469 .35483 L
.45468 .35484 L
.45467 .35484 L
.45466 .35484 L
.45465 .35484 L
.45464 .35485 L
.45463 .35485 L
.45462 .35485 L
.45461 .35485 L
.4546 .35486 L
.45459 .35486 L
.45458 .35486 L
.45457 .35486 L
.45456 .35486 L
.45455 .35487 L
.45454 .35487 L
.45453 .35487 L
.45452 .35487 L
.45451 .35488 L
.4545 .35488 L
.45449 .35488 L
.45448 .35488 L
.45447 .35489 L
.45446 .35489 L
.45445 .35489 L
.45444 .35489 L
.45443 .35489 L
.45442 .3549 L
.45441 .3549 L
.45439 .3549 L
Mistroke
.45438 .3549 L
.45437 .35491 L
.45436 .35491 L
.45435 .35491 L
.45434 .35491 L
.45433 .35491 L
.45432 .35492 L
.45431 .35492 L
.4543 .35492 L
.45429 .35492 L
.45428 .35492 L
.45427 .35493 L
.45426 .35493 L
.45425 .35493 L
.45424 .35493 L
.45423 .35493 L
.45422 .35494 L
.45421 .35494 L
.4542 .35494 L
.45419 .35494 L
.45418 .35494 L
.45417 .35495 L
.45416 .35495 L
.45415 .35495 L
.45414 .35495 L
.45413 .35495 L
.45412 .35496 L
.45411 .35496 L
.4541 .35496 L
.45409 .35496 L
.45408 .35496 L
.45407 .35497 L
.45406 .35497 L
.45405 .35497 L
.45404 .35497 L
.45403 .35497 L
.45402 .35498 L
.45401 .35498 L
.454 .35498 L
.45399 .35498 L
.45398 .35498 L
.45397 .35498 L
.45396 .35499 L
.45396 .35499 L
.45395 .35499 L
.45394 .35499 L
.45393 .35499 L
.45392 .35499 L
.45391 .355 L
.4539 .355 L
Mistroke
.45389 .355 L
.45388 .355 L
.45387 .355 L
.45386 .355 L
.45385 .35501 L
.45384 .35501 L
.45383 .35501 L
.45382 .35501 L
.45381 .35501 L
.4538 .35501 L
.45379 .35502 L
.45378 .35502 L
.45377 .35502 L
.45376 .35502 L
.45375 .35502 L
.45374 .35502 L
.45373 .35503 L
.45372 .35503 L
.45371 .35503 L
.4537 .35503 L
.45369 .35503 L
.45368 .35503 L
.45367 .35503 L
.45366 .35504 L
.45365 .35504 L
.45364 .35504 L
.45364 .35504 L
.45363 .35504 L
.45362 .35504 L
.45361 .35504 L
.4536 .35505 L
.45359 .35505 L
.45358 .35505 L
.45357 .35505 L
.45356 .35505 L
.45355 .35505 L
.45354 .35505 L
.45353 .35506 L
.45352 .35506 L
.45351 .35506 L
.4535 .35506 L
.45349 .35506 L
.45348 .35506 L
.45347 .35506 L
.45346 .35506 L
.45345 .35507 L
.45345 .35507 L
.45344 .35507 L
.45343 .35507 L
.45342 .35507 L
Mistroke
.45341 .35507 L
.4534 .35507 L
.45339 .35507 L
.45338 .35508 L
.45337 .35508 L
.45336 .35508 L
.45335 .35508 L
.45334 .35508 L
.45333 .35508 L
.45332 .35508 L
.45331 .35508 L
.45331 .35508 L
.4533 .35509 L
.45329 .35509 L
.45328 .35509 L
.45327 .35509 L
.45326 .35509 L
.45325 .35509 L
.45324 .35509 L
.45323 .35509 L
.45322 .35509 L
.45321 .3551 L
.4532 .3551 L
.45319 .3551 L
.45319 .3551 L
.45318 .3551 L
.45317 .3551 L
.45316 .3551 L
.45315 .3551 L
.45314 .3551 L
.45313 .3551 L
.45312 .3551 L
.45311 .35511 L
.4531 .35511 L
.45309 .35511 L
.45308 .35511 L
.45308 .35511 L
.45307 .35511 L
.45306 .35511 L
.45305 .35511 L
.45304 .35511 L
.45303 .35511 L
.45302 .35511 L
.45301 .35512 L
.453 .35512 L
.45299 .35512 L
.45298 .35512 L
.45298 .35512 L
.45297 .35512 L
.45296 .35512 L
Mistroke
.45295 .35512 L
.45294 .35512 L
.45293 .35512 L
.45292 .35512 L
.45291 .35512 L
.4529 .35512 L
.4529 .35513 L
.45289 .35513 L
.45288 .35513 L
.45287 .35513 L
.45286 .35513 L
.45285 .35513 L
.45284 .35513 L
.45283 .35513 L
.45282 .35513 L
.45282 .35513 L
.45281 .35513 L
.4528 .35513 L
.45279 .35513 L
.45278 .35513 L
.45277 .35513 L
.45276 .35513 L
.45275 .35514 L
.45274 .35514 L
.45274 .35514 L
.45273 .35514 L
.45272 .35514 L
.45271 .35514 L
.4527 .35514 L
.45269 .35514 L
.45268 .35514 L
.45267 .35514 L
.45267 .35514 L
.45266 .35514 L
.45265 .35514 L
.45264 .35514 L
.45263 .35514 L
.45262 .35514 L
.45261 .35514 L
.4526 .35514 L
.4526 .35514 L
.45259 .35514 L
.45258 .35514 L
.45257 .35514 L
.45256 .35515 L
.45255 .35515 L
.45254 .35515 L
.45254 .35515 L
.45253 .35515 L
.45252 .35515 L
Mistroke
.45251 .35515 L
.4525 .35515 L
.45249 .35515 L
.45248 .35515 L
.45248 .35515 L
.45247 .35515 L
.45246 .35515 L
.45245 .35515 L
.45244 .35515 L
.45243 .35515 L
.45242 .35515 L
.45242 .35515 L
.45241 .35515 L
.4524 .35515 L
.45239 .35515 L
.45238 .35515 L
.45237 .35515 L
.45237 .35515 L
.45236 .35515 L
.45235 .35515 L
.45234 .35515 L
.45233 .35515 L
.45232 .35515 L
.45232 .35515 L
.45231 .35515 L
.4523 .35515 L
.45229 .35515 L
.45228 .35515 L
.45227 .35515 L
.45227 .35515 L
.45226 .35515 L
.45225 .35515 L
.45224 .35515 L
.45223 .35515 L
.45222 .35515 L
.45222 .35515 L
.45221 .35515 L
.4522 .35515 L
.45219 .35515 L
.45218 .35515 L
.45217 .35515 L
.45217 .35515 L
.45216 .35515 L
.45215 .35515 L
.45214 .35515 L
.45213 .35515 L
.45212 .35515 L
.45212 .35515 L
.45211 .35515 L
.4521 .35515 L
Mistroke
.45209 .35515 L
.45208 .35515 L
.45208 .35515 L
.45207 .35515 L
.45206 .35515 L
.45205 .35515 L
.45204 .35515 L
.45204 .35515 L
.45203 .35515 L
.45202 .35515 L
.45201 .35515 L
.452 .35515 L
.45199 .35515 L
.45199 .35515 L
.45198 .35515 L
.45197 .35515 L
.45196 .35515 L
.45195 .35515 L
.45195 .35515 L
.45194 .35515 L
.45193 .35515 L
.45192 .35515 L
.45191 .35515 L
.45191 .35515 L
.4519 .35515 L
.45189 .35515 L
.45188 .35515 L
.45187 .35515 L
.45187 .35515 L
.45186 .35515 L
.45185 .35515 L
.45184 .35515 L
.45184 .35514 L
.45183 .35514 L
.45182 .35514 L
.45181 .35514 L
.4518 .35514 L
.4518 .35514 L
.45179 .35514 L
.45178 .35514 L
.45177 .35514 L
.45176 .35514 L
.45176 .35514 L
.45175 .35514 L
.45174 .35514 L
.45173 .35514 L
.45173 .35514 L
.45172 .35514 L
.45171 .35514 L
.4517 .35514 L
Mistroke
.45169 .35514 L
.45169 .35514 L
.45168 .35514 L
.45167 .35514 L
.45166 .35514 L
.45166 .35513 L
.45165 .35513 L
.45164 .35513 L
.45163 .35513 L
.45163 .35513 L
.45162 .35513 L
.45161 .35513 L
.4516 .35513 L
.45159 .35513 L
.45159 .35513 L
.45158 .35513 L
.45157 .35513 L
.45156 .35513 L
.45156 .35513 L
.45155 .35513 L
.45154 .35513 L
.45153 .35512 L
.45153 .35512 L
.45152 .35512 L
.45151 .35512 L
.4515 .35512 L
.4515 .35512 L
.45149 .35512 L
.45148 .35512 L
.45147 .35512 L
.45147 .35512 L
.45146 .35512 L
.45145 .35512 L
.45144 .35512 L
.45144 .35512 L
.45143 .35511 L
.45142 .35511 L
.45141 .35511 L
.45141 .35511 L
.4514 .35511 L
.45139 .35511 L
.45138 .35511 L
.45138 .35511 L
.45137 .35511 L
.45136 .35511 L
.45136 .35511 L
.45135 .35511 L
.45134 .35511 L
.45133 .3551 L
.45133 .3551 L
Mistroke
.45132 .3551 L
.45131 .3551 L
.4513 .3551 L
.4513 .3551 L
.45129 .3551 L
.45128 .3551 L
.45127 .3551 L
.45127 .3551 L
.45126 .3551 L
.45125 .35509 L
.45125 .35509 L
.45124 .35509 L
.45123 .35509 L
.45122 .35509 L
.45122 .35509 L
.45121 .35509 L
.4512 .35509 L
.4512 .35509 L
.45119 .35509 L
.45118 .35508 L
.45117 .35508 L
.45117 .35508 L
.45116 .35508 L
.45115 .35508 L
.45115 .35508 L
.45114 .35508 L
.45113 .35508 L
.45112 .35508 L
.45112 .35508 L
.45111 .35507 L
.4511 .35507 L
.4511 .35507 L
.45109 .35507 L
.45108 .35507 L
.45107 .35507 L
.45107 .35507 L
.45106 .35507 L
.45105 .35507 L
.45105 .35506 L
.45104 .35506 L
.45103 .35506 L
.45103 .35506 L
.45102 .35506 L
.45101 .35506 L
.451 .35506 L
.451 .35506 L
.45099 .35505 L
.45098 .35505 L
.45098 .35505 L
.45097 .35505 L
Mistroke
.45096 .35505 L
.45096 .35505 L
.45095 .35505 L
.45094 .35505 L
.45094 .35505 L
.45093 .35504 L
.45092 .35504 L
.45091 .35504 L
.45091 .35504 L
.4509 .35504 L
.45089 .35504 L
.45089 .35504 L
.45088 .35503 L
.45087 .35503 L
.45087 .35503 L
.45086 .35503 L
.45085 .35503 L
.45085 .35503 L
.45084 .35503 L
.45083 .35503 L
.45083 .35502 L
.45082 .35502 L
.45081 .35502 L
.45081 .35502 L
.4508 .35502 L
.45079 .35502 L
.45079 .35502 L
.45078 .35501 L
.45077 .35501 L
.45077 .35501 L
.45076 .35501 L
.45075 .35501 L
.45075 .35501 L
.45074 .35501 L
.45073 .355 L
.45073 .355 L
.45072 .355 L
.45071 .355 L
.45071 .355 L
.4507 .355 L
.45069 .355 L
.45069 .35499 L
.45068 .35499 L
.45067 .35499 L
.45067 .35499 L
.45066 .35499 L
.45065 .35499 L
.45065 .35498 L
.45064 .35498 L
.45064 .35498 L
Mistroke
.45063 .35498 L
.45062 .35498 L
.45062 .35498 L
.45061 .35498 L
.4506 .35497 L
.4506 .35497 L
.45059 .35497 L
.45058 .35497 L
.45058 .35497 L
.45057 .35497 L
.45056 .35496 L
.45056 .35496 L
.45055 .35496 L
.45055 .35496 L
.45054 .35496 L
.45053 .35496 L
.45053 .35495 L
.45052 .35495 L
.45051 .35495 L
.45051 .35495 L
.4505 .35495 L
.45049 .35495 L
.45049 .35494 L
.45048 .35494 L
.45048 .35494 L
.45047 .35494 L
.45046 .35494 L
.45046 .35494 L
.45045 .35493 L
.45044 .35493 L
.45044 .35493 L
.45043 .35493 L
.45043 .35493 L
.45042 .35493 L
.45041 .35492 L
.45041 .35492 L
.4504 .35492 L
.45039 .35492 L
.45039 .35492 L
.45038 .35491 L
.45038 .35491 L
.45037 .35491 L
.45036 .35491 L
.45036 .35491 L
.45035 .35491 L
.45035 .3549 L
.45034 .3549 L
.45033 .3549 L
.45033 .3549 L
.45032 .3549 L
Mistroke
.45032 .35489 L
.45031 .35489 L
.4503 .35489 L
.4503 .35489 L
.45029 .35489 L
.45029 .35488 L
.45028 .35488 L
.45027 .35488 L
.45027 .35488 L
.45026 .35488 L
.45026 .35488 L
.45025 .35487 L
.45024 .35487 L
.45024 .35487 L
.45023 .35487 L
.45023 .35487 L
.45022 .35486 L
.45021 .35486 L
.45021 .35486 L
.4502 .35486 L
.4502 .35486 L
.45019 .35485 L
.45018 .35485 L
.45018 .35485 L
.45017 .35485 L
.45017 .35485 L
.45016 .35484 L
.45015 .35484 L
.45015 .35484 L
.45014 .35484 L
.45014 .35484 L
.45013 .35483 L
.45013 .35483 L
.45012 .35483 L
.45011 .35483 L
.45011 .35483 L
.4501 .35482 L
.4501 .35482 L
.45009 .35482 L
.45009 .35482 L
.45008 .35481 L
.45007 .35481 L
.45007 .35481 L
.45006 .35481 L
.45006 .35481 L
.45005 .3548 L
.45005 .3548 L
.45004 .3548 L
.45003 .3548 L
.45003 .3548 L
Mistroke
.45002 .35479 L
.45002 .35479 L
.45001 .35479 L
.45001 .35479 L
.45 .35478 L
.44999 .35478 L
.44999 .35478 L
.44998 .35478 L
.44998 .35478 L
.44997 .35477 L
.44997 .35477 L
.44996 .35477 L
.44996 .35477 L
.44995 .35476 L
.44994 .35476 L
.44994 .35476 L
.44993 .35476 L
.44993 .35476 L
.44992 .35475 L
.44992 .35475 L
.44991 .35475 L
.44991 .35475 L
.4499 .35474 L
.4499 .35474 L
.44989 .35474 L
.44988 .35474 L
.44988 .35474 L
.44987 .35473 L
.44987 .35473 L
.44986 .35473 L
.44986 .35473 L
.44985 .35472 L
.44985 .35472 L
.44984 .35472 L
.44984 .35472 L
.44983 .35471 L
.44983 .35471 L
.44982 .35471 L
.44981 .35471 L
.44981 .3547 L
.4498 .3547 L
.4498 .3547 L
.44979 .3547 L
.44979 .3547 L
.44978 .35469 L
.44978 .35469 L
.44977 .35469 L
.44977 .35469 L
.44976 .35468 L
.44976 .35468 L
Mistroke
.44975 .35468 L
.44975 .35468 L
.44974 .35467 L
.44974 .35467 L
.44973 .35467 L
.44973 .35467 L
.44972 .35466 L
.44971 .35466 L
.44971 .35466 L
.4497 .35466 L
.4497 .35465 L
.44969 .35465 L
.44969 .35465 L
.44968 .35465 L
.44968 .35464 L
.44967 .35464 L
.44967 .35464 L
.44966 .35464 L
.44966 .35463 L
.44965 .35463 L
.44965 .35463 L
.44964 .35463 L
.44964 .35462 L
.44963 .35462 L
.44963 .35462 L
.44962 .35462 L
.44962 .35461 L
.44961 .35461 L
.44961 .35461 L
.4496 .35461 L
.4496 .3546 L
.44959 .3546 L
.44959 .3546 L
.44958 .3546 L
.44958 .35459 L
.44957 .35459 L
.44957 .35459 L
.44956 .35458 L
.44956 .35458 L
.44955 .35458 L
.44955 .35458 L
.44954 .35457 L
.44954 .35457 L
.44953 .35457 L
.44953 .35457 L
.44952 .35456 L
.44952 .35456 L
.44951 .35456 L
.44951 .35456 L
.4495 .35455 L
Mistroke
.4495 .35455 L
.44949 .35455 L
.44949 .35455 L
.44949 .35454 L
.44948 .35454 L
.44948 .35454 L
.44947 .35453 L
.44947 .35453 L
.44946 .35453 L
.44946 .35453 L
.44945 .35452 L
.44945 .35452 L
.44944 .35452 L
.44944 .35452 L
.44943 .35451 L
.44943 .35451 L
.44942 .35451 L
.44942 .3545 L
.44941 .3545 L
.44941 .3545 L
.4494 .3545 L
.4494 .35449 L
.4494 .35449 L
.44939 .35449 L
.44939 .35448 L
.44938 .35448 L
.44938 .35448 L
.44937 .35448 L
.44937 .35447 L
.44936 .35447 L
.44936 .35447 L
.44935 .35447 L
.44935 .35446 L
.44934 .35446 L
.44934 .35446 L
.44934 .35445 L
.44933 .35445 L
.44933 .35445 L
.44932 .35445 L
.44932 .35444 L
.44931 .35444 L
.44931 .35444 L
.4493 .35443 L
.4493 .35443 L
.4493 .35443 L
.44929 .35443 L
.44929 .35442 L
.44928 .35442 L
.44928 .35442 L
.44927 .35441 L
Mistroke
.44927 .35441 L
.44926 .35441 L
.44926 .3544 L
.44926 .3544 L
.44925 .3544 L
.44925 .3544 L
.44924 .35439 L
.44924 .35439 L
.44923 .35439 L
.44923 .35438 L
.44922 .35438 L
.44922 .35438 L
.44922 .35438 L
.44921 .35437 L
.44921 .35437 L
.4492 .35437 L
.4492 .35436 L
.44919 .35436 L
.44919 .35436 L
.44919 .35435 L
.44918 .35435 L
.44918 .35435 L
.44917 .35435 L
.44917 .35434 L
.44916 .35434 L
.44916 .35434 L
.44916 .35433 L
.44915 .35433 L
.44915 .35433 L
.44914 .35432 L
.44914 .35432 L
.44914 .35432 L
.44913 .35432 L
.44913 .35431 L
.44912 .35431 L
.44912 .35431 L
.44911 .3543 L
.44911 .3543 L
.44911 .3543 L
.4491 .35429 L
.4491 .35429 L
.44909 .35429 L
.44909 .35428 L
.44909 .35428 L
.44908 .35428 L
.44908 .35428 L
.44907 .35427 L
.44907 .35427 L
.44907 .35427 L
.44906 .35426 L
Mistroke
.44906 .35426 L
.44905 .35426 L
.44905 .35425 L
.44905 .35425 L
.44904 .35425 L
.44904 .35424 L
.44903 .35424 L
.44903 .35424 L
.44903 .35423 L
.44902 .35423 L
.44902 .35423 L
.44901 .35423 L
.44901 .35422 L
.44901 .35422 L
.449 .35422 L
.449 .35421 L
.44899 .35421 L
.44899 .35421 L
.44899 .3542 L
.44898 .3542 L
.44898 .3542 L
.44897 .35419 L
.44897 .35419 L
.44897 .35419 L
.44896 .35418 L
.44896 .35418 L
.44896 .35418 L
.44895 .35417 L
.44895 .35417 L
.44894 .35417 L
.44894 .35416 L
.44894 .35416 L
.44893 .35416 L
.44893 .35415 L
.44892 .35415 L
.44892 .35415 L
.44892 .35415 L
.44891 .35414 L
.44891 .35414 L
.44891 .35414 L
.4489 .35413 L
.4489 .35413 L
.4489 .35413 L
.44889 .35412 L
.44889 .35412 L
.44888 .35412 L
.44888 .35411 L
.44888 .35411 L
.44887 .35411 L
.44887 .3541 L
Mistroke
.44887 .3541 L
.44886 .3541 L
.44886 .35409 L
.44885 .35409 L
.44885 .35409 L
.44885 .35408 L
.44884 .35408 L
.44884 .35408 L
.44884 .35407 L
.44883 .35407 L
.44883 .35407 L
.44883 .35406 L
.44882 .35406 L
.44882 .35406 L
.44882 .35405 L
.44881 .35405 L
.44881 .35405 L
.4488 .35404 L
.4488 .35404 L
.4488 .35404 L
.44879 .35403 L
.44879 .35403 L
.44879 .35403 L
.44878 .35402 L
.44878 .35402 L
.44878 .35402 L
.44877 .35401 L
.44877 .35401 L
.44877 .35401 L
.44876 .354 L
.44876 .354 L
.44876 .35399 L
.44875 .35399 L
.44875 .35399 L
.44875 .35398 L
.44874 .35398 L
.44874 .35398 L
.44874 .35397 L
.44873 .35397 L
.44873 .35397 L
.44873 .35396 L
.44872 .35396 L
.44872 .35396 L
.44872 .35395 L
.44871 .35395 L
.44871 .35395 L
.44871 .35394 L
.4487 .35394 L
.4487 .35394 L
.4487 .35393 L
Mistroke
.44869 .35393 L
.44869 .35393 L
.44869 .35392 L
.44868 .35392 L
.44868 .35392 L
.44868 .35391 L
.44867 .35391 L
.44867 .3539 L
.44867 .3539 L
.44866 .3539 L
.44866 .35389 L
.44866 .35389 L
.44865 .35389 L
.44865 .35388 L
.44865 .35388 L
.44864 .35388 L
.44864 .35387 L
.44864 .35387 L
.44864 .35387 L
.44863 .35386 L
.44863 .35386 L
.44863 .35386 L
.44862 .35385 L
.44862 .35385 L
.44862 .35384 L
.44861 .35384 L
.44861 .35384 L
.44861 .35383 L
.4486 .35383 L
.4486 .35383 L
.4486 .35382 L
.4486 .35382 L
.44859 .35382 L
.44859 .35381 L
.44859 .35381 L
.44858 .35381 L
.44858 .3538 L
.44858 .3538 L
.44857 .35379 L
.44857 .35379 L
.44857 .35379 L
.44857 .35378 L
.44856 .35378 L
.44856 .35378 L
.44856 .35377 L
.44855 .35377 L
.44855 .35377 L
.44855 .35376 L
.44854 .35376 L
.44854 .35376 L
Mistroke
.44854 .35375 L
.44854 .35375 L
.44853 .35374 L
.44853 .35374 L
.44853 .35374 L
.44852 .35373 L
.44852 .35373 L
.44852 .35373 L
.44852 .35372 L
.44851 .35372 L
.44851 .35372 L
.44851 .35371 L
.4485 .35371 L
.4485 .3537 L
.4485 .3537 L
.4485 .3537 L
.44849 .35369 L
.44849 .35369 L
.44849 .35369 L
.44849 .35368 L
.44848 .35368 L
.44848 .35367 L
.44848 .35367 L
.44847 .35367 L
.44847 .35366 L
.44847 .35366 L
.44847 .35366 L
.44846 .35365 L
.44846 .35365 L
.44846 .35365 L
.44846 .35364 L
.44845 .35364 L
.44845 .35363 L
.44845 .35363 L
.44844 .35363 L
.44844 .35362 L
.44844 .35362 L
.44844 .35362 L
.44843 .35361 L
.44843 .35361 L
.44843 .3536 L
.44843 .3536 L
.44842 .3536 L
.44842 .35359 L
.44842 .35359 L
.44842 .35359 L
.44841 .35358 L
.44841 .35358 L
.44841 .35357 L
.44841 .35357 L
Mistroke
.4484 .35357 L
.4484 .35356 L
.4484 .35356 L
.4484 .35356 L
.44839 .35355 L
.44839 .35355 L
.44839 .35354 L
.44839 .35354 L
.44838 .35354 L
.44838 .35353 L
.44838 .35353 L
.44838 .35353 L
.44837 .35352 L
.44837 .35352 L
.44837 .35351 L
.44837 .35351 L
.44836 .35351 L
.44836 .3535 L
.44836 .3535 L
.44836 .35349 L
.44835 .35349 L
.44835 .35349 L
.44835 .35348 L
.44835 .35348 L
.44834 .35348 L
.44834 .35347 L
.44834 .35347 L
.44834 .35346 L
.44834 .35346 L
.44833 .35346 L
.44833 .35345 L
.44833 .35345 L
.44833 .35345 L
.44832 .35344 L
.44832 .35344 L
.44832 .35343 L
.44832 .35343 L
.44831 .35343 L
.44831 .35342 L
.44831 .35342 L
.44831 .35341 L
.44831 .35341 L
.4483 .35341 L
.4483 .3534 L
.4483 .3534 L
.4483 .3534 L
.44829 .35339 L
.44829 .35339 L
.44829 .35338 L
.44829 .35338 L
Mistroke
.44829 .35338 L
.44828 .35337 L
.44828 .35337 L
.44828 .35336 L
.44828 .35336 L
.44827 .35336 L
.44827 .35335 L
.44827 .35335 L
.44827 .35334 L
.44827 .35334 L
.44826 .35334 L
.44826 .35333 L
.44826 .35333 L
.44826 .35333 L
.44826 .35332 L
.44825 .35332 L
.44825 .35331 L
.44825 .35331 L
.44825 .35331 L
.44824 .3533 L
.44824 .3533 L
.44824 .35329 L
.44824 .35329 L
.44824 .35329 L
.44823 .35328 L
.44823 .35328 L
.44823 .35327 L
.44823 .35327 L
.44823 .35327 L
.44822 .35326 L
.44822 .35326 L
.44822 .35325 L
.44822 .35325 L
.44822 .35325 L
.44821 .35324 L
.44821 .35324 L
.44821 .35323 L
.44821 .35323 L
.44821 .35323 L
.44821 .35322 L
.4482 .35322 L
.4482 .35322 L
.4482 .35321 L
.4482 .35321 L
.4482 .3532 L
.44819 .3532 L
.44819 .3532 L
.44819 .35319 L
.44819 .35319 L
.44819 .35318 L
Mistroke
.44818 .35318 L
.44818 .35318 L
.44818 .35317 L
.44818 .35317 L
.44818 .35316 L
.44818 .35316 L
.44817 .35316 L
.44817 .35315 L
.44817 .35315 L
.44817 .35314 L
.44817 .35314 L
.44816 .35314 L
.44816 .35313 L
.44816 .35313 L
.44816 .35312 L
.44816 .35312 L
.44816 .35312 L
.44815 .35311 L
.44815 .35311 L
.44815 .3531 L
.44815 .3531 L
.44815 .3531 L
.44815 .35309 L
.44814 .35309 L
.44814 .35308 L
.44814 .35308 L
.44814 .35308 L
.44814 .35307 L
.44814 .35307 L
.44813 .35306 L
.44813 .35306 L
.44813 .35306 L
.44813 .35305 L
.44813 .35305 L
.44813 .35304 L
.44812 .35304 L
.44812 .35304 L
.44812 .35303 L
.44812 .35303 L
.44812 .35302 L
.44812 .35302 L
.44811 .35301 L
.44811 .35301 L
.44811 .35301 L
.44811 .353 L
.44811 .353 L
.44811 .35299 L
.4481 .35299 L
.4481 .35299 L
.4481 .35298 L
Mistroke
.4481 .35298 L
.4481 .35297 L
.4481 .35297 L
.4481 .35297 L
.44809 .35296 L
.44809 .35296 L
.44809 .35295 L
.44809 .35295 L
.44809 .35295 L
.44809 .35294 L
.44809 .35294 L
.44808 .35293 L
.44808 .35293 L
.44808 .35293 L
.44808 .35292 L
.44808 .35292 L
.44808 .35291 L
.44808 .35291 L
.44807 .35291 L
.44807 .3529 L
.44807 .3529 L
.44807 .35289 L
.44807 .35289 L
.44807 .35288 L
.44807 .35288 L
.44806 .35288 L
.44806 .35287 L
.44806 .35287 L
.44806 .35286 L
.44806 .35286 L
.44806 .35286 L
.44806 .35285 L
.44805 .35285 L
.44805 .35284 L
.44805 .35284 L
.44805 .35284 L
.44805 .35283 L
.44805 .35283 L
.44805 .35282 L
.44805 .35282 L
.44804 .35282 L
.44804 .35281 L
.44804 .35281 L
.44804 .3528 L
.44804 .3528 L
.44804 .35279 L
.44804 .35279 L
.44804 .35279 L
.44803 .35278 L
.44803 .35278 L
Mistroke
.44803 .35277 L
.44803 .35277 L
.44803 .35277 L
.44803 .35276 L
.44803 .35276 L
.44803 .35275 L
.44802 .35275 L
.44802 .35275 L
.44802 .35274 L
.44802 .35274 L
.44802 .35273 L
.44802 .35273 L
.44802 .35272 L
.44802 .35272 L
.44802 .35272 L
.44801 .35271 L
.44801 .35271 L
.44801 .3527 L
.44801 .3527 L
.44801 .3527 L
.44801 .35269 L
.44801 .35269 L
.44801 .35268 L
.44801 .35268 L
.448 .35267 L
.448 .35267 L
.448 .35267 L
.448 .35266 L
.448 .35266 L
.448 .35265 L
.448 .35265 L
.448 .35265 L
.448 .35264 L
.448 .35264 L
.44799 .35263 L
.44799 .35263 L
.44799 .35262 L
.44799 .35262 L
.44799 .35262 L
.44799 .35261 L
.44799 .35261 L
.44799 .3526 L
.44799 .3526 L
.44799 .3526 L
.44798 .35259 L
.44798 .35259 L
.44798 .35258 L
.44798 .35258 L
.44798 .35257 L
.44798 .35257 L
Mistroke
.44798 .35257 L
.44798 .35256 L
.44798 .35256 L
.44798 .35255 L
.44798 .35255 L
.44797 .35255 L
.44797 .35254 L
.44797 .35254 L
.44797 .35253 L
.44797 .35253 L
.44797 .35252 L
.44797 .35252 L
.44797 .35252 L
.44797 .35251 L
.44797 .35251 L
.44797 .3525 L
.44797 .3525 L
.44796 .3525 L
.44796 .35249 L
.44796 .35249 L
.44796 .35248 L
.44796 .35248 L
.44796 .35247 L
.44796 .35247 L
.44796 .35247 L
.44796 .35246 L
.44796 .35246 L
.44796 .35245 L
.44796 .35245 L
.44796 .35245 L
.44795 .35244 L
.44795 .35244 L
.44795 .35243 L
.44795 .35243 L
.44795 .35242 L
.44795 .35242 L
.44795 .35242 L
.44795 .35241 L
.44795 .35241 L
.44795 .3524 L
.44795 .3524 L
.44795 .35239 L
.44795 .35239 L
.44795 .35239 L
.44794 .35238 L
.44794 .35238 L
.44794 .35237 L
.44794 .35237 L
.44794 .35237 L
.44794 .35236 L
Mistroke
.44794 .35236 L
.44794 .35235 L
.44794 .35235 L
.44794 .35234 L
.44794 .35234 L
.44794 .35234 L
.44794 .35233 L
.44794 .35233 L
.44794 .35232 L
.44794 .35232 L
.44794 .35231 L
.44793 .35231 L
.44793 .35231 L
.44793 .3523 L
.44793 .3523 L
.44793 .35229 L
.44793 .35229 L
.44793 .35229 L
.44793 .35228 L
.44793 .35228 L
.44793 .35227 L
.44793 .35227 L
.44793 .35226 L
.44793 .35226 L
.44793 .35226 L
.44793 .35225 L
.44793 .35225 L
.44793 .35224 L
.44793 .35224 L
.44793 .35223 L
.44793 .35223 L
.44792 .35223 L
.44792 .35222 L
.44792 .35222 L
.44792 .35221 L
.44792 .35221 L
.44792 .35221 L
.44792 .3522 L
.44792 .3522 L
.44792 .35219 L
.44792 .35219 L
.44792 .35218 L
.44792 .35218 L
.44792 .35218 L
.44792 .35217 L
.44792 .35217 L
.44792 .35216 L
.44792 .35216 L
.44792 .35215 L
.44792 .35215 L
Mistroke
.44792 .35215 L
.44792 .35214 L
.44792 .35214 L
.44792 .35213 L
.44792 .35213 L
.44792 .35212 L
.44792 .35212 L
.44791 .35212 L
.44791 .35211 L
.44791 .35211 L
.44791 .3521 L
.44791 .3521 L
.44791 .3521 L
.44791 .35209 L
.44791 .35209 L
.44791 .35208 L
.44791 .35208 L
.44791 .35207 L
.44791 .35207 L
.44791 .35207 L
.44791 .35206 L
.44791 .35206 L
.44791 .35205 L
.44791 .35205 L
.44791 .35204 L
.44791 .35204 L
.44791 .35204 L
.44791 .35203 L
.44791 .35203 L
.44791 .35202 L
.44791 .35202 L
.44791 .35201 L
.44791 .35201 L
.44791 .35201 L
.44791 .352 L
.44791 .352 L
.44791 .35199 L
.44791 .35199 L
.44791 .35199 L
.44791 .35198 L
.44791 .35198 L
.44791 .35197 L
.44791 .35197 L
.44791 .35196 L
.44791 .35196 L
.44791 .35196 L
.44791 .35195 L
.44791 .35195 L
.44791 .35194 L
.44791 .35194 L
Mistroke
.44791 .35193 L
.44791 .35193 L
.44791 .35193 L
.44791 .35192 L
.44791 .35192 L
.44791 .35191 L
.44791 .35191 L
.44791 .3519 L
.44791 .3519 L
.44791 .3519 L
.44791 .35189 L
.44791 .35189 L
.44791 .35188 L
.44791 .35188 L
.44791 .35187 L
.44791 .35187 L
.44791 .35187 L
.44791 .35186 L
.44791 .35186 L
.44791 .35185 L
.44791 .35185 L
.44791 .35185 L
.44791 .35184 L
.44791 .35184 L
.44791 .35183 L
.44791 .35183 L
.44791 .35182 L
.44791 .35182 L
.44791 .35182 L
.44791 .35181 L
.44791 .35181 L
.44791 .3518 L
.44791 .3518 L
.44791 .35179 L
.44791 .35179 L
.44791 .35179 L
.44791 .35178 L
.44791 .35178 L
.44791 .35177 L
.44791 .35177 L
.44791 .35176 L
.44791 .35176 L
.44791 .35176 L
.44791 .35175 L
.44791 .35175 L
.44791 .35174 L
.44791 .35174 L
.44791 .35174 L
.44791 .35173 L
.44791 .35173 L
Mistroke
.44791 .35172 L
.44791 .35172 L
.44791 .35171 L
.44791 .35171 L
.44791 .35171 L
.44791 .3517 L
.44791 .3517 L
.44791 .35169 L
.44791 .35169 L
.44791 .35168 L
.44791 .35168 L
.44791 .35168 L
.44791 .35167 L
.44791 .35167 L
.44791 .35166 L
.44791 .35166 L
.44791 .35165 L
.44791 .35165 L
.44791 .35165 L
.44791 .35164 L
.44791 .35164 L
.44791 .35163 L
.44791 .35163 L
.44792 .35163 L
.44792 .35162 L
.44792 .35162 L
.44792 .35161 L
.44792 .35161 L
.44792 .3516 L
.44792 .3516 L
.44792 .3516 L
.44792 .35159 L
.44792 .35159 L
.44792 .35158 L
.44792 .35158 L
.44792 .35157 L
.44792 .35157 L
.44792 .35157 L
.44792 .35156 L
.44792 .35156 L
.44792 .35155 L
.44792 .35155 L
.44792 .35155 L
.44792 .35154 L
.44792 .35154 L
.44792 .35153 L
.44792 .35153 L
.44792 .35152 L
.44792 .35152 L
.44792 .35152 L
Mistroke
.44792 .35151 L
.44793 .35151 L
.44793 .3515 L
.44793 .3515 L
.44793 .35149 L
.44793 .35149 L
.44793 .35149 L
.44793 .35148 L
.44793 .35148 L
.44793 .35147 L
.44793 .35147 L
.44793 .35146 L
.44793 .35146 L
.44793 .35146 L
.44793 .35145 L
.44793 .35145 L
.44793 .35144 L
.44793 .35144 L
.44793 .35144 L
.44793 .35143 L
.44793 .35143 L
.44793 .35142 L
.44794 .35142 L
.44794 .35141 L
.44794 .35141 L
.44794 .35141 L
.44794 .3514 L
.44794 .3514 L
.44794 .35139 L
.44794 .35139 L
.44794 .35139 L
.44794 .35138 L
.44794 .35138 L
.44794 .35137 L
.44794 .35137 L
.44794 .35136 L
.44794 .35136 L
.44794 .35136 L
.44794 .35135 L
.44794 .35135 L
.44795 .35134 L
.44795 .35134 L
.44795 .35133 L
.44795 .35133 L
.44795 .35133 L
.44795 .35132 L
.44795 .35132 L
.44795 .35131 L
.44795 .35131 L
.44795 .35131 L
Mistroke
.44795 .3513 L
.44795 .3513 L
.44795 .35129 L
.44795 .35129 L
.44795 .35128 L
.44795 .35128 L
.44796 .35128 L
.44796 .35127 L
.44796 .35127 L
.44796 .35126 L
.44796 .35126 L
.44796 .35126 L
.44796 .35125 L
.44796 .35125 L
.44796 .35124 L
.44796 .35124 L
.44796 .35123 L
.44796 .35123 L
.44796 .35123 L
.44796 .35122 L
.44797 .35122 L
.44797 .35121 L
.44797 .35121 L
.44797 .35121 L
.44797 .3512 L
.44797 .3512 L
.44797 .35119 L
.44797 .35119 L
.44797 .35118 L
.44797 .35118 L
.44797 .35118 L
.44797 .35117 L
.44797 .35117 L
.44798 .35116 L
.44798 .35116 L
.44798 .35116 L
.44798 .35115 L
.44798 .35115 L
.44798 .35114 L
.44798 .35114 L
.44798 .35113 L
.44798 .35113 L
.44798 .35113 L
.44798 .35112 L
.44798 .35112 L
.44799 .35111 L
.44799 .35111 L
.44799 .35111 L
.44799 .3511 L
.44799 .3511 L
Mistroke
.44799 .35109 L
.44799 .35109 L
.44799 .35108 L
.44799 .35108 L
.44799 .35108 L
.44799 .35107 L
.44799 .35107 L
.448 .35106 L
.448 .35106 L
.448 .35106 L
.448 .35105 L
.448 .35105 L
.448 .35104 L
.448 .35104 L
.448 .35103 L
.448 .35103 L
.448 .35103 L
.448 .35102 L
.44801 .35102 L
.44801 .35101 L
.44801 .35101 L
.44801 .35101 L
.44801 .351 L
.44801 .351 L
.44801 .35099 L
.44801 .35099 L
.44801 .35099 L
.44801 .35098 L
.44802 .35098 L
.44802 .35097 L
.44802 .35097 L
.44802 .35096 L
.44802 .35096 L
.44802 .35096 L
.44802 .35095 L
.44802 .35095 L
.44802 .35094 L
.44802 .35094 L
.44803 .35094 L
.44803 .35093 L
.44803 .35093 L
.44803 .35092 L
.44803 .35092 L
.44803 .35092 L
.44803 .35091 L
.44803 .35091 L
.44803 .3509 L
.44803 .3509 L
.44804 .35089 L
.44804 .35089 L
Mistroke
.44804 .35089 L
.44804 .35088 L
.44804 .35088 L
.44804 .35087 L
.44804 .35087 L
.44804 .35087 L
.44804 .35086 L
.44805 .35086 L
.44805 .35085 L
.44805 .35085 L
.44805 .35085 L
.44805 .35084 L
.44805 .35084 L
.44805 .35083 L
.44805 .35083 L
.44805 .35083 L
.44805 .35082 L
.44806 .35082 L
.44806 .35081 L
.44806 .35081 L
.44806 .35081 L
.44806 .3508 L
.44806 .3508 L
.44806 .35079 L
.44806 .35079 L
.44807 .35078 L
.44807 .35078 L
.44807 .35078 L
.44807 .35077 L
.44807 .35077 L
.44807 .35076 L
.44807 .35076 L
.44807 .35076 L
.44807 .35075 L
.44808 .35075 L
.44808 .35074 L
.44808 .35074 L
.44808 .35074 L
.44808 .35073 L
.44808 .35073 L
.44808 .35072 L
.44808 .35072 L
.44809 .35072 L
.44809 .35071 L
.44809 .35071 L
.44809 .3507 L
.44809 .3507 L
.44809 .3507 L
.44809 .35069 L
.44809 .35069 L
Mistroke
.4481 .35068 L
.4481 .35068 L
.4481 .35068 L
.4481 .35067 L
.4481 .35067 L
.4481 .35066 L
.4481 .35066 L
.4481 .35066 L
.44811 .35065 L
.44811 .35065 L
.44811 .35064 L
.44811 .35064 L
.44811 .35063 L
.44811 .35063 L
.44811 .35063 L
.44811 .35062 L
.44812 .35062 L
.44812 .35061 L
.44812 .35061 L
.44812 .35061 L
.44812 .3506 L
.44812 .3506 L
.44812 .35059 L
.44813 .35059 L
.44813 .35059 L
.44813 .35058 L
.44813 .35058 L
.44813 .35057 L
.44813 .35057 L
.44813 .35057 L
.44813 .35056 L
.44814 .35056 L
.44814 .35055 L
.44814 .35055 L
.44814 .35055 L
.44814 .35054 L
.44814 .35054 L
.44814 .35053 L
.44815 .35053 L
.44815 .35053 L
.44815 .35052 L
.44815 .35052 L
.44815 .35051 L
.44815 .35051 L
.44815 .35051 L
.44816 .3505 L
.44816 .3505 L
.44816 .3505 L
.44816 .35049 L
.44816 .35049 L
Mistroke
.44816 .35048 L
.44816 .35048 L
.44817 .35048 L
.44817 .35047 L
.44817 .35047 L
.44817 .35046 L
.44817 .35046 L
.44817 .35046 L
.44817 .35045 L
.44818 .35045 L
.44818 .35044 L
.44818 .35044 L
.44818 .35044 L
.44818 .35043 L
.44818 .35043 L
.44818 .35042 L
.44819 .35042 L
.44819 .35042 L
.44819 .35041 L
.44819 .35041 L
.44819 .3504 L
.44819 .3504 L
.44819 .3504 L
.4482 .35039 L
.4482 .35039 L
.4482 .35038 L
.4482 .35038 L
.4482 .35038 L
.4482 .35037 L
.4482 .35037 L
.44821 .35036 L
.44821 .35036 L
.44821 .35036 L
.44821 .35035 L
.44821 .35035 L
.44821 .35035 L
.44822 .35034 L
.44822 .35034 L
.44822 .35033 L
.44822 .35033 L
.44822 .35033 L
.44822 .35032 L
.44822 .35032 L
.44823 .35031 L
.44823 .35031 L
.44823 .35031 L
.44823 .3503 L
.44823 .3503 L
.44823 .35029 L
.44824 .35029 L
Mistroke
.44824 .35029 L
.44824 .35028 L
.44824 .35028 L
.44824 .35027 L
.44824 .35027 L
.44825 .35027 L
.44825 .35026 L
.44825 .35026 L
.44825 .35026 L
.44825 .35025 L
.44825 .35025 L
.44826 .35024 L
.44826 .35024 L
.44826 .35024 L
.44826 .35023 L
.44826 .35023 L
.44826 .35022 L
.44827 .35022 L
.44827 .35022 L
.44827 .35021 L
.44827 .35021 L
.44827 .35021 L
.44827 .3502 L
.44827 .3502 L
.44828 .35019 L
.44828 .35019 L
.44828 .35019 L
.44828 .35018 L
.44828 .35018 L
.44828 .35017 L
.44829 .35017 L
.44829 .35017 L
.44829 .35016 L
.44829 .35016 L
.44829 .35016 L
.4483 .35015 L
.4483 .35015 L
.4483 .35014 L
.4483 .35014 L
.4483 .35014 L
.4483 .35013 L
.44831 .35013 L
.44831 .35012 L
.44831 .35012 L
.44831 .35012 L
.44831 .35011 L
.44831 .35011 L
.44832 .35011 L
.44832 .3501 L
.44832 .3501 L
Mistroke
.44832 .35009 L
.44832 .35009 L
.44832 .35009 L
.44833 .35008 L
.44833 .35008 L
.44833 .35007 L
.44833 .35007 L
.44833 .35007 L
.44833 .35006 L
.44834 .35006 L
.44834 .35006 L
.44834 .35005 L
.44834 .35005 L
.44834 .35004 L
.44835 .35004 L
.44835 .35004 L
.44835 .35003 L
.44835 .35003 L
.44835 .35003 L
.44835 .35002 L
.44836 .35002 L
.44836 .35001 L
.44836 .35001 L
.44836 .35001 L
.44836 .35 L
.44837 .35 L
.44837 .35 L
.44837 .34999 L
.44837 .34999 L
.44837 .34998 L
.44837 .34998 L
.44838 .34998 L
.44838 .34997 L
.44838 .34997 L
.44838 .34997 L
.44838 .34996 L
.44839 .34996 L
.44839 .34995 L
.44839 .34995 L
.44839 .34995 L
.44839 .34994 L
.44839 .34994 L
.4484 .34994 L
.4484 .34993 L
.4484 .34993 L
.4484 .34992 L
.4484 .34992 L
.44841 .34992 L
.44841 .34991 L
.44841 .34991 L
Mistroke
.44841 .34991 L
.44841 .3499 L
.44841 .3499 L
.44842 .34989 L
.44842 .34989 L
.44842 .34989 L
.44842 .34988 L
.44842 .34988 L
.44843 .34988 L
.44843 .34987 L
.44843 .34987 L
.44843 .34986 L
.44843 .34986 L
.44844 .34986 L
.44844 .34985 L
.44844 .34985 L
.44844 .34985 L
.44844 .34984 L
.44845 .34984 L
.44845 .34984 L
.44845 .34983 L
.44845 .34983 L
.44845 .34982 L
.44845 .34982 L
.44846 .34982 L
.44846 .34981 L
.44846 .34981 L
.44846 .34981 L
.44846 .3498 L
.44847 .3498 L
.44847 .34979 L
.44847 .34979 L
.44847 .34979 L
.44847 .34978 L
.44848 .34978 L
.44848 .34978 L
.44848 .34977 L
.44848 .34977 L
.44848 .34977 L
.44849 .34976 L
.44849 .34976 L
.44849 .34975 L
.44849 .34975 L
.44849 .34975 L
.4485 .34974 L
.4485 .34974 L
.4485 .34974 L
.4485 .34973 L
.4485 .34973 L
.44851 .34973 L
Mistroke
.44851 .34972 L
.44851 .34972 L
.44851 .34971 L
.44851 .34971 L
.44852 .34971 L
.44852 .3497 L
.44852 .3497 L
.44852 .3497 L
.44852 .34969 L
.44853 .34969 L
.44853 .34969 L
.44853 .34968 L
.44853 .34968 L
.44853 .34967 L
.44854 .34967 L
.44854 .34967 L
.44854 .34966 L
.44854 .34966 L
.44854 .34966 L
.44855 .34965 L
.44855 .34965 L
.44855 .34965 L
.44855 .34964 L
.44855 .34964 L
.44856 .34964 L
.44856 .34963 L
.44856 .34963 L
.44856 .34962 L
.44857 .34962 L
.44857 .34962 L
.44857 .34961 L
.44857 .34961 L
.44857 .34961 L
.44858 .3496 L
.44858 .3496 L
.44858 .3496 L
.44858 .34959 L
.44858 .34959 L
.44859 .34959 L
.44859 .34958 L
.44859 .34958 L
.44859 .34958 L
.44859 .34957 L
.4486 .34957 L
.4486 .34956 L
.4486 .34956 L
.4486 .34956 L
.4486 .34955 L
.44861 .34955 L
.44861 .34955 L
Mistroke
.44861 .34954 L
.44861 .34954 L
.44862 .34954 L
.44862 .34953 L
.44862 .34953 L
.44862 .34953 L
.44862 .34952 L
.44863 .34952 L
.44863 .34952 L
.44863 .34951 L
.44863 .34951 L
.44863 .3495 L
.44864 .3495 L
.44864 .3495 L
.44864 .34949 L
.44864 .34949 L
.44865 .34949 L
.44865 .34948 L
.44865 .34948 L
.44865 .34948 L
.44865 .34947 L
.44866 .34947 L
.44866 .34947 L
.44866 .34946 L
.44866 .34946 L
.44866 .34946 L
.44867 .34945 L
.44867 .34945 L
.44867 .34945 L
.44867 .34944 L
.44868 .34944 L
.44868 .34944 L
.44868 .34943 L
.44868 .34943 L
.44868 .34942 L
.44869 .34942 L
.44869 .34942 L
.44869 .34941 L
.44869 .34941 L
.4487 .34941 L
.4487 .3494 L
.4487 .3494 L
.4487 .3494 L
.4487 .34939 L
.44871 .34939 L
.44871 .34939 L
.44871 .34938 L
.44871 .34938 L
.44871 .34938 L
.44872 .34937 L
Mistroke
.44872 .34937 L
.44872 .34937 L
.44872 .34936 L
.44873 .34936 L
.44873 .34936 L
.44873 .34935 L
.44873 .34935 L
.44873 .34935 L
.44874 .34934 L
.44874 .34934 L
.44874 .34934 L
.44874 .34933 L
.44875 .34933 L
.44875 .34933 L
.44875 .34932 L
.44875 .34932 L
.44876 .34932 L
.44876 .34931 L
.44876 .34931 L
.44876 .34931 L
.44876 .3493 L
.44877 .3493 L
.44877 .3493 L
.44877 .34929 L
.44877 .34929 L
.44878 .34929 L
.44878 .34928 L
.44878 .34928 L
.44878 .34928 L
.44878 .34927 L
.44879 .34927 L
.44879 .34927 L
.44879 .34926 L
.44879 .34926 L
.4488 .34926 L
.4488 .34925 L
.4488 .34925 L
.4488 .34925 L
.4488 .34924 L
.44881 .34924 L
.44881 .34924 L
.44881 .34923 L
.44881 .34923 L
.44882 .34923 L
.44882 .34922 L
.44882 .34922 L
.44882 .34922 L
.44883 .34921 L
.44883 .34921 L
.44883 .34921 L
Mistroke
.44883 .3492 L
.44883 .3492 L
.44884 .3492 L
.44884 .34919 L
.44884 .34919 L
.44884 .34919 L
.44885 .34918 L
.44885 .34918 L
.44885 .34918 L
.44885 .34917 L
.44886 .34917 L
.44886 .34917 L
.44886 .34916 L
.44886 .34916 L
.44886 .34916 L
.44887 .34915 L
.44887 .34915 L
.44887 .34915 L
.44887 .34914 L
.44888 .34914 L
.44888 .34914 L
.44888 .34913 L
.44888 .34913 L
.44889 .34913 L
.44889 .34912 L
.44889 .34912 L
.44889 .34912 L
.4489 .34911 L
.4489 .34911 L
.4489 .34911 L
.4489 .3491 L
.4489 .3491 L
.44891 .3491 L
.44891 .34909 L
.44891 .34909 L
.44891 .34909 L
.44892 .34908 L
.44892 .34908 L
.44892 .34908 L
.44892 .34908 L
.44893 .34907 L
.44893 .34907 L
.44893 .34907 L
.44893 .34906 L
.44894 .34906 L
.44894 .34906 L
.44894 .34905 L
.44894 .34905 L
.44895 .34905 L
.44895 .34904 L
Mistroke
.44895 .34904 L
.44895 .34904 L
.44895 .34903 L
.44896 .34903 L
.44896 .34903 L
.44896 .34902 L
.44896 .34902 L
.44897 .34902 L
.44897 .34901 L
.44897 .34901 L
.44897 .34901 L
.44898 .34901 L
.44898 .349 L
.44898 .349 L
.44898 .349 L
.44899 .34899 L
.44899 .34899 L
.44899 .34899 L
.44899 .34898 L
.449 .34898 L
.449 .34898 L
.449 .34897 L
.449 .34897 L
.44901 .34897 L
.44901 .34896 L
.44901 .34896 L
.44901 .34896 L
.44901 .34895 L
.44902 .34895 L
.44902 .34895 L
.44902 .34895 L
.44902 .34894 L
.44903 .34894 L
.44903 .34894 L
.44903 .34893 L
.44903 .34893 L
.44904 .34893 L
.44904 .34892 L
.44904 .34892 L
.44904 .34892 L
.44905 .34891 L
.44905 .34891 L
.44905 .34891 L
.44905 .34891 L
.44906 .3489 L
.44906 .3489 L
.44906 .3489 L
.44906 .34889 L
.44907 .34889 L
.44907 .34889 L
Mistroke
.44907 .34888 L
.44907 .34888 L
.44908 .34888 L
.44908 .34887 L
.44908 .34887 L
.44908 .34887 L
.44909 .34887 L
.44909 .34886 L
.44909 .34886 L
.44909 .34886 L
.4491 .34885 L
.4491 .34885 L
.4491 .34885 L
.4491 .34884 L
.44911 .34884 L
.44911 .34884 L
.44911 .34884 L
.44911 .34883 L
.44912 .34883 L
.44912 .34883 L
.44912 .34882 L
.44912 .34882 L
.44913 .34882 L
.44913 .34881 L
.44913 .34881 L
.44913 .34881 L
.44914 .3488 L
.44914 .3488 L
.44914 .3488 L
.44914 .3488 L
.44915 .34879 L
.44915 .34879 L
.44915 .34879 L
.44915 .34878 L
.44916 .34878 L
.44916 .34878 L
.44916 .34878 L
.44916 .34877 L
.44917 .34877 L
.44917 .34877 L
.44917 .34876 L
.44917 .34876 L
.44918 .34876 L
.44918 .34875 L
.44918 .34875 L
.44918 .34875 L
.44919 .34875 L
.44919 .34874 L
.44919 .34874 L
.44919 .34874 L
Mistroke
.4492 .34873 L
.4492 .34873 L
.4492 .34873 L
.4492 .34872 L
.44921 .34872 L
.44921 .34872 L
.44921 .34872 L
.44921 .34871 L
.44922 .34871 L
.44922 .34871 L
.44922 .3487 L
.44922 .3487 L
.44923 .3487 L
.44923 .3487 L
.44923 .34869 L
.44923 .34869 L
.44924 .34869 L
.44924 .34868 L
.44924 .34868 L
.44924 .34868 L
.44925 .34868 L
.44925 .34867 L
.44925 .34867 L
.44925 .34867 L
.44926 .34866 L
.44926 .34866 L
.44926 .34866 L
.44926 .34866 L
.44927 .34865 L
.44927 .34865 L
.44927 .34865 L
.44927 .34864 L
.44928 .34864 L
.44928 .34864 L
.44928 .34864 L
.44928 .34863 L
.44929 .34863 L
.44929 .34863 L
.44929 .34862 L
.44929 .34862 L
.4493 .34862 L
.4493 .34862 L
.4493 .34861 L
.4493 .34861 L
.44931 .34861 L
.44931 .3486 L
.44931 .3486 L
.44931 .3486 L
.44932 .3486 L
.44932 .34859 L
Mistroke
.44932 .34859 L
.44933 .34859 L
.44933 .34858 L
.44933 .34858 L
.44933 .34858 L
.44934 .34858 L
.44934 .34857 L
.44934 .34857 L
.44934 .34857 L
.44935 .34856 L
.44935 .34856 L
.44935 .34856 L
.44935 .34856 L
.44936 .34855 L
.44936 .34855 L
.44936 .34855 L
.44936 .34854 L
.44937 .34854 L
.44937 .34854 L
.44937 .34854 L
.44937 .34853 L
.44938 .34853 L
.44938 .34853 L
.44938 .34853 L
.44938 .34852 L
.44939 .34852 L
.44939 .34852 L
.44939 .34851 L
.44939 .34851 L
.4494 .34851 L
.4494 .34851 L
.4494 .3485 L
.4494 .3485 L
.44941 .3485 L
.44941 .3485 L
.44941 .34849 L
.44942 .34849 L
.44942 .34849 L
.44942 .34848 L
.44942 .34848 L
.44943 .34848 L
.44943 .34848 L
.44943 .34847 L
.44943 .34847 L
.44944 .34847 L
.44944 .34847 L
.44944 .34846 L
.44944 .34846 L
.44945 .34846 L
.44945 .34845 L
Mistroke
.44945 .34845 L
.44945 .34845 L
.44946 .34845 L
.44946 .34844 L
.44946 .34844 L
.44946 .34844 L
.44947 .34844 L
.44947 .34843 L
.44947 .34843 L
.44948 .34843 L
.44948 .34843 L
.44948 .34842 L
.44948 .34842 L
.44949 .34842 L
.44949 .34841 L
.44949 .34841 L
.44949 .34841 L
.4495 .34841 L
.4495 .3484 L
.4495 .3484 L
.4495 .3484 L
.44951 .3484 L
.44951 .34839 L
.44951 .34839 L
.44951 .34839 L
.44952 .34839 L
.44952 .34838 L
.44952 .34838 L
.44952 .34838 L
.44953 .34838 L
.44953 .34837 L
.44953 .34837 L
.44954 .34837 L
.44954 .34836 L
.44954 .34836 L
.44954 .34836 L
.44955 .34836 L
.44955 .34835 L
.44955 .34835 L
.44955 .34835 L
.44956 .34835 L
.44956 .34834 L
.44956 .34834 L
.44956 .34834 L
.44957 .34834 L
.44957 .34833 L
.44957 .34833 L
.44957 .34833 L
.44958 .34833 L
.44958 .34832 L
Mistroke
.44958 .34832 L
.44959 .34832 L
.44959 .34832 L
.44959 .34831 L
.44959 .34831 L
.4496 .34831 L
.4496 .34831 L
.4496 .3483 L
.4496 .3483 L
.44961 .3483 L
.44961 .3483 L
.44961 .34829 L
.44961 .34829 L
.44962 .34829 L
.44962 .34829 L
.44962 .34828 L
.44962 .34828 L
.44963 .34828 L
.44963 .34828 L
.44963 .34827 L
.44964 .34827 L
.44964 .34827 L
.44964 .34827 L
.44964 .34826 L
.44965 .34826 L
.44965 .34826 L
.44965 .34826 L
.44965 .34825 L
.44966 .34825 L
.44966 .34825 L
.44966 .34825 L
.44966 .34824 L
.44967 .34824 L
.44967 .34824 L
.44967 .34824 L
.44968 .34823 L
.44968 .34823 L
.44968 .34823 L
.44968 .34823 L
.44969 .34822 L
.44969 .34822 L
.44969 .34822 L
.44969 .34822 L
.4497 .34821 L
.4497 .34821 L
.4497 .34821 L
.4497 .34821 L
.44971 .3482 L
.44971 .3482 L
.44971 .3482 L
Mistroke
.44971 .3482 L
.44972 .34819 L
.44972 .34819 L
.44972 .34819 L
.44973 .34819 L
.44973 .34818 L
.44973 .34818 L
.44973 .34818 L
.44974 .34818 L
.44974 .34817 L
.44974 .34817 L
.44974 .34817 L
.44975 .34817 L
.44975 .34816 L
.44975 .34816 L
.44975 .34816 L
.44976 .34816 L
.44976 .34816 L
.44976 .34815 L
.44977 .34815 L
.44977 .34815 L
.44977 .34815 L
.44977 .34814 L
.44978 .34814 L
.44978 .34814 L
.44978 .34814 L
.44978 .34813 L
.44979 .34813 L
.44979 .34813 L
.44979 .34813 L
.44979 .34812 L
.4498 .34812 L
.4498 .34812 L
.4498 .34812 L
.44981 .34811 L
.44981 .34811 L
.44981 .34811 L
.44981 .34811 L
.44982 .34811 L
.44982 .3481 L
.44982 .3481 L
.44982 .3481 L
.44983 .3481 L
.44983 .34809 L
.44983 .34809 L
.44983 .34809 L
.44984 .34809 L
.44984 .34808 L
.44984 .34808 L
.44985 .34808 L
Mistroke
.44985 .34808 L
.44985 .34808 L
.44985 .34807 L
.44986 .34807 L
.44986 .34807 L
.44986 .34807 L
.44986 .34806 L
.44987 .34806 L
.44987 .34806 L
.44987 .34806 L
.44987 .34805 L
.44988 .34805 L
.44988 .34805 L
.44988 .34805 L
.44989 .34805 L
.44989 .34804 L
.44989 .34804 L
.44989 .34804 L
.4499 .34804 L
.4499 .34803 L
.4499 .34803 L
.4499 .34803 L
.44991 .34803 L
.44991 .34803 L
.44991 .34802 L
.44991 .34802 L
.44992 .34802 L
.44992 .34802 L
.44992 .34801 L
.44993 .34801 L
.44993 .34801 L
.44993 .34801 L
.44993 .34801 L
.44994 .348 L
.44994 .348 L
.44994 .348 L
.44994 .348 L
.44995 .34799 L
.44995 .34799 L
.44995 .34799 L
.44995 .34799 L
.44996 .34799 L
.44996 .34798 L
.44996 .34798 L
.44997 .34798 L
.44997 .34798 L
.44997 .34797 L
.44997 .34797 L
.44998 .34797 L
.44998 .34797 L
Mistroke
.44998 .34797 L
.44998 .34796 L
.44999 .34796 L
.44999 .34796 L
.44999 .34796 L
.44999 .34796 L
.45 .34795 L
.45 .34795 L
.45 .34795 L
.45001 .34795 L
.45001 .34794 L
.45001 .34794 L
.45001 .34794 L
.45002 .34794 L
.45002 .34794 L
.45002 .34793 L
.45002 .34793 L
.45003 .34793 L
.45003 .34793 L
.45003 .34793 L
.45003 .34792 L
.45004 .34792 L
.45004 .34792 L
.45004 .34792 L
.45005 .34791 L
.45005 .34791 L
.45005 .34791 L
.45005 .34791 L
.45006 .34791 L
.45006 .3479 L
.45006 .3479 L
.45006 .3479 L
.45007 .3479 L
.45007 .3479 L
.45007 .34789 L
.45007 .34789 L
.45008 .34789 L
.45008 .34789 L
.45008 .34789 L
.45009 .34788 L
.45009 .34788 L
.45009 .34788 L
.45009 .34788 L
.4501 .34788 L
.4501 .34787 L
.4501 .34787 L
.4501 .34787 L
.45011 .34787 L
.45011 .34787 L
.45011 .34786 L
Mistroke
.45011 .34786 L
.45012 .34786 L
.45012 .34786 L
.45012 .34785 L
.45013 .34785 L
.45013 .34785 L
.45013 .34785 L
.45013 .34785 L
.45014 .34784 L
.45014 .34784 L
.45014 .34784 L
.45014 .34784 L
.45015 .34784 L
.45015 .34783 L
.45015 .34783 L
.45015 .34783 L
.45016 .34783 L
.45016 .34783 L
.45016 .34782 L
.45017 .34782 L
.45017 .34782 L
.45017 .34782 L
.45017 .34782 L
.45018 .34781 L
.45018 .34781 L
.45018 .34781 L
.45018 .34781 L
.45019 .34781 L
.45019 .3478 L
.45019 .3478 L
.45019 .3478 L
.4502 .3478 L
.4502 .3478 L
.4502 .3478 L
.45021 .34779 L
.45021 .34779 L
.45021 .34779 L
.45021 .34779 L
.45022 .34779 L
.45022 .34778 L
.45022 .34778 L
.45022 .34778 L
.45023 .34778 L
.45023 .34778 L
.45023 .34777 L
.45023 .34777 L
.45024 .34777 L
.45024 .34777 L
.45024 .34777 L
.45024 .34776 L
Mistroke
.45025 .34776 L
.45025 .34776 L
.45025 .34776 L
.45026 .34776 L
.45026 .34775 L
.45026 .34775 L
.45026 .34775 L
.45027 .34775 L
.45027 .34775 L
.45027 .34775 L
.45027 .34774 L
.45028 .34774 L
.45028 .34774 L
.45028 .34774 L
.45028 .34774 L
.45029 .34773 L
.45029 .34773 L
.45029 .34773 L
.4503 .34773 L
.4503 .34773 L
.4503 .34772 L
.4503 .34772 L
.45031 .34772 L
.45031 .34772 L
.45031 .34772 L
.45031 .34772 L
.45032 .34771 L
.45032 .34771 L
.45032 .34771 L
.45032 .34771 L
.45033 .34771 L
.45033 .3477 L
.45033 .3477 L
.45034 .3477 L
.45034 .3477 L
.45034 .3477 L
.45034 .3477 L
.45035 .34769 L
.45035 .34769 L
.45035 .34769 L
.45035 .34769 L
.45036 .34769 L
.45036 .34768 L
.45036 .34768 L
.45036 .34768 L
.45037 .34768 L
.45037 .34768 L
.45037 .34768 L
.45037 .34767 L
.45038 .34767 L
Mistroke
.45038 .34767 L
.45038 .34767 L
.45039 .34767 L
.45039 .34766 L
.45039 .34766 L
.45039 .34766 L
.4504 .34766 L
.4504 .34766 L
.4504 .34766 L
.4504 .34765 L
.45041 .34765 L
.45041 .34765 L
.45041 .34765 L
.45041 .34765 L
.45042 .34765 L
.45042 .34764 L
.45042 .34764 L
.45042 .34764 L
.45043 .34764 L
.45043 .34764 L
.45043 .34764 L
.45044 .34763 L
.45044 .34763 L
.45044 .34763 L
.45044 .34763 L
.45045 .34763 L
.45045 .34762 L
.45045 .34762 L
.45045 .34762 L
.45046 .34762 L
.45046 .34762 L
.45046 .34762 L
.45046 .34761 L
.45047 .34761 L
.45047 .34761 L
.45047 .34761 L
.45047 .34761 L
.45048 .34761 L
.45048 .3476 L
.45048 .3476 L
.45048 .3476 L
.45049 .3476 L
.45049 .3476 L
.45049 .3476 L
.4505 .34759 L
.4505 .34759 L
.4505 .34759 L
.4505 .34759 L
.45051 .34759 L
.45051 .34759 L
Mistroke
.45051 .34758 L
.45051 .34758 L
.45052 .34758 L
.45052 .34758 L
.45052 .34758 L
.45052 .34758 L
.45053 .34757 L
.45053 .34757 L
.45053 .34757 L
.45053 .34757 L
.45054 .34757 L
.45054 .34757 L
.45054 .34757 L
.45054 .34756 L
.45055 .34756 L
.45055 .34756 L
.45055 .34756 L
.45056 .34756 L
.45056 .34756 L
.45056 .34755 L
.45056 .34755 L
.45057 .34755 L
.45057 .34755 L
.45057 .34755 L
.45057 .34755 L
.45058 .34754 L
.45058 .34754 L
.45058 .34754 L
.45058 .34754 L
.45059 .34754 L
.45059 .34754 L
.45059 .34753 L
.45059 .34753 L
.4506 .34753 L
.4506 .34753 L
.4506 .34753 L
.4506 .34753 L
.45061 .34753 L
.45061 .34752 L
.45061 .34752 L
.45061 .34752 L
.45062 .34752 L
.45062 .34752 L
.45062 .34752 L
.45063 .34751 L
.45063 .34751 L
.45063 .34751 L
.45063 .34751 L
.45064 .34751 L
.45064 .34751 L
Mistroke
.45064 .34751 L
.45064 .3475 L
.45065 .3475 L
.45065 .3475 L
.45065 .3475 L
.45065 .3475 L
.45066 .3475 L
.45066 .34749 L
.45066 .34749 L
.45066 .34749 L
.45067 .34749 L
.45067 .34749 L
.45067 .34749 L
.45067 .34749 L
.45068 .34748 L
.45068 .34748 L
.45068 .34748 L
.45068 .34748 L
.45069 .34748 L
.45069 .34748 L
.45069 .34748 L
.45069 .34747 L
.4507 .34747 L
.4507 .34747 L
.4507 .34747 L
.45071 .34747 L
.45071 .34747 L
.45071 .34747 L
.45071 .34746 L
.45072 .34746 L
.45072 .34746 L
.45072 .34746 L
.45072 .34746 L
.45073 .34746 L
.45073 .34746 L
.45073 .34745 L
.45073 .34745 L
.45074 .34745 L
.45074 .34745 L
.45074 .34745 L
.45074 .34745 L
.45075 .34745 L
.45075 .34744 L
.45075 .34744 L
.45075 .34744 L
.45076 .34744 L
.45076 .34744 L
.45076 .34744 L
.45076 .34744 L
.45077 .34743 L
Mistroke
.45077 .34743 L
.45077 .34743 L
.45077 .34743 L
.45078 .34743 L
.45078 .34743 L
.45078 .34743 L
.45078 .34742 L
.45079 .34742 L
.45079 .34742 L
.45079 .34742 L
.45079 .34742 L
.4508 .34742 L
.4508 .34742 L
.4508 .34741 L
.4508 .34741 L
.45081 .34741 L
.45081 .34741 L
.45081 .34741 L
.45081 .34741 L
.45082 .34741 L
.45082 .3474 L
.45082 .3474 L
.45082 .3474 L
.45083 .3474 L
.45083 .3474 L
.45083 .3474 L
.45083 .3474 L
.45084 .3474 L
.45084 .34739 L
.45084 .34739 L
.45084 .34739 L
.45085 .34739 L
.45085 .34739 L
.45085 .34739 L
.45085 .34739 L
.45086 .34738 L
.45086 .34738 L
.45086 .34738 L
.45086 .34738 L
.45087 .34738 L
.45087 .34738 L
.45087 .34738 L
.45087 .34738 L
.45088 .34737 L
.45088 .34737 L
.45088 .34737 L
.45088 .34737 L
.45089 .34737 L
.45089 .34737 L
.45089 .34737 L
Mistroke
.45089 .34737 L
.4509 .34736 L
.4509 .34736 L
.4509 .34736 L
.4509 .34736 L
.45091 .34736 L
.45091 .34736 L
.45091 .34736 L
.45091 .34736 L
.45092 .34735 L
.45092 .34735 L
.45092 .34735 L
.45092 .34735 L
.45093 .34735 L
.45093 .34735 L
.45093 .34735 L
.45093 .34735 L
.45094 .34734 L
.45094 .34734 L
.45094 .34734 L
.45094 .34734 L
.45095 .34734 L
.45095 .34734 L
.45095 .34734 L
.45095 .34734 L
.45096 .34733 L
.45096 .34733 L
.45096 .34733 L
.45096 .34733 L
.45097 .34733 L
.45097 .34733 L
.45097 .34733 L
.45097 .34733 L
.45098 .34732 L
.45098 .34732 L
.45098 .34732 L
.45098 .34732 L
.45099 .34732 L
.45099 .34732 L
.45099 .34732 L
.45099 .34732 L
.451 .34732 L
.451 .34731 L
.451 .34731 L
.451 .34731 L
.45101 .34731 L
.45101 .34731 L
.45101 .34731 L
.45101 .34731 L
.45102 .34731 L
Mistroke
.45102 .3473 L
.45102 .3473 L
.45102 .3473 L
.45103 .3473 L
.45103 .3473 L
.45103 .3473 L
.45103 .3473 L
.45104 .3473 L
.45104 .3473 L
.45104 .34729 L
.45104 .34729 L
.45105 .34729 L
.45105 .34729 L
.45105 .34729 L
.45105 .34729 L
.45106 .34729 L
.45106 .34729 L
.45106 .34729 L
.45106 .34728 L
.45106 .34728 L
.45107 .34728 L
.45107 .34728 L
.45107 .34728 L
.45107 .34728 L
.45108 .34728 L
.45108 .34728 L
.45108 .34728 L
.45108 .34727 L
.45109 .34727 L
.45109 .34727 L
.45109 .34727 L
.45109 .34727 L
.4511 .34727 L
.4511 .34727 L
.4511 .34727 L
.4511 .34727 L
.45111 .34726 L
.45111 .34726 L
.45111 .34726 L
.45111 .34726 L
.45112 .34726 L
.45112 .34726 L
.45112 .34726 L
.45112 .34726 L
.45113 .34726 L
.45113 .34726 L
.45113 .34725 L
.45113 .34725 L
.45113 .34725 L
.45114 .34725 L
Mistroke
.45114 .34725 L
.45114 .34725 L
.45114 .34725 L
.45115 .34725 L
.45115 .34725 L
.45115 .34725 L
.45115 .34724 L
.45116 .34724 L
.45116 .34724 L
.45116 .34724 L
.45116 .34724 L
.45117 .34724 L
.45117 .34724 L
.45117 .34724 L
.45117 .34724 L
.45118 .34723 L
.45118 .34723 L
.45118 .34723 L
.45118 .34723 L
.45119 .34723 L
.45119 .34723 L
.45119 .34723 L
.45119 .34723 L
.45119 .34723 L
.4512 .34723 L
.4512 .34723 L
.4512 .34722 L
.4512 .34722 L
.45121 .34722 L
.45121 .34722 L
.45121 .34722 L
.45121 .34722 L
.45122 .34722 L
.45122 .34722 L
.45122 .34722 L
.45122 .34722 L
.45123 .34721 L
.45123 .34721 L
.45123 .34721 L
.45123 .34721 L
.45123 .34721 L
.45124 .34721 L
.45124 .34721 L
.45124 .34721 L
.45124 .34721 L
.45125 .34721 L
.45125 .34721 L
.45125 .3472 L
.45125 .3472 L
.45126 .3472 L
Mistroke
.45126 .3472 L
.45126 .3472 L
.45126 .3472 L
.45127 .3472 L
.45127 .3472 L
.45127 .3472 L
.45127 .3472 L
.45127 .34719 L
.45128 .34719 L
.45128 .34719 L
.45128 .34719 L
.45128 .34719 L
.45129 .34719 L
.45129 .34719 L
.45129 .34719 L
.45129 .34719 L
.4513 .34719 L
.4513 .34719 L
.4513 .34719 L
.4513 .34718 L
.4513 .34718 L
.45131 .34718 L
.45131 .34718 L
.45131 .34718 L
.45131 .34718 L
.45132 .34718 L
.45132 .34718 L
.45132 .34718 L
.45132 .34718 L
.45133 .34718 L
.45133 .34717 L
.45133 .34717 L
.45133 .34717 L
.45133 .34717 L
.45134 .34717 L
.45134 .34717 L
.45134 .34717 L
.45134 .34717 L
.45135 .34717 L
.45135 .34717 L
.45135 .34717 L
.45135 .34717 L
.45136 .34716 L
.45136 .34716 L
.45136 .34716 L
.45136 .34716 L
.45136 .34716 L
.45137 .34716 L
.45137 .34716 L
.45137 .34716 L
Mistroke
.45137 .34716 L
.45138 .34716 L
.45138 .34716 L
.45138 .34716 L
.45138 .34716 L
.45139 .34715 L
.45139 .34715 L
.45139 .34715 L
.45139 .34715 L
.45139 .34715 L
.4514 .34715 L
.4514 .34715 L
.4514 .34715 L
.4514 .34715 L
.45141 .34715 L
.45141 .34715 L
.45141 .34715 L
.45141 .34714 L
.45141 .34714 L
.45142 .34714 L
.45142 .34714 L
.45142 .34714 L
.45142 .34714 L
.45143 .34714 L
.45143 .34714 L
.45143 .34714 L
.45143 .34714 L
.45143 .34714 L
.45144 .34714 L
.45144 .34714 L
.45144 .34714 L
.45144 .34713 L
.45145 .34713 L
.45145 .34713 L
.45145 .34713 L
.45145 .34713 L
.45145 .34713 L
.45146 .34713 L
.45146 .34713 L
.45146 .34713 L
.45146 .34713 L
.45147 .34713 L
.45147 .34713 L
.45147 .34713 L
.45147 .34712 L
.45147 .34712 L
.45148 .34712 L
.45148 .34712 L
.45148 .34712 L
.45148 .34712 L
Mistroke
.45149 .34712 L
.45149 .34712 L
.45149 .34712 L
.45149 .34712 L
.45149 .34712 L
.4515 .34712 L
.4515 .34712 L
.4515 .34712 L
.4515 .34712 L
.45151 .34711 L
.45151 .34711 L
.45151 .34711 L
.45151 .34711 L
.45151 .34711 L
.45152 .34711 L
.45152 .34711 L
.45152 .34711 L
.45152 .34711 L
.45153 .34711 L
.45153 .34711 L
.45153 .34711 L
.45153 .34711 L
.45153 .34711 L
.45154 .34711 L
.45154 .3471 L
.45154 .3471 L
.45154 .3471 L
.45155 .3471 L
.45155 .3471 L
.45155 .3471 L
.45155 .3471 L
.45155 .3471 L
.45156 .3471 L
.45156 .3471 L
.45156 .3471 L
.45156 .3471 L
.45156 .3471 L
.45157 .3471 L
.45157 .3471 L
.45157 .3471 L
.45157 .34709 L
.45158 .34709 L
.45158 .34709 L
.45158 .34709 L
.45158 .34709 L
.45158 .34709 L
.45159 .34709 L
.45159 .34709 L
.45159 .34709 L
.45159 .34709 L
Mistroke
.4516 .34709 L
.4516 .34709 L
.4516 .34709 L
.4516 .34709 L
.4516 .34709 L
.45161 .34709 L
.45161 .34708 L
.45161 .34708 L
.45161 .34708 L
.45161 .34708 L
.45162 .34708 L
.45162 .34708 L
.45162 .34708 L
.45162 .34708 L
.45162 .34708 L
.45163 .34708 L
.45163 .34708 L
.45163 .34708 L
.45163 .34708 L
.45164 .34708 L
.45164 .34708 L
.45164 .34708 L
.45164 .34708 L
.45164 .34708 L
.45165 .34707 L
.45165 .34707 L
.45165 .34707 L
.45165 .34707 L
.45165 .34707 L
.45166 .34707 L
.45166 .34707 L
.45166 .34707 L
.45166 .34707 L
.45167 .34707 L
.45167 .34707 L
.45167 .34707 L
.45167 .34707 L
.45167 .34707 L
.45168 .34707 L
.45168 .34707 L
.45168 .34707 L
.45168 .34707 L
.45168 .34707 L
.45169 .34706 L
.45169 .34706 L
.45169 .34706 L
.45169 .34706 L
.45169 .34706 L
.4517 .34706 L
.4517 .34706 L
Mistroke
.4517 .34706 L
.4517 .34706 L
.4517 .34706 L
.45171 .34706 L
.45171 .34706 L
.45171 .34706 L
.45171 .34706 L
.45172 .34706 L
.45172 .34706 L
.45172 .34706 L
.45172 .34706 L
.45172 .34706 L
.45173 .34706 L
.45173 .34706 L
.45173 .34705 L
.45173 .34705 L
.45173 .34705 L
.45174 .34705 L
.45174 .34705 L
.45174 .34705 L
.45174 .34705 L
.45174 .34705 L
.45175 .34705 L
.45175 .34705 L
.45175 .34705 L
.45175 .34705 L
.45175 .34705 L
.45176 .34705 L
.45176 .34705 L
.45176 .34705 L
.45176 .34705 L
.45176 .34705 L
.45177 .34705 L
.45177 .34705 L
.45177 .34705 L
.45177 .34705 L
.45177 .34705 L
.45178 .34704 L
.45178 .34704 L
.45178 .34704 L
.45178 .34704 L
.45178 .34704 L
.45179 .34704 L
.45179 .34704 L
.45179 .34704 L
.45179 .34704 L
.45179 .34704 L
.4518 .34704 L
.4518 .34704 L
.4518 .34704 L
Mistroke
.4518 .34704 L
.4518 .34704 L
.45181 .34704 L
.45181 .34704 L
.45181 .34704 L
.45181 .34704 L
.45181 .34704 L
.45182 .34704 L
.45182 .34704 L
.45182 .34704 L
.45182 .34704 L
.45182 .34704 L
.45183 .34704 L
.45183 .34703 L
.45183 .34703 L
.45183 .34703 L
.45183 .34703 L
.45184 .34703 L
.45184 .34703 L
.45184 .34703 L
.45184 .34703 L
.45184 .34703 L
.45185 .34703 L
.45185 .34703 L
.45185 .34703 L
.45185 .34703 L
.45185 .34703 L
.45186 .34703 L
.45186 .34703 L
.45186 .34703 L
.45186 .34703 L
.45186 .34703 L
.45187 .34703 L
.45187 .34703 L
.45187 .34703 L
.45187 .34703 L
.45187 .34703 L
.45188 .34703 L
.45188 .34703 L
.45188 .34703 L
.45188 .34703 L
.45188 .34703 L
.45189 .34702 L
.45189 .34702 L
.45189 .34702 L
.45189 .34702 L
.45189 .34702 L
.4519 .34702 L
.4519 .34702 L
.4519 .34702 L
Mistroke
.4519 .34702 L
.4519 .34702 L
.4519 .34702 L
.45191 .34702 L
.45191 .34702 L
.45191 .34702 L
.45191 .34702 L
.45191 .34702 L
.45192 .34702 L
.45192 .34702 L
.45192 .34702 L
.45192 .34702 L
.45192 .34702 L
.45193 .34702 L
.45193 .34702 L
.45193 .34702 L
.45193 .34702 L
.45193 .34702 L
.45194 .34702 L
.45194 .34702 L
.45194 .34702 L
.45194 .34702 L
.45194 .34702 L
.45194 .34702 L
.45195 .34702 L
.45195 .34702 L
.45195 .34702 L
.45195 .34702 L
.45195 .34702 L
.45196 .34701 L
.45196 .34701 L
.45196 .34701 L
.45196 .34701 L
.45196 .34701 L
.45197 .34701 L
.45197 .34701 L
.45197 .34701 L
.45197 .34701 L
.45197 .34701 L
.45197 .34701 L
.45198 .34701 L
.45198 .34701 L
.45198 .34701 L
.45198 .34701 L
.45198 .34701 L
.45199 .34701 L
.45199 .34701 L
.45199 .34701 L
.45199 .34701 L
.45199 .34701 L
Mistroke
.452 .34701 L
.452 .34701 L
.452 .34701 L
.452 .34701 L
.452 .34701 L
.452 .34701 L
.45201 .34701 L
.45201 .34701 L
.45201 .34701 L
.45201 .34701 L
.45201 .34701 L
.45202 .34701 L
.45202 .34701 L
.45202 .34701 L
.45202 .34701 L
.45202 .34701 L
.45202 .34701 L
.45203 .34701 L
.45203 .34701 L
.45203 .34701 L
.45203 .34701 L
.45203 .34701 L
.45204 .34701 L
.45204 .34701 L
.45204 .34701 L
.45204 .34701 L
.45204 .34701 L
.45204 .34701 L
.45205 .34701 L
.45205 .34701 L
.45205 .347 L
.45205 .347 L
.45205 .347 L
.45206 .347 L
.45206 .347 L
.45206 .347 L
.45206 .347 L
.45206 .347 L
.45206 .347 L
.45207 .347 L
.45207 .347 L
.45207 .347 L
.45207 .347 L
.45207 .347 L
.45207 .347 L
.45208 .347 L
.45208 .347 L
.45208 .347 L
.45208 .347 L
.45208 .347 L
Mistroke
.45209 .347 L
.45209 .347 L
.45209 .347 L
.45209 .347 L
.45209 .347 L
.45209 .347 L
.4521 .347 L
.4521 .347 L
.4521 .347 L
.4521 .347 L
.4521 .347 L
.4521 .347 L
.45211 .347 L
.45211 .347 L
.45211 .347 L
.45211 .347 L
.45211 .347 L
.45212 .347 L
.45212 .347 L
.45212 .347 L
.45212 .347 L
.45212 .347 L
.45212 .347 L
.45213 .347 L
.45213 .347 L
.45213 .347 L
.45213 .347 L
.45213 .347 L
.45213 .347 L
.45214 .347 L
.45214 .347 L
.45214 .347 L
.45214 .347 L
.45214 .347 L
.45214 .347 L
.45215 .347 L
.45215 .347 L
.45215 .347 L
.45215 .347 L
.45215 .347 L
.45216 .347 L
.45216 .347 L
.45216 .347 L
.45216 .347 L
.45216 .347 L
.45216 .347 L
.45217 .347 L
.45217 .347 L
.45217 .347 L
.45217 .347 L
Mistroke
.45217 .347 L
.45217 .347 L
.45218 .347 L
.45218 .347 L
.45218 .347 L
.45218 .347 L
.45218 .347 L
.45218 .347 L
.45219 .347 L
.45219 .347 L
.45219 .347 L
.45219 .347 L
.45219 .347 L
.45219 .347 L
.4522 .347 L
.4522 .347 L
.4522 .347 L
.4522 .347 L
.4522 .347 L
.4522 .347 L
.45221 .347 L
.45221 .347 L
.45221 .347 L
.45221 .347 L
.45221 .347 L
.45221 .347 L
.45222 .347 L
.45222 .347 L
.45222 .347 L
.45222 .347 L
.45222 .347 L
.45222 .347 L
.45223 .347 L
.45223 .347 L
.45223 .347 L
.45223 .347 L
.45223 .347 L
.45223 .347 L
.45224 .347 L
.45224 .347 L
.45224 .347 L
.45224 .347 L
.45224 .347 L
.45224 .347 L
.45224 .347 L
.45225 .347 L
.45225 .347 L
.45225 .347 L
.45225 .347 L
.45225 .347 L
Mistroke
.45225 .347 L
.45226 .347 L
.45226 .347 L
.45226 .347 L
.45226 .347 L
.45226 .347 L
.45226 .347 L
.45227 .347 L
.45227 .347 L
.45227 .347 L
.45227 .347 L
.45227 .347 L
.45227 .347 L
.45228 .347 L
.45228 .347 L
.45228 .347 L
.45228 .347 L
.45228 .347 L
.45228 .347 L
.45228 .347 L
.45229 .347 L
.45229 .347 L
.45229 .347 L
.45229 .347 L
.45229 .347 L
.45229 .347 L
.4523 .347 L
.4523 .347 L
.4523 .347 L
.4523 .347 L
.4523 .347 L
.4523 .347 L
.4523 .347 L
.45231 .347 L
.45231 .347 L
.45231 .347 L
.45231 .347 L
.45231 .347 L
.45231 .347 L
.45232 .347 L
.45232 .347 L
.45232 .347 L
.45232 .347 L
.45232 .347 L
.45232 .347 L
.45233 .347 L
.45233 .347 L
.45233 .347 L
.45233 .347 L
.45233 .347 L
Mistroke
.45233 .347 L
.45233 .347 L
.45234 .347 L
.45234 .347 L
.45234 .347 L
.45234 .347 L
.45234 .347 L
.45234 .347 L
.45234 .347 L
.45235 .34701 L
.45235 .34701 L
.45235 .34701 L
.45235 .34701 L
.45235 .34701 L
.45235 .34701 L
.45236 .34701 L
.45236 .34701 L
.45236 .34701 L
.45236 .34701 L
.45236 .34701 L
.45236 .34701 L
.45236 .34701 L
.45237 .34701 L
.45237 .34701 L
.45237 .34701 L
.45237 .34701 L
.45237 .34701 L
.45237 .34701 L
.45237 .34701 L
.45238 .34701 L
.45238 .34701 L
.45238 .34701 L
.45238 .34701 L
.45238 .34701 L
.45238 .34701 L
.45239 .34701 L
.45239 .34701 L
.45239 .34701 L
.45239 .34701 L
.45239 .34701 L
.45239 .34701 L
.45239 .34701 L
.4524 .34701 L
.4524 .34701 L
.4524 .34701 L
.4524 .34701 L
.4524 .34701 L
.4524 .34701 L
.4524 .34701 L
.45241 .34701 L
Mistroke
.45241 .34701 L
.45241 .34701 L
.45241 .34701 L
.45241 .34701 L
.45241 .34701 L
.45241 .34701 L
.45242 .34701 L
.45242 .34701 L
.45242 .34701 L
.45242 .34701 L
.45242 .34701 L
.45242 .34701 L
.45242 .34701 L
.45243 .34701 L
.45243 .34702 L
.45243 .34702 L
.45243 .34702 L
.45243 .34702 L
.45243 .34702 L
.45243 .34702 L
.45244 .34702 L
.45244 .34702 L
.45244 .34702 L
.45244 .34702 L
.45244 .34702 L
.45244 .34702 L
.45244 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45245 .34702 L
.45246 .34702 L
.45246 .34702 L
.45246 .34702 L
.45246 .34702 L
.45246 .34702 L
.45246 .34702 L
.45246 .34702 L
.45247 .34702 L
.45247 .34702 L
.45247 .34702 L
.45247 .34702 L
.45247 .34702 L
.45247 .34702 L
.45247 .34702 L
.45248 .34702 L
Mistroke
.45248 .34702 L
.45248 .34702 L
.45248 .34702 L
.45248 .34702 L
.45248 .34702 L
.45248 .34703 L
.45248 .34703 L
.45249 .34703 L
.45249 .34703 L
.45249 .34703 L
.45249 .34703 L
.45249 .34703 L
.45249 .34703 L
.45249 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.4525 .34703 L
.45251 .34703 L
.45251 .34703 L
.45251 .34703 L
.45251 .34703 L
.45251 .34703 L
.45251 .34703 L
.45251 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45252 .34703 L
.45253 .34703 L
.45253 .34703 L
.45253 .34704 L
.45253 .34704 L
.45253 .34704 L
.45253 .34704 L
.45253 .34704 L
.45253 .34704 L
.45254 .34704 L
.45254 .34704 L
.45254 .34704 L
.45254 .34704 L
.45254 .34704 L
Mistroke
.45254 .34704 L
.45254 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45255 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45256 .34704 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45257 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45258 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.45259 .34705 L
.4526 .34705 L
.4526 .34705 L
.4526 .34706 L
.4526 .34706 L
.4526 .34706 L
.4526 .34706 L
.4526 .34706 L
Mistroke
.4526 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45261 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45262 .34706 L
.45263 .34706 L
.45263 .34706 L
.45263 .34707 L
.45263 .34707 L
.45263 .34707 L
.45263 .34707 L
.45263 .34707 L
.45263 .34707 L
.45263 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45264 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45265 .34707 L
.45266 .34708 L
.45266 .34708 L
.45266 .34708 L
.45266 .34708 L
.45266 .34708 L
.45266 .34708 L
Mistroke
.45266 .34708 L
.45266 .34708 L
.45266 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45267 .34708 L
.45268 .34708 L
.45268 .34708 L
.45268 .34708 L
.45268 .34708 L
.45268 .34709 L
.45268 .34709 L
.45268 .34709 L
.45268 .34709 L
.45268 .34709 L
.45268 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.45269 .34709 L
.4527 .34709 L
.4527 .34709 L
.4527 .34709 L
.4527 .34709 L
.4527 .34709 L
.4527 .34709 L
.4527 .3471 L
.4527 .3471 L
.4527 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
.45271 .3471 L
Mistroke
.45272 .3471 L
.45272 .3471 L
.45272 .3471 L
.45272 .3471 L
.45272 .3471 L
.45272 .3471 L
.45272 .3471 L
.45272 .34711 L
.45272 .34711 L
.45272 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45273 .34711 L
.45274 .34711 L
.45274 .34711 L
.45274 .34711 L
.45274 .34711 L
.45274 .34711 L
.45274 .34711 L
.45274 .34712 L
.45274 .34712 L
.45274 .34712 L
.45274 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45275 .34712 L
.45276 .34712 L
.45276 .34712 L
.45276 .34712 L
.45276 .34712 L
.45276 .34712 L
.45276 .34713 L
.45276 .34713 L
.45276 .34713 L
.45276 .34713 L
.45276 .34713 L
Mistroke
.45276 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45277 .34713 L
.45278 .34713 L
.45278 .34713 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45278 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34714 L
.45279 .34715 L
.45279 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.4528 .34715 L
.45281 .34715 L
.45281 .34715 L
.45281 .34715 L
.45281 .34715 L
.45281 .34716 L
.45281 .34716 L
Mistroke
.45281 .34716 L
.45281 .34716 L
.45281 .34716 L
.45281 .34716 L
.45281 .34716 L
.45281 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34716 L
.45282 .34717 L
.45282 .34717 L
.45282 .34717 L
.45282 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45283 .34717 L
.45284 .34717 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45284 .34718 L
.45285 .34718 L
.45285 .34718 L
.45285 .34718 L
.45285 .34718 L
.45285 .34718 L
.45285 .34719 L
.45285 .34719 L
.45285 .34719 L
Mistroke
.45285 .34719 L
.45285 .34719 L
.45285 .34719 L
.45285 .34719 L
.45285 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .34719 L
.45286 .3472 L
.45286 .3472 L
.45286 .3472 L
.45286 .3472 L
.45286 .3472 L
.45286 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .3472 L
.45287 .34721 L
.45287 .34721 L
.45287 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34721 L
.45288 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
Mistroke
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.45289 .34722 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.4529 .34723 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34724 L
.45291 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
.45292 .34725 L
Mistroke
.45292 .34725 L
.45292 .34726 L
.45292 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34726 L
.45293 .34727 L
.45293 .34727 L
.45293 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34727 L
.45294 .34728 L
.45294 .34728 L
.45294 .34728 L
.45294 .34728 L
.45294 .34728 L
.45294 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34728 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
Mistroke
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45295 .34729 L
.45296 .34729 L
.45296 .34729 L
.45296 .34729 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .3473 L
.45296 .34731 L
.45296 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34731 L
.45297 .34732 L
.45297 .34732 L
.45297 .34732 L
.45297 .34732 L
.45297 .34732 L
.45297 .34732 L
.45297 .34732 L
.45298 .34732 L
.45298 .34732 L
.45298 .34732 L
.45298 .34732 L
.45298 .34732 L
.45298 .34732 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
Mistroke
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34733 L
.45298 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34734 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.45299 .34735 L
.453 .34735 L
.453 .34735 L
.453 .34735 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34736 L
.453 .34737 L
Mistroke
.453 .34737 L
.453 .34737 L
.453 .34737 L
.453 .34737 L
.453 .34737 L
.453 .34737 L
.45301 .34737 L
.45301 .34737 L
.45301 .34737 L
.45301 .34737 L
.45301 .34737 L
.45301 .34737 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34738 L
.45301 .34739 L
.45301 .34739 L
.45301 .34739 L
.45301 .34739 L
.45301 .34739 L
.45301 .34739 L
.45302 .34739 L
.45302 .34739 L
.45302 .34739 L
.45302 .34739 L
.45302 .34739 L
.45302 .34739 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
.45302 .3474 L
Mistroke
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45302 .34741 L
.45303 .34741 L
.45303 .34741 L
.45303 .34741 L
.45303 .34741 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34742 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34743 L
.45303 .34744 L
.45303 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34744 L
.45304 .34745 L
Mistroke
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34745 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45304 .34746 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34747 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34748 L
.45305 .34749 L
.45305 .34749 L
Mistroke
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .34749 L
.45305 .3475 L
.45305 .3475 L
.45305 .3475 L
.45305 .3475 L
.45305 .3475 L
.45305 .3475 L
.45305 .3475 L
.45306 .3475 L
.45306 .3475 L
.45306 .3475 L
.45306 .3475 L
.45306 .3475 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34751 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34752 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
Mistroke
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34753 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34754 L
.45306 .34755 L
.45306 .34755 L
.45306 .34755 L
.45306 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34755 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34756 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
Mistroke
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34757 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34758 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .34759 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .3476 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
.45307 .34761 L
Mistroke
.45307 .34761 L
.45307 .34761 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34762 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34763 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34764 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34765 L
.45307 .34766 L
Mistroke
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34766 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34767 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34768 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .34769 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
Mistroke
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .3477 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34771 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34772 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34773 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
Mistroke
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34774 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34775 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34776 L
.45307 .34777 L
.45307 .34777 L
.45307 .34777 L
.45307 .34777 L
.45307 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34777 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
.45306 .34778 L
Mistroke
.45306 .34778 L
.45306 .34778 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .34779 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .3478 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34781 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45306 .34782 L
.45305 .34782 L
.45305 .34782 L
Mistroke
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34783 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34784 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34785 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45305 .34786 L
.45304 .34786 L
.45304 .34786 L
.45304 .34787 L
Mistroke
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34787 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34788 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .34789 L
.45304 .3479 L
.45304 .3479 L
.45304 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .3479 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
Mistroke
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34791 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34792 L
.45303 .34793 L
.45303 .34793 L
.45303 .34793 L
.45303 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34793 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34794 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
Mistroke
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45302 .34795 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34796 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34797 L
.45301 .34798 L
.45301 .34798 L
.45301 .34798 L
.45301 .34798 L
.45301 .34798 L
.45301 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34798 L
.453 .34799 L
.453 .34799 L
Mistroke
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .34799 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.453 .348 L
.45299 .348 L
.45299 .348 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34801 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45299 .34802 L
.45298 .34803 L
Mistroke
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34803 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45298 .34804 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34805 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
.45297 .34806 L
Mistroke
.45297 .34806 L
.45297 .34806 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34807 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45296 .34808 L
.45295 .34808 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .34809 L
.45295 .3481 L
.45295 .3481 L
.45295 .3481 L
.45295 .3481 L
.45295 .3481 L
.45295 .3481 L
.45295 .3481 L
Mistroke
.45295 .3481 L
.45295 .3481 L
.45294 .3481 L
.45294 .3481 L
.45294 .3481 L
.45294 .3481 L
.45294 .3481 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34811 L
.45294 .34812 L
.45294 .34812 L
.45294 .34812 L
.45294 .34812 L
.45294 .34812 L
.45294 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34812 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34813 L
.45293 .34814 L
.45292 .34814 L
Mistroke
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34814 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45292 .34815 L
.45291 .34815 L
.45291 .34815 L
.45291 .34815 L
.45291 .34815 L
.45291 .34815 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34816 L
.45291 .34817 L
.45291 .34817 L
.45291 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
Mistroke
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34817 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.4529 .34818 L
.45289 .34818 L
.45289 .34818 L
.45289 .34818 L
.45289 .34818 L
.45289 .34818 L
.45289 .34818 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .34819 L
.45289 .3482 L
.45289 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
.45288 .3482 L
Mistroke
.45288 .3482 L
.45288 .34821 L
.45288 .34821 L
.45288 .34821 L
.45288 .34821 L
.45288 .34821 L
.45288 .34821 L
.45288 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34821 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45287 .34822 L
.45286 .34822 L
.45286 .34822 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34823 L
.45286 .34824 L
.45286 .34824 L
.45285 .34824 L
Mistroke
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34824 L
.45285 .34825 L
.45285 .34825 L
.45285 .34825 L
.45285 .34825 L
.45285 .34825 L
.45285 .34825 L
.45285 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34825 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45284 .34826 L
.45283 .34826 L
.45283 .34826 L
.45283 .34826 L
.45283 .34826 L
.45283 .34826 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
Mistroke
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45283 .34827 L
.45282 .34827 L
.45282 .34827 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34828 L
.45282 .34829 L
.45282 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .34829 L
.45281 .3483 L
.45281 .3483 L
.45281 .3483 L
.45281 .3483 L
.4528 .3483 L
.4528 .3483 L
Mistroke
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .3483 L
.4528 .34831 L
.4528 .34831 L
.4528 .34831 L
.4528 .34831 L
.4528 .34831 L
.4528 .34831 L
.4528 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34831 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45279 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34832 L
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
Mistroke
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
.45278 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34833 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45277 .34834 L
.45276 .34834 L
.45276 .34834 L
.45276 .34834 L
.45276 .34834 L
.45276 .34834 L
.45276 .34834 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45276 .34835 L
.45275 .34835 L
.45275 .34835 L
.45275 .34835 L
.45275 .34835 L
.45275 .34835 L
.45275 .34835 L
.45275 .34835 L
Mistroke
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45275 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34836 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45274 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34837 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45273 .34838 L
.45272 .34838 L
Mistroke
.45272 .34838 L
.45272 .34838 L
.45272 .34838 L
.45272 .34838 L
.45272 .34838 L
.45272 .34838 L
.45272 .34838 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45272 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .34839 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.45271 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .3484 L
.4527 .34841 L
.4527 .34841 L
.4527 .34841 L
Mistroke
.4527 .34841 L
.4527 .34841 L
.4527 .34841 L
.4527 .34841 L
.4527 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34841 L
.45269 .34842 L
.45269 .34842 L
.45269 .34842 L
.45269 .34842 L
.45269 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34842 L
.45268 .34843 L
.45268 .34843 L
.45268 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
Mistroke
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45267 .34843 L
.45266 .34843 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45266 .34844 L
.45265 .34844 L
.45265 .34844 L
.45265 .34844 L
.45265 .34844 L
.45265 .34844 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45265 .34845 L
.45264 .34845 L
.45264 .34845 L
.45264 .34845 L
Mistroke
.45264 .34845 L
.45264 .34845 L
.45264 .34845 L
.45264 .34845 L
.45264 .34845 L
.45264 .34845 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45264 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34846 L
.45263 .34847 L
.45263 .34847 L
.45263 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
.45262 .34847 L
Mistroke
.45262 .34847 L
.45262 .34847 L
.45261 .34847 L
.45261 .34847 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.45261 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34848 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.4526 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
Mistroke
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .34849 L
.45259 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45258 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .3485 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45257 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
Mistroke
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34851 L
.45256 .34852 L
.45256 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45255 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34852 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
.45254 .34853 L
Mistroke
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45253 .34853 L
.45252 .34853 L
.45252 .34853 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45252 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
Mistroke
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34854 L
.45251 .34855 L
.45251 .34855 L
.45251 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.4525 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34855 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45249 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
Mistroke
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45248 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34856 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45247 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
Mistroke
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45246 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34857 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45245 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45244 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
Mistroke
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34858 L
.45243 .34859 L
.45243 .34859 L
.45243 .34859 L
.45243 .34859 L
.45243 .34859 L
.45243 .34859 L
.45243 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45242 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
Mistroke
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .34859 L
.45241 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.4524 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45239 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
Mistroke
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .3486 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45238 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45237 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
Mistroke
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45236 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34861 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45235 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
Mistroke
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45234 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45233 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34862 L
.45232 .34863 L
.45232 .34863 L
.45232 .34863 L
.45232 .34863 L
Mistroke
.45232 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.45231 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.4523 .34863 L
.45229 .34863 L
.45229 .34863 L
Mistroke
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45229 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45228 .34863 L
.45227 .34863 L
.45227 .34863 L
.45227 .34863 L
Mistroke
.45227 .34863 L
.45227 .34863 L
.45227 .34863 L
.45227 .34863 L
.45227 .34863 L
.45227 .34863 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45227 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45226 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
Mistroke
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45225 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
.45224 .34864 L
Mistroke
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45223 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
Mistroke
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45222 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.45221 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
Mistroke
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.4522 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45219 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
Mistroke
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45218 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
Mistroke
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45217 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45216 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
Mistroke
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45215 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
.45214 .34864 L
Mistroke
.45214 .34864 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45214 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
.45213 .34863 L
Mistroke
.45213 .34863 L
.45213 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45212 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
Mistroke
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34863 L
.45211 .34862 L
.45211 .34862 L
.45211 .34862 L
.45211 .34862 L
.45211 .34862 L
.45211 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
Mistroke
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.4521 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
Mistroke
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34862 L
.45209 .34861 L
.45209 .34861 L
.45209 .34861 L
.45209 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
Mistroke
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45208 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
Mistroke
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .34861 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45207 .3486 L
.45206 .3486 L
.45206 .3486 L
Mistroke
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .3486 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
Mistroke
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45206 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
Mistroke
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34859 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
.45205 .34858 L
Mistroke
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34858 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
Mistroke
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34857 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
Mistroke
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45204 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34856 L
.45203 .34855 L
.45203 .34855 L
Mistroke
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
Mistroke
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34855 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
Mistroke
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34854 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45203 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
Mistroke
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34853 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
Mistroke
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34852 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
Mistroke
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .34851 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
Mistroke
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .3485 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
Mistroke
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
Mistroke
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34849 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45202 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
Mistroke
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34848 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
Mistroke
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34847 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
Mistroke
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34846 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
Mistroke
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45203 .34845 L
.45204 .34845 L
.45204 .34845 L
.45204 .34845 L
.45204 .34845 L
.45204 .34845 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
Mistroke
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
Mistroke
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34844 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
Mistroke
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34843 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45204 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
Mistroke
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34842 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
Mistroke
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45205 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
Mistroke
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .34841 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
Mistroke
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .3484 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
.45206 .34839 L
Mistroke
.45206 .34839 L
.45206 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
Mistroke
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34839 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
.45207 .34838 L
Mistroke
.45207 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34838 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
Mistroke
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45208 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
Mistroke
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34837 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
Mistroke
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.45209 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
Mistroke
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34836 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
Mistroke
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.4521 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
Mistroke
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34835 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
Mistroke
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45211 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
Mistroke
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34834 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
Mistroke
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45212 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
Mistroke
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
.45213 .34833 L
Mistroke
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34833 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
Mistroke
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45214 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
Mistroke
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
Mistroke
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45215 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
Mistroke
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34832 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
Mistroke
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45216 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
Mistroke
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
Mistroke
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
.45217 .34831 L
Mistroke
.45217 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
Mistroke
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
.45218 .34831 L
Mistroke
.45218 .34831 L
Mfstroke
1 0 1 r
.29803 .24421 m
.29826 .2441 L
.2985 .24399 L
.29874 .24388 L
.29897 .24378 L
.29921 .24367 L
.29944 .24356 L
.29968 .24345 L
.29992 .24335 L
.30015 .24324 L
.30039 .24313 L
.30062 .24303 L
.30086 .24292 L
.30109 .24282 L
.30133 .24271 L
.30156 .2426 L
.3018 .2425 L
.30203 .24239 L
.30227 .24229 L
.3025 .24218 L
.30274 .24208 L
.30297 .24197 L
.30321 .24187 L
.30344 .24177 L
.30367 .24166 L
.30391 .24156 L
.30414 .24146 L
.30438 .24135 L
.30461 .24125 L
.30485 .24115 L
.30508 .24105 L
.30531 .24094 L
.30555 .24084 L
.30578 .24074 L
.30601 .24064 L
.30625 .24054 L
.30648 .24043 L
.30671 .24033 L
.30695 .24023 L
.30718 .24013 L
.30741 .24003 L
.30765 .23993 L
.30788 .23983 L
.30811 .23973 L
.30835 .23963 L
.30858 .23953 L
.30881 .23943 L
.30904 .23933 L
.30928 .23923 L
.30951 .23914 L
Mistroke
.30974 .23904 L
.30997 .23894 L
.3102 .23884 L
.31044 .23874 L
.31067 .23865 L
.3109 .23855 L
.31113 .23845 L
.31136 .23835 L
.3116 .23826 L
.31183 .23816 L
.31206 .23806 L
.31229 .23797 L
.31252 .23787 L
.31275 .23777 L
.31298 .23768 L
.31321 .23758 L
.31345 .23749 L
.31368 .23739 L
.31391 .2373 L
.31414 .2372 L
.31437 .23711 L
.3146 .23701 L
.31483 .23692 L
.31506 .23683 L
.31529 .23673 L
.31552 .23664 L
.31575 .23654 L
.31598 .23645 L
.31621 .23636 L
.31644 .23627 L
.31667 .23617 L
.3169 .23608 L
.31713 .23599 L
.31736 .2359 L
.31759 .2358 L
.31782 .23571 L
.31805 .23562 L
.31828 .23553 L
.31851 .23544 L
.31874 .23535 L
.31897 .23526 L
.3192 .23517 L
.31942 .23508 L
.31965 .23499 L
.31988 .2349 L
.32011 .23481 L
.32034 .23472 L
.32057 .23463 L
.3208 .23454 L
.32103 .23445 L
Mistroke
.32125 .23436 L
.32148 .23427 L
.32171 .23418 L
.32194 .23409 L
.32217 .234 L
.32239 .23392 L
.32262 .23383 L
.32285 .23374 L
.32308 .23365 L
.3233 .23357 L
.32353 .23348 L
.32376 .23339 L
.32399 .23331 L
.32421 .23322 L
.32444 .23313 L
.32467 .23305 L
.3249 .23296 L
.32512 .23288 L
.32535 .23279 L
.32558 .2327 L
.3258 .23262 L
.32603 .23253 L
.32626 .23245 L
.32648 .23236 L
.32671 .23228 L
.32694 .2322 L
.32716 .23211 L
.32739 .23203 L
.32761 .23194 L
.32784 .23186 L
.32807 .23178 L
.32829 .23169 L
.32852 .23161 L
.32874 .23153 L
.32897 .23144 L
.3292 .23136 L
.32942 .23128 L
.32965 .2312 L
.32987 .23111 L
.3301 .23103 L
.33032 .23095 L
.33055 .23087 L
.33077 .23079 L
.331 .23071 L
.33122 .23063 L
.33145 .23055 L
.33167 .23046 L
.3319 .23038 L
.33212 .2303 L
.33235 .23022 L
Mistroke
.33257 .23014 L
.33279 .23006 L
.33302 .22998 L
.33324 .22991 L
.33347 .22983 L
.33369 .22975 L
.33391 .22967 L
.33414 .22959 L
.33436 .22951 L
.33459 .22943 L
.33481 .22935 L
.33503 .22928 L
.33526 .2292 L
.33548 .22912 L
.3357 .22904 L
.33593 .22897 L
.33615 .22889 L
.33637 .22881 L
.33659 .22873 L
.33682 .22866 L
.33704 .22858 L
.33726 .22851 L
.33749 .22843 L
.33771 .22835 L
.33793 .22828 L
.33815 .2282 L
.33838 .22813 L
.3386 .22805 L
.33882 .22798 L
.33904 .2279 L
.33926 .22783 L
.33949 .22775 L
.33971 .22768 L
.33993 .2276 L
.34015 .22753 L
.34037 .22746 L
.34059 .22738 L
.34082 .22731 L
.34104 .22723 L
.34126 .22716 L
.34148 .22709 L
.3417 .22702 L
.34192 .22694 L
.34214 .22687 L
.34236 .2268 L
.34258 .22672 L
.34281 .22665 L
.34303 .22658 L
.34325 .22651 L
.34347 .22644 L
Mistroke
.34369 .22637 L
.34391 .22629 L
.34413 .22622 L
.34435 .22615 L
.34457 .22608 L
.34479 .22601 L
.34501 .22594 L
.34523 .22587 L
.34545 .2258 L
.34567 .22573 L
.34589 .22566 L
.34611 .22559 L
.34633 .22552 L
.34655 .22545 L
.34677 .22538 L
.34698 .22531 L
.3472 .22525 L
.34742 .22518 L
.34764 .22511 L
.34786 .22504 L
.34808 .22497 L
.3483 .2249 L
.34852 .22484 L
.34874 .22477 L
.34895 .2247 L
.34917 .22463 L
.34939 .22457 L
.34961 .2245 L
.34983 .22443 L
.35004 .22437 L
.35026 .2243 L
.35048 .22423 L
.3507 .22417 L
.35092 .2241 L
.35113 .22403 L
.35135 .22397 L
.35157 .2239 L
.35179 .22384 L
.352 .22377 L
.35222 .22371 L
.35244 .22364 L
.35266 .22358 L
.35287 .22351 L
.35309 .22345 L
.35331 .22338 L
.35352 .22332 L
.35374 .22326 L
.35396 .22319 L
.35417 .22313 L
.35439 .22306 L
Mistroke
.35461 .223 L
.35482 .22294 L
.35504 .22288 L
.35525 .22281 L
.35547 .22275 L
.35569 .22269 L
.3559 .22262 L
.35612 .22256 L
.35633 .2225 L
.35655 .22244 L
.35677 .22238 L
.35698 .22231 L
.3572 .22225 L
.35741 .22219 L
.35763 .22213 L
.35784 .22207 L
.35806 .22201 L
.35827 .22195 L
.35849 .22189 L
.3587 .22183 L
.35892 .22177 L
.35913 .22171 L
.35935 .22165 L
.35956 .22159 L
.35978 .22153 L
.35999 .22147 L
.3602 .22141 L
.36042 .22135 L
.36063 .22129 L
.36085 .22123 L
.36106 .22117 L
.36127 .22111 L
.36149 .22105 L
.3617 .221 L
.36192 .22094 L
.36213 .22088 L
.36234 .22082 L
.36256 .22076 L
.36277 .22071 L
.36298 .22065 L
.3632 .22059 L
.36341 .22054 L
.36362 .22048 L
.36383 .22042 L
.36405 .22037 L
.36426 .22031 L
.36447 .22025 L
.36469 .2202 L
.3649 .22014 L
.36511 .22008 L
Mistroke
.36532 .22003 L
.36553 .21997 L
.36575 .21992 L
.36596 .21986 L
.36617 .21981 L
.36638 .21975 L
.36659 .2197 L
.36681 .21964 L
.36702 .21959 L
.36723 .21953 L
.36744 .21948 L
.36765 .21942 L
.36786 .21937 L
.36808 .21932 L
.36829 .21926 L
.3685 .21921 L
.36871 .21916 L
.36892 .2191 L
.36913 .21905 L
.36934 .219 L
.36955 .21894 L
.36976 .21889 L
.36997 .21884 L
.37018 .21879 L
.37039 .21873 L
.3706 .21868 L
.37081 .21863 L
.37102 .21858 L
.37123 .21853 L
.37144 .21848 L
.37165 .21842 L
.37186 .21837 L
.37207 .21832 L
.37228 .21827 L
.37249 .21822 L
.3727 .21817 L
.37291 .21812 L
.37312 .21807 L
.37333 .21802 L
.37354 .21797 L
.37375 .21792 L
.37396 .21787 L
.37417 .21782 L
.37437 .21777 L
.37458 .21772 L
.37479 .21767 L
.375 .21762 L
.37521 .21757 L
.37542 .21752 L
.37563 .21748 L
Mistroke
.37583 .21743 L
.37604 .21738 L
.37625 .21733 L
.37646 .21728 L
.37667 .21723 L
.37687 .21719 L
.37708 .21714 L
.37729 .21709 L
.3775 .21704 L
.3777 .217 L
.37791 .21695 L
.37812 .2169 L
.37833 .21686 L
.37853 .21681 L
.37874 .21676 L
.37895 .21672 L
.37915 .21667 L
.37936 .21662 L
.37957 .21658 L
.37977 .21653 L
.37998 .21649 L
.38019 .21644 L
.38039 .2164 L
.3806 .21635 L
.3808 .21631 L
.38101 .21626 L
.38122 .21622 L
.38142 .21617 L
.38163 .21613 L
.38183 .21608 L
.38204 .21604 L
.38225 .21599 L
.38245 .21595 L
.38266 .21591 L
.38286 .21586 L
.38307 .21582 L
.38327 .21577 L
.38348 .21573 L
.38368 .21569 L
.38389 .21564 L
.38409 .2156 L
.3843 .21556 L
.3845 .21552 L
.38471 .21547 L
.38491 .21543 L
.38511 .21539 L
.38532 .21535 L
.38552 .2153 L
.38573 .21526 L
.38593 .21522 L
Mistroke
.38613 .21518 L
.38634 .21514 L
.38654 .2151 L
.38675 .21506 L
.38695 .21501 L
.38715 .21497 L
.38736 .21493 L
.38756 .21489 L
.38776 .21485 L
.38797 .21481 L
.38817 .21477 L
.38837 .21473 L
.38858 .21469 L
.38878 .21465 L
.38898 .21461 L
.38918 .21457 L
.38939 .21453 L
.38959 .21449 L
.38979 .21445 L
.38999 .21442 L
.3902 .21438 L
.3904 .21434 L
.3906 .2143 L
.3908 .21426 L
.391 .21422 L
.39121 .21418 L
.39141 .21415 L
.39161 .21411 L
.39181 .21407 L
.39201 .21403 L
.39221 .21399 L
.39241 .21396 L
.39262 .21392 L
.39282 .21388 L
.39302 .21385 L
.39322 .21381 L
.39342 .21377 L
.39362 .21374 L
.39382 .2137 L
.39402 .21366 L
.39422 .21363 L
.39442 .21359 L
.39462 .21355 L
.39482 .21352 L
.39502 .21348 L
.39522 .21345 L
.39542 .21341 L
.39562 .21338 L
.39582 .21334 L
.39602 .21331 L
Mistroke
.39622 .21327 L
.39642 .21324 L
.39662 .2132 L
.39682 .21317 L
.39702 .21313 L
.39722 .2131 L
.39742 .21306 L
.39762 .21303 L
.39781 .213 L
.39801 .21296 L
.39821 .21293 L
.39841 .21289 L
.39861 .21286 L
.39881 .21283 L
.39901 .21279 L
.3992 .21276 L
.3994 .21273 L
.3996 .2127 L
.3998 .21266 L
.4 .21263 L
.40019 .2126 L
.40039 .21257 L
.40059 .21253 L
.40079 .2125 L
.40098 .21247 L
.40118 .21244 L
.40138 .21241 L
.40158 .21238 L
.40177 .21234 L
.40197 .21231 L
.40217 .21228 L
.40236 .21225 L
.40256 .21222 L
.40276 .21219 L
.40295 .21216 L
.40315 .21213 L
.40335 .2121 L
.40354 .21207 L
.40374 .21204 L
.40394 .21201 L
.40413 .21198 L
.40433 .21195 L
.40452 .21192 L
.40472 .21189 L
.40492 .21186 L
.40511 .21183 L
.40531 .2118 L
.4055 .21177 L
.4057 .21174 L
.40589 .21171 L
Mistroke
.40609 .21169 L
.40628 .21166 L
.40648 .21163 L
.40667 .2116 L
.40687 .21157 L
.40706 .21154 L
.40726 .21152 L
.40745 .21149 L
.40765 .21146 L
.40784 .21143 L
.40803 .21141 L
.40823 .21138 L
.40842 .21135 L
.40862 .21132 L
.40881 .2113 L
.409 .21127 L
.4092 .21124 L
.40939 .21122 L
.40958 .21119 L
.40978 .21116 L
.40997 .21114 L
.41016 .21111 L
.41036 .21109 L
.41055 .21106 L
.41074 .21103 L
.41094 .21101 L
.41113 .21098 L
.41132 .21096 L
.41151 .21093 L
.41171 .21091 L
.4119 .21088 L
.41209 .21086 L
.41228 .21083 L
.41248 .21081 L
.41267 .21078 L
.41286 .21076 L
.41305 .21074 L
.41324 .21071 L
.41344 .21069 L
.41363 .21066 L
.41382 .21064 L
.41401 .21062 L
.4142 .21059 L
.41439 .21057 L
.41458 .21055 L
.41477 .21052 L
.41497 .2105 L
.41516 .21048 L
.41535 .21045 L
.41554 .21043 L
Mistroke
.41573 .21041 L
.41592 .21039 L
.41611 .21037 L
.4163 .21034 L
.41649 .21032 L
.41668 .2103 L
.41687 .21028 L
.41706 .21026 L
.41725 .21023 L
.41744 .21021 L
.41763 .21019 L
.41782 .21017 L
.41801 .21015 L
.4182 .21013 L
.41839 .21011 L
.41858 .21009 L
.41876 .21007 L
.41895 .21004 L
.41914 .21002 L
.41933 .21 L
.41952 .20998 L
.41971 .20996 L
.4199 .20994 L
.42008 .20992 L
.42027 .2099 L
.42046 .20988 L
.42065 .20987 L
.42084 .20985 L
.42103 .20983 L
.42121 .20981 L
.4214 .20979 L
.42159 .20977 L
.42178 .20975 L
.42196 .20973 L
.42215 .20971 L
.42234 .2097 L
.42253 .20968 L
.42271 .20966 L
.4229 .20964 L
.42309 .20962 L
.42327 .2096 L
.42346 .20959 L
.42365 .20957 L
.42383 .20955 L
.42402 .20953 L
.42421 .20952 L
.42439 .2095 L
.42458 .20948 L
.42476 .20947 L
.42495 .20945 L
Mistroke
.42514 .20943 L
.42532 .20942 L
.42551 .2094 L
.42569 .20938 L
.42588 .20937 L
.42606 .20935 L
.42625 .20934 L
.42643 .20932 L
.42662 .2093 L
.4268 .20929 L
.42699 .20927 L
.42717 .20926 L
.42736 .20924 L
.42754 .20923 L
.42773 .20921 L
.42791 .2092 L
.4281 .20918 L
.42828 .20917 L
.42846 .20915 L
.42865 .20914 L
.42883 .20912 L
.42902 .20911 L
.4292 .20909 L
.42938 .20908 L
.42957 .20907 L
.42975 .20905 L
.42993 .20904 L
.43012 .20903 L
.4303 .20901 L
.43048 .209 L
.43067 .20899 L
.43085 .20897 L
.43103 .20896 L
.43121 .20895 L
.4314 .20893 L
.43158 .20892 L
.43176 .20891 L
.43194 .2089 L
.43213 .20888 L
.43231 .20887 L
.43249 .20886 L
.43267 .20885 L
.43285 .20883 L
.43304 .20882 L
.43322 .20881 L
.4334 .2088 L
.43358 .20879 L
.43376 .20878 L
.43394 .20877 L
.43412 .20875 L
Mistroke
.4343 .20874 L
.43449 .20873 L
.43467 .20872 L
.43485 .20871 L
.43503 .2087 L
.43521 .20869 L
.43539 .20868 L
.43557 .20867 L
.43575 .20866 L
.43593 .20865 L
.43611 .20864 L
.43629 .20863 L
.43647 .20862 L
.43665 .20861 L
.43683 .2086 L
.43701 .20859 L
.43719 .20858 L
.43737 .20857 L
.43754 .20856 L
.43772 .20855 L
.4379 .20855 L
.43808 .20854 L
.43826 .20853 L
.43844 .20852 L
.43862 .20851 L
.4388 .2085 L
.43897 .2085 L
.43915 .20849 L
.43933 .20848 L
.43951 .20847 L
.43969 .20846 L
.43987 .20846 L
.44004 .20845 L
.44022 .20844 L
.4404 .20843 L
.44058 .20843 L
.44075 .20842 L
.44093 .20841 L
.44111 .20841 L
.44128 .2084 L
.44146 .20839 L
.44164 .20839 L
.44182 .20838 L
.44199 .20837 L
.44217 .20837 L
.44235 .20836 L
.44252 .20835 L
.4427 .20835 L
.44287 .20834 L
.44305 .20834 L
Mistroke
.44323 .20833 L
.4434 .20833 L
.44358 .20832 L
.44375 .20832 L
.44393 .20831 L
.4441 .20831 L
.44428 .2083 L
.44446 .2083 L
.44463 .20829 L
.44481 .20829 L
.44498 .20828 L
.44516 .20828 L
.44533 .20827 L
.4455 .20827 L
.44568 .20826 L
.44585 .20826 L
.44603 .20826 L
.4462 .20825 L
.44638 .20825 L
.44655 .20825 L
.44672 .20824 L
.4469 .20824 L
.44707 .20824 L
.44725 .20823 L
.44742 .20823 L
.44759 .20823 L
.44777 .20822 L
.44794 .20822 L
.44811 .20822 L
.44829 .20822 L
.44846 .20821 L
.44863 .20821 L
.4488 .20821 L
.44898 .20821 L
.44915 .20821 L
.44932 .2082 L
.44949 .2082 L
.44967 .2082 L
.44984 .2082 L
.45001 .2082 L
.45018 .2082 L
.45035 .20819 L
.45052 .20819 L
.4507 .20819 L
.45087 .20819 L
.45104 .20819 L
.45121 .20819 L
.45138 .20819 L
.45155 .20819 L
.45172 .20819 L
Mistroke
.45189 .20819 L
.45206 .20819 L
.45224 .20819 L
.45241 .20819 L
.45258 .20819 L
.45275 .20819 L
.45292 .20819 L
.45309 .20819 L
.45326 .20819 L
.45343 .20819 L
.4536 .20819 L
.45377 .20819 L
.45394 .20819 L
.45411 .20819 L
.45427 .2082 L
.45444 .2082 L
.45461 .2082 L
.45478 .2082 L
.45495 .2082 L
.45512 .2082 L
.45529 .2082 L
.45546 .20821 L
.45563 .20821 L
.45579 .20821 L
.45596 .20821 L
.45613 .20821 L
.4563 .20822 L
.45647 .20822 L
.45663 .20822 L
.4568 .20822 L
.45697 .20823 L
.45714 .20823 L
.4573 .20823 L
.45747 .20824 L
.45764 .20824 L
.45781 .20824 L
.45797 .20825 L
.45814 .20825 L
.45831 .20825 L
.45847 .20826 L
.45864 .20826 L
.45881 .20827 L
.45897 .20827 L
.45914 .20827 L
.45931 .20828 L
.45947 .20828 L
.45964 .20829 L
.4598 .20829 L
.45997 .2083 L
.46014 .2083 L
Mistroke
.4603 .20831 L
.46047 .20831 L
.46063 .20832 L
.4608 .20832 L
.46096 .20833 L
.46113 .20833 L
.46129 .20834 L
.46146 .20834 L
.46162 .20835 L
.46179 .20835 L
.46195 .20836 L
.46211 .20837 L
.46228 .20837 L
.46244 .20838 L
.46261 .20838 L
.46277 .20839 L
.46293 .2084 L
.4631 .2084 L
.46326 .20841 L
.46342 .20842 L
.46359 .20842 L
.46375 .20843 L
.46391 .20844 L
.46408 .20844 L
.46424 .20845 L
.4644 .20846 L
.46457 .20847 L
.46473 .20847 L
.46489 .20848 L
.46505 .20849 L
.46522 .2085 L
.46538 .2085 L
.46554 .20851 L
.4657 .20852 L
.46586 .20853 L
.46603 .20854 L
.46619 .20855 L
.46635 .20855 L
.46651 .20856 L
.46667 .20857 L
.46683 .20858 L
.46699 .20859 L
.46715 .2086 L
.46732 .20861 L
.46748 .20862 L
.46764 .20863 L
.4678 .20864 L
.46796 .20865 L
.46812 .20865 L
.46828 .20866 L
Mistroke
.46844 .20867 L
.4686 .20868 L
.46876 .20869 L
.46892 .2087 L
.46908 .20871 L
.46924 .20872 L
.4694 .20874 L
.46955 .20875 L
.46971 .20876 L
.46987 .20877 L
.47003 .20878 L
.47019 .20879 L
.47035 .2088 L
.47051 .20881 L
.47067 .20882 L
.47083 .20883 L
.47098 .20884 L
.47114 .20886 L
.4713 .20887 L
.47146 .20888 L
.47162 .20889 L
.47177 .2089 L
.47193 .20891 L
.47209 .20893 L
.47225 .20894 L
.4724 .20895 L
.47256 .20896 L
.47272 .20898 L
.47287 .20899 L
.47303 .209 L
.47319 .20901 L
.47334 .20903 L
.4735 .20904 L
.47366 .20905 L
.47381 .20907 L
.47397 .20908 L
.47413 .20909 L
.47428 .20911 L
.47444 .20912 L
.47459 .20913 L
.47475 .20915 L
.4749 .20916 L
.47506 .20917 L
.47521 .20919 L
.47537 .2092 L
.47552 .20922 L
.47568 .20923 L
.47583 .20925 L
.47599 .20926 L
.47614 .20927 L
Mistroke
.4763 .20929 L
.47645 .2093 L
.47661 .20932 L
.47676 .20933 L
.47691 .20935 L
.47707 .20936 L
.47722 .20938 L
.47738 .20939 L
.47753 .20941 L
.47768 .20942 L
.47784 .20944 L
.47799 .20946 L
.47814 .20947 L
.47829 .20949 L
.47845 .2095 L
.4786 .20952 L
.47875 .20954 L
.47891 .20955 L
.47906 .20957 L
.47921 .20959 L
.47936 .2096 L
.47951 .20962 L
.47967 .20964 L
.47982 .20965 L
.47997 .20967 L
.48012 .20969 L
.48027 .2097 L
.48042 .20972 L
.48057 .20974 L
.48073 .20975 L
.48088 .20977 L
.48103 .20979 L
.48118 .20981 L
.48133 .20983 L
.48148 .20984 L
.48163 .20986 L
.48178 .20988 L
.48193 .2099 L
.48208 .20992 L
.48223 .20993 L
.48238 .20995 L
.48253 .20997 L
.48268 .20999 L
.48283 .21001 L
.48298 .21003 L
.48313 .21005 L
.48328 .21006 L
.48343 .21008 L
.48357 .2101 L
.48372 .21012 L
Mistroke
.48387 .21014 L
.48402 .21016 L
.48417 .21018 L
.48432 .2102 L
.48447 .21022 L
.48461 .21024 L
.48476 .21026 L
.48491 .21028 L
.48506 .2103 L
.4852 .21032 L
.48535 .21034 L
.4855 .21036 L
.48565 .21038 L
.48579 .2104 L
.48594 .21042 L
.48609 .21044 L
.48623 .21046 L
.48638 .21049 L
.48653 .21051 L
.48667 .21053 L
.48682 .21055 L
.48697 .21057 L
.48711 .21059 L
.48726 .21061 L
.4874 .21063 L
.48755 .21066 L
.4877 .21068 L
.48784 .2107 L
.48799 .21072 L
.48813 .21074 L
.48828 .21077 L
.48842 .21079 L
.48857 .21081 L
.48871 .21083 L
.48886 .21085 L
.489 .21088 L
.48914 .2109 L
.48929 .21092 L
.48943 .21095 L
.48958 .21097 L
.48972 .21099 L
.48986 .21101 L
.49001 .21104 L
.49015 .21106 L
.4903 .21108 L
.49044 .21111 L
.49058 .21113 L
.49072 .21116 L
.49087 .21118 L
.49101 .2112 L
Mistroke
.49115 .21123 L
.4913 .21125 L
.49144 .21128 L
.49158 .2113 L
.49172 .21132 L
.49186 .21135 L
.49201 .21137 L
.49215 .2114 L
.49229 .21142 L
.49243 .21145 L
.49257 .21147 L
.49272 .2115 L
.49286 .21152 L
.493 .21155 L
.49314 .21157 L
.49328 .2116 L
.49342 .21162 L
.49356 .21165 L
.4937 .21167 L
.49384 .2117 L
.49398 .21172 L
.49412 .21175 L
.49426 .21178 L
.4944 .2118 L
.49454 .21183 L
.49468 .21185 L
.49482 .21188 L
.49496 .21191 L
.4951 .21193 L
.49524 .21196 L
.49538 .21199 L
.49552 .21201 L
.49566 .21204 L
.49579 .21207 L
.49593 .21209 L
.49607 .21212 L
.49621 .21215 L
.49635 .21218 L
.49649 .2122 L
.49662 .21223 L
.49676 .21226 L
.4969 .21229 L
.49704 .21231 L
.49717 .21234 L
.49731 .21237 L
.49745 .2124 L
.49759 .21243 L
.49772 .21245 L
.49786 .21248 L
.498 .21251 L
Mistroke
.49813 .21254 L
.49827 .21257 L
.49841 .2126 L
.49854 .21262 L
.49868 .21265 L
.49881 .21268 L
.49895 .21271 L
.49909 .21274 L
.49922 .21277 L
.49936 .2128 L
.49949 .21283 L
.49963 .21286 L
.49976 .21289 L
.4999 .21292 L
.50003 .21295 L
.50017 .21298 L
.5003 .21301 L
.50044 .21303 L
.50057 .21306 L
.50071 .21309 L
.50084 .21313 L
.50097 .21316 L
.50111 .21319 L
.50124 .21322 L
.50137 .21325 L
.50151 .21328 L
.50164 .21331 L
.50177 .21334 L
.50191 .21337 L
.50204 .2134 L
.50217 .21343 L
.50231 .21346 L
.50244 .21349 L
.50257 .21353 L
.5027 .21356 L
.50284 .21359 L
.50297 .21362 L
.5031 .21365 L
.50323 .21368 L
.50336 .21371 L
.5035 .21375 L
.50363 .21378 L
.50376 .21381 L
.50389 .21384 L
.50402 .21388 L
.50415 .21391 L
.50428 .21394 L
.50441 .21397 L
.50454 .214 L
.50467 .21404 L
Mistroke
.5048 .21407 L
.50494 .2141 L
.50507 .21414 L
.5052 .21417 L
.50532 .2142 L
.50545 .21424 L
.50558 .21427 L
.50571 .2143 L
.50584 .21434 L
.50597 .21437 L
.5061 .2144 L
.50623 .21444 L
.50636 .21447 L
.50649 .2145 L
.50662 .21454 L
.50674 .21457 L
.50687 .21461 L
.507 .21464 L
.50713 .21467 L
.50726 .21471 L
.50739 .21474 L
.50751 .21478 L
.50764 .21481 L
.50777 .21485 L
.5079 .21488 L
.50802 .21492 L
.50815 .21495 L
.50828 .21499 L
.5084 .21502 L
.50853 .21506 L
.50866 .21509 L
.50878 .21513 L
.50891 .21516 L
.50904 .2152 L
.50916 .21524 L
.50929 .21527 L
.50941 .21531 L
.50954 .21534 L
.50966 .21538 L
.50979 .21541 L
.50991 .21545 L
.51004 .21549 L
.51016 .21552 L
.51029 .21556 L
.51041 .2156 L
.51054 .21563 L
.51066 .21567 L
.51079 .21571 L
.51091 .21574 L
.51104 .21578 L
Mistroke
.51116 .21582 L
.51128 .21585 L
.51141 .21589 L
.51153 .21593 L
.51165 .21597 L
.51178 .216 L
.5119 .21604 L
.51202 .21608 L
.51215 .21612 L
.51227 .21615 L
.51239 .21619 L
.51251 .21623 L
.51264 .21627 L
.51276 .21631 L
.51288 .21634 L
.513 .21638 L
.51313 .21642 L
.51325 .21646 L
.51337 .2165 L
.51349 .21654 L
.51361 .21657 L
.51373 .21661 L
.51385 .21665 L
.51397 .21669 L
.5141 .21673 L
.51422 .21677 L
.51434 .21681 L
.51446 .21685 L
.51458 .21689 L
.5147 .21693 L
.51482 .21697 L
.51494 .21701 L
.51506 .21705 L
.51518 .21708 L
.5153 .21712 L
.51542 .21716 L
.51554 .2172 L
.51565 .21724 L
.51577 .21728 L
.51589 .21733 L
.51601 .21737 L
.51613 .21741 L
.51625 .21745 L
.51637 .21749 L
.51648 .21753 L
.5166 .21757 L
.51672 .21761 L
.51684 .21765 L
.51696 .21769 L
.51707 .21773 L
Mistroke
.51719 .21777 L
.51731 .21781 L
.51743 .21786 L
.51754 .2179 L
.51766 .21794 L
.51778 .21798 L
.51789 .21802 L
.51801 .21806 L
.51813 .2181 L
.51824 .21815 L
.51836 .21819 L
.51847 .21823 L
.51859 .21827 L
.51871 .21832 L
.51882 .21836 L
.51894 .2184 L
.51905 .21844 L
.51917 .21848 L
.51928 .21853 L
.5194 .21857 L
.51951 .21861 L
.51963 .21866 L
.51974 .2187 L
.51985 .21874 L
.51997 .21878 L
.52008 .21883 L
.5202 .21887 L
.52031 .21891 L
.52042 .21896 L
.52054 .219 L
.52065 .21904 L
.52076 .21909 L
.52088 .21913 L
.52099 .21918 L
.5211 .21922 L
.52122 .21926 L
.52133 .21931 L
.52144 .21935 L
.52155 .2194 L
.52167 .21944 L
.52178 .21948 L
.52189 .21953 L
.522 .21957 L
.52211 .21962 L
.52223 .21966 L
.52234 .21971 L
.52245 .21975 L
.52256 .2198 L
.52267 .21984 L
.52278 .21989 L
Mistroke
.52289 .21993 L
.523 .21998 L
.52311 .22002 L
.52322 .22007 L
.52333 .22011 L
.52344 .22016 L
.52355 .22021 L
.52366 .22025 L
.52377 .2203 L
.52388 .22034 L
.52399 .22039 L
.5241 .22043 L
.52421 .22048 L
.52432 .22053 L
.52443 .22057 L
.52454 .22062 L
.52465 .22067 L
.52475 .22071 L
.52486 .22076 L
.52497 .22081 L
.52508 .22085 L
.52519 .2209 L
.52529 .22095 L
.5254 .22099 L
.52551 .22104 L
.52562 .22109 L
.52572 .22113 L
.52583 .22118 L
.52594 .22123 L
.52604 .22128 L
.52615 .22132 L
.52626 .22137 L
.52636 .22142 L
.52647 .22147 L
.52658 .22151 L
.52668 .22156 L
.52679 .22161 L
.52689 .22166 L
.527 .22171 L
.5271 .22175 L
.52721 .2218 L
.52732 .22185 L
.52742 .2219 L
.52753 .22195 L
.52763 .222 L
.52773 .22205 L
.52784 .22209 L
.52794 .22214 L
.52805 .22219 L
.52815 .22224 L
Mistroke
.52826 .22229 L
.52836 .22234 L
.52846 .22239 L
.52857 .22244 L
.52867 .22249 L
.52877 .22254 L
.52888 .22259 L
.52898 .22264 L
.52908 .22269 L
.52918 .22274 L
.52929 .22278 L
.52939 .22283 L
.52949 .22288 L
.52959 .22293 L
.5297 .22298 L
.5298 .22304 L
.5299 .22309 L
.53 .22314 L
.5301 .22319 L
.5302 .22324 L
.53031 .22329 L
.53041 .22334 L
.53051 .22339 L
.53061 .22344 L
.53071 .22349 L
.53081 .22354 L
.53091 .22359 L
.53101 .22364 L
.53111 .22369 L
.53121 .22375 L
.53131 .2238 L
.53141 .22385 L
.53151 .2239 L
.53161 .22395 L
.53171 .224 L
.53181 .22406 L
.53191 .22411 L
.532 .22416 L
.5321 .22421 L
.5322 .22426 L
.5323 .22431 L
.5324 .22437 L
.5325 .22442 L
.53259 .22447 L
.53269 .22452 L
.53279 .22458 L
.53289 .22463 L
.53298 .22468 L
.53308 .22473 L
.53318 .22479 L
Mistroke
.53328 .22484 L
.53337 .22489 L
.53347 .22495 L
.53357 .225 L
.53366 .22505 L
.53376 .22511 L
.53385 .22516 L
.53395 .22521 L
.53405 .22527 L
.53414 .22532 L
.53424 .22537 L
.53433 .22543 L
.53443 .22548 L
.53452 .22553 L
.53462 .22559 L
.53471 .22564 L
.53481 .2257 L
.5349 .22575 L
.535 .2258 L
.53509 .22586 L
.53519 .22591 L
.53528 .22597 L
.53537 .22602 L
.53547 .22608 L
.53556 .22613 L
.53566 .22619 L
.53575 .22624 L
.53584 .22629 L
.53594 .22635 L
.53603 .2264 L
.53612 .22646 L
.53621 .22651 L
.53631 .22657 L
.5364 .22663 L
.53649 .22668 L
.53658 .22674 L
.53667 .22679 L
.53677 .22685 L
.53686 .2269 L
.53695 .22696 L
.53704 .22701 L
.53713 .22707 L
.53722 .22713 L
.53731 .22718 L
.53741 .22724 L
.5375 .22729 L
.53759 .22735 L
.53768 .22741 L
.53777 .22746 L
.53786 .22752 L
Mistroke
.53795 .22758 L
.53804 .22763 L
.53813 .22769 L
.53822 .22775 L
.53831 .2278 L
.5384 .22786 L
.53848 .22792 L
.53857 .22797 L
.53866 .22803 L
.53875 .22809 L
.53884 .22815 L
.53893 .2282 L
.53902 .22826 L
.5391 .22832 L
.53919 .22838 L
.53928 .22843 L
.53937 .22849 L
.53946 .22855 L
.53954 .22861 L
.53963 .22866 L
.53972 .22872 L
.5398 .22878 L
.53989 .22884 L
.53998 .2289 L
.54006 .22895 L
.54015 .22901 L
.54024 .22907 L
.54032 .22913 L
.54041 .22919 L
.5405 .22925 L
.54058 .22931 L
.54067 .22936 L
.54075 .22942 L
.54084 .22948 L
.54092 .22954 L
.54101 .2296 L
.54109 .22966 L
.54118 .22972 L
.54126 .22978 L
.54135 .22984 L
.54143 .2299 L
.54151 .22995 L
.5416 .23001 L
.54168 .23007 L
.54177 .23013 L
.54185 .23019 L
.54193 .23025 L
.54202 .23031 L
.5421 .23037 L
.54218 .23043 L
Mistroke
.54227 .23049 L
.54235 .23055 L
.54243 .23061 L
.54251 .23067 L
.5426 .23073 L
.54268 .23079 L
.54276 .23085 L
.54284 .23092 L
.54292 .23098 L
.543 .23104 L
.54309 .2311 L
.54317 .23116 L
.54325 .23122 L
.54333 .23128 L
.54341 .23134 L
.54349 .2314 L
.54357 .23146 L
.54365 .23152 L
.54373 .23159 L
.54381 .23165 L
.54389 .23171 L
.54397 .23177 L
.54405 .23183 L
.54413 .23189 L
.54421 .23195 L
.54429 .23202 L
.54437 .23208 L
.54445 .23214 L
.54453 .2322 L
.54461 .23226 L
.54468 .23233 L
.54476 .23239 L
.54484 .23245 L
.54492 .23251 L
.545 .23258 L
.54507 .23264 L
.54515 .2327 L
.54523 .23276 L
.54531 .23283 L
.54538 .23289 L
.54546 .23295 L
.54554 .23301 L
.54562 .23308 L
.54569 .23314 L
.54577 .2332 L
.54585 .23327 L
.54592 .23333 L
.546 .23339 L
.54607 .23346 L
.54615 .23352 L
Mistroke
.54622 .23358 L
.5463 .23365 L
.54638 .23371 L
.54645 .23377 L
.54653 .23384 L
.5466 .2339 L
.54668 .23397 L
.54675 .23403 L
.54683 .23409 L
.5469 .23416 L
.54697 .23422 L
.54705 .23429 L
.54712 .23435 L
.5472 .23441 L
.54727 .23448 L
.54734 .23454 L
.54742 .23461 L
.54749 .23467 L
.54756 .23474 L
.54764 .2348 L
.54771 .23487 L
.54778 .23493 L
.54785 .235 L
.54793 .23506 L
.548 .23513 L
.54807 .23519 L
.54814 .23526 L
.54821 .23532 L
.54828 .23539 L
.54836 .23545 L
.54843 .23552 L
.5485 .23558 L
.54857 .23565 L
.54864 .23571 L
.54871 .23578 L
.54878 .23585 L
.54885 .23591 L
.54892 .23598 L
.54899 .23604 L
.54906 .23611 L
.54913 .23618 L
.5492 .23624 L
.54927 .23631 L
.54934 .23637 L
.54941 .23644 L
.54948 .23651 L
.54955 .23657 L
.54962 .23664 L
.54969 .23671 L
.54975 .23677 L
Mistroke
.54982 .23684 L
.54989 .23691 L
.54996 .23697 L
.55003 .23704 L
.5501 .23711 L
.55016 .23718 L
.55023 .23724 L
.5503 .23731 L
.55037 .23738 L
.55043 .23744 L
.5505 .23751 L
.55057 .23758 L
.55063 .23765 L
.5507 .23771 L
.55077 .23778 L
.55083 .23785 L
.5509 .23792 L
.55096 .23798 L
.55103 .23805 L
.5511 .23812 L
.55116 .23819 L
.55123 .23826 L
.55129 .23832 L
.55136 .23839 L
.55142 .23846 L
.55149 .23853 L
.55155 .2386 L
.55162 .23867 L
.55168 .23873 L
.55174 .2388 L
.55181 .23887 L
.55187 .23894 L
.55194 .23901 L
.552 .23908 L
.55206 .23915 L
.55213 .23922 L
.55219 .23928 L
.55225 .23935 L
.55231 .23942 L
.55238 .23949 L
.55244 .23956 L
.5525 .23963 L
.55256 .2397 L
.55263 .23977 L
.55269 .23984 L
.55275 .23991 L
.55281 .23998 L
.55287 .24005 L
.55294 .24012 L
.553 .24019 L
Mistroke
.55306 .24026 L
.55312 .24033 L
.55318 .2404 L
.55324 .24047 L
.5533 .24054 L
.55336 .24061 L
.55342 .24068 L
.55348 .24075 L
.55354 .24082 L
.5536 .24089 L
.55366 .24096 L
.55372 .24103 L
.55378 .2411 L
.55384 .24117 L
.5539 .24124 L
.55396 .24131 L
.55402 .24138 L
.55407 .24145 L
.55413 .24153 L
.55419 .2416 L
.55425 .24167 L
.55431 .24174 L
.55436 .24181 L
.55442 .24188 L
.55448 .24195 L
.55454 .24202 L
.55459 .24209 L
.55465 .24217 L
.55471 .24224 L
.55477 .24231 L
.55482 .24238 L
.55488 .24245 L
.55494 .24252 L
.55499 .2426 L
.55505 .24267 L
.5551 .24274 L
.55516 .24281 L
.55522 .24288 L
.55527 .24296 L
.55533 .24303 L
.55538 .2431 L
.55544 .24317 L
.55549 .24325 L
.55555 .24332 L
.5556 .24339 L
.55566 .24346 L
.55571 .24354 L
.55576 .24361 L
.55582 .24368 L
.55587 .24375 L
Mistroke
.55593 .24383 L
.55598 .2439 L
.55603 .24397 L
.55609 .24405 L
.55614 .24412 L
.55619 .24419 L
.55625 .24426 L
.5563 .24434 L
.55635 .24441 L
.5564 .24448 L
.55646 .24456 L
.55651 .24463 L
.55656 .2447 L
.55661 .24478 L
.55666 .24485 L
.55671 .24493 L
.55677 .245 L
.55682 .24507 L
.55687 .24515 L
.55692 .24522 L
.55697 .24529 L
.55702 .24537 L
.55707 .24544 L
.55712 .24552 L
.55717 .24559 L
.55722 .24567 L
.55727 .24574 L
.55732 .24581 L
.55737 .24589 L
.55742 .24596 L
.55747 .24604 L
.55752 .24611 L
.55757 .24619 L
.55762 .24626 L
.55767 .24634 L
.55772 .24641 L
.55776 .24649 L
.55781 .24656 L
.55786 .24664 L
.55791 .24671 L
.55796 .24679 L
.558 .24686 L
.55805 .24694 L
.5581 .24701 L
.55815 .24709 L
.55819 .24716 L
.55824 .24724 L
.55829 .24731 L
.55833 .24739 L
.55838 .24746 L
Mistroke
.55843 .24754 L
.55847 .24762 L
.55852 .24769 L
.55857 .24777 L
.55861 .24784 L
.55866 .24792 L
.5587 .24799 L
.55875 .24807 L
.55879 .24815 L
.55884 .24822 L
.55888 .2483 L
.55893 .24838 L
.55897 .24845 L
.55902 .24853 L
.55906 .2486 L
.55911 .24868 L
.55915 .24876 L
.55919 .24883 L
.55924 .24891 L
.55928 .24899 L
.55933 .24906 L
.55937 .24914 L
.55941 .24922 L
.55945 .24929 L
.5595 .24937 L
.55954 .24945 L
.55958 .24952 L
.55963 .2496 L
.55967 .24968 L
.55971 .24976 L
.55975 .24983 L
.55979 .24991 L
.55984 .24999 L
.55988 .25007 L
.55992 .25014 L
.55996 .25022 L
.56 .2503 L
.56004 .25038 L
.56008 .25045 L
.56012 .25053 L
.56016 .25061 L
.5602 .25069 L
.56025 .25076 L
.56029 .25084 L
.56033 .25092 L
.56037 .251 L
.5604 .25108 L
.56044 .25115 L
.56048 .25123 L
.56052 .25131 L
Mistroke
.56056 .25139 L
.5606 .25147 L
.56064 .25154 L
.56068 .25162 L
.56072 .2517 L
.56076 .25178 L
.56079 .25186 L
.56083 .25194 L
.56087 .25202 L
.56091 .25209 L
.56095 .25217 L
.56098 .25225 L
.56102 .25233 L
.56106 .25241 L
.56109 .25249 L
.56113 .25257 L
.56117 .25265 L
.5612 .25273 L
.56124 .25281 L
.56128 .25288 L
.56131 .25296 L
.56135 .25304 L
.56139 .25312 L
.56142 .2532 L
.56146 .25328 L
.56149 .25336 L
.56153 .25344 L
.56156 .25352 L
.5616 .2536 L
.56163 .25368 L
.56167 .25376 L
.5617 .25384 L
.56174 .25392 L
.56177 .254 L
.56181 .25408 L
.56184 .25416 L
.56187 .25424 L
.56191 .25432 L
.56194 .2544 L
.56197 .25448 L
.56201 .25456 L
.56204 .25464 L
.56207 .25472 L
.56211 .2548 L
.56214 .25488 L
.56217 .25496 L
.5622 .25504 L
.56224 .25512 L
.56227 .2552 L
.5623 .25528 L
Mistroke
.56233 .25536 L
.56236 .25544 L
.5624 .25552 L
.56243 .25561 L
.56246 .25569 L
.56249 .25577 L
.56252 .25585 L
.56255 .25593 L
.56258 .25601 L
.56261 .25609 L
.56264 .25617 L
.56267 .25625 L
.5627 .25633 L
.56273 .25642 L
.56276 .2565 L
.56279 .25658 L
.56282 .25666 L
.56285 .25674 L
.56288 .25682 L
.56291 .2569 L
.56294 .25699 L
.56297 .25707 L
.563 .25715 L
.56302 .25723 L
.56305 .25731 L
.56308 .25739 L
.56311 .25748 L
.56314 .25756 L
.56316 .25764 L
.56319 .25772 L
.56322 .2578 L
.56325 .25789 L
.56327 .25797 L
.5633 .25805 L
.56333 .25813 L
.56335 .25822 L
.56338 .2583 L
.56341 .25838 L
.56343 .25846 L
.56346 .25854 L
.56349 .25863 L
.56351 .25871 L
.56354 .25879 L
.56356 .25887 L
.56359 .25896 L
.56361 .25904 L
.56364 .25912 L
.56366 .25921 L
.56369 .25929 L
.56371 .25937 L
Mistroke
.56374 .25945 L
.56376 .25954 L
.56379 .25962 L
.56381 .2597 L
.56384 .25979 L
.56386 .25987 L
.56388 .25995 L
.56391 .26004 L
.56393 .26012 L
.56395 .2602 L
.56398 .26029 L
.564 .26037 L
.56402 .26045 L
.56405 .26054 L
.56407 .26062 L
.56409 .2607 L
.56411 .26079 L
.56413 .26087 L
.56416 .26095 L
.56418 .26104 L
.5642 .26112 L
.56422 .26121 L
.56424 .26129 L
.56426 .26137 L
.56429 .26146 L
.56431 .26154 L
.56433 .26162 L
.56435 .26171 L
.56437 .26179 L
.56439 .26188 L
.56441 .26196 L
.56443 .26205 L
.56445 .26213 L
.56447 .26221 L
.56449 .2623 L
.56451 .26238 L
.56453 .26247 L
.56455 .26255 L
.56457 .26264 L
.56459 .26272 L
.5646 .2628 L
.56462 .26289 L
.56464 .26297 L
.56466 .26306 L
.56468 .26314 L
.5647 .26323 L
.56471 .26331 L
.56473 .2634 L
.56475 .26348 L
.56477 .26357 L
Mistroke
.56479 .26365 L
.5648 .26374 L
.56482 .26382 L
.56484 .26391 L
.56485 .26399 L
.56487 .26408 L
.56489 .26416 L
.5649 .26425 L
.56492 .26433 L
.56494 .26442 L
.56495 .2645 L
.56497 .26459 L
.56498 .26467 L
.565 .26476 L
.56501 .26485 L
.56503 .26493 L
.56505 .26502 L
.56506 .2651 L
.56508 .26519 L
.56509 .26527 L
.5651 .26536 L
.56512 .26544 L
.56513 .26553 L
.56515 .26562 L
.56516 .2657 L
.56518 .26579 L
.56519 .26587 L
.5652 .26596 L
.56522 .26605 L
.56523 .26613 L
.56524 .26622 L
.56526 .2663 L
.56527 .26639 L
.56528 .26648 L
.56529 .26656 L
.56531 .26665 L
.56532 .26673 L
.56533 .26682 L
.56534 .26691 L
.56536 .26699 L
.56537 .26708 L
.56538 .26717 L
.56539 .26725 L
.5654 .26734 L
.56541 .26743 L
.56542 .26751 L
.56544 .2676 L
.56545 .26769 L
.56546 .26777 L
.56547 .26786 L
Mistroke
.56548 .26795 L
.56549 .26803 L
.5655 .26812 L
.56551 .26821 L
.56552 .26829 L
.56553 .26838 L
.56554 .26847 L
.56555 .26855 L
.56556 .26864 L
.56557 .26873 L
.56557 .26881 L
.56558 .2689 L
.56559 .26899 L
.5656 .26908 L
.56561 .26916 L
.56562 .26925 L
.56563 .26934 L
.56563 .26943 L
.56564 .26951 L
.56565 .2696 L
.56566 .26969 L
.56566 .26977 L
.56567 .26986 L
.56568 .26995 L
.56569 .27004 L
.56569 .27012 L
.5657 .27021 L
.56571 .2703 L
.56571 .27039 L
.56572 .27048 L
.56573 .27056 L
.56573 .27065 L
.56574 .27074 L
.56574 .27083 L
.56575 .27091 L
.56575 .271 L
.56576 .27109 L
.56576 .27118 L
.56577 .27127 L
.56578 .27135 L
.56578 .27144 L
.56578 .27153 L
.56579 .27162 L
.56579 .27171 L
.5658 .27179 L
.5658 .27188 L
.56581 .27197 L
.56581 .27206 L
.56581 .27215 L
.56582 .27224 L
Mistroke
.56582 .27232 L
.56582 .27241 L
.56583 .2725 L
.56583 .27259 L
.56583 .27268 L
.56584 .27277 L
.56584 .27285 L
.56584 .27294 L
.56584 .27303 L
.56585 .27312 L
.56585 .27321 L
.56585 .2733 L
.56585 .27339 L
.56585 .27347 L
.56586 .27356 L
.56586 .27365 L
.56586 .27374 L
.56586 .27383 L
.56586 .27392 L
.56586 .27401 L
.56586 .2741 L
.56586 .27418 L
.56586 .27427 L
.56586 .27436 L
.56586 .27445 L
.56586 .27454 L
.56586 .27463 L
.56586 .27472 L
.56586 .27481 L
.56586 .2749 L
.56586 .27499 L
.56586 .27508 L
.56586 .27516 L
.56586 .27525 L
.56586 .27534 L
.56586 .27543 L
.56586 .27552 L
.56585 .27561 L
.56585 .2757 L
.56585 .27579 L
.56585 .27588 L
.56585 .27597 L
.56584 .27606 L
.56584 .27615 L
.56584 .27624 L
.56584 .27633 L
.56583 .27642 L
.56583 .27651 L
.56583 .2766 L
.56583 .27668 L
Mistroke
.56582 .27677 L
.56582 .27686 L
.56582 .27695 L
.56581 .27704 L
.56581 .27713 L
.5658 .27722 L
.5658 .27731 L
.5658 .2774 L
.56579 .27749 L
.56579 .27758 L
.56578 .27767 L
.56578 .27776 L
.56577 .27785 L
.56577 .27794 L
.56576 .27803 L
.56576 .27812 L
.56575 .27821 L
.56575 .2783 L
.56574 .27839 L
.56574 .27848 L
.56573 .27857 L
.56572 .27866 L
.56572 .27875 L
.56571 .27884 L
.5657 .27893 L
.5657 .27902 L
.56569 .27911 L
.56568 .2792 L
.56568 .27929 L
.56567 .27938 L
.56566 .27947 L
.56566 .27956 L
.56565 .27966 L
.56564 .27975 L
.56563 .27984 L
.56562 .27993 L
.56562 .28002 L
.56561 .28011 L
.5656 .2802 L
.56559 .28029 L
.56558 .28038 L
.56557 .28047 L
.56557 .28056 L
.56556 .28065 L
.56555 .28074 L
.56554 .28083 L
.56553 .28092 L
.56552 .28101 L
.56551 .2811 L
.5655 .28119 L
Mistroke
.56549 .28129 L
.56548 .28138 L
.56547 .28147 L
.56546 .28156 L
.56545 .28165 L
.56544 .28174 L
.56543 .28183 L
.56542 .28192 L
.56541 .28201 L
.5654 .2821 L
.56538 .28219 L
.56537 .28228 L
.56536 .28238 L
.56535 .28247 L
.56534 .28256 L
.56533 .28265 L
.56532 .28274 L
.5653 .28283 L
.56529 .28292 L
.56528 .28301 L
.56527 .2831 L
.56525 .2832 L
.56524 .28329 L
.56523 .28338 L
.56522 .28347 L
.5652 .28356 L
.56519 .28365 L
.56518 .28374 L
.56516 .28383 L
.56515 .28392 L
.56513 .28402 L
.56512 .28411 L
.56511 .2842 L
.56509 .28429 L
.56508 .28438 L
.56506 .28447 L
.56505 .28456 L
.56504 .28466 L
.56502 .28475 L
.56501 .28484 L
.56499 .28493 L
.56498 .28502 L
.56496 .28511 L
.56495 .2852 L
.56493 .2853 L
.56491 .28539 L
.5649 .28548 L
.56488 .28557 L
.56487 .28566 L
.56485 .28575 L
Mistroke
.56483 .28584 L
.56482 .28594 L
.5648 .28603 L
.56478 .28612 L
.56477 .28621 L
.56475 .2863 L
.56473 .28639 L
.56472 .28649 L
.5647 .28658 L
.56468 .28667 L
.56466 .28676 L
.56465 .28685 L
.56463 .28694 L
.56461 .28704 L
.56459 .28713 L
.56458 .28722 L
.56456 .28731 L
.56454 .2874 L
.56452 .28749 L
.5645 .28759 L
.56448 .28768 L
.56446 .28777 L
.56445 .28786 L
.56443 .28795 L
.56441 .28805 L
.56439 .28814 L
.56437 .28823 L
.56435 .28832 L
.56433 .28841 L
.56431 .28851 L
.56429 .2886 L
.56427 .28869 L
.56425 .28878 L
.56423 .28887 L
.56421 .28896 L
.56419 .28906 L
.56417 .28915 L
.56415 .28924 L
.56413 .28933 L
.5641 .28942 L
.56408 .28952 L
.56406 .28961 L
.56404 .2897 L
.56402 .28979 L
.564 .28989 L
.56398 .28998 L
.56395 .29007 L
.56393 .29016 L
.56391 .29025 L
.56389 .29035 L
Mistroke
.56386 .29044 L
.56384 .29053 L
.56382 .29062 L
.5638 .29071 L
.56377 .29081 L
.56375 .2909 L
.56373 .29099 L
.5637 .29108 L
.56368 .29118 L
.56366 .29127 L
.56363 .29136 L
.56361 .29145 L
.56359 .29154 L
.56356 .29164 L
.56354 .29173 L
.56351 .29182 L
.56349 .29191 L
.56347 .29201 L
.56344 .2921 L
.56342 .29219 L
.56339 .29228 L
.56337 .29237 L
.56334 .29247 L
.56332 .29256 L
.56329 .29265 L
.56327 .29274 L
.56324 .29284 L
.56321 .29293 L
.56319 .29302 L
.56316 .29311 L
.56314 .29321 L
.56311 .2933 L
.56308 .29339 L
.56306 .29348 L
.56303 .29357 L
.56301 .29367 L
.56298 .29376 L
.56295 .29385 L
.56293 .29394 L
.5629 .29404 L
.56287 .29413 L
.56284 .29422 L
.56282 .29431 L
.56279 .29441 L
.56276 .2945 L
.56273 .29459 L
.56271 .29468 L
.56268 .29478 L
.56265 .29487 L
.56262 .29496 L
Mistroke
.56259 .29505 L
.56256 .29515 L
.56254 .29524 L
.56251 .29533 L
.56248 .29542 L
.56245 .29551 L
.56242 .29561 L
.56239 .2957 L
.56236 .29579 L
.56233 .29588 L
.5623 .29598 L
.56227 .29607 L
.56224 .29616 L
.56221 .29625 L
.56218 .29635 L
.56215 .29644 L
.56212 .29653 L
.56209 .29662 L
.56206 .29672 L
.56203 .29681 L
.562 .2969 L
.56197 .29699 L
.56194 .29709 L
.56191 .29718 L
.56188 .29727 L
.56185 .29736 L
.56182 .29746 L
.56179 .29755 L
.56175 .29764 L
.56172 .29773 L
.56169 .29783 L
.56166 .29792 L
.56163 .29801 L
.56159 .2981 L
.56156 .2982 L
.56153 .29829 L
.5615 .29838 L
.56147 .29847 L
.56143 .29857 L
.5614 .29866 L
.56137 .29875 L
.56133 .29884 L
.5613 .29894 L
.56127 .29903 L
.56123 .29912 L
.5612 .29921 L
.56117 .29931 L
.56113 .2994 L
.5611 .29949 L
.56107 .29958 L
Mistroke
.56103 .29968 L
.561 .29977 L
.56096 .29986 L
.56093 .29995 L
.5609 .30005 L
.56086 .30014 L
.56083 .30023 L
.56079 .30032 L
.56076 .30041 L
.56072 .30051 L
.56069 .3006 L
.56065 .30069 L
.56062 .30078 L
.56058 .30088 L
.56055 .30097 L
.56051 .30106 L
.56047 .30115 L
.56044 .30125 L
.5604 .30134 L
.56037 .30143 L
.56033 .30152 L
.56029 .30162 L
.56026 .30171 L
.56022 .3018 L
.56019 .30189 L
.56015 .30199 L
.56011 .30208 L
.56008 .30217 L
.56004 .30226 L
.56 .30235 L
.55996 .30245 L
.55993 .30254 L
.55989 .30263 L
.55985 .30272 L
.55981 .30282 L
.55978 .30291 L
.55974 .303 L
.5597 .30309 L
.55966 .30319 L
.55962 .30328 L
.55959 .30337 L
.55955 .30346 L
.55951 .30355 L
.55947 .30365 L
.55943 .30374 L
.55939 .30383 L
.55935 .30392 L
.55932 .30402 L
.55928 .30411 L
.55924 .3042 L
Mistroke
.5592 .30429 L
.55916 .30438 L
.55912 .30448 L
.55908 .30457 L
.55904 .30466 L
.559 .30475 L
.55896 .30485 L
.55892 .30494 L
.55888 .30503 L
.55884 .30512 L
.5588 .30521 L
.55876 .30531 L
.55872 .3054 L
.55868 .30549 L
.55864 .30558 L
.5586 .30567 L
.55855 .30577 L
.55851 .30586 L
.55847 .30595 L
.55843 .30604 L
.55839 .30613 L
.55835 .30623 L
.55831 .30632 L
.55827 .30641 L
.55822 .3065 L
.55818 .30659 L
.55814 .30669 L
.5581 .30678 L
.55806 .30687 L
.55801 .30696 L
.55797 .30705 L
.55793 .30715 L
.55789 .30724 L
.55784 .30733 L
.5578 .30742 L
.55776 .30751 L
.55771 .3076 L
.55767 .3077 L
.55763 .30779 L
.55758 .30788 L
.55754 .30797 L
.5575 .30806 L
.55745 .30816 L
.55741 .30825 L
.55737 .30834 L
.55732 .30843 L
.55728 .30852 L
.55723 .30861 L
.55719 .30871 L
.55715 .3088 L
Mistroke
.5571 .30889 L
.55706 .30898 L
.55701 .30907 L
.55697 .30916 L
.55692 .30926 L
.55688 .30935 L
.55683 .30944 L
.55679 .30953 L
.55674 .30962 L
.5567 .30971 L
.55665 .3098 L
.55661 .3099 L
.55656 .30999 L
.55652 .31008 L
.55647 .31017 L
.55642 .31026 L
.55638 .31035 L
.55633 .31045 L
.55629 .31054 L
.55624 .31063 L
.55619 .31072 L
.55615 .31081 L
.5561 .3109 L
.55605 .31099 L
.55601 .31108 L
.55596 .31118 L
.55591 .31127 L
.55587 .31136 L
.55582 .31145 L
.55577 .31154 L
.55573 .31163 L
.55568 .31172 L
.55563 .31181 L
.55558 .31191 L
.55554 .312 L
.55549 .31209 L
.55544 .31218 L
.55539 .31227 L
.55534 .31236 L
.5553 .31245 L
.55525 .31254 L
.5552 .31263 L
.55515 .31273 L
.5551 .31282 L
.55505 .31291 L
.55501 .313 L
.55496 .31309 L
.55491 .31318 L
.55486 .31327 L
.55481 .31336 L
Mistroke
.55476 .31345 L
.55471 .31354 L
.55466 .31363 L
.55461 .31372 L
.55456 .31382 L
.55451 .31391 L
.55447 .314 L
.55442 .31409 L
.55437 .31418 L
.55432 .31427 L
.55427 .31436 L
.55422 .31445 L
.55417 .31454 L
.55412 .31463 L
.55406 .31472 L
.55401 .31481 L
.55396 .3149 L
.55391 .31499 L
.55386 .31508 L
.55381 .31517 L
.55376 .31527 L
.55371 .31536 L
.55366 .31545 L
.55361 .31554 L
.55356 .31563 L
.5535 .31572 L
.55345 .31581 L
.5534 .3159 L
.55335 .31599 L
.5533 .31608 L
.55325 .31617 L
.5532 .31626 L
.55314 .31635 L
.55309 .31644 L
.55304 .31653 L
.55299 .31662 L
.55293 .31671 L
.55288 .3168 L
.55283 .31689 L
.55278 .31698 L
.55272 .31707 L
.55267 .31716 L
.55262 .31725 L
.55257 .31734 L
.55251 .31743 L
.55246 .31752 L
.55241 .31761 L
.55235 .3177 L
.5523 .31779 L
.55225 .31788 L
Mistroke
.55219 .31797 L
.55214 .31806 L
.55209 .31815 L
.55203 .31824 L
.55198 .31833 L
.55192 .31842 L
.55187 .31851 L
.55182 .3186 L
.55176 .31869 L
.55171 .31877 L
.55165 .31886 L
.5516 .31895 L
.55154 .31904 L
.55149 .31913 L
.55144 .31922 L
.55138 .31931 L
.55133 .3194 L
.55127 .31949 L
.55122 .31958 L
.55116 .31967 L
.55111 .31976 L
.55105 .31985 L
.55099 .31994 L
.55094 .32003 L
.55088 .32011 L
.55083 .3202 L
.55077 .32029 L
.55072 .32038 L
.55066 .32047 L
.55061 .32056 L
.55055 .32065 L
.55049 .32074 L
.55044 .32083 L
.55038 .32092 L
.55032 .321 L
.55027 .32109 L
.55021 .32118 L
.55016 .32127 L
.5501 .32136 L
.55004 .32145 L
.54999 .32154 L
.54993 .32163 L
.54987 .32171 L
.54981 .3218 L
.54976 .32189 L
.5497 .32198 L
.54964 .32207 L
.54959 .32216 L
.54953 .32225 L
.54947 .32233 L
Mistroke
.54941 .32242 L
.54936 .32251 L
.5493 .3226 L
.54924 .32269 L
.54918 .32278 L
.54912 .32286 L
.54907 .32295 L
.54901 .32304 L
.54895 .32313 L
.54889 .32322 L
.54883 .32331 L
.54877 .32339 L
.54872 .32348 L
.54866 .32357 L
.5486 .32366 L
.54854 .32375 L
.54848 .32383 L
.54842 .32392 L
.54836 .32401 L
.5483 .3241 L
.54825 .32418 L
.54819 .32427 L
.54813 .32436 L
.54807 .32445 L
.54801 .32454 L
.54795 .32462 L
.54789 .32471 L
.54783 .3248 L
.54777 .32489 L
.54771 .32497 L
.54765 .32506 L
.54759 .32515 L
.54753 .32524 L
.54747 .32532 L
.54741 .32541 L
.54735 .3255 L
.54729 .32559 L
.54723 .32567 L
.54717 .32576 L
.54711 .32585 L
.54705 .32593 L
.54699 .32602 L
.54693 .32611 L
.54687 .3262 L
.54681 .32628 L
.54674 .32637 L
.54668 .32646 L
.54662 .32654 L
.54656 .32663 L
.5465 .32672 L
Mistroke
.54644 .3268 L
.54638 .32689 L
.54632 .32698 L
.54626 .32706 L
.54619 .32715 L
.54613 .32724 L
.54607 .32732 L
.54601 .32741 L
.54595 .3275 L
.54588 .32758 L
.54582 .32767 L
.54576 .32776 L
.5457 .32784 L
.54564 .32793 L
.54557 .32801 L
.54551 .3281 L
.54545 .32819 L
.54539 .32827 L
.54532 .32836 L
.54526 .32845 L
.5452 .32853 L
.54514 .32862 L
.54507 .3287 L
.54501 .32879 L
.54495 .32888 L
.54489 .32896 L
.54482 .32905 L
.54476 .32913 L
.5447 .32922 L
.54463 .3293 L
.54457 .32939 L
.54451 .32948 L
.54444 .32956 L
.54438 .32965 L
.54432 .32973 L
.54425 .32982 L
.54419 .3299 L
.54412 .32999 L
.54406 .33007 L
.544 .33016 L
.54393 .33025 L
.54387 .33033 L
.5438 .33042 L
.54374 .3305 L
.54368 .33059 L
.54361 .33067 L
.54355 .33076 L
.54348 .33084 L
.54342 .33093 L
.54335 .33101 L
Mistroke
.54329 .3311 L
.54322 .33118 L
.54316 .33127 L
.5431 .33135 L
.54303 .33144 L
.54297 .33152 L
.5429 .33161 L
.54284 .33169 L
.54277 .33177 L
.54271 .33186 L
.54264 .33194 L
.54257 .33203 L
.54251 .33211 L
.54244 .3322 L
.54238 .33228 L
.54231 .33237 L
.54225 .33245 L
.54218 .33253 L
.54212 .33262 L
.54205 .3327 L
.54198 .33279 L
.54192 .33287 L
.54185 .33295 L
.54179 .33304 L
.54172 .33312 L
.54165 .33321 L
.54159 .33329 L
.54152 .33337 L
.54146 .33346 L
.54139 .33354 L
.54132 .33363 L
.54126 .33371 L
.54119 .33379 L
.54112 .33388 L
.54106 .33396 L
.54099 .33404 L
.54092 .33413 L
.54086 .33421 L
.54079 .33429 L
.54072 .33438 L
.54066 .33446 L
.54059 .33454 L
.54052 .33463 L
.54045 .33471 L
.54039 .33479 L
.54032 .33488 L
.54025 .33496 L
.54018 .33504 L
.54012 .33512 L
.54005 .33521 L
Mistroke
.53998 .33529 L
.53991 .33537 L
.53985 .33546 L
.53978 .33554 L
.53971 .33562 L
.53964 .3357 L
.53958 .33579 L
.53951 .33587 L
.53944 .33595 L
.53937 .33603 L
.5393 .33612 L
.53924 .3362 L
.53917 .33628 L
.5391 .33636 L
.53903 .33645 L
.53896 .33653 L
.53889 .33661 L
.53882 .33669 L
.53876 .33677 L
.53869 .33686 L
.53862 .33694 L
.53855 .33702 L
.53848 .3371 L
.53841 .33718 L
.53834 .33726 L
.53827 .33735 L
.53821 .33743 L
.53814 .33751 L
.53807 .33759 L
.538 .33767 L
.53793 .33775 L
.53786 .33784 L
.53779 .33792 L
.53772 .338 L
.53765 .33808 L
.53758 .33816 L
.53751 .33824 L
.53744 .33832 L
.53737 .3384 L
.5373 .33848 L
.53723 .33857 L
.53717 .33865 L
.5371 .33873 L
.53703 .33881 L
.53696 .33889 L
.53689 .33897 L
.53682 .33905 L
.53675 .33913 L
.53668 .33921 L
.53661 .33929 L
Mistroke
.53654 .33937 L
.53647 .33945 L
.53639 .33953 L
.53632 .33961 L
.53625 .33969 L
.53618 .33977 L
.53611 .33985 L
.53604 .33993 L
.53597 .34001 L
.5359 .34009 L
.53583 .34017 L
.53576 .34025 L
.53569 .34033 L
.53562 .34041 L
.53555 .34049 L
.53548 .34057 L
.53541 .34065 L
.53533 .34073 L
.53526 .34081 L
.53519 .34089 L
.53512 .34097 L
.53505 .34105 L
.53498 .34113 L
.53491 .34121 L
.53484 .34129 L
.53477 .34137 L
.53469 .34145 L
.53462 .34153 L
.53455 .34161 L
.53448 .34168 L
.53441 .34176 L
.53434 .34184 L
.53426 .34192 L
.53419 .342 L
.53412 .34208 L
.53405 .34216 L
.53398 .34224 L
.53391 .34232 L
.53383 .34239 L
.53376 .34247 L
.53369 .34255 L
.53362 .34263 L
.53355 .34271 L
.53347 .34279 L
.5334 .34286 L
.53333 .34294 L
.53326 .34302 L
.53318 .3431 L
.53311 .34318 L
.53304 .34325 L
Mistroke
.53297 .34333 L
.5329 .34341 L
.53282 .34349 L
.53275 .34357 L
.53268 .34364 L
.5326 .34372 L
.53253 .3438 L
.53246 .34388 L
.53239 .34395 L
.53231 .34403 L
.53224 .34411 L
.53217 .34419 L
.5321 .34426 L
.53202 .34434 L
.53195 .34442 L
.53188 .34449 L
.5318 .34457 L
.53173 .34465 L
.53166 .34473 L
.53158 .3448 L
.53151 .34488 L
.53144 .34496 L
.53136 .34503 L
.53129 .34511 L
.53122 .34519 L
.53114 .34526 L
.53107 .34534 L
.531 .34542 L
.53092 .34549 L
.53085 .34557 L
.53078 .34564 L
.5307 .34572 L
.53063 .3458 L
.53056 .34587 L
.53048 .34595 L
.53041 .34603 L
.53033 .3461 L
.53026 .34618 L
.53019 .34625 L
.53011 .34633 L
.53004 .3464 L
.52996 .34648 L
.52989 .34656 L
.52982 .34663 L
.52974 .34671 L
.52967 .34678 L
.52959 .34686 L
.52952 .34693 L
.52945 .34701 L
.52937 .34708 L
Mistroke
.5293 .34716 L
.52922 .34723 L
.52915 .34731 L
.52907 .34738 L
.529 .34746 L
.52893 .34753 L
.52885 .34761 L
.52878 .34768 L
.5287 .34776 L
.52863 .34783 L
.52855 .34791 L
.52848 .34798 L
.5284 .34806 L
.52833 .34813 L
.52825 .3482 L
.52818 .34828 L
.5281 .34835 L
.52803 .34843 L
.52795 .3485 L
.52788 .34858 L
.5278 .34865 L
.52773 .34872 L
.52765 .3488 L
.52758 .34887 L
.5275 .34895 L
.52743 .34902 L
.52735 .34909 L
.52728 .34917 L
.5272 .34924 L
.52713 .34931 L
.52705 .34939 L
.52698 .34946 L
.5269 .34953 L
.52683 .34961 L
.52675 .34968 L
.52668 .34975 L
.5266 .34983 L
.52653 .3499 L
.52645 .34997 L
.52637 .35004 L
.5263 .35012 L
.52622 .35019 L
.52615 .35026 L
.52607 .35034 L
.526 .35041 L
.52592 .35048 L
.52585 .35055 L
.52577 .35063 L
.52569 .3507 L
.52562 .35077 L
Mistroke
.52554 .35084 L
.52547 .35091 L
.52539 .35099 L
.52531 .35106 L
.52524 .35113 L
.52516 .3512 L
.52509 .35127 L
.52501 .35135 L
.52493 .35142 L
.52486 .35149 L
.52478 .35156 L
.52471 .35163 L
.52463 .3517 L
.52455 .35178 L
.52448 .35185 L
.5244 .35192 L
.52433 .35199 L
.52425 .35206 L
.52417 .35213 L
.5241 .3522 L
.52402 .35227 L
.52394 .35234 L
.52387 .35242 L
.52379 .35249 L
.52372 .35256 L
.52364 .35263 L
.52356 .3527 L
.52349 .35277 L
.52341 .35284 L
.52333 .35291 L
.52326 .35298 L
.52318 .35305 L
.5231 .35312 L
.52303 .35319 L
.52295 .35326 L
.52287 .35333 L
.5228 .3534 L
.52272 .35347 L
.52264 .35354 L
.52257 .35361 L
.52249 .35368 L
.52241 .35375 L
.52234 .35382 L
.52226 .35389 L
.52218 .35396 L
.52211 .35403 L
.52203 .3541 L
.52195 .35417 L
.52187 .35424 L
.5218 .35431 L
Mistroke
.52172 .35437 L
.52164 .35444 L
.52157 .35451 L
.52149 .35458 L
.52141 .35465 L
.52134 .35472 L
.52126 .35479 L
.52118 .35486 L
.5211 .35493 L
.52103 .35499 L
.52095 .35506 L
.52087 .35513 L
.5208 .3552 L
.52072 .35527 L
.52064 .35534 L
.52056 .3554 L
.52049 .35547 L
.52041 .35554 L
.52033 .35561 L
.52025 .35568 L
.52018 .35574 L
.5201 .35581 L
.52002 .35588 L
.51995 .35595 L
.51987 .35601 L
.51979 .35608 L
.51971 .35615 L
.51964 .35622 L
.51956 .35628 L
.51948 .35635 L
.5194 .35642 L
.51933 .35648 L
.51925 .35655 L
.51917 .35662 L
.51909 .35669 L
.51902 .35675 L
.51894 .35682 L
.51886 .35689 L
.51878 .35695 L
.5187 .35702 L
.51863 .35709 L
.51855 .35715 L
.51847 .35722 L
.51839 .35728 L
.51832 .35735 L
.51824 .35742 L
.51816 .35748 L
.51808 .35755 L
.51801 .35762 L
.51793 .35768 L
Mistroke
.51785 .35775 L
.51777 .35781 L
.51769 .35788 L
.51762 .35794 L
.51754 .35801 L
.51746 .35808 L
.51738 .35814 L
.51731 .35821 L
.51723 .35827 L
.51715 .35834 L
.51707 .3584 L
.51699 .35847 L
.51692 .35853 L
.51684 .3586 L
.51676 .35866 L
.51668 .35873 L
.5166 .35879 L
.51653 .35886 L
.51645 .35892 L
.51637 .35899 L
.51629 .35905 L
.51621 .35911 L
.51614 .35918 L
.51606 .35924 L
.51598 .35931 L
.5159 .35937 L
.51582 .35944 L
.51575 .3595 L
.51567 .35956 L
.51559 .35963 L
.51551 .35969 L
.51543 .35976 L
.51535 .35982 L
.51528 .35988 L
.5152 .35995 L
.51512 .36001 L
.51504 .36007 L
.51496 .36014 L
.51489 .3602 L
.51481 .36026 L
.51473 .36033 L
.51465 .36039 L
.51457 .36045 L
.51449 .36051 L
.51442 .36058 L
.51434 .36064 L
.51426 .3607 L
.51418 .36077 L
.5141 .36083 L
.51403 .36089 L
Mistroke
.51395 .36095 L
.51387 .36102 L
.51379 .36108 L
.51371 .36114 L
.51363 .3612 L
.51356 .36126 L
.51348 .36133 L
.5134 .36139 L
.51332 .36145 L
.51324 .36151 L
.51316 .36157 L
.51309 .36164 L
.51301 .3617 L
.51293 .36176 L
.51285 .36182 L
.51277 .36188 L
.51269 .36194 L
.51262 .362 L
.51254 .36207 L
.51246 .36213 L
.51238 .36219 L
.5123 .36225 L
.51222 .36231 L
.51215 .36237 L
.51207 .36243 L
.51199 .36249 L
.51191 .36255 L
.51183 .36261 L
.51175 .36267 L
.51167 .36273 L
.5116 .3628 L
.51152 .36286 L
.51144 .36292 L
.51136 .36298 L
.51128 .36304 L
.5112 .3631 L
.51113 .36316 L
.51105 .36322 L
.51097 .36328 L
.51089 .36334 L
.51081 .36339 L
.51073 .36345 L
.51066 .36351 L
.51058 .36357 L
.5105 .36363 L
.51042 .36369 L
.51034 .36375 L
.51026 .36381 L
.51018 .36387 L
.51011 .36393 L
Mistroke
.51003 .36399 L
.50995 .36405 L
.50987 .36411 L
.50979 .36416 L
.50971 .36422 L
.50964 .36428 L
.50956 .36434 L
.50948 .3644 L
.5094 .36446 L
.50932 .36452 L
.50924 .36457 L
.50916 .36463 L
.50909 .36469 L
.50901 .36475 L
.50893 .36481 L
.50885 .36486 L
.50877 .36492 L
.50869 .36498 L
.50862 .36504 L
.50854 .36509 L
.50846 .36515 L
.50838 .36521 L
.5083 .36527 L
.50822 .36532 L
.50815 .36538 L
.50807 .36544 L
.50799 .3655 L
.50791 .36555 L
.50783 .36561 L
.50775 .36567 L
.50768 .36572 L
.5076 .36578 L
.50752 .36584 L
.50744 .36589 L
.50736 .36595 L
.50728 .36601 L
.5072 .36606 L
.50713 .36612 L
.50705 .36618 L
.50697 .36623 L
.50689 .36629 L
.50681 .36634 L
.50673 .3664 L
.50666 .36646 L
.50658 .36651 L
.5065 .36657 L
.50642 .36662 L
.50634 .36668 L
.50626 .36673 L
.50619 .36679 L
Mistroke
.50611 .36684 L
.50603 .3669 L
.50595 .36696 L
.50587 .36701 L
.50579 .36707 L
.50572 .36712 L
.50564 .36718 L
.50556 .36723 L
.50548 .36729 L
.5054 .36734 L
.50533 .36739 L
.50525 .36745 L
.50517 .3675 L
.50509 .36756 L
.50501 .36761 L
.50493 .36767 L
.50486 .36772 L
.50478 .36777 L
.5047 .36783 L
.50462 .36788 L
.50454 .36794 L
.50447 .36799 L
.50439 .36804 L
.50431 .3681 L
.50423 .36815 L
.50415 .36821 L
.50407 .36826 L
.504 .36831 L
.50392 .36837 L
.50384 .36842 L
.50376 .36847 L
.50368 .36853 L
.50361 .36858 L
.50353 .36863 L
.50345 .36868 L
.50337 .36874 L
.50329 .36879 L
.50322 .36884 L
.50314 .36889 L
.50306 .36895 L
.50298 .369 L
.5029 .36905 L
.50283 .3691 L
.50275 .36916 L
.50267 .36921 L
.50259 .36926 L
.50251 .36931 L
.50244 .36937 L
.50236 .36942 L
.50228 .36947 L
Mistroke
.5022 .36952 L
.50212 .36957 L
.50205 .36962 L
.50197 .36968 L
.50189 .36973 L
.50181 .36978 L
.50174 .36983 L
.50166 .36988 L
.50158 .36993 L
.5015 .36998 L
.50142 .37003 L
.50135 .37008 L
.50127 .37014 L
.50119 .37019 L
.50111 .37024 L
.50104 .37029 L
.50096 .37034 L
.50088 .37039 L
.5008 .37044 L
.50073 .37049 L
.50065 .37054 L
.50057 .37059 L
.50049 .37064 L
.50041 .37069 L
.50034 .37074 L
.50026 .37079 L
.50018 .37084 L
.5001 .37089 L
.50003 .37094 L
.49995 .37099 L
.49987 .37104 L
.49979 .37109 L
.49972 .37114 L
.49964 .37119 L
.49956 .37124 L
.49949 .37128 L
.49941 .37133 L
.49933 .37138 L
.49925 .37143 L
.49918 .37148 L
.4991 .37153 L
.49902 .37158 L
.49894 .37163 L
.49887 .37167 L
.49879 .37172 L
.49871 .37177 L
.49863 .37182 L
.49856 .37187 L
.49848 .37192 L
.4984 .37196 L
Mistroke
.49833 .37201 L
.49825 .37206 L
.49817 .37211 L
.49809 .37216 L
.49802 .3722 L
.49794 .37225 L
.49786 .3723 L
.49779 .37235 L
.49771 .37239 L
.49763 .37244 L
.49755 .37249 L
.49748 .37254 L
.4974 .37258 L
.49732 .37263 L
.49725 .37268 L
.49717 .37272 L
.49709 .37277 L
.49702 .37282 L
.49694 .37286 L
.49686 .37291 L
.49679 .37296 L
.49671 .373 L
.49663 .37305 L
.49656 .3731 L
.49648 .37314 L
.4964 .37319 L
.49633 .37323 L
.49625 .37328 L
.49617 .37333 L
.4961 .37337 L
.49602 .37342 L
.49594 .37346 L
.49587 .37351 L
.49579 .37356 L
.49571 .3736 L
.49564 .37365 L
.49556 .37369 L
.49548 .37374 L
.49541 .37378 L
.49533 .37383 L
.49525 .37387 L
.49518 .37392 L
.4951 .37396 L
.49502 .37401 L
.49495 .37405 L
.49487 .3741 L
.4948 .37414 L
.49472 .37419 L
.49464 .37423 L
.49457 .37427 L
Mistroke
.49449 .37432 L
.49441 .37436 L
.49434 .37441 L
.49426 .37445 L
.49419 .37449 L
.49411 .37454 L
.49403 .37458 L
.49396 .37463 L
.49388 .37467 L
.49381 .37471 L
.49373 .37476 L
.49365 .3748 L
.49358 .37484 L
.4935 .37489 L
.49343 .37493 L
.49335 .37497 L
.49327 .37502 L
.4932 .37506 L
.49312 .3751 L
.49305 .37515 L
.49297 .37519 L
.49289 .37523 L
.49282 .37527 L
.49274 .37532 L
.49267 .37536 L
.49259 .3754 L
.49252 .37544 L
.49244 .37549 L
.49237 .37553 L
.49229 .37557 L
.49221 .37561 L
.49214 .37565 L
.49206 .3757 L
.49199 .37574 L
.49191 .37578 L
.49184 .37582 L
.49176 .37586 L
.49169 .3759 L
.49161 .37595 L
.49154 .37599 L
.49146 .37603 L
.49139 .37607 L
.49131 .37611 L
.49123 .37615 L
.49116 .37619 L
.49108 .37623 L
.49101 .37627 L
.49093 .37632 L
.49086 .37636 L
.49078 .3764 L
Mistroke
.49071 .37644 L
.49063 .37648 L
.49056 .37652 L
.49048 .37656 L
.49041 .3766 L
.49033 .37664 L
.49026 .37668 L
.49018 .37672 L
.49011 .37676 L
.49003 .3768 L
.48996 .37684 L
.48989 .37688 L
.48981 .37692 L
.48974 .37696 L
.48966 .377 L
.48959 .37704 L
.48951 .37708 L
.48944 .37712 L
.48936 .37715 L
.48929 .37719 L
.48921 .37723 L
.48914 .37727 L
.48907 .37731 L
.48899 .37735 L
.48892 .37739 L
.48884 .37743 L
.48877 .37747 L
.48869 .3775 L
.48862 .37754 L
.48854 .37758 L
.48847 .37762 L
.4884 .37766 L
.48832 .3777 L
.48825 .37773 L
.48817 .37777 L
.4881 .37781 L
.48803 .37785 L
.48795 .37789 L
.48788 .37792 L
.4878 .37796 L
.48773 .378 L
.48766 .37804 L
.48758 .37807 L
.48751 .37811 L
.48743 .37815 L
.48736 .37818 L
.48729 .37822 L
.48721 .37826 L
.48714 .3783 L
.48707 .37833 L
Mistroke
.48699 .37837 L
.48692 .37841 L
.48685 .37844 L
.48677 .37848 L
.4867 .37852 L
.48662 .37855 L
.48655 .37859 L
.48648 .37863 L
.4864 .37866 L
.48633 .3787 L
.48626 .37873 L
.48618 .37877 L
.48611 .37881 L
.48604 .37884 L
.48597 .37888 L
.48589 .37891 L
.48582 .37895 L
.48575 .37898 L
.48567 .37902 L
.4856 .37906 L
.48553 .37909 L
.48545 .37913 L
.48538 .37916 L
.48531 .3792 L
.48523 .37923 L
.48516 .37927 L
.48509 .3793 L
.48502 .37934 L
.48494 .37937 L
.48487 .37941 L
.4848 .37944 L
.48473 .37947 L
.48465 .37951 L
.48458 .37954 L
.48451 .37958 L
.48444 .37961 L
.48436 .37965 L
.48429 .37968 L
.48422 .37971 L
.48415 .37975 L
.48407 .37978 L
.484 .37982 L
.48393 .37985 L
.48386 .37988 L
.48378 .37992 L
.48371 .37995 L
.48364 .37998 L
.48357 .38002 L
.4835 .38005 L
.48342 .38008 L
Mistroke
.48335 .38012 L
.48328 .38015 L
.48321 .38018 L
.48314 .38022 L
.48306 .38025 L
.48299 .38028 L
.48292 .38031 L
.48285 .38035 L
.48278 .38038 L
.48271 .38041 L
.48263 .38044 L
.48256 .38048 L
.48249 .38051 L
.48242 .38054 L
.48235 .38057 L
.48228 .3806 L
.4822 .38064 L
.48213 .38067 L
.48206 .3807 L
.48199 .38073 L
.48192 .38076 L
.48185 .38079 L
.48178 .38083 L
.48171 .38086 L
.48163 .38089 L
.48156 .38092 L
.48149 .38095 L
.48142 .38098 L
.48135 .38101 L
.48128 .38104 L
.48121 .38108 L
.48114 .38111 L
.48107 .38114 L
.48099 .38117 L
.48092 .3812 L
.48085 .38123 L
.48078 .38126 L
.48071 .38129 L
.48064 .38132 L
.48057 .38135 L
.4805 .38138 L
.48043 .38141 L
.48036 .38144 L
.48029 .38147 L
.48022 .3815 L
.48015 .38153 L
.48008 .38156 L
.48001 .38159 L
.47994 .38162 L
.47987 .38165 L
Mistroke
.4798 .38168 L
.47973 .38171 L
.47966 .38174 L
.47959 .38177 L
.47952 .3818 L
.47945 .38182 L
.47938 .38185 L
.47931 .38188 L
.47924 .38191 L
.47917 .38194 L
.4791 .38197 L
.47903 .382 L
.47896 .38203 L
.47889 .38205 L
.47882 .38208 L
.47875 .38211 L
.47868 .38214 L
.47861 .38217 L
.47854 .3822 L
.47847 .38222 L
.4784 .38225 L
.47833 .38228 L
.47826 .38231 L
.47819 .38234 L
.47812 .38236 L
.47805 .38239 L
.47798 .38242 L
.47791 .38245 L
.47785 .38247 L
.47778 .3825 L
.47771 .38253 L
.47764 .38256 L
.47757 .38258 L
.4775 .38261 L
.47743 .38264 L
.47736 .38266 L
.47729 .38269 L
.47722 .38272 L
.47716 .38274 L
.47709 .38277 L
.47702 .3828 L
.47695 .38282 L
.47688 .38285 L
.47681 .38288 L
.47674 .3829 L
.47668 .38293 L
.47661 .38296 L
.47654 .38298 L
.47647 .38301 L
.4764 .38303 L
Mistroke
.47633 .38306 L
.47627 .38309 L
.4762 .38311 L
.47613 .38314 L
.47606 .38316 L
.47599 .38319 L
.47593 .38321 L
.47586 .38324 L
.47579 .38326 L
.47572 .38329 L
.47565 .38331 L
.47559 .38334 L
.47552 .38336 L
.47545 .38339 L
.47538 .38341 L
.47531 .38344 L
.47525 .38346 L
.47518 .38349 L
.47511 .38351 L
.47504 .38354 L
.47498 .38356 L
.47491 .38359 L
.47484 .38361 L
.47477 .38363 L
.47471 .38366 L
.47464 .38368 L
.47457 .38371 L
.47451 .38373 L
.47444 .38375 L
.47437 .38378 L
.4743 .3838 L
.47424 .38383 L
.47417 .38385 L
.4741 .38387 L
.47404 .3839 L
.47397 .38392 L
.4739 .38394 L
.47384 .38397 L
.47377 .38399 L
.4737 .38401 L
.47364 .38404 L
.47357 .38406 L
.4735 .38408 L
.47344 .3841 L
.47337 .38413 L
.4733 .38415 L
.47324 .38417 L
.47317 .38419 L
.47311 .38422 L
.47304 .38424 L
Mistroke
.47297 .38426 L
.47291 .38428 L
.47284 .38431 L
.47277 .38433 L
.47271 .38435 L
.47264 .38437 L
.47258 .38439 L
.47251 .38442 L
.47245 .38444 L
.47238 .38446 L
.47231 .38448 L
.47225 .3845 L
.47218 .38452 L
.47212 .38455 L
.47205 .38457 L
.47199 .38459 L
.47192 .38461 L
.47185 .38463 L
.47179 .38465 L
.47172 .38467 L
.47166 .38469 L
.47159 .38471 L
.47153 .38474 L
.47146 .38476 L
.4714 .38478 L
.47133 .3848 L
.47127 .38482 L
.4712 .38484 L
.47114 .38486 L
.47107 .38488 L
.47101 .3849 L
.47094 .38492 L
.47088 .38494 L
.47081 .38496 L
.47075 .38498 L
.47068 .385 L
.47062 .38502 L
.47056 .38504 L
.47049 .38506 L
.47043 .38508 L
.47036 .3851 L
.4703 .38512 L
.47023 .38514 L
.47017 .38516 L
.4701 .38518 L
.47004 .3852 L
.46998 .38521 L
.46991 .38523 L
.46985 .38525 L
.46978 .38527 L
Mistroke
.46972 .38529 L
.46966 .38531 L
.46959 .38533 L
.46953 .38535 L
.46946 .38537 L
.4694 .38538 L
.46934 .3854 L
.46927 .38542 L
.46921 .38544 L
.46915 .38546 L
.46908 .38548 L
.46902 .38549 L
.46896 .38551 L
.46889 .38553 L
.46883 .38555 L
.46877 .38557 L
.4687 .38558 L
.46864 .3856 L
.46858 .38562 L
.46851 .38564 L
.46845 .38565 L
.46839 .38567 L
.46832 .38569 L
.46826 .38571 L
.4682 .38572 L
.46814 .38574 L
.46807 .38576 L
.46801 .38577 L
.46795 .38579 L
.46789 .38581 L
.46782 .38583 L
.46776 .38584 L
.4677 .38586 L
.46763 .38588 L
.46757 .38589 L
.46751 .38591 L
.46745 .38593 L
.46739 .38594 L
.46732 .38596 L
.46726 .38597 L
.4672 .38599 L
.46714 .38601 L
.46708 .38602 L
.46701 .38604 L
.46695 .38605 L
.46689 .38607 L
.46683 .38609 L
.46677 .3861 L
.4667 .38612 L
.46664 .38613 L
Mistroke
.46658 .38615 L
.46652 .38616 L
.46646 .38618 L
.4664 .3862 L
.46633 .38621 L
.46627 .38623 L
.46621 .38624 L
.46615 .38626 L
.46609 .38627 L
.46603 .38629 L
.46597 .3863 L
.46591 .38632 L
.46584 .38633 L
.46578 .38635 L
.46572 .38636 L
.46566 .38637 L
.4656 .38639 L
.46554 .3864 L
.46548 .38642 L
.46542 .38643 L
.46536 .38645 L
.4653 .38646 L
.46524 .38647 L
.46518 .38649 L
.46512 .3865 L
.46506 .38652 L
.46499 .38653 L
.46493 .38654 L
.46487 .38656 L
.46481 .38657 L
.46475 .38659 L
.46469 .3866 L
.46463 .38661 L
.46457 .38663 L
.46451 .38664 L
.46445 .38665 L
.46439 .38667 L
.46433 .38668 L
.46427 .38669 L
.46421 .3867 L
.46415 .38672 L
.46409 .38673 L
.46404 .38674 L
.46398 .38676 L
.46392 .38677 L
.46386 .38678 L
.4638 .38679 L
.46374 .38681 L
.46368 .38682 L
.46362 .38683 L
Mistroke
.46356 .38684 L
.4635 .38686 L
.46344 .38687 L
.46338 .38688 L
.46332 .38689 L
.46326 .3869 L
.46321 .38692 L
.46315 .38693 L
.46309 .38694 L
.46303 .38695 L
.46297 .38696 L
.46291 .38697 L
.46285 .38699 L
.46279 .387 L
.46274 .38701 L
.46268 .38702 L
.46262 .38703 L
.46256 .38704 L
.4625 .38705 L
.46244 .38707 L
.46239 .38708 L
.46233 .38709 L
.46227 .3871 L
.46221 .38711 L
.46215 .38712 L
.4621 .38713 L
.46204 .38714 L
.46198 .38715 L
.46192 .38716 L
.46186 .38717 L
.46181 .38718 L
.46175 .38719 L
.46169 .3872 L
.46163 .38721 L
.46158 .38722 L
.46152 .38723 L
.46146 .38725 L
.4614 .38726 L
.46135 .38726 L
.46129 .38727 L
.46123 .38728 L
.46117 .38729 L
.46112 .3873 L
.46106 .38731 L
.461 .38732 L
.46095 .38733 L
.46089 .38734 L
.46083 .38735 L
.46078 .38736 L
.46072 .38737 L
Mistroke
.46066 .38738 L
.46061 .38739 L
.46055 .3874 L
.46049 .38741 L
.46044 .38742 L
.46038 .38742 L
.46032 .38743 L
.46027 .38744 L
.46021 .38745 L
.46015 .38746 L
.4601 .38747 L
.46004 .38748 L
.45998 .38749 L
.45993 .38749 L
.45987 .3875 L
.45982 .38751 L
.45976 .38752 L
.4597 .38753 L
.45965 .38753 L
.45959 .38754 L
.45954 .38755 L
.45948 .38756 L
.45943 .38757 L
.45937 .38757 L
.45932 .38758 L
.45926 .38759 L
.4592 .3876 L
.45915 .3876 L
.45909 .38761 L
.45904 .38762 L
.45898 .38763 L
.45893 .38763 L
.45887 .38764 L
.45882 .38765 L
.45876 .38766 L
.45871 .38766 L
.45865 .38767 L
.4586 .38768 L
.45854 .38768 L
.45849 .38769 L
.45843 .3877 L
.45838 .3877 L
.45832 .38771 L
.45827 .38772 L
.45822 .38772 L
.45816 .38773 L
.45811 .38774 L
.45805 .38774 L
.458 .38775 L
.45794 .38776 L
Mistroke
.45789 .38776 L
.45784 .38777 L
.45778 .38777 L
.45773 .38778 L
.45767 .38779 L
.45762 .38779 L
.45757 .3878 L
.45751 .3878 L
.45746 .38781 L
.4574 .38782 L
.45735 .38782 L
.4573 .38783 L
.45724 .38783 L
.45719 .38784 L
.45714 .38784 L
.45708 .38785 L
.45703 .38785 L
.45698 .38786 L
.45692 .38786 L
.45687 .38787 L
.45682 .38787 L
.45676 .38788 L
.45671 .38788 L
.45666 .38789 L
.4566 .38789 L
.45655 .3879 L
.4565 .3879 L
.45645 .38791 L
.45639 .38791 L
.45634 .38792 L
.45629 .38792 L
.45624 .38793 L
.45618 .38793 L
.45613 .38793 L
.45608 .38794 L
.45603 .38794 L
.45597 .38795 L
.45592 .38795 L
.45587 .38796 L
.45582 .38796 L
.45576 .38796 L
.45571 .38797 L
.45566 .38797 L
.45561 .38797 L
.45556 .38798 L
.4555 .38798 L
.45545 .38799 L
.4554 .38799 L
.45535 .38799 L
.4553 .388 L
Mistroke
.45525 .388 L
.45519 .388 L
.45514 .38801 L
.45509 .38801 L
.45504 .38801 L
.45499 .38802 L
.45494 .38802 L
.45489 .38802 L
.45484 .38802 L
.45478 .38803 L
.45473 .38803 L
.45468 .38803 L
.45463 .38804 L
.45458 .38804 L
.45453 .38804 L
.45448 .38804 L
.45443 .38805 L
.45438 .38805 L
.45433 .38805 L
.45428 .38805 L
.45423 .38805 L
.45417 .38806 L
.45412 .38806 L
.45407 .38806 L
.45402 .38806 L
.45397 .38807 L
.45392 .38807 L
.45387 .38807 L
.45382 .38807 L
.45377 .38807 L
.45372 .38807 L
.45367 .38808 L
.45362 .38808 L
.45357 .38808 L
.45352 .38808 L
.45347 .38808 L
.45342 .38808 L
.45337 .38808 L
.45332 .38809 L
.45327 .38809 L
.45323 .38809 L
.45318 .38809 L
.45313 .38809 L
.45308 .38809 L
.45303 .38809 L
.45298 .38809 L
.45293 .38809 L
.45288 .38809 L
.45283 .3881 L
.45278 .3881 L
Mistroke
.45273 .3881 L
.45268 .3881 L
.45264 .3881 L
.45259 .3881 L
.45254 .3881 L
.45249 .3881 L
.45244 .3881 L
.45239 .3881 L
.45234 .3881 L
.45229 .3881 L
.45225 .3881 L
.4522 .3881 L
.45215 .3881 L
.4521 .3881 L
.45205 .3881 L
.452 .3881 L
.45196 .3881 L
.45191 .3881 L
.45186 .3881 L
.45181 .3881 L
.45176 .3881 L
.45172 .3881 L
.45167 .3881 L
.45162 .3881 L
.45157 .3881 L
.45153 .3881 L
.45148 .38809 L
.45143 .38809 L
.45138 .38809 L
.45134 .38809 L
.45129 .38809 L
.45124 .38809 L
.45119 .38809 L
.45115 .38809 L
.4511 .38809 L
.45105 .38809 L
.45101 .38808 L
.45096 .38808 L
.45091 .38808 L
.45086 .38808 L
.45082 .38808 L
.45077 .38808 L
.45072 .38808 L
.45068 .38807 L
.45063 .38807 L
.45058 .38807 L
.45054 .38807 L
.45049 .38807 L
.45044 .38807 L
.4504 .38806 L
Mistroke
.45035 .38806 L
.45031 .38806 L
.45026 .38806 L
.45021 .38806 L
.45017 .38805 L
.45012 .38805 L
.45007 .38805 L
.45003 .38805 L
.44998 .38804 L
.44994 .38804 L
.44989 .38804 L
.44985 .38804 L
.4498 .38803 L
.44975 .38803 L
.44971 .38803 L
.44966 .38803 L
.44962 .38802 L
.44957 .38802 L
.44953 .38802 L
.44948 .38802 L
.44944 .38801 L
.44939 .38801 L
.44935 .38801 L
.4493 .388 L
.44926 .388 L
.44921 .388 L
.44917 .38799 L
.44912 .38799 L
.44908 .38799 L
.44903 .38798 L
.44899 .38798 L
.44894 .38798 L
.4489 .38797 L
.44885 .38797 L
.44881 .38797 L
.44876 .38796 L
.44872 .38796 L
.44867 .38796 L
.44863 .38795 L
.44859 .38795 L
.44854 .38794 L
.4485 .38794 L
.44845 .38794 L
.44841 .38793 L
.44837 .38793 L
.44832 .38792 L
.44828 .38792 L
.44823 .38791 L
.44819 .38791 L
.44815 .38791 L
Mistroke
.4481 .3879 L
.44806 .3879 L
.44802 .38789 L
.44797 .38789 L
.44793 .38788 L
.44789 .38788 L
.44784 .38787 L
.4478 .38787 L
.44776 .38787 L
.44771 .38786 L
.44767 .38786 L
.44763 .38785 L
.44758 .38785 L
.44754 .38784 L
.4475 .38784 L
.44745 .38783 L
.44741 .38783 L
.44737 .38782 L
.44733 .38781 L
.44728 .38781 L
.44724 .3878 L
.4472 .3878 L
.44716 .38779 L
.44711 .38779 L
.44707 .38778 L
.44703 .38778 L
.44699 .38777 L
.44694 .38777 L
.4469 .38776 L
.44686 .38775 L
.44682 .38775 L
.44677 .38774 L
.44673 .38774 L
.44669 .38773 L
.44665 .38773 L
.44661 .38772 L
.44657 .38771 L
.44652 .38771 L
.44648 .3877 L
.44644 .38769 L
.4464 .38769 L
.44636 .38768 L
.44632 .38768 L
.44627 .38767 L
.44623 .38766 L
.44619 .38766 L
.44615 .38765 L
.44611 .38764 L
.44607 .38764 L
.44603 .38763 L
Mistroke
.44599 .38762 L
.44595 .38762 L
.4459 .38761 L
.44586 .3876 L
.44582 .3876 L
.44578 .38759 L
.44574 .38758 L
.4457 .38758 L
.44566 .38757 L
.44562 .38756 L
.44558 .38755 L
.44554 .38755 L
.4455 .38754 L
.44546 .38753 L
.44542 .38753 L
.44538 .38752 L
.44534 .38751 L
.4453 .3875 L
.44526 .3875 L
.44522 .38749 L
.44518 .38748 L
.44514 .38747 L
.4451 .38747 L
.44506 .38746 L
.44502 .38745 L
.44498 .38744 L
.44494 .38743 L
.4449 .38743 L
.44486 .38742 L
.44482 .38741 L
.44478 .3874 L
.44474 .3874 L
.4447 .38739 L
.44466 .38738 L
.44462 .38737 L
.44458 .38736 L
.44454 .38735 L
.4445 .38735 L
.44447 .38734 L
.44443 .38733 L
.44439 .38732 L
.44435 .38731 L
.44431 .3873 L
.44427 .3873 L
.44423 .38729 L
.44419 .38728 L
.44416 .38727 L
.44412 .38726 L
.44408 .38725 L
.44404 .38724 L
Mistroke
.444 .38724 L
.44396 .38723 L
.44392 .38722 L
.44389 .38721 L
.44385 .3872 L
.44381 .38719 L
.44377 .38718 L
.44373 .38717 L
.4437 .38716 L
.44366 .38715 L
.44362 .38714 L
.44358 .38714 L
.44354 .38713 L
.44351 .38712 L
.44347 .38711 L
.44343 .3871 L
.44339 .38709 L
.44336 .38708 L
.44332 .38707 L
.44328 .38706 L
.44324 .38705 L
.44321 .38704 L
.44317 .38703 L
.44313 .38702 L
.4431 .38701 L
.44306 .387 L
.44302 .38699 L
.44298 .38698 L
.44295 .38697 L
.44291 .38696 L
.44287 .38695 L
.44284 .38694 L
.4428 .38693 L
.44276 .38692 L
.44273 .38691 L
.44269 .3869 L
.44265 .38689 L
.44262 .38688 L
.44258 .38687 L
.44254 .38686 L
.44251 .38685 L
.44247 .38684 L
.44244 .38683 L
.4424 .38682 L
.44236 .38681 L
.44233 .3868 L
.44229 .38679 L
.44225 .38678 L
.44222 .38676 L
.44218 .38675 L
Mistroke
.44215 .38674 L
.44211 .38673 L
.44208 .38672 L
.44204 .38671 L
.442 .3867 L
.44197 .38669 L
.44193 .38668 L
.4419 .38667 L
.44186 .38666 L
.44183 .38664 L
.44179 .38663 L
.44176 .38662 L
.44172 .38661 L
.44169 .3866 L
.44165 .38659 L
.44162 .38658 L
.44158 .38657 L
.44155 .38655 L
.44151 .38654 L
.44148 .38653 L
.44144 .38652 L
.44141 .38651 L
.44137 .3865 L
.44134 .38648 L
.4413 .38647 L
.44127 .38646 L
.44123 .38645 L
.4412 .38644 L
.44117 .38643 L
.44113 .38641 L
.4411 .3864 L
.44106 .38639 L
.44103 .38638 L
.44099 .38637 L
.44096 .38635 L
.44093 .38634 L
.44089 .38633 L
.44086 .38632 L
.44083 .3863 L
.44079 .38629 L
.44076 .38628 L
.44072 .38627 L
.44069 .38626 L
.44066 .38624 L
.44062 .38623 L
.44059 .38622 L
.44056 .38621 L
.44052 .38619 L
.44049 .38618 L
.44046 .38617 L
Mistroke
.44042 .38616 L
.44039 .38614 L
.44036 .38613 L
.44032 .38612 L
.44029 .3861 L
.44026 .38609 L
.44022 .38608 L
.44019 .38607 L
.44016 .38605 L
.44013 .38604 L
.44009 .38603 L
.44006 .38601 L
.44003 .386 L
.44 .38599 L
.43996 .38597 L
.43993 .38596 L
.4399 .38595 L
.43987 .38594 L
.43983 .38592 L
.4398 .38591 L
.43977 .3859 L
.43974 .38588 L
.4397 .38587 L
.43967 .38585 L
.43964 .38584 L
.43961 .38583 L
.43958 .38581 L
.43954 .3858 L
.43951 .38579 L
.43948 .38577 L
.43945 .38576 L
.43942 .38575 L
.43939 .38573 L
.43935 .38572 L
.43932 .3857 L
.43929 .38569 L
.43926 .38568 L
.43923 .38566 L
.4392 .38565 L
.43917 .38564 L
.43914 .38562 L
.4391 .38561 L
.43907 .38559 L
.43904 .38558 L
.43901 .38556 L
.43898 .38555 L
.43895 .38554 L
.43892 .38552 L
.43889 .38551 L
.43886 .38549 L
Mistroke
.43883 .38548 L
.4388 .38546 L
.43876 .38545 L
.43873 .38544 L
.4387 .38542 L
.43867 .38541 L
.43864 .38539 L
.43861 .38538 L
.43858 .38536 L
.43855 .38535 L
.43852 .38533 L
.43849 .38532 L
.43846 .3853 L
.43843 .38529 L
.4384 .38528 L
.43837 .38526 L
.43834 .38525 L
.43831 .38523 L
.43828 .38522 L
.43825 .3852 L
.43822 .38519 L
.43819 .38517 L
.43816 .38516 L
.43813 .38514 L
.4381 .38513 L
.43808 .38511 L
.43805 .3851 L
.43802 .38508 L
.43799 .38506 L
.43796 .38505 L
.43793 .38503 L
.4379 .38502 L
.43787 .385 L
.43784 .38499 L
.43781 .38497 L
.43778 .38496 L
.43775 .38494 L
.43773 .38493 L
.4377 .38491 L
.43767 .3849 L
.43764 .38488 L
.43761 .38486 L
.43758 .38485 L
.43755 .38483 L
.43752 .38482 L
.4375 .3848 L
.43747 .38479 L
.43744 .38477 L
.43741 .38475 L
.43738 .38474 L
Mistroke
.43735 .38472 L
.43733 .38471 L
.4373 .38469 L
.43727 .38467 L
.43724 .38466 L
.43721 .38464 L
.43719 .38463 L
.43716 .38461 L
.43713 .38459 L
.4371 .38458 L
.43708 .38456 L
.43705 .38455 L
.43702 .38453 L
.43699 .38451 L
.43697 .3845 L
.43694 .38448 L
.43691 .38446 L
.43688 .38445 L
.43686 .38443 L
.43683 .38441 L
.4368 .3844 L
.43677 .38438 L
.43675 .38436 L
.43672 .38435 L
.43669 .38433 L
.43667 .38431 L
.43664 .3843 L
.43661 .38428 L
.43659 .38426 L
.43656 .38425 L
.43653 .38423 L
.4365 .38421 L
.43648 .3842 L
.43645 .38418 L
.43643 .38416 L
.4364 .38415 L
.43637 .38413 L
.43635 .38411 L
.43632 .3841 L
.43629 .38408 L
.43627 .38406 L
.43624 .38405 L
.43621 .38403 L
.43619 .38401 L
.43616 .38399 L
.43614 .38398 L
.43611 .38396 L
.43608 .38394 L
.43606 .38392 L
.43603 .38391 L
Mistroke
.43601 .38389 L
.43598 .38387 L
.43596 .38386 L
.43593 .38384 L
.4359 .38382 L
.43588 .3838 L
.43585 .38379 L
.43583 .38377 L
.4358 .38375 L
.43578 .38373 L
.43575 .38372 L
.43573 .3837 L
.4357 .38368 L
.43568 .38366 L
.43565 .38365 L
.43563 .38363 L
.4356 .38361 L
.43558 .38359 L
.43555 .38357 L
.43553 .38356 L
.4355 .38354 L
.43548 .38352 L
.43545 .3835 L
.43543 .38348 L
.4354 .38347 L
.43538 .38345 L
.43535 .38343 L
.43533 .38341 L
.4353 .38339 L
.43528 .38338 L
.43526 .38336 L
.43523 .38334 L
.43521 .38332 L
.43518 .3833 L
.43516 .38329 L
.43514 .38327 L
.43511 .38325 L
.43509 .38323 L
.43506 .38321 L
.43504 .38319 L
.43502 .38318 L
.43499 .38316 L
.43497 .38314 L
.43494 .38312 L
.43492 .3831 L
.4349 .38308 L
.43487 .38307 L
.43485 .38305 L
.43483 .38303 L
.4348 .38301 L
Mistroke
.43478 .38299 L
.43476 .38297 L
.43473 .38295 L
.43471 .38294 L
.43469 .38292 L
.43466 .3829 L
.43464 .38288 L
.43462 .38286 L
.43459 .38284 L
.43457 .38282 L
.43455 .3828 L
.43453 .38279 L
.4345 .38277 L
.43448 .38275 L
.43446 .38273 L
.43443 .38271 L
.43441 .38269 L
.43439 .38267 L
.43437 .38265 L
.43434 .38263 L
.43432 .38261 L
.4343 .3826 L
.43428 .38258 L
.43425 .38256 L
.43423 .38254 L
.43421 .38252 L
.43419 .3825 L
.43417 .38248 L
.43414 .38246 L
.43412 .38244 L
.4341 .38242 L
.43408 .3824 L
.43406 .38238 L
.43403 .38237 L
.43401 .38235 L
.43399 .38233 L
.43397 .38231 L
.43395 .38229 L
.43392 .38227 L
.4339 .38225 L
.43388 .38223 L
.43386 .38221 L
.43384 .38219 L
.43382 .38217 L
.4338 .38215 L
.43377 .38213 L
.43375 .38211 L
.43373 .38209 L
.43371 .38207 L
.43369 .38205 L
Mistroke
.43367 .38203 L
.43365 .38201 L
.43363 .38199 L
.43361 .38197 L
.43359 .38195 L
.43356 .38193 L
.43354 .38191 L
.43352 .38189 L
.4335 .38187 L
.43348 .38185 L
.43346 .38183 L
.43344 .38181 L
.43342 .38179 L
.4334 .38177 L
.43338 .38175 L
.43336 .38173 L
.43334 .38171 L
.43332 .38169 L
.4333 .38167 L
.43328 .38165 L
.43326 .38163 L
.43324 .38161 L
.43322 .38159 L
.4332 .38157 L
.43318 .38155 L
.43316 .38153 L
.43314 .38151 L
.43312 .38149 L
.4331 .38147 L
.43308 .38145 L
.43306 .38143 L
.43304 .38141 L
.43302 .38139 L
.433 .38137 L
.43298 .38135 L
.43296 .38133 L
.43294 .38131 L
.43292 .38129 L
.4329 .38127 L
.43288 .38125 L
.43286 .38123 L
.43284 .38121 L
.43282 .38119 L
.43281 .38116 L
.43279 .38114 L
.43277 .38112 L
.43275 .3811 L
.43273 .38108 L
.43271 .38106 L
.43269 .38104 L
Mistroke
.43267 .38102 L
.43265 .381 L
.43264 .38098 L
.43262 .38096 L
.4326 .38094 L
.43258 .38092 L
.43256 .38089 L
.43254 .38087 L
.43252 .38085 L
.43251 .38083 L
.43249 .38081 L
.43247 .38079 L
.43245 .38077 L
.43243 .38075 L
.43241 .38073 L
.4324 .38071 L
.43238 .38069 L
.43236 .38066 L
.43234 .38064 L
.43232 .38062 L
.43231 .3806 L
.43229 .38058 L
.43227 .38056 L
.43225 .38054 L
.43223 .38052 L
.43222 .3805 L
.4322 .38047 L
.43218 .38045 L
.43216 .38043 L
.43215 .38041 L
.43213 .38039 L
.43211 .38037 L
.43209 .38035 L
.43208 .38033 L
.43206 .3803 L
.43204 .38028 L
.43202 .38026 L
.43201 .38024 L
.43199 .38022 L
.43197 .3802 L
.43196 .38018 L
.43194 .38015 L
.43192 .38013 L
.43191 .38011 L
.43189 .38009 L
.43187 .38007 L
.43185 .38005 L
.43184 .38002 L
.43182 .38 L
.4318 .37998 L
Mistroke
.43179 .37996 L
.43177 .37994 L
.43175 .37992 L
.43174 .37989 L
.43172 .37987 L
.43171 .37985 L
.43169 .37983 L
.43167 .37981 L
.43166 .37979 L
.43164 .37976 L
.43162 .37974 L
.43161 .37972 L
.43159 .3797 L
.43158 .37968 L
.43156 .37966 L
.43154 .37963 L
.43153 .37961 L
.43151 .37959 L
.4315 .37957 L
.43148 .37955 L
.43146 .37952 L
.43145 .3795 L
.43143 .37948 L
.43142 .37946 L
.4314 .37944 L
.43139 .37941 L
.43137 .37939 L
.43135 .37937 L
.43134 .37935 L
.43132 .37933 L
.43131 .3793 L
.43129 .37928 L
.43128 .37926 L
.43126 .37924 L
.43125 .37921 L
.43123 .37919 L
.43122 .37917 L
.4312 .37915 L
.43119 .37913 L
.43117 .3791 L
.43116 .37908 L
.43114 .37906 L
.43113 .37904 L
.43111 .37901 L
.4311 .37899 L
.43108 .37897 L
.43107 .37895 L
.43105 .37893 L
.43104 .3789 L
.43102 .37888 L
Mistroke
.43101 .37886 L
.431 .37884 L
.43098 .37881 L
.43097 .37879 L
.43095 .37877 L
.43094 .37875 L
.43092 .37872 L
.43091 .3787 L
.4309 .37868 L
.43088 .37866 L
.43087 .37863 L
.43085 .37861 L
.43084 .37859 L
.43083 .37857 L
.43081 .37854 L
.4308 .37852 L
.43078 .3785 L
.43077 .37848 L
.43076 .37845 L
.43074 .37843 L
.43073 .37841 L
.43071 .37838 L
.4307 .37836 L
.43069 .37834 L
.43067 .37832 L
.43066 .37829 L
.43065 .37827 L
.43063 .37825 L
.43062 .37823 L
.43061 .3782 L
.43059 .37818 L
.43058 .37816 L
.43057 .37813 L
.43055 .37811 L
.43054 .37809 L
.43053 .37807 L
.43051 .37804 L
.4305 .37802 L
.43049 .378 L
.43048 .37797 L
.43046 .37795 L
.43045 .37793 L
.43044 .37791 L
.43042 .37788 L
.43041 .37786 L
.4304 .37784 L
.43039 .37781 L
.43037 .37779 L
.43036 .37777 L
.43035 .37774 L
Mistroke
.43034 .37772 L
.43032 .3777 L
.43031 .37768 L
.4303 .37765 L
.43029 .37763 L
.43027 .37761 L
.43026 .37758 L
.43025 .37756 L
.43024 .37754 L
.43023 .37751 L
.43021 .37749 L
.4302 .37747 L
.43019 .37744 L
.43018 .37742 L
.43017 .3774 L
.43015 .37737 L
.43014 .37735 L
.43013 .37733 L
.43012 .3773 L
.43011 .37728 L
.43009 .37726 L
.43008 .37723 L
.43007 .37721 L
.43006 .37719 L
.43005 .37716 L
.43004 .37714 L
.43003 .37712 L
.43001 .37709 L
.43 .37707 L
.42999 .37705 L
.42998 .37702 L
.42997 .377 L
.42996 .37698 L
.42995 .37695 L
.42994 .37693 L
.42992 .37691 L
.42991 .37688 L
.4299 .37686 L
.42989 .37684 L
.42988 .37681 L
.42987 .37679 L
.42986 .37677 L
.42985 .37674 L
.42984 .37672 L
.42983 .3767 L
.42981 .37667 L
.4298 .37665 L
.42979 .37663 L
.42978 .3766 L
.42977 .37658 L
Mistroke
.42976 .37656 L
.42975 .37653 L
.42974 .37651 L
.42973 .37648 L
.42972 .37646 L
.42971 .37644 L
.4297 .37641 L
.42969 .37639 L
.42968 .37637 L
.42967 .37634 L
.42966 .37632 L
.42965 .3763 L
.42964 .37627 L
.42963 .37625 L
.42962 .37622 L
.42961 .3762 L
.4296 .37618 L
.42959 .37615 L
.42958 .37613 L
.42957 .37611 L
.42956 .37608 L
.42955 .37606 L
.42954 .37603 L
.42953 .37601 L
.42952 .37599 L
.42951 .37596 L
.4295 .37594 L
.42949 .37591 L
.42948 .37589 L
.42947 .37587 L
.42946 .37584 L
.42945 .37582 L
.42945 .3758 L
.42944 .37577 L
.42943 .37575 L
.42942 .37572 L
.42941 .3757 L
.4294 .37568 L
.42939 .37565 L
.42938 .37563 L
.42937 .3756 L
.42936 .37558 L
.42935 .37556 L
.42935 .37553 L
.42934 .37551 L
.42933 .37548 L
.42932 .37546 L
.42931 .37544 L
.4293 .37541 L
.42929 .37539 L
Mistroke
.42928 .37536 L
.42928 .37534 L
.42927 .37532 L
.42926 .37529 L
.42925 .37527 L
.42924 .37524 L
.42923 .37522 L
.42922 .3752 L
.42922 .37517 L
.42921 .37515 L
.4292 .37512 L
.42919 .3751 L
.42918 .37508 L
.42918 .37505 L
.42917 .37503 L
.42916 .375 L
.42915 .37498 L
.42914 .37496 L
.42913 .37493 L
.42913 .37491 L
.42912 .37488 L
.42911 .37486 L
.4291 .37483 L
.4291 .37481 L
.42909 .37479 L
.42908 .37476 L
.42907 .37474 L
.42906 .37471 L
.42906 .37469 L
.42905 .37466 L
.42904 .37464 L
.42903 .37462 L
.42903 .37459 L
.42902 .37457 L
.42901 .37454 L
.429 .37452 L
.429 .3745 L
.42899 .37447 L
.42898 .37445 L
.42898 .37442 L
.42897 .3744 L
.42896 .37437 L
.42895 .37435 L
.42895 .37433 L
.42894 .3743 L
.42893 .37428 L
.42893 .37425 L
.42892 .37423 L
.42891 .3742 L
.42891 .37418 L
Mistroke
.4289 .37415 L
.42889 .37413 L
.42888 .37411 L
.42888 .37408 L
.42887 .37406 L
.42886 .37403 L
.42886 .37401 L
.42885 .37398 L
.42884 .37396 L
.42884 .37394 L
.42883 .37391 L
.42883 .37389 L
.42882 .37386 L
.42881 .37384 L
.42881 .37381 L
.4288 .37379 L
.42879 .37376 L
.42879 .37374 L
.42878 .37372 L
.42878 .37369 L
.42877 .37367 L
.42876 .37364 L
.42876 .37362 L
.42875 .37359 L
.42874 .37357 L
.42874 .37354 L
.42873 .37352 L
.42873 .3735 L
.42872 .37347 L
.42872 .37345 L
.42871 .37342 L
.4287 .3734 L
.4287 .37337 L
.42869 .37335 L
.42869 .37332 L
.42868 .3733 L
.42868 .37327 L
.42867 .37325 L
.42866 .37323 L
.42866 .3732 L
.42865 .37318 L
.42865 .37315 L
.42864 .37313 L
.42864 .3731 L
.42863 .37308 L
.42863 .37305 L
.42862 .37303 L
.42862 .373 L
.42861 .37298 L
.42861 .37296 L
Mistroke
.4286 .37293 L
.4286 .37291 L
.42859 .37288 L
.42859 .37286 L
.42858 .37283 L
.42858 .37281 L
.42857 .37278 L
.42857 .37276 L
.42856 .37273 L
.42856 .37271 L
.42855 .37268 L
.42855 .37266 L
.42854 .37264 L
.42854 .37261 L
.42853 .37259 L
.42853 .37256 L
.42852 .37254 L
.42852 .37251 L
.42851 .37249 L
.42851 .37246 L
.42851 .37244 L
.4285 .37241 L
.4285 .37239 L
.42849 .37236 L
.42849 .37234 L
.42848 .37232 L
.42848 .37229 L
.42848 .37227 L
.42847 .37224 L
.42847 .37222 L
.42846 .37219 L
.42846 .37217 L
.42846 .37214 L
.42845 .37212 L
.42845 .37209 L
.42844 .37207 L
.42844 .37204 L
.42844 .37202 L
.42843 .37199 L
.42843 .37197 L
.42842 .37194 L
.42842 .37192 L
.42842 .3719 L
.42841 .37187 L
.42841 .37185 L
.42841 .37182 L
.4284 .3718 L
.4284 .37177 L
.42839 .37175 L
.42839 .37172 L
Mistroke
.42839 .3717 L
.42838 .37167 L
.42838 .37165 L
.42838 .37162 L
.42837 .3716 L
.42837 .37157 L
.42837 .37155 L
.42836 .37152 L
.42836 .3715 L
.42836 .37147 L
.42836 .37145 L
.42835 .37143 L
.42835 .3714 L
.42835 .37138 L
.42834 .37135 L
.42834 .37133 L
.42834 .3713 L
.42833 .37128 L
.42833 .37125 L
.42833 .37123 L
.42833 .3712 L
.42832 .37118 L
.42832 .37115 L
.42832 .37113 L
.42831 .3711 L
.42831 .37108 L
.42831 .37105 L
.42831 .37103 L
.4283 .371 L
.4283 .37098 L
.4283 .37095 L
.4283 .37093 L
.42829 .37091 L
.42829 .37088 L
.42829 .37086 L
.42829 .37083 L
.42828 .37081 L
.42828 .37078 L
.42828 .37076 L
.42828 .37073 L
.42828 .37071 L
.42827 .37068 L
.42827 .37066 L
.42827 .37063 L
.42827 .37061 L
.42826 .37058 L
.42826 .37056 L
.42826 .37053 L
.42826 .37051 L
.42826 .37048 L
Mistroke
.42826 .37046 L
.42825 .37043 L
.42825 .37041 L
.42825 .37038 L
.42825 .37036 L
.42825 .37034 L
.42824 .37031 L
.42824 .37029 L
.42824 .37026 L
.42824 .37024 L
.42824 .37021 L
.42824 .37019 L
.42823 .37016 L
.42823 .37014 L
.42823 .37011 L
.42823 .37009 L
.42823 .37006 L
.42823 .37004 L
.42823 .37001 L
.42823 .36999 L
.42822 .36996 L
.42822 .36994 L
.42822 .36991 L
.42822 .36989 L
.42822 .36986 L
.42822 .36984 L
.42822 .36981 L
.42822 .36979 L
.42821 .36976 L
.42821 .36974 L
.42821 .36972 L
.42821 .36969 L
.42821 .36967 L
.42821 .36964 L
.42821 .36962 L
.42821 .36959 L
.42821 .36957 L
.42821 .36954 L
.42821 .36952 L
.4282 .36949 L
.4282 .36947 L
.4282 .36944 L
.4282 .36942 L
.4282 .36939 L
.4282 .36937 L
.4282 .36934 L
.4282 .36932 L
.4282 .36929 L
.4282 .36927 L
.4282 .36924 L
Mistroke
.4282 .36922 L
.4282 .36919 L
.4282 .36917 L
.4282 .36915 L
.4282 .36912 L
.4282 .3691 L
.4282 .36907 L
.4282 .36905 L
.4282 .36902 L
.4282 .369 L
.4282 .36897 L
.4282 .36895 L
.4282 .36892 L
.4282 .3689 L
.4282 .36887 L
.4282 .36885 L
.4282 .36882 L
.4282 .3688 L
.4282 .36877 L
.4282 .36875 L
.4282 .36872 L
.4282 .3687 L
.4282 .36868 L
.4282 .36865 L
.4282 .36863 L
.4282 .3686 L
.4282 .36858 L
.4282 .36855 L
.4282 .36853 L
.4282 .3685 L
.4282 .36848 L
.4282 .36845 L
.4282 .36843 L
.4282 .3684 L
.4282 .36838 L
.4282 .36835 L
.4282 .36833 L
.4282 .3683 L
.4282 .36828 L
.42821 .36825 L
.42821 .36823 L
.42821 .36821 L
.42821 .36818 L
.42821 .36816 L
.42821 .36813 L
.42821 .36811 L
.42821 .36808 L
.42821 .36806 L
.42821 .36803 L
.42821 .36801 L
Mistroke
.42822 .36798 L
.42822 .36796 L
.42822 .36793 L
.42822 .36791 L
.42822 .36788 L
.42822 .36786 L
.42822 .36784 L
.42822 .36781 L
.42822 .36779 L
.42823 .36776 L
.42823 .36774 L
.42823 .36771 L
.42823 .36769 L
.42823 .36766 L
.42823 .36764 L
.42823 .36761 L
.42823 .36759 L
.42824 .36756 L
.42824 .36754 L
.42824 .36751 L
.42824 .36749 L
.42824 .36747 L
.42824 .36744 L
.42825 .36742 L
.42825 .36739 L
.42825 .36737 L
.42825 .36734 L
.42825 .36732 L
.42825 .36729 L
.42826 .36727 L
.42826 .36724 L
.42826 .36722 L
.42826 .36719 L
.42826 .36717 L
.42827 .36715 L
.42827 .36712 L
.42827 .3671 L
.42827 .36707 L
.42827 .36705 L
.42828 .36702 L
.42828 .367 L
.42828 .36697 L
.42828 .36695 L
.42828 .36692 L
.42829 .3669 L
.42829 .36688 L
.42829 .36685 L
.42829 .36683 L
.4283 .3668 L
.4283 .36678 L
Mistroke
.4283 .36675 L
.4283 .36673 L
.4283 .3667 L
.42831 .36668 L
.42831 .36665 L
.42831 .36663 L
.42831 .36661 L
.42832 .36658 L
.42832 .36656 L
.42832 .36653 L
.42832 .36651 L
.42833 .36648 L
.42833 .36646 L
.42833 .36643 L
.42834 .36641 L
.42834 .36639 L
.42834 .36636 L
.42834 .36634 L
.42835 .36631 L
.42835 .36629 L
.42835 .36626 L
.42835 .36624 L
.42836 .36621 L
.42836 .36619 L
.42836 .36617 L
.42837 .36614 L
.42837 .36612 L
.42837 .36609 L
.42838 .36607 L
.42838 .36604 L
.42838 .36602 L
.42839 .36599 L
.42839 .36597 L
.42839 .36595 L
.42839 .36592 L
.4284 .3659 L
.4284 .36587 L
.4284 .36585 L
.42841 .36582 L
.42841 .3658 L
.42841 .36578 L
.42842 .36575 L
.42842 .36573 L
.42842 .3657 L
.42843 .36568 L
.42843 .36565 L
.42843 .36563 L
.42844 .36561 L
.42844 .36558 L
.42845 .36556 L
Mistroke
.42845 .36553 L
.42845 .36551 L
.42846 .36548 L
.42846 .36546 L
.42846 .36544 L
.42847 .36541 L
.42847 .36539 L
.42848 .36536 L
.42848 .36534 L
.42848 .36531 L
.42849 .36529 L
.42849 .36527 L
.42849 .36524 L
.4285 .36522 L
.4285 .36519 L
.42851 .36517 L
.42851 .36514 L
.42851 .36512 L
.42852 .3651 L
.42852 .36507 L
.42853 .36505 L
.42853 .36502 L
.42853 .365 L
.42854 .36498 L
.42854 .36495 L
.42855 .36493 L
.42855 .3649 L
.42856 .36488 L
.42856 .36485 L
.42856 .36483 L
.42857 .36481 L
.42857 .36478 L
.42858 .36476 L
.42858 .36473 L
.42859 .36471 L
.42859 .36469 L
.42859 .36466 L
.4286 .36464 L
.4286 .36461 L
.42861 .36459 L
.42861 .36457 L
.42862 .36454 L
.42862 .36452 L
.42863 .36449 L
.42863 .36447 L
.42864 .36445 L
.42864 .36442 L
.42865 .3644 L
.42865 .36437 L
.42865 .36435 L
Mistroke
.42866 .36433 L
.42866 .3643 L
.42867 .36428 L
.42867 .36425 L
.42868 .36423 L
.42868 .36421 L
.42869 .36418 L
.42869 .36416 L
.4287 .36413 L
.4287 .36411 L
.42871 .36409 L
.42871 .36406 L
.42872 .36404 L
.42872 .36401 L
.42873 .36399 L
.42873 .36397 L
.42874 .36394 L
.42874 .36392 L
.42875 .36389 L
.42875 .36387 L
.42876 .36385 L
.42876 .36382 L
.42877 .3638 L
.42878 .36377 L
.42878 .36375 L
.42879 .36373 L
.42879 .3637 L
.4288 .36368 L
.4288 .36366 L
.42881 .36363 L
.42881 .36361 L
.42882 .36358 L
.42882 .36356 L
.42883 .36354 L
.42884 .36351 L
.42884 .36349 L
.42885 .36347 L
.42885 .36344 L
.42886 .36342 L
.42886 .36339 L
.42887 .36337 L
.42887 .36335 L
.42888 .36332 L
.42889 .3633 L
.42889 .36328 L
.4289 .36325 L
.4289 .36323 L
.42891 .3632 L
.42891 .36318 L
.42892 .36316 L
Mistroke
.42893 .36313 L
.42893 .36311 L
.42894 .36309 L
.42894 .36306 L
.42895 .36304 L
.42896 .36302 L
.42896 .36299 L
.42897 .36297 L
.42897 .36294 L
.42898 .36292 L
.42899 .3629 L
.42899 .36287 L
.429 .36285 L
.429 .36283 L
.42901 .3628 L
.42902 .36278 L
.42902 .36276 L
.42903 .36273 L
.42904 .36271 L
.42904 .36269 L
.42905 .36266 L
.42905 .36264 L
.42906 .36262 L
.42907 .36259 L
.42907 .36257 L
.42908 .36254 L
.42909 .36252 L
.42909 .3625 L
.4291 .36247 L
.42911 .36245 L
.42911 .36243 L
.42912 .3624 L
.42913 .36238 L
.42913 .36236 L
.42914 .36233 L
.42915 .36231 L
.42915 .36229 L
.42916 .36226 L
.42917 .36224 L
.42917 .36222 L
.42918 .36219 L
.42919 .36217 L
.42919 .36215 L
.4292 .36212 L
.42921 .3621 L
.42921 .36208 L
.42922 .36205 L
.42923 .36203 L
.42923 .36201 L
.42924 .36198 L
Mistroke
.42925 .36196 L
.42925 .36194 L
.42926 .36191 L
.42927 .36189 L
.42927 .36187 L
.42928 .36184 L
.42929 .36182 L
.4293 .3618 L
.4293 .36177 L
.42931 .36175 L
.42932 .36173 L
.42932 .36171 L
.42933 .36168 L
.42934 .36166 L
.42935 .36164 L
.42935 .36161 L
.42936 .36159 L
.42937 .36157 L
.42937 .36154 L
.42938 .36152 L
.42939 .3615 L
.4294 .36147 L
.4294 .36145 L
.42941 .36143 L
.42942 .3614 L
.42943 .36138 L
.42943 .36136 L
.42944 .36134 L
.42945 .36131 L
.42946 .36129 L
.42946 .36127 L
.42947 .36124 L
.42948 .36122 L
.42949 .3612 L
.42949 .36117 L
.4295 .36115 L
.42951 .36113 L
.42952 .36111 L
.42952 .36108 L
.42953 .36106 L
.42954 .36104 L
.42955 .36101 L
.42955 .36099 L
.42956 .36097 L
.42957 .36095 L
.42958 .36092 L
.42959 .3609 L
.42959 .36088 L
.4296 .36085 L
.42961 .36083 L
Mistroke
.42962 .36081 L
.42962 .36079 L
.42963 .36076 L
.42964 .36074 L
.42965 .36072 L
.42966 .36069 L
.42966 .36067 L
.42967 .36065 L
.42968 .36063 L
.42969 .3606 L
.4297 .36058 L
.4297 .36056 L
.42971 .36054 L
.42972 .36051 L
.42973 .36049 L
.42974 .36047 L
.42974 .36044 L
.42975 .36042 L
.42976 .3604 L
.42977 .36038 L
.42978 .36035 L
.42979 .36033 L
.42979 .36031 L
.4298 .36029 L
.42981 .36026 L
.42982 .36024 L
.42983 .36022 L
.42984 .3602 L
.42984 .36017 L
.42985 .36015 L
.42986 .36013 L
.42987 .36011 L
.42988 .36008 L
.42989 .36006 L
.42989 .36004 L
.4299 .36002 L
.42991 .35999 L
.42992 .35997 L
.42993 .35995 L
.42994 .35993 L
.42995 .3599 L
.42995 .35988 L
.42996 .35986 L
.42997 .35984 L
.42998 .35981 L
.42999 .35979 L
.43 .35977 L
.43001 .35975 L
.43002 .35972 L
.43002 .3597 L
Mistroke
.43003 .35968 L
.43004 .35966 L
.43005 .35964 L
.43006 .35961 L
.43007 .35959 L
.43008 .35957 L
.43009 .35955 L
.43009 .35952 L
.4301 .3595 L
.43011 .35948 L
.43012 .35946 L
.43013 .35943 L
.43014 .35941 L
.43015 .35939 L
.43016 .35937 L
.43017 .35935 L
.43017 .35932 L
.43018 .3593 L
.43019 .35928 L
.4302 .35926 L
.43021 .35924 L
.43022 .35921 L
.43023 .35919 L
.43024 .35917 L
.43025 .35915 L
.43026 .35912 L
.43027 .3591 L
.43028 .35908 L
.43028 .35906 L
.43029 .35904 L
.4303 .35901 L
.43031 .35899 L
.43032 .35897 L
.43033 .35895 L
.43034 .35893 L
.43035 .3589 L
.43036 .35888 L
.43037 .35886 L
.43038 .35884 L
.43039 .35882 L
.4304 .35879 L
.43041 .35877 L
.43041 .35875 L
.43042 .35873 L
.43043 .35871 L
.43044 .35869 L
.43045 .35866 L
.43046 .35864 L
.43047 .35862 L
.43048 .3586 L
Mistroke
.43049 .35858 L
.4305 .35855 L
.43051 .35853 L
.43052 .35851 L
.43053 .35849 L
.43054 .35847 L
.43055 .35845 L
.43056 .35842 L
.43057 .3584 L
.43058 .35838 L
.43059 .35836 L
.4306 .35834 L
.43061 .35832 L
.43062 .35829 L
.43063 .35827 L
.43064 .35825 L
.43065 .35823 L
.43066 .35821 L
.43067 .35819 L
.43068 .35816 L
.43069 .35814 L
.4307 .35812 L
.43071 .3581 L
.43072 .35808 L
.43072 .35806 L
.43073 .35803 L
.43074 .35801 L
.43075 .35799 L
.43076 .35797 L
.43077 .35795 L
.43078 .35793 L
.43079 .35791 L
.4308 .35788 L
.43081 .35786 L
.43083 .35784 L
.43084 .35782 L
.43085 .3578 L
.43086 .35778 L
.43087 .35776 L
.43088 .35773 L
.43089 .35771 L
.4309 .35769 L
.43091 .35767 L
.43092 .35765 L
.43093 .35763 L
.43094 .35761 L
.43095 .35758 L
.43096 .35756 L
.43097 .35754 L
.43098 .35752 L
Mistroke
.43099 .3575 L
.431 .35748 L
.43101 .35746 L
.43102 .35744 L
.43103 .35741 L
.43104 .35739 L
.43105 .35737 L
.43106 .35735 L
.43107 .35733 L
.43108 .35731 L
.43109 .35729 L
.4311 .35727 L
.43111 .35725 L
.43112 .35722 L
.43113 .3572 L
.43114 .35718 L
.43116 .35716 L
.43117 .35714 L
.43118 .35712 L
.43119 .3571 L
.4312 .35708 L
.43121 .35706 L
.43122 .35704 L
.43123 .35701 L
.43124 .35699 L
.43125 .35697 L
.43126 .35695 L
.43127 .35693 L
.43128 .35691 L
.43129 .35689 L
.4313 .35687 L
.43131 .35685 L
.43133 .35683 L
.43134 .35681 L
.43135 .35678 L
.43136 .35676 L
.43137 .35674 L
.43138 .35672 L
.43139 .3567 L
.4314 .35668 L
.43141 .35666 L
.43142 .35664 L
.43143 .35662 L
.43144 .3566 L
.43146 .35658 L
.43147 .35656 L
.43148 .35653 L
.43149 .35651 L
.4315 .35649 L
.43151 .35647 L
Mistroke
.43152 .35645 L
.43153 .35643 L
.43154 .35641 L
.43155 .35639 L
.43157 .35637 L
.43158 .35635 L
.43159 .35633 L
.4316 .35631 L
.43161 .35629 L
.43162 .35627 L
.43163 .35625 L
.43164 .35623 L
.43165 .35621 L
.43167 .35618 L
.43168 .35616 L
.43169 .35614 L
.4317 .35612 L
.43171 .3561 L
.43172 .35608 L
.43173 .35606 L
.43174 .35604 L
.43175 .35602 L
.43177 .356 L
.43178 .35598 L
.43179 .35596 L
.4318 .35594 L
.43181 .35592 L
.43182 .3559 L
.43183 .35588 L
.43185 .35586 L
.43186 .35584 L
.43187 .35582 L
.43188 .3558 L
.43189 .35578 L
.4319 .35576 L
.43191 .35574 L
.43193 .35572 L
.43194 .3557 L
.43195 .35568 L
.43196 .35566 L
.43197 .35564 L
.43198 .35562 L
.43199 .3556 L
.43201 .35558 L
.43202 .35556 L
.43203 .35554 L
.43204 .35551 L
.43205 .35549 L
.43206 .35547 L
.43207 .35545 L
Mistroke
.43209 .35543 L
.4321 .35541 L
.43211 .35539 L
.43212 .35537 L
.43213 .35535 L
.43214 .35533 L
.43216 .35531 L
.43217 .35529 L
.43218 .35527 L
.43219 .35525 L
.4322 .35523 L
.43221 .35522 L
.43223 .3552 L
.43224 .35518 L
.43225 .35516 L
.43226 .35514 L
.43227 .35512 L
.43229 .3551 L
.4323 .35508 L
.43231 .35506 L
.43232 .35504 L
.43233 .35502 L
.43234 .355 L
.43236 .35498 L
.43237 .35496 L
.43238 .35494 L
.43239 .35492 L
.4324 .3549 L
.43242 .35488 L
.43243 .35486 L
.43244 .35484 L
.43245 .35482 L
.43246 .3548 L
.43248 .35478 L
.43249 .35476 L
.4325 .35474 L
.43251 .35472 L
.43252 .3547 L
.43254 .35468 L
.43255 .35466 L
.43256 .35464 L
.43257 .35462 L
.43258 .3546 L
.4326 .35458 L
.43261 .35457 L
.43262 .35455 L
.43263 .35453 L
.43264 .35451 L
.43266 .35449 L
.43267 .35447 L
Mistroke
.43268 .35445 L
.43269 .35443 L
.43271 .35441 L
.43272 .35439 L
.43273 .35437 L
.43274 .35435 L
.43275 .35433 L
.43277 .35431 L
.43278 .35429 L
.43279 .35427 L
.4328 .35426 L
.43282 .35424 L
.43283 .35422 L
.43284 .3542 L
.43285 .35418 L
.43286 .35416 L
.43288 .35414 L
.43289 .35412 L
.4329 .3541 L
.43291 .35408 L
.43293 .35406 L
.43294 .35404 L
.43295 .35403 L
.43296 .35401 L
.43298 .35399 L
.43299 .35397 L
.433 .35395 L
.43301 .35393 L
.43303 .35391 L
.43304 .35389 L
.43305 .35387 L
.43306 .35385 L
.43308 .35383 L
.43309 .35382 L
.4331 .3538 L
.43311 .35378 L
.43313 .35376 L
.43314 .35374 L
.43315 .35372 L
.43316 .3537 L
.43318 .35368 L
.43319 .35366 L
.4332 .35365 L
.43321 .35363 L
.43323 .35361 L
.43324 .35359 L
.43325 .35357 L
.43326 .35355 L
.43328 .35353 L
.43329 .35351 L
Mistroke
.4333 .3535 L
.43331 .35348 L
.43333 .35346 L
.43334 .35344 L
.43335 .35342 L
.43336 .3534 L
.43338 .35338 L
.43339 .35336 L
.4334 .35335 L
.43342 .35333 L
.43343 .35331 L
.43344 .35329 L
.43345 .35327 L
.43347 .35325 L
.43348 .35323 L
.43349 .35322 L
.4335 .3532 L
.43352 .35318 L
.43353 .35316 L
.43354 .35314 L
.43356 .35312 L
.43357 .35311 L
.43358 .35309 L
.43359 .35307 L
.43361 .35305 L
.43362 .35303 L
.43363 .35301 L
.43365 .35299 L
.43366 .35298 L
.43367 .35296 L
.43368 .35294 L
.4337 .35292 L
.43371 .3529 L
.43372 .35288 L
.43374 .35287 L
.43375 .35285 L
.43376 .35283 L
.43378 .35281 L
.43379 .35279 L
.4338 .35278 L
.43381 .35276 L
.43383 .35274 L
.43384 .35272 L
.43385 .3527 L
.43387 .35268 L
.43388 .35267 L
.43389 .35265 L
.43391 .35263 L
.43392 .35261 L
.43393 .35259 L
Mistroke
.43394 .35258 L
.43396 .35256 L
.43397 .35254 L
.43398 .35252 L
.434 .3525 L
.43401 .35249 L
.43402 .35247 L
.43404 .35245 L
.43405 .35243 L
.43406 .35241 L
.43408 .3524 L
.43409 .35238 L
.4341 .35236 L
.43412 .35234 L
.43413 .35232 L
.43414 .35231 L
.43415 .35229 L
.43417 .35227 L
.43418 .35225 L
.43419 .35224 L
.43421 .35222 L
.43422 .3522 L
.43423 .35218 L
.43425 .35216 L
.43426 .35215 L
.43427 .35213 L
.43429 .35211 L
.4343 .35209 L
.43431 .35208 L
.43433 .35206 L
.43434 .35204 L
.43435 .35202 L
.43437 .35201 L
.43438 .35199 L
.43439 .35197 L
.43441 .35195 L
.43442 .35193 L
.43443 .35192 L
.43445 .3519 L
.43446 .35188 L
.43447 .35186 L
.43449 .35185 L
.4345 .35183 L
.43451 .35181 L
.43453 .35179 L
.43454 .35178 L
.43455 .35176 L
.43457 .35174 L
.43458 .35173 L
.43459 .35171 L
Mistroke
.43461 .35169 L
.43462 .35167 L
.43464 .35166 L
.43465 .35164 L
.43466 .35162 L
.43468 .3516 L
.43469 .35159 L
.4347 .35157 L
.43472 .35155 L
.43473 .35153 L
.43474 .35152 L
.43476 .3515 L
.43477 .35148 L
.43478 .35147 L
.4348 .35145 L
.43481 .35143 L
.43482 .35141 L
.43484 .3514 L
.43485 .35138 L
.43487 .35136 L
.43488 .35135 L
.43489 .35133 L
.43491 .35131 L
.43492 .3513 L
.43493 .35128 L
.43495 .35126 L
.43496 .35124 L
.43497 .35123 L
.43499 .35121 L
.435 .35119 L
.43501 .35118 L
.43503 .35116 L
.43504 .35114 L
.43506 .35113 L
.43507 .35111 L
.43508 .35109 L
.4351 .35107 L
.43511 .35106 L
.43512 .35104 L
.43514 .35102 L
.43515 .35101 L
.43517 .35099 L
.43518 .35097 L
.43519 .35096 L
.43521 .35094 L
.43522 .35092 L
.43523 .35091 L
.43525 .35089 L
.43526 .35087 L
.43528 .35086 L
Mistroke
.43529 .35084 L
.4353 .35082 L
.43532 .35081 L
.43533 .35079 L
.43534 .35077 L
.43536 .35076 L
.43537 .35074 L
.43539 .35072 L
.4354 .35071 L
.43541 .35069 L
.43543 .35067 L
.43544 .35066 L
.43545 .35064 L
.43547 .35063 L
.43548 .35061 L
.4355 .35059 L
.43551 .35058 L
.43552 .35056 L
.43554 .35054 L
.43555 .35053 L
.43557 .35051 L
.43558 .35049 L
.43559 .35048 L
.43561 .35046 L
.43562 .35045 L
.43564 .35043 L
.43565 .35041 L
.43566 .3504 L
.43568 .35038 L
.43569 .35036 L
.4357 .35035 L
.43572 .35033 L
.43573 .35032 L
.43575 .3503 L
.43576 .35028 L
.43577 .35027 L
.43579 .35025 L
.4358 .35023 L
.43582 .35022 L
.43583 .3502 L
.43584 .35019 L
.43586 .35017 L
.43587 .35015 L
.43589 .35014 L
.4359 .35012 L
.43591 .35011 L
.43593 .35009 L
.43594 .35007 L
.43596 .35006 L
.43597 .35004 L
Mistroke
.43598 .35003 L
.436 .35001 L
.43601 .34999 L
.43603 .34998 L
.43604 .34996 L
.43606 .34995 L
.43607 .34993 L
.43608 .34992 L
.4361 .3499 L
.43611 .34988 L
.43613 .34987 L
.43614 .34985 L
.43615 .34984 L
.43617 .34982 L
.43618 .3498 L
.4362 .34979 L
.43621 .34977 L
.43622 .34976 L
.43624 .34974 L
.43625 .34973 L
.43627 .34971 L
.43628 .34969 L
.43629 .34968 L
.43631 .34966 L
.43632 .34965 L
.43634 .34963 L
.43635 .34962 L
.43637 .3496 L
.43638 .34959 L
.43639 .34957 L
.43641 .34955 L
.43642 .34954 L
.43644 .34952 L
.43645 .34951 L
.43646 .34949 L
.43648 .34948 L
.43649 .34946 L
.43651 .34945 L
.43652 .34943 L
.43654 .34942 L
.43655 .3494 L
.43656 .34939 L
.43658 .34937 L
.43659 .34935 L
.43661 .34934 L
.43662 .34932 L
.43664 .34931 L
.43665 .34929 L
.43666 .34928 L
.43668 .34926 L
Mistroke
.43669 .34925 L
.43671 .34923 L
.43672 .34922 L
.43674 .3492 L
.43675 .34919 L
.43676 .34917 L
.43678 .34916 L
.43679 .34914 L
.43681 .34913 L
.43682 .34911 L
.43684 .3491 L
.43685 .34908 L
.43686 .34907 L
.43688 .34905 L
.43689 .34904 L
.43691 .34902 L
.43692 .34901 L
.43694 .34899 L
.43695 .34898 L
.43696 .34896 L
.43698 .34895 L
.43699 .34893 L
.43701 .34892 L
.43702 .3489 L
.43704 .34889 L
.43705 .34887 L
.43706 .34886 L
.43708 .34884 L
.43709 .34883 L
.43711 .34881 L
.43712 .3488 L
.43714 .34878 L
.43715 .34877 L
.43716 .34875 L
.43718 .34874 L
.43719 .34872 L
.43721 .34871 L
.43722 .3487 L
.43724 .34868 L
.43725 .34867 L
.43727 .34865 L
.43728 .34864 L
.43729 .34862 L
.43731 .34861 L
.43732 .34859 L
.43734 .34858 L
.43735 .34856 L
.43737 .34855 L
.43738 .34854 L
.43739 .34852 L
Mistroke
.43741 .34851 L
.43742 .34849 L
.43744 .34848 L
.43745 .34846 L
.43747 .34845 L
.43748 .34843 L
.4375 .34842 L
.43751 .34841 L
.43752 .34839 L
.43754 .34838 L
.43755 .34836 L
.43757 .34835 L
.43758 .34833 L
.4376 .34832 L
.43761 .34831 L
.43763 .34829 L
.43764 .34828 L
.43765 .34826 L
.43767 .34825 L
.43768 .34823 L
.4377 .34822 L
.43771 .34821 L
.43773 .34819 L
.43774 .34818 L
.43776 .34816 L
.43777 .34815 L
.43779 .34814 L
.4378 .34812 L
.43781 .34811 L
.43783 .34809 L
.43784 .34808 L
.43786 .34806 L
.43787 .34805 L
.43789 .34804 L
.4379 .34802 L
.43792 .34801 L
.43793 .34799 L
.43794 .34798 L
.43796 .34797 L
.43797 .34795 L
.43799 .34794 L
.438 .34793 L
.43802 .34791 L
.43803 .3479 L
.43805 .34788 L
.43806 .34787 L
.43808 .34786 L
.43809 .34784 L
.4381 .34783 L
.43812 .34781 L
Mistroke
.43813 .3478 L
.43815 .34779 L
.43816 .34777 L
.43818 .34776 L
.43819 .34775 L
.43821 .34773 L
.43822 .34772 L
.43824 .34771 L
.43825 .34769 L
.43826 .34768 L
.43828 .34766 L
.43829 .34765 L
.43831 .34764 L
.43832 .34762 L
.43834 .34761 L
.43835 .3476 L
.43837 .34758 L
.43838 .34757 L
.4384 .34756 L
.43841 .34754 L
.43842 .34753 L
.43844 .34752 L
.43845 .3475 L
.43847 .34749 L
.43848 .34748 L
.4385 .34746 L
.43851 .34745 L
.43853 .34744 L
.43854 .34742 L
.43856 .34741 L
.43857 .3474 L
.43858 .34738 L
.4386 .34737 L
.43861 .34736 L
.43863 .34734 L
.43864 .34733 L
.43866 .34732 L
.43867 .3473 L
.43869 .34729 L
.4387 .34728 L
.43872 .34726 L
.43873 .34725 L
.43875 .34724 L
.43876 .34722 L
.43877 .34721 L
.43879 .3472 L
.4388 .34718 L
.43882 .34717 L
.43883 .34716 L
.43885 .34715 L
Mistroke
.43886 .34713 L
.43888 .34712 L
.43889 .34711 L
.43891 .34709 L
.43892 .34708 L
.43894 .34707 L
.43895 .34706 L
.43896 .34704 L
.43898 .34703 L
.43899 .34702 L
.43901 .347 L
.43902 .34699 L
.43904 .34698 L
.43905 .34697 L
.43907 .34695 L
.43908 .34694 L
.4391 .34693 L
.43911 .34691 L
.43913 .3469 L
.43914 .34689 L
.43915 .34688 L
.43917 .34686 L
.43918 .34685 L
.4392 .34684 L
.43921 .34683 L
.43923 .34681 L
.43924 .3468 L
.43926 .34679 L
.43927 .34677 L
.43929 .34676 L
.4393 .34675 L
.43932 .34674 L
.43933 .34672 L
.43934 .34671 L
.43936 .3467 L
.43937 .34669 L
.43939 .34667 L
.4394 .34666 L
.43942 .34665 L
.43943 .34664 L
.43945 .34662 L
.43946 .34661 L
.43948 .3466 L
.43949 .34659 L
.43951 .34658 L
.43952 .34656 L
.43953 .34655 L
.43955 .34654 L
.43956 .34653 L
.43958 .34651 L
Mistroke
.43959 .3465 L
.43961 .34649 L
.43962 .34648 L
.43964 .34646 L
.43965 .34645 L
.43967 .34644 L
.43968 .34643 L
.4397 .34642 L
.43971 .3464 L
.43973 .34639 L
.43974 .34638 L
.43975 .34637 L
.43977 .34635 L
.43978 .34634 L
.4398 .34633 L
.43981 .34632 L
.43983 .34631 L
.43984 .34629 L
.43986 .34628 L
.43987 .34627 L
.43989 .34626 L
.4399 .34625 L
.43992 .34623 L
.43993 .34622 L
.43994 .34621 L
.43996 .3462 L
.43997 .34619 L
.43999 .34618 L
.44 .34616 L
.44002 .34615 L
.44003 .34614 L
.44005 .34613 L
.44006 .34612 L
.44008 .3461 L
.44009 .34609 L
.44011 .34608 L
.44012 .34607 L
.44014 .34606 L
.44015 .34605 L
.44016 .34603 L
.44018 .34602 L
.44019 .34601 L
.44021 .346 L
.44022 .34599 L
.44024 .34598 L
.44025 .34596 L
.44027 .34595 L
.44028 .34594 L
.4403 .34593 L
.44031 .34592 L
Mistroke
.44033 .34591 L
.44034 .34589 L
.44035 .34588 L
.44037 .34587 L
.44038 .34586 L
.4404 .34585 L
.44041 .34584 L
.44043 .34583 L
.44044 .34581 L
.44046 .3458 L
.44047 .34579 L
.44049 .34578 L
.4405 .34577 L
.44052 .34576 L
.44053 .34575 L
.44054 .34573 L
.44056 .34572 L
.44057 .34571 L
.44059 .3457 L
.4406 .34569 L
.44062 .34568 L
.44063 .34567 L
.44065 .34566 L
.44066 .34564 L
.44068 .34563 L
.44069 .34562 L
.44071 .34561 L
.44072 .3456 L
.44073 .34559 L
.44075 .34558 L
.44076 .34557 L
.44078 .34556 L
.44079 .34554 L
.44081 .34553 L
.44082 .34552 L
.44084 .34551 L
.44085 .3455 L
.44087 .34549 L
.44088 .34548 L
.44089 .34547 L
.44091 .34546 L
.44092 .34545 L
.44094 .34543 L
.44095 .34542 L
.44097 .34541 L
.44098 .3454 L
.441 .34539 L
.44101 .34538 L
.44103 .34537 L
.44104 .34536 L
Mistroke
.44106 .34535 L
.44107 .34534 L
.44108 .34533 L
.4411 .34532 L
.44111 .3453 L
.44113 .34529 L
.44114 .34528 L
.44116 .34527 L
.44117 .34526 L
.44119 .34525 L
.4412 .34524 L
.44122 .34523 L
.44123 .34522 L
.44124 .34521 L
.44126 .3452 L
.44127 .34519 L
.44129 .34518 L
.4413 .34517 L
.44132 .34516 L
.44133 .34514 L
.44135 .34513 L
.44136 .34512 L
.44138 .34511 L
.44139 .3451 L
.4414 .34509 L
.44142 .34508 L
.44143 .34507 L
.44145 .34506 L
.44146 .34505 L
.44148 .34504 L
.44149 .34503 L
.44151 .34502 L
.44152 .34501 L
.44154 .345 L
.44155 .34499 L
.44156 .34498 L
.44158 .34497 L
.44159 .34496 L
.44161 .34495 L
.44162 .34494 L
.44164 .34493 L
.44165 .34492 L
.44167 .34491 L
.44168 .3449 L
.44169 .34489 L
.44171 .34488 L
.44172 .34487 L
.44174 .34486 L
.44175 .34485 L
.44177 .34483 L
Mistroke
.44178 .34482 L
.4418 .34481 L
.44181 .3448 L
.44183 .34479 L
.44184 .34478 L
.44185 .34477 L
.44187 .34476 L
.44188 .34475 L
.4419 .34474 L
.44191 .34473 L
.44193 .34472 L
.44194 .34471 L
.44196 .3447 L
.44197 .34469 L
.44198 .34468 L
.442 .34468 L
.44201 .34467 L
.44203 .34466 L
.44204 .34465 L
.44206 .34464 L
.44207 .34463 L
.44209 .34462 L
.4421 .34461 L
.44211 .3446 L
.44213 .34459 L
.44214 .34458 L
.44216 .34457 L
.44217 .34456 L
.44219 .34455 L
.4422 .34454 L
.44222 .34453 L
.44223 .34452 L
.44224 .34451 L
.44226 .3445 L
.44227 .34449 L
.44229 .34448 L
.4423 .34447 L
.44232 .34446 L
.44233 .34445 L
.44234 .34444 L
.44236 .34443 L
.44237 .34442 L
.44239 .34441 L
.4424 .3444 L
.44242 .34439 L
.44243 .34439 L
.44245 .34438 L
.44246 .34437 L
.44247 .34436 L
.44249 .34435 L
Mistroke
.4425 .34434 L
.44252 .34433 L
.44253 .34432 L
.44255 .34431 L
.44256 .3443 L
.44257 .34429 L
.44259 .34428 L
.4426 .34427 L
.44262 .34426 L
.44263 .34425 L
.44265 .34424 L
.44266 .34424 L
.44268 .34423 L
.44269 .34422 L
.4427 .34421 L
.44272 .3442 L
.44273 .34419 L
.44275 .34418 L
.44276 .34417 L
.44278 .34416 L
.44279 .34415 L
.4428 .34414 L
.44282 .34413 L
.44283 .34413 L
.44285 .34412 L
.44286 .34411 L
.44288 .3441 L
.44289 .34409 L
.4429 .34408 L
.44292 .34407 L
.44293 .34406 L
.44295 .34405 L
.44296 .34404 L
.44298 .34404 L
.44299 .34403 L
.443 .34402 L
.44302 .34401 L
.44303 .344 L
.44305 .34399 L
.44306 .34398 L
.44308 .34397 L
.44309 .34397 L
.4431 .34396 L
.44312 .34395 L
.44313 .34394 L
.44315 .34393 L
.44316 .34392 L
.44317 .34391 L
.44319 .3439 L
.4432 .3439 L
Mistroke
.44322 .34389 L
.44323 .34388 L
.44325 .34387 L
.44326 .34386 L
.44327 .34385 L
.44329 .34384 L
.4433 .34383 L
.44332 .34383 L
.44333 .34382 L
.44334 .34381 L
.44336 .3438 L
.44337 .34379 L
.44339 .34378 L
.4434 .34377 L
.44342 .34377 L
.44343 .34376 L
.44344 .34375 L
.44346 .34374 L
.44347 .34373 L
.44349 .34372 L
.4435 .34372 L
.44351 .34371 L
.44353 .3437 L
.44354 .34369 L
.44356 .34368 L
.44357 .34367 L
.44359 .34367 L
.4436 .34366 L
.44361 .34365 L
.44363 .34364 L
.44364 .34363 L
.44366 .34362 L
.44367 .34362 L
.44368 .34361 L
.4437 .3436 L
.44371 .34359 L
.44373 .34358 L
.44374 .34357 L
.44375 .34357 L
.44377 .34356 L
.44378 .34355 L
.4438 .34354 L
.44381 .34353 L
.44382 .34353 L
.44384 .34352 L
.44385 .34351 L
.44387 .3435 L
.44388 .34349 L
.44389 .34349 L
.44391 .34348 L
Mistroke
.44392 .34347 L
.44394 .34346 L
.44395 .34345 L
.44396 .34345 L
.44398 .34344 L
.44399 .34343 L
.44401 .34342 L
.44402 .34341 L
.44403 .34341 L
.44405 .3434 L
.44406 .34339 L
.44408 .34338 L
.44409 .34337 L
.4441 .34337 L
.44412 .34336 L
.44413 .34335 L
.44415 .34334 L
.44416 .34334 L
.44417 .34333 L
.44419 .34332 L
.4442 .34331 L
.44422 .3433 L
.44423 .3433 L
.44424 .34329 L
.44426 .34328 L
.44427 .34327 L
.44429 .34327 L
.4443 .34326 L
.44431 .34325 L
.44433 .34324 L
.44434 .34324 L
.44436 .34323 L
.44437 .34322 L
.44438 .34321 L
.4444 .34321 L
.44441 .3432 L
.44442 .34319 L
.44444 .34318 L
.44445 .34318 L
.44447 .34317 L
.44448 .34316 L
.44449 .34315 L
.44451 .34315 L
.44452 .34314 L
.44454 .34313 L
.44455 .34312 L
.44456 .34312 L
.44458 .34311 L
.44459 .3431 L
.4446 .34309 L
Mistroke
.44462 .34309 L
.44463 .34308 L
.44465 .34307 L
.44466 .34307 L
.44467 .34306 L
.44469 .34305 L
.4447 .34304 L
.44471 .34304 L
.44473 .34303 L
.44474 .34302 L
.44476 .34301 L
.44477 .34301 L
.44478 .343 L
.4448 .34299 L
.44481 .34299 L
.44482 .34298 L
.44484 .34297 L
.44485 .34296 L
.44487 .34296 L
.44488 .34295 L
.44489 .34294 L
.44491 .34294 L
.44492 .34293 L
.44493 .34292 L
.44495 .34292 L
.44496 .34291 L
.44497 .3429 L
.44499 .34289 L
.445 .34289 L
.44502 .34288 L
.44503 .34287 L
.44504 .34287 L
.44506 .34286 L
.44507 .34285 L
.44508 .34285 L
.4451 .34284 L
.44511 .34283 L
.44512 .34283 L
.44514 .34282 L
.44515 .34281 L
.44517 .34281 L
.44518 .3428 L
.44519 .34279 L
.44521 .34279 L
.44522 .34278 L
.44523 .34277 L
.44525 .34276 L
.44526 .34276 L
.44527 .34275 L
.44529 .34274 L
Mistroke
.4453 .34274 L
.44532 .34273 L
.44533 .34272 L
.44534 .34272 L
.44536 .34271 L
.44537 .34271 L
.44538 .3427 L
.4454 .34269 L
.44541 .34269 L
.44542 .34268 L
.44544 .34267 L
.44545 .34267 L
.44546 .34266 L
.44548 .34265 L
.44549 .34265 L
.4455 .34264 L
.44552 .34263 L
.44553 .34263 L
.44554 .34262 L
.44556 .34261 L
.44557 .34261 L
.44558 .3426 L
.4456 .3426 L
.44561 .34259 L
.44563 .34258 L
.44564 .34258 L
.44565 .34257 L
.44567 .34256 L
.44568 .34256 L
.44569 .34255 L
.44571 .34254 L
.44572 .34254 L
.44573 .34253 L
.44575 .34253 L
.44576 .34252 L
.44577 .34251 L
.44579 .34251 L
.4458 .3425 L
.44581 .3425 L
.44583 .34249 L
.44584 .34248 L
.44585 .34248 L
.44587 .34247 L
.44588 .34246 L
.44589 .34246 L
.44591 .34245 L
.44592 .34245 L
.44593 .34244 L
.44595 .34243 L
.44596 .34243 L
Mistroke
.44597 .34242 L
.44599 .34242 L
.446 .34241 L
.44601 .3424 L
.44603 .3424 L
.44604 .34239 L
.44605 .34239 L
.44606 .34238 L
.44608 .34237 L
.44609 .34237 L
.4461 .34236 L
.44612 .34236 L
.44613 .34235 L
.44614 .34235 L
.44616 .34234 L
.44617 .34233 L
.44618 .34233 L
.4462 .34232 L
.44621 .34232 L
.44622 .34231 L
.44624 .3423 L
.44625 .3423 L
.44626 .34229 L
.44628 .34229 L
.44629 .34228 L
.4463 .34228 L
.44632 .34227 L
.44633 .34226 L
.44634 .34226 L
.44635 .34225 L
.44637 .34225 L
.44638 .34224 L
.44639 .34224 L
.44641 .34223 L
.44642 .34223 L
.44643 .34222 L
.44645 .34221 L
.44646 .34221 L
.44647 .3422 L
.44649 .3422 L
.4465 .34219 L
.44651 .34219 L
.44652 .34218 L
.44654 .34218 L
.44655 .34217 L
.44656 .34217 L
.44658 .34216 L
.44659 .34215 L
.4466 .34215 L
.44662 .34214 L
Mistroke
.44663 .34214 L
.44664 .34213 L
.44665 .34213 L
.44667 .34212 L
.44668 .34212 L
.44669 .34211 L
.44671 .34211 L
.44672 .3421 L
.44673 .3421 L
.44675 .34209 L
.44676 .34209 L
.44677 .34208 L
.44678 .34207 L
.4468 .34207 L
.44681 .34206 L
.44682 .34206 L
.44684 .34205 L
.44685 .34205 L
.44686 .34204 L
.44687 .34204 L
.44689 .34203 L
.4469 .34203 L
.44691 .34202 L
.44693 .34202 L
.44694 .34201 L
.44695 .34201 L
.44696 .342 L
.44698 .342 L
.44699 .34199 L
.447 .34199 L
.44702 .34198 L
.44703 .34198 L
.44704 .34197 L
.44705 .34197 L
.44707 .34196 L
.44708 .34196 L
.44709 .34195 L
.4471 .34195 L
.44712 .34194 L
.44713 .34194 L
.44714 .34193 L
.44716 .34193 L
.44717 .34192 L
.44718 .34192 L
.44719 .34191 L
.44721 .34191 L
.44722 .3419 L
.44723 .3419 L
.44724 .3419 L
.44726 .34189 L
Mistroke
.44727 .34189 L
.44728 .34188 L
.4473 .34188 L
.44731 .34187 L
.44732 .34187 L
.44733 .34186 L
.44735 .34186 L
.44736 .34185 L
.44737 .34185 L
.44738 .34184 L
.4474 .34184 L
.44741 .34183 L
.44742 .34183 L
.44743 .34183 L
.44745 .34182 L
.44746 .34182 L
.44747 .34181 L
.44748 .34181 L
.4475 .3418 L
.44751 .3418 L
.44752 .34179 L
.44753 .34179 L
.44755 .34178 L
.44756 .34178 L
.44757 .34178 L
.44758 .34177 L
.4476 .34177 L
.44761 .34176 L
.44762 .34176 L
.44763 .34175 L
.44765 .34175 L
.44766 .34174 L
.44767 .34174 L
.44768 .34174 L
.4477 .34173 L
.44771 .34173 L
.44772 .34172 L
.44773 .34172 L
.44775 .34171 L
.44776 .34171 L
.44777 .34171 L
.44778 .3417 L
.4478 .3417 L
.44781 .34169 L
.44782 .34169 L
.44783 .34168 L
.44785 .34168 L
.44786 .34168 L
.44787 .34167 L
.44788 .34167 L
Mistroke
.44789 .34166 L
.44791 .34166 L
.44792 .34166 L
.44793 .34165 L
.44794 .34165 L
.44796 .34164 L
.44797 .34164 L
.44798 .34164 L
.44799 .34163 L
.44801 .34163 L
.44802 .34162 L
.44803 .34162 L
.44804 .34162 L
.44805 .34161 L
.44807 .34161 L
.44808 .3416 L
.44809 .3416 L
.4481 .3416 L
.44812 .34159 L
.44813 .34159 L
.44814 .34158 L
.44815 .34158 L
.44816 .34158 L
.44818 .34157 L
.44819 .34157 L
.4482 .34156 L
.44821 .34156 L
.44822 .34156 L
.44824 .34155 L
.44825 .34155 L
.44826 .34155 L
.44827 .34154 L
.44829 .34154 L
.4483 .34153 L
.44831 .34153 L
.44832 .34153 L
.44833 .34152 L
.44835 .34152 L
.44836 .34152 L
.44837 .34151 L
.44838 .34151 L
.44839 .3415 L
.44841 .3415 L
.44842 .3415 L
.44843 .34149 L
.44844 .34149 L
.44845 .34149 L
.44847 .34148 L
.44848 .34148 L
.44849 .34148 L
Mistroke
.4485 .34147 L
.44851 .34147 L
.44853 .34146 L
.44854 .34146 L
.44855 .34146 L
.44856 .34145 L
.44857 .34145 L
.44859 .34145 L
.4486 .34144 L
.44861 .34144 L
.44862 .34144 L
.44863 .34143 L
.44864 .34143 L
.44866 .34143 L
.44867 .34142 L
.44868 .34142 L
.44869 .34142 L
.4487 .34141 L
.44872 .34141 L
.44873 .34141 L
.44874 .3414 L
.44875 .3414 L
.44876 .3414 L
.44878 .34139 L
.44879 .34139 L
.4488 .34139 L
.44881 .34138 L
.44882 .34138 L
.44883 .34138 L
.44885 .34137 L
.44886 .34137 L
.44887 .34137 L
.44888 .34136 L
.44889 .34136 L
.4489 .34136 L
.44892 .34135 L
.44893 .34135 L
.44894 .34135 L
.44895 .34134 L
.44896 .34134 L
.44897 .34134 L
.44899 .34134 L
.449 .34133 L
.44901 .34133 L
.44902 .34133 L
.44903 .34132 L
.44904 .34132 L
.44906 .34132 L
.44907 .34131 L
.44908 .34131 L
Mistroke
.44909 .34131 L
.4491 .34131 L
.44911 .3413 L
.44913 .3413 L
.44914 .3413 L
.44915 .34129 L
.44916 .34129 L
.44917 .34129 L
.44918 .34128 L
.4492 .34128 L
.44921 .34128 L
.44922 .34128 L
.44923 .34127 L
.44924 .34127 L
.44925 .34127 L
.44926 .34126 L
.44928 .34126 L
.44929 .34126 L
.4493 .34126 L
.44931 .34125 L
.44932 .34125 L
.44933 .34125 L
.44934 .34125 L
.44936 .34124 L
.44937 .34124 L
.44938 .34124 L
.44939 .34123 L
.4494 .34123 L
.44941 .34123 L
.44942 .34123 L
.44944 .34122 L
.44945 .34122 L
.44946 .34122 L
.44947 .34122 L
.44948 .34121 L
.44949 .34121 L
.4495 .34121 L
.44951 .34121 L
.44953 .3412 L
.44954 .3412 L
.44955 .3412 L
.44956 .34119 L
.44957 .34119 L
.44958 .34119 L
.44959 .34119 L
.4496 .34118 L
.44962 .34118 L
.44963 .34118 L
.44964 .34118 L
.44965 .34118 L
Mistroke
.44966 .34117 L
.44967 .34117 L
.44968 .34117 L
.44969 .34117 L
.44971 .34116 L
.44972 .34116 L
.44973 .34116 L
.44974 .34116 L
.44975 .34115 L
.44976 .34115 L
.44977 .34115 L
.44978 .34115 L
.4498 .34114 L
.44981 .34114 L
.44982 .34114 L
.44983 .34114 L
.44984 .34113 L
.44985 .34113 L
.44986 .34113 L
.44987 .34113 L
.44988 .34113 L
.44989 .34112 L
.44991 .34112 L
.44992 .34112 L
.44993 .34112 L
.44994 .34111 L
.44995 .34111 L
.44996 .34111 L
.44997 .34111 L
.44998 .34111 L
.44999 .3411 L
.45 .3411 L
.45002 .3411 L
.45003 .3411 L
.45004 .3411 L
.45005 .34109 L
.45006 .34109 L
.45007 .34109 L
.45008 .34109 L
.45009 .34109 L
.4501 .34108 L
.45011 .34108 L
.45012 .34108 L
.45014 .34108 L
.45015 .34108 L
.45016 .34107 L
.45017 .34107 L
.45018 .34107 L
.45019 .34107 L
.4502 .34107 L
Mistroke
.45021 .34106 L
.45022 .34106 L
.45023 .34106 L
.45024 .34106 L
.45025 .34106 L
.45027 .34105 L
.45028 .34105 L
.45029 .34105 L
.4503 .34105 L
.45031 .34105 L
.45032 .34105 L
.45033 .34104 L
.45034 .34104 L
.45035 .34104 L
.45036 .34104 L
.45037 .34104 L
.45038 .34103 L
.45039 .34103 L
.4504 .34103 L
.45042 .34103 L
.45043 .34103 L
.45044 .34103 L
.45045 .34102 L
.45046 .34102 L
.45047 .34102 L
.45048 .34102 L
.45049 .34102 L
.4505 .34102 L
.45051 .34101 L
.45052 .34101 L
.45053 .34101 L
.45054 .34101 L
.45055 .34101 L
.45056 .34101 L
.45057 .341 L
.45058 .341 L
.4506 .341 L
.45061 .341 L
.45062 .341 L
.45063 .341 L
.45064 .341 L
.45065 .34099 L
.45066 .34099 L
.45067 .34099 L
.45068 .34099 L
.45069 .34099 L
.4507 .34099 L
.45071 .34099 L
.45072 .34098 L
.45073 .34098 L
Mistroke
.45074 .34098 L
.45075 .34098 L
.45076 .34098 L
.45077 .34098 L
.45078 .34098 L
.45079 .34097 L
.4508 .34097 L
.45081 .34097 L
.45082 .34097 L
.45083 .34097 L
.45085 .34097 L
.45086 .34097 L
.45087 .34097 L
.45088 .34096 L
.45089 .34096 L
.4509 .34096 L
.45091 .34096 L
.45092 .34096 L
.45093 .34096 L
.45094 .34096 L
.45095 .34096 L
.45096 .34095 L
.45097 .34095 L
.45098 .34095 L
.45099 .34095 L
.451 .34095 L
.45101 .34095 L
.45102 .34095 L
.45103 .34095 L
.45104 .34094 L
.45105 .34094 L
.45106 .34094 L
.45107 .34094 L
.45108 .34094 L
.45109 .34094 L
.4511 .34094 L
.45111 .34094 L
.45112 .34094 L
.45113 .34093 L
.45114 .34093 L
.45115 .34093 L
.45116 .34093 L
.45117 .34093 L
.45118 .34093 L
.45119 .34093 L
.4512 .34093 L
.45121 .34093 L
.45122 .34093 L
.45123 .34093 L
.45124 .34092 L
Mistroke
.45125 .34092 L
.45126 .34092 L
.45127 .34092 L
.45128 .34092 L
.45129 .34092 L
.4513 .34092 L
.45131 .34092 L
.45132 .34092 L
.45133 .34092 L
.45134 .34092 L
.45135 .34091 L
.45136 .34091 L
.45137 .34091 L
.45138 .34091 L
.45139 .34091 L
.4514 .34091 L
.45141 .34091 L
.45142 .34091 L
.45143 .34091 L
.45144 .34091 L
.45145 .34091 L
.45146 .34091 L
.45147 .34091 L
.45148 .3409 L
.45149 .3409 L
.4515 .3409 L
.45151 .3409 L
.45152 .3409 L
.45153 .3409 L
.45154 .3409 L
.45155 .3409 L
.45156 .3409 L
.45157 .3409 L
.45158 .3409 L
.45158 .3409 L
.45159 .3409 L
.4516 .3409 L
.45161 .3409 L
.45162 .3409 L
.45163 .34089 L
.45164 .34089 L
.45165 .34089 L
.45166 .34089 L
.45167 .34089 L
.45168 .34089 L
.45169 .34089 L
.4517 .34089 L
.45171 .34089 L
.45172 .34089 L
.45173 .34089 L
Mistroke
.45174 .34089 L
.45175 .34089 L
.45176 .34089 L
.45177 .34089 L
.45178 .34089 L
.45179 .34089 L
.4518 .34089 L
.45181 .34089 L
.45181 .34089 L
.45182 .34089 L
.45183 .34089 L
.45184 .34088 L
.45185 .34088 L
.45186 .34088 L
.45187 .34088 L
.45188 .34088 L
.45189 .34088 L
.4519 .34088 L
.45191 .34088 L
.45192 .34088 L
.45193 .34088 L
.45194 .34088 L
.45195 .34088 L
.45196 .34088 L
.45197 .34088 L
.45197 .34088 L
.45198 .34088 L
.45199 .34088 L
.452 .34088 L
.45201 .34088 L
.45202 .34088 L
.45203 .34088 L
.45204 .34088 L
.45205 .34088 L
.45206 .34088 L
.45207 .34088 L
.45208 .34088 L
.45209 .34088 L
.4521 .34088 L
.4521 .34088 L
.45211 .34088 L
.45212 .34088 L
.45213 .34088 L
.45214 .34088 L
.45215 .34088 L
.45216 .34088 L
.45217 .34088 L
.45218 .34088 L
.45219 .34088 L
.4522 .34088 L
Mistroke
.45221 .34088 L
.45221 .34088 L
.45222 .34088 L
.45223 .34088 L
.45224 .34088 L
.45225 .34088 L
.45226 .34088 L
.45227 .34088 L
.45228 .34088 L
.45229 .34088 L
.4523 .34088 L
.4523 .34088 L
.45231 .34088 L
.45232 .34088 L
.45233 .34088 L
.45234 .34088 L
.45235 .34088 L
.45236 .34088 L
.45237 .34088 L
.45238 .34088 L
.45239 .34088 L
.45239 .34088 L
.4524 .34088 L
.45241 .34088 L
.45242 .34088 L
.45243 .34088 L
.45244 .34088 L
.45245 .34088 L
.45246 .34088 L
.45247 .34088 L
.45247 .34088 L
.45248 .34088 L
.45249 .34088 L
.4525 .34088 L
.45251 .34088 L
.45252 .34088 L
.45253 .34088 L
.45254 .34088 L
.45254 .34088 L
.45255 .34088 L
.45256 .34089 L
.45257 .34089 L
.45258 .34089 L
.45259 .34089 L
.4526 .34089 L
.45261 .34089 L
.45261 .34089 L
.45262 .34089 L
.45263 .34089 L
.45264 .34089 L
Mistroke
.45265 .34089 L
.45266 .34089 L
.45267 .34089 L
.45268 .34089 L
.45268 .34089 L
.45269 .34089 L
.4527 .34089 L
.45271 .34089 L
.45272 .34089 L
.45273 .34089 L
.45274 .34089 L
.45274 .34089 L
.45275 .34089 L
.45276 .3409 L
.45277 .3409 L
.45278 .3409 L
.45279 .3409 L
.4528 .3409 L
.4528 .3409 L
.45281 .3409 L
.45282 .3409 L
.45283 .3409 L
.45284 .3409 L
.45285 .3409 L
.45285 .3409 L
.45286 .3409 L
.45287 .3409 L
.45288 .3409 L
.45289 .3409 L
.4529 .3409 L
.45291 .34091 L
.45291 .34091 L
.45292 .34091 L
.45293 .34091 L
.45294 .34091 L
.45295 .34091 L
.45296 .34091 L
.45296 .34091 L
.45297 .34091 L
.45298 .34091 L
.45299 .34091 L
.453 .34091 L
.45301 .34091 L
.45301 .34091 L
.45302 .34092 L
.45303 .34092 L
.45304 .34092 L
.45305 .34092 L
.45305 .34092 L
.45306 .34092 L
Mistroke
.45307 .34092 L
.45308 .34092 L
.45309 .34092 L
.4531 .34092 L
.4531 .34092 L
.45311 .34092 L
.45312 .34093 L
.45313 .34093 L
.45314 .34093 L
.45314 .34093 L
.45315 .34093 L
.45316 .34093 L
.45317 .34093 L
.45318 .34093 L
.45319 .34093 L
.45319 .34093 L
.4532 .34093 L
.45321 .34094 L
.45322 .34094 L
.45323 .34094 L
.45323 .34094 L
.45324 .34094 L
.45325 .34094 L
.45326 .34094 L
.45327 .34094 L
.45327 .34094 L
.45328 .34094 L
.45329 .34095 L
.4533 .34095 L
.45331 .34095 L
.45331 .34095 L
.45332 .34095 L
.45333 .34095 L
.45334 .34095 L
.45335 .34095 L
.45335 .34095 L
.45336 .34096 L
.45337 .34096 L
.45338 .34096 L
.45338 .34096 L
.45339 .34096 L
.4534 .34096 L
.45341 .34096 L
.45342 .34096 L
.45342 .34096 L
.45343 .34097 L
.45344 .34097 L
.45345 .34097 L
.45346 .34097 L
.45346 .34097 L
Mistroke
.45347 .34097 L
.45348 .34097 L
.45349 .34097 L
.45349 .34098 L
.4535 .34098 L
.45351 .34098 L
.45352 .34098 L
.45353 .34098 L
.45353 .34098 L
.45354 .34098 L
.45355 .34098 L
.45356 .34099 L
.45356 .34099 L
.45357 .34099 L
.45358 .34099 L
.45359 .34099 L
.45359 .34099 L
.4536 .34099 L
.45361 .34099 L
.45362 .341 L
.45362 .341 L
.45363 .341 L
.45364 .341 L
.45365 .341 L
.45365 .341 L
.45366 .341 L
.45367 .34101 L
.45368 .34101 L
.45368 .34101 L
.45369 .34101 L
.4537 .34101 L
.45371 .34101 L
.45371 .34101 L
.45372 .34102 L
.45373 .34102 L
.45374 .34102 L
.45374 .34102 L
.45375 .34102 L
.45376 .34102 L
.45377 .34102 L
.45377 .34103 L
.45378 .34103 L
.45379 .34103 L
.4538 .34103 L
.4538 .34103 L
.45381 .34103 L
.45382 .34104 L
.45383 .34104 L
.45383 .34104 L
.45384 .34104 L
Mistroke
.45385 .34104 L
.45386 .34104 L
.45386 .34104 L
.45387 .34105 L
.45388 .34105 L
.45388 .34105 L
.45389 .34105 L
.4539 .34105 L
.45391 .34105 L
.45391 .34106 L
.45392 .34106 L
.45393 .34106 L
.45394 .34106 L
.45394 .34106 L
.45395 .34106 L
.45396 .34107 L
.45396 .34107 L
.45397 .34107 L
.45398 .34107 L
.45399 .34107 L
.45399 .34107 L
.454 .34108 L
.45401 .34108 L
.45401 .34108 L
.45402 .34108 L
.45403 .34108 L
.45404 .34108 L
.45404 .34109 L
.45405 .34109 L
.45406 .34109 L
.45406 .34109 L
.45407 .34109 L
.45408 .3411 L
.45408 .3411 L
.45409 .3411 L
.4541 .3411 L
.45411 .3411 L
.45411 .3411 L
.45412 .34111 L
.45413 .34111 L
.45413 .34111 L
.45414 .34111 L
.45415 .34111 L
.45415 .34112 L
.45416 .34112 L
.45417 .34112 L
.45418 .34112 L
.45418 .34112 L
.45419 .34112 L
.4542 .34113 L
Mistroke
.4542 .34113 L
.45421 .34113 L
.45422 .34113 L
.45422 .34113 L
.45423 .34114 L
.45424 .34114 L
.45424 .34114 L
.45425 .34114 L
.45426 .34114 L
.45426 .34115 L
.45427 .34115 L
.45428 .34115 L
.45428 .34115 L
.45429 .34115 L
.4543 .34116 L
.4543 .34116 L
.45431 .34116 L
.45432 .34116 L
.45432 .34116 L
.45433 .34117 L
.45434 .34117 L
.45435 .34117 L
.45435 .34117 L
.45436 .34117 L
.45437 .34118 L
.45437 .34118 L
.45438 .34118 L
.45438 .34118 L
.45439 .34118 L
.4544 .34119 L
.4544 .34119 L
.45441 .34119 L
.45442 .34119 L
.45442 .3412 L
.45443 .3412 L
.45444 .3412 L
.45444 .3412 L
.45445 .3412 L
.45446 .34121 L
.45446 .34121 L
.45447 .34121 L
.45448 .34121 L
.45448 .34121 L
.45449 .34122 L
.4545 .34122 L
.4545 .34122 L
.45451 .34122 L
.45452 .34123 L
.45452 .34123 L
.45453 .34123 L
Mistroke
.45454 .34123 L
.45454 .34123 L
.45455 .34124 L
.45455 .34124 L
.45456 .34124 L
.45457 .34124 L
.45457 .34125 L
.45458 .34125 L
.45459 .34125 L
.45459 .34125 L
.4546 .34126 L
.45461 .34126 L
.45461 .34126 L
.45462 .34126 L
.45462 .34126 L
.45463 .34127 L
.45464 .34127 L
.45464 .34127 L
.45465 .34127 L
.45466 .34128 L
.45466 .34128 L
.45467 .34128 L
.45467 .34128 L
.45468 .34129 L
.45469 .34129 L
.45469 .34129 L
.4547 .34129 L
.45471 .3413 L
.45471 .3413 L
.45472 .3413 L
.45472 .3413 L
.45473 .3413 L
.45474 .34131 L
.45474 .34131 L
.45475 .34131 L
.45475 .34131 L
.45476 .34132 L
.45477 .34132 L
.45477 .34132 L
.45478 .34132 L
.45478 .34133 L
.45479 .34133 L
.4548 .34133 L
.4548 .34133 L
.45481 .34134 L
.45481 .34134 L
.45482 .34134 L
.45483 .34134 L
.45483 .34135 L
.45484 .34135 L
Mistroke
.45484 .34135 L
.45485 .34135 L
.45486 .34136 L
.45486 .34136 L
.45487 .34136 L
.45487 .34136 L
.45488 .34137 L
.45489 .34137 L
.45489 .34137 L
.4549 .34137 L
.4549 .34138 L
.45491 .34138 L
.45492 .34138 L
.45492 .34139 L
.45493 .34139 L
.45493 .34139 L
.45494 .34139 L
.45495 .3414 L
.45495 .3414 L
.45496 .3414 L
.45496 .3414 L
.45497 .34141 L
.45497 .34141 L
.45498 .34141 L
.45499 .34141 L
.45499 .34142 L
.455 .34142 L
.455 .34142 L
.45501 .34142 L
.45501 .34143 L
.45502 .34143 L
.45503 .34143 L
.45503 .34144 L
.45504 .34144 L
.45504 .34144 L
.45505 .34144 L
.45505 .34145 L
.45506 .34145 L
.45507 .34145 L
.45507 .34145 L
.45508 .34146 L
.45508 .34146 L
.45509 .34146 L
.45509 .34147 L
.4551 .34147 L
.4551 .34147 L
.45511 .34147 L
.45512 .34148 L
.45512 .34148 L
.45513 .34148 L
Mistroke
.45513 .34149 L
.45514 .34149 L
.45514 .34149 L
.45515 .34149 L
.45515 .3415 L
.45516 .3415 L
.45517 .3415 L
.45517 .34151 L
.45518 .34151 L
.45518 .34151 L
.45519 .34151 L
.45519 .34152 L
.4552 .34152 L
.4552 .34152 L
.45521 .34153 L
.45521 .34153 L
.45522 .34153 L
.45523 .34153 L
.45523 .34154 L
.45524 .34154 L
.45524 .34154 L
.45525 .34155 L
.45525 .34155 L
.45526 .34155 L
.45526 .34155 L
.45527 .34156 L
.45527 .34156 L
.45528 .34156 L
.45528 .34157 L
.45529 .34157 L
.45529 .34157 L
.4553 .34158 L
.45531 .34158 L
.45531 .34158 L
.45532 .34158 L
.45532 .34159 L
.45533 .34159 L
.45533 .34159 L
.45534 .3416 L
.45534 .3416 L
.45535 .3416 L
.45535 .34161 L
.45536 .34161 L
.45536 .34161 L
.45537 .34161 L
.45537 .34162 L
.45538 .34162 L
.45538 .34162 L
.45539 .34163 L
.45539 .34163 L
Mistroke
.4554 .34163 L
.4554 .34164 L
.45541 .34164 L
.45541 .34164 L
.45542 .34164 L
.45542 .34165 L
.45543 .34165 L
.45543 .34165 L
.45544 .34166 L
.45544 .34166 L
.45545 .34166 L
.45545 .34167 L
.45546 .34167 L
.45546 .34167 L
.45547 .34168 L
.45547 .34168 L
.45548 .34168 L
.45548 .34169 L
.45549 .34169 L
.45549 .34169 L
.4555 .34169 L
.4555 .3417 L
.45551 .3417 L
.45551 .3417 L
.45552 .34171 L
.45552 .34171 L
.45553 .34171 L
.45553 .34172 L
.45554 .34172 L
.45554 .34172 L
.45555 .34173 L
.45555 .34173 L
.45556 .34173 L
.45556 .34174 L
.45557 .34174 L
.45557 .34174 L
.45558 .34175 L
.45558 .34175 L
.45559 .34175 L
.45559 .34176 L
.4556 .34176 L
.4556 .34176 L
.4556 .34177 L
.45561 .34177 L
.45561 .34177 L
.45562 .34178 L
.45562 .34178 L
.45563 .34178 L
.45563 .34179 L
.45564 .34179 L
Mistroke
.45564 .34179 L
.45565 .3418 L
.45565 .3418 L
.45566 .3418 L
.45566 .3418 L
.45567 .34181 L
.45567 .34181 L
.45567 .34181 L
.45568 .34182 L
.45568 .34182 L
.45569 .34182 L
.45569 .34183 L
.4557 .34183 L
.4557 .34184 L
.45571 .34184 L
.45571 .34184 L
.45572 .34185 L
.45572 .34185 L
.45572 .34185 L
.45573 .34186 L
.45573 .34186 L
.45574 .34186 L
.45574 .34187 L
.45575 .34187 L
.45575 .34187 L
.45576 .34188 L
.45576 .34188 L
.45577 .34188 L
.45577 .34189 L
.45577 .34189 L
.45578 .34189 L
.45578 .3419 L
.45579 .3419 L
.45579 .3419 L
.4558 .34191 L
.4558 .34191 L
.4558 .34191 L
.45581 .34192 L
.45581 .34192 L
.45582 .34192 L
.45582 .34193 L
.45583 .34193 L
.45583 .34193 L
.45583 .34194 L
.45584 .34194 L
.45584 .34194 L
.45585 .34195 L
.45585 .34195 L
.45586 .34196 L
.45586 .34196 L
Mistroke
.45586 .34196 L
.45587 .34197 L
.45587 .34197 L
.45588 .34197 L
.45588 .34198 L
.45589 .34198 L
.45589 .34198 L
.45589 .34199 L
.4559 .34199 L
.4559 .34199 L
.45591 .342 L
.45591 .342 L
.45592 .342 L
.45592 .34201 L
.45592 .34201 L
.45593 .34202 L
.45593 .34202 L
.45594 .34202 L
.45594 .34203 L
.45594 .34203 L
.45595 .34203 L
.45595 .34204 L
.45596 .34204 L
.45596 .34204 L
.45596 .34205 L
.45597 .34205 L
.45597 .34206 L
.45598 .34206 L
.45598 .34206 L
.45598 .34207 L
.45599 .34207 L
.45599 .34207 L
.456 .34208 L
.456 .34208 L
.456 .34208 L
.45601 .34209 L
.45601 .34209 L
.45602 .3421 L
.45602 .3421 L
.45602 .3421 L
.45603 .34211 L
.45603 .34211 L
.45604 .34211 L
.45604 .34212 L
.45604 .34212 L
.45605 .34212 L
.45605 .34213 L
.45605 .34213 L
.45606 .34214 L
.45606 .34214 L
Mistroke
.45607 .34214 L
.45607 .34215 L
.45607 .34215 L
.45608 .34215 L
.45608 .34216 L
.45609 .34216 L
.45609 .34217 L
.45609 .34217 L
.4561 .34217 L
.4561 .34218 L
.4561 .34218 L
.45611 .34218 L
.45611 .34219 L
.45612 .34219 L
.45612 .3422 L
.45612 .3422 L
.45613 .3422 L
.45613 .34221 L
.45613 .34221 L
.45614 .34221 L
.45614 .34222 L
.45614 .34222 L
.45615 .34223 L
.45615 .34223 L
.45616 .34223 L
.45616 .34224 L
.45616 .34224 L
.45617 .34224 L
.45617 .34225 L
.45617 .34225 L
.45618 .34226 L
.45618 .34226 L
.45618 .34226 L
.45619 .34227 L
.45619 .34227 L
.4562 .34228 L
.4562 .34228 L
.4562 .34228 L
.45621 .34229 L
.45621 .34229 L
.45621 .34229 L
.45622 .3423 L
.45622 .3423 L
.45622 .34231 L
.45623 .34231 L
.45623 .34231 L
.45623 .34232 L
.45624 .34232 L
.45624 .34233 L
.45624 .34233 L
Mistroke
.45625 .34233 L
.45625 .34234 L
.45625 .34234 L
.45626 .34234 L
.45626 .34235 L
.45626 .34235 L
.45627 .34236 L
.45627 .34236 L
.45627 .34236 L
.45628 .34237 L
.45628 .34237 L
.45628 .34238 L
.45629 .34238 L
.45629 .34238 L
.45629 .34239 L
.4563 .34239 L
.4563 .3424 L
.4563 .3424 L
.45631 .3424 L
.45631 .34241 L
.45631 .34241 L
.45632 .34242 L
.45632 .34242 L
.45632 .34242 L
.45633 .34243 L
.45633 .34243 L
.45633 .34244 L
.45634 .34244 L
.45634 .34244 L
.45634 .34245 L
.45635 .34245 L
.45635 .34246 L
.45635 .34246 L
.45636 .34246 L
.45636 .34247 L
.45636 .34247 L
.45636 .34248 L
.45637 .34248 L
.45637 .34248 L
.45637 .34249 L
.45638 .34249 L
.45638 .3425 L
.45638 .3425 L
.45639 .3425 L
.45639 .34251 L
.45639 .34251 L
.4564 .34252 L
.4564 .34252 L
.4564 .34252 L
.4564 .34253 L
Mistroke
.45641 .34253 L
.45641 .34254 L
.45641 .34254 L
.45642 .34254 L
.45642 .34255 L
.45642 .34255 L
.45643 .34256 L
.45643 .34256 L
.45643 .34256 L
.45643 .34257 L
.45644 .34257 L
.45644 .34258 L
.45644 .34258 L
.45645 .34258 L
.45645 .34259 L
.45645 .34259 L
.45645 .3426 L
.45646 .3426 L
.45646 .3426 L
.45646 .34261 L
.45647 .34261 L
.45647 .34262 L
.45647 .34262 L
.45647 .34263 L
.45648 .34263 L
.45648 .34263 L
.45648 .34264 L
.45649 .34264 L
.45649 .34265 L
.45649 .34265 L
.45649 .34265 L
.4565 .34266 L
.4565 .34266 L
.4565 .34267 L
.45651 .34267 L
.45651 .34268 L
.45651 .34268 L
.45651 .34268 L
.45652 .34269 L
.45652 .34269 L
.45652 .3427 L
.45652 .3427 L
.45653 .3427 L
.45653 .34271 L
.45653 .34271 L
.45654 .34272 L
.45654 .34272 L
.45654 .34272 L
.45654 .34273 L
.45655 .34273 L
Mistroke
.45655 .34274 L
.45655 .34274 L
.45655 .34275 L
.45656 .34275 L
.45656 .34275 L
.45656 .34276 L
.45656 .34276 L
.45657 .34277 L
.45657 .34277 L
.45657 .34278 L
.45657 .34278 L
.45658 .34278 L
.45658 .34279 L
.45658 .34279 L
.45658 .3428 L
.45659 .3428 L
.45659 .3428 L
.45659 .34281 L
.45659 .34281 L
.4566 .34282 L
.4566 .34282 L
.4566 .34283 L
.4566 .34283 L
.45661 .34283 L
.45661 .34284 L
.45661 .34284 L
.45661 .34285 L
.45662 .34285 L
.45662 .34286 L
.45662 .34286 L
.45662 .34286 L
.45663 .34287 L
.45663 .34287 L
.45663 .34288 L
.45663 .34288 L
.45664 .34289 L
.45664 .34289 L
.45664 .34289 L
.45664 .3429 L
.45665 .3429 L
.45665 .34291 L
.45665 .34291 L
.45665 .34292 L
.45665 .34292 L
.45666 .34292 L
.45666 .34293 L
.45666 .34293 L
.45666 .34294 L
.45667 .34294 L
.45667 .34295 L
Mistroke
.45667 .34295 L
.45667 .34295 L
.45667 .34296 L
.45668 .34296 L
.45668 .34297 L
.45668 .34297 L
.45668 .34298 L
.45669 .34298 L
.45669 .34298 L
.45669 .34299 L
.45669 .34299 L
.45669 .343 L
.4567 .343 L
.4567 .34301 L
.4567 .34301 L
.4567 .34301 L
.45671 .34302 L
.45671 .34302 L
.45671 .34303 L
.45671 .34303 L
.45671 .34304 L
.45672 .34304 L
.45672 .34304 L
.45672 .34305 L
.45672 .34305 L
.45672 .34306 L
.45673 .34306 L
.45673 .34307 L
.45673 .34307 L
.45673 .34308 L
.45673 .34308 L
.45674 .34308 L
.45674 .34309 L
.45674 .34309 L
.45674 .3431 L
.45674 .3431 L
.45675 .34311 L
.45675 .34311 L
.45675 .34311 L
.45675 .34312 L
.45675 .34312 L
.45676 .34313 L
.45676 .34313 L
.45676 .34314 L
.45676 .34314 L
.45676 .34315 L
.45677 .34315 L
.45677 .34315 L
.45677 .34316 L
.45677 .34316 L
Mistroke
.45677 .34317 L
.45678 .34317 L
.45678 .34318 L
.45678 .34318 L
.45678 .34319 L
.45678 .34319 L
.45678 .34319 L
.45679 .3432 L
.45679 .3432 L
.45679 .34321 L
.45679 .34321 L
.45679 .34322 L
.4568 .34322 L
.4568 .34322 L
.4568 .34323 L
.4568 .34323 L
.4568 .34324 L
.4568 .34324 L
.45681 .34325 L
.45681 .34325 L
.45681 .34326 L
.45681 .34326 L
.45681 .34326 L
.45681 .34327 L
.45682 .34327 L
.45682 .34328 L
.45682 .34328 L
.45682 .34329 L
.45682 .34329 L
.45682 .3433 L
.45683 .3433 L
.45683 .3433 L
.45683 .34331 L
.45683 .34331 L
.45683 .34332 L
.45683 .34332 L
.45684 .34333 L
.45684 .34333 L
.45684 .34334 L
.45684 .34334 L
.45684 .34335 L
.45684 .34335 L
.45685 .34335 L
.45685 .34336 L
.45685 .34336 L
.45685 .34337 L
.45685 .34337 L
.45685 .34338 L
.45686 .34338 L
.45686 .34339 L
Mistroke
.45686 .34339 L
.45686 .34339 L
.45686 .3434 L
.45686 .3434 L
.45686 .34341 L
.45687 .34341 L
.45687 .34342 L
.45687 .34342 L
.45687 .34343 L
.45687 .34343 L
.45687 .34343 L
.45687 .34344 L
.45688 .34344 L
.45688 .34345 L
.45688 .34345 L
.45688 .34346 L
.45688 .34346 L
.45688 .34347 L
.45688 .34347 L
.45689 .34348 L
.45689 .34348 L
.45689 .34348 L
.45689 .34349 L
.45689 .34349 L
.45689 .3435 L
.45689 .3435 L
.4569 .34351 L
.4569 .34351 L
.4569 .34352 L
.4569 .34352 L
.4569 .34353 L
.4569 .34353 L
.4569 .34353 L
.4569 .34354 L
.45691 .34354 L
.45691 .34355 L
.45691 .34355 L
.45691 .34356 L
.45691 .34356 L
.45691 .34357 L
.45691 .34357 L
.45691 .34358 L
.45692 .34358 L
.45692 .34358 L
.45692 .34359 L
.45692 .34359 L
.45692 .3436 L
.45692 .3436 L
.45692 .34361 L
.45692 .34361 L
Mistroke
.45693 .34362 L
.45693 .34362 L
.45693 .34363 L
.45693 .34363 L
.45693 .34363 L
.45693 .34364 L
.45693 .34364 L
.45693 .34365 L
.45693 .34365 L
.45694 .34366 L
.45694 .34366 L
.45694 .34367 L
.45694 .34367 L
.45694 .34368 L
.45694 .34368 L
.45694 .34368 L
.45694 .34369 L
.45694 .34369 L
.45695 .3437 L
.45695 .3437 L
.45695 .34371 L
.45695 .34371 L
.45695 .34372 L
.45695 .34372 L
.45695 .34373 L
.45695 .34373 L
.45695 .34374 L
.45695 .34374 L
.45696 .34374 L
.45696 .34375 L
.45696 .34375 L
.45696 .34376 L
.45696 .34376 L
.45696 .34377 L
.45696 .34377 L
.45696 .34378 L
.45696 .34378 L
.45696 .34379 L
.45697 .34379 L
.45697 .34379 L
.45697 .3438 L
.45697 .3438 L
.45697 .34381 L
.45697 .34381 L
.45697 .34382 L
.45697 .34382 L
.45697 .34383 L
.45697 .34383 L
.45697 .34384 L
.45698 .34384 L
Mistroke
.45698 .34385 L
.45698 .34385 L
.45698 .34385 L
.45698 .34386 L
.45698 .34386 L
.45698 .34387 L
.45698 .34387 L
.45698 .34388 L
.45698 .34388 L
.45698 .34389 L
.45698 .34389 L
.45699 .3439 L
.45699 .3439 L
.45699 .34391 L
.45699 .34391 L
.45699 .34391 L
.45699 .34392 L
.45699 .34392 L
.45699 .34393 L
.45699 .34393 L
.45699 .34394 L
.45699 .34394 L
.45699 .34395 L
.45699 .34395 L
.45699 .34396 L
.457 .34396 L
.457 .34397 L
.457 .34397 L
.457 .34397 L
.457 .34398 L
.457 .34398 L
.457 .34399 L
.457 .34399 L
.457 .344 L
.457 .344 L
.457 .34401 L
.457 .34401 L
.457 .34402 L
.457 .34402 L
.457 .34403 L
.457 .34403 L
.45701 .34404 L
.45701 .34404 L
.45701 .34404 L
.45701 .34405 L
.45701 .34405 L
.45701 .34406 L
.45701 .34406 L
.45701 .34407 L
.45701 .34407 L
Mistroke
.45701 .34408 L
.45701 .34408 L
.45701 .34409 L
.45701 .34409 L
.45701 .3441 L
.45701 .3441 L
.45701 .3441 L
.45701 .34411 L
.45701 .34411 L
.45701 .34412 L
.45702 .34412 L
.45702 .34413 L
.45702 .34413 L
.45702 .34414 L
.45702 .34414 L
.45702 .34415 L
.45702 .34415 L
.45702 .34416 L
.45702 .34416 L
.45702 .34417 L
.45702 .34417 L
.45702 .34417 L
.45702 .34418 L
.45702 .34418 L
.45702 .34419 L
.45702 .34419 L
.45702 .3442 L
.45702 .3442 L
.45702 .34421 L
.45702 .34421 L
.45702 .34422 L
.45702 .34422 L
.45702 .34423 L
.45702 .34423 L
.45702 .34424 L
.45703 .34424 L
.45703 .34424 L
.45703 .34425 L
.45703 .34425 L
.45703 .34426 L
.45703 .34426 L
.45703 .34427 L
.45703 .34427 L
.45703 .34428 L
.45703 .34428 L
.45703 .34429 L
.45703 .34429 L
.45703 .3443 L
.45703 .3443 L
.45703 .34431 L
Mistroke
.45703 .34431 L
.45703 .34431 L
.45703 .34432 L
.45703 .34432 L
.45703 .34433 L
.45703 .34433 L
.45703 .34434 L
.45703 .34434 L
.45703 .34435 L
.45703 .34435 L
.45703 .34436 L
.45703 .34436 L
.45703 .34437 L
.45703 .34437 L
.45703 .34438 L
.45703 .34438 L
.45703 .34438 L
.45703 .34439 L
.45703 .34439 L
.45703 .3444 L
.45703 .3444 L
.45703 .34441 L
.45703 .34441 L
.45703 .34442 L
.45703 .34442 L
.45703 .34443 L
.45703 .34443 L
.45703 .34444 L
.45703 .34444 L
.45703 .34445 L
.45703 .34445 L
.45703 .34445 L
.45703 .34446 L
.45703 .34446 L
.45703 .34447 L
.45703 .34447 L
.45703 .34448 L
.45703 .34448 L
.45703 .34449 L
.45703 .34449 L
.45703 .3445 L
.45703 .3445 L
.45703 .34451 L
.45703 .34451 L
.45703 .34452 L
.45703 .34452 L
.45703 .34452 L
.45703 .34453 L
.45703 .34453 L
.45703 .34454 L
Mistroke
.45703 .34454 L
.45703 .34455 L
.45703 .34455 L
.45703 .34456 L
.45703 .34456 L
.45703 .34457 L
.45703 .34457 L
.45703 .34458 L
.45703 .34458 L
.45703 .34459 L
.45703 .34459 L
.45703 .34459 L
.45703 .3446 L
.45703 .3446 L
.45703 .34461 L
.45703 .34461 L
.45703 .34462 L
.45703 .34462 L
.45703 .34463 L
.45703 .34463 L
.45703 .34464 L
.45703 .34464 L
.45703 .34465 L
.45703 .34465 L
.45703 .34466 L
.45703 .34466 L
.45703 .34466 L
.45703 .34467 L
.45703 .34467 L
.45703 .34468 L
.45703 .34468 L
.45703 .34469 L
.45703 .34469 L
.45703 .3447 L
.45703 .3447 L
.45703 .34471 L
.45703 .34471 L
.45703 .34472 L
.45703 .34472 L
.45703 .34473 L
.45703 .34473 L
.45703 .34474 L
.45703 .34474 L
.45702 .34474 L
.45702 .34475 L
.45702 .34475 L
.45702 .34476 L
.45702 .34476 L
.45702 .34477 L
.45702 .34477 L
Mistroke
.45702 .34478 L
.45702 .34478 L
.45702 .34479 L
.45702 .34479 L
.45702 .3448 L
.45702 .3448 L
.45702 .34481 L
.45702 .34481 L
.45702 .34481 L
.45702 .34482 L
.45702 .34482 L
.45702 .34483 L
.45702 .34483 L
.45702 .34484 L
.45702 .34484 L
.45702 .34485 L
.45702 .34485 L
.45702 .34486 L
.45702 .34486 L
.45702 .34487 L
.45701 .34487 L
.45701 .34488 L
.45701 .34488 L
.45701 .34488 L
.45701 .34489 L
.45701 .34489 L
.45701 .3449 L
.45701 .3449 L
.45701 .34491 L
.45701 .34491 L
.45701 .34492 L
.45701 .34492 L
.45701 .34493 L
.45701 .34493 L
.45701 .34494 L
.45701 .34494 L
.45701 .34494 L
.45701 .34495 L
.45701 .34495 L
.45701 .34496 L
.457 .34496 L
.457 .34497 L
.457 .34497 L
.457 .34498 L
.457 .34498 L
.457 .34499 L
.457 .34499 L
.457 .345 L
.457 .345 L
.457 .34501 L
Mistroke
.457 .34501 L
.457 .34501 L
.457 .34502 L
.457 .34502 L
.457 .34503 L
.457 .34503 L
.45699 .34504 L
.45699 .34504 L
.45699 .34505 L
.45699 .34505 L
.45699 .34506 L
.45699 .34506 L
.45699 .34507 L
.45699 .34507 L
.45699 .34507 L
.45699 .34508 L
.45699 .34508 L
.45699 .34509 L
.45699 .34509 L
.45699 .3451 L
.45699 .3451 L
.45698 .34511 L
.45698 .34511 L
.45698 .34512 L
.45698 .34512 L
.45698 .34513 L
.45698 .34513 L
.45698 .34514 L
.45698 .34514 L
.45698 .34514 L
.45698 .34515 L
.45698 .34515 L
.45698 .34516 L
.45698 .34516 L
.45698 .34517 L
.45697 .34517 L
.45697 .34518 L
.45697 .34518 L
.45697 .34519 L
.45697 .34519 L
.45697 .3452 L
.45697 .3452 L
.45697 .3452 L
.45697 .34521 L
.45697 .34521 L
.45697 .34522 L
.45697 .34522 L
.45696 .34523 L
.45696 .34523 L
.45696 .34524 L
Mistroke
.45696 .34524 L
.45696 .34525 L
.45696 .34525 L
.45696 .34526 L
.45696 .34526 L
.45696 .34526 L
.45696 .34527 L
.45696 .34527 L
.45696 .34528 L
.45695 .34528 L
.45695 .34529 L
.45695 .34529 L
.45695 .3453 L
.45695 .3453 L
.45695 .34531 L
.45695 .34531 L
.45695 .34532 L
.45695 .34532 L
.45695 .34532 L
.45694 .34533 L
.45694 .34533 L
.45694 .34534 L
.45694 .34534 L
.45694 .34535 L
.45694 .34535 L
.45694 .34536 L
.45694 .34536 L
.45694 .34537 L
.45694 .34537 L
.45694 .34538 L
.45693 .34538 L
.45693 .34538 L
.45693 .34539 L
.45693 .34539 L
.45693 .3454 L
.45693 .3454 L
.45693 .34541 L
.45693 .34541 L
.45693 .34542 L
.45692 .34542 L
.45692 .34543 L
.45692 .34543 L
.45692 .34543 L
.45692 .34544 L
.45692 .34544 L
.45692 .34545 L
.45692 .34545 L
.45692 .34546 L
.45692 .34546 L
.45691 .34547 L
Mistroke
.45691 .34547 L
.45691 .34548 L
.45691 .34548 L
.45691 .34548 L
.45691 .34549 L
.45691 .34549 L
.45691 .3455 L
.45691 .3455 L
.4569 .34551 L
.4569 .34551 L
.4569 .34552 L
.4569 .34552 L
.4569 .34553 L
.4569 .34553 L
.4569 .34554 L
.4569 .34554 L
.4569 .34554 L
.45689 .34555 L
.45689 .34555 L
.45689 .34556 L
.45689 .34556 L
.45689 .34557 L
.45689 .34557 L
.45689 .34558 L
.45689 .34558 L
.45688 .34559 L
.45688 .34559 L
.45688 .34559 L
.45688 .3456 L
.45688 .3456 L
.45688 .34561 L
.45688 .34561 L
.45688 .34562 L
.45687 .34562 L
.45687 .34563 L
.45687 .34563 L
.45687 .34564 L
.45687 .34564 L
.45687 .34564 L
.45687 .34565 L
.45687 .34565 L
.45686 .34566 L
.45686 .34566 L
.45686 .34567 L
.45686 .34567 L
.45686 .34568 L
.45686 .34568 L
.45686 .34568 L
.45686 .34569 L
.45685 .34569 L
Mistroke
.45685 .3457 L
.45685 .3457 L
.45685 .34571 L
.45685 .34571 L
.45685 .34572 L
.45685 .34572 L
.45685 .34573 L
.45684 .34573 L
.45684 .34573 L
.45684 .34574 L
.45684 .34574 L
.45684 .34575 L
.45684 .34575 L
.45684 .34576 L
.45683 .34576 L
.45683 .34577 L
.45683 .34577 L
.45683 .34577 L
.45683 .34578 L
.45683 .34578 L
.45683 .34579 L
.45682 .34579 L
.45682 .3458 L
.45682 .3458 L
.45682 .34581 L
.45682 .34581 L
.45682 .34582 L
.45682 .34582 L
.45681 .34582 L
.45681 .34583 L
.45681 .34583 L
.45681 .34584 L
.45681 .34584 L
.45681 .34585 L
.45681 .34585 L
.4568 .34586 L
.4568 .34586 L
.4568 .34586 L
.4568 .34587 L
.4568 .34587 L
.4568 .34588 L
.4568 .34588 L
.45679 .34589 L
.45679 .34589 L
.45679 .3459 L
.45679 .3459 L
.45679 .3459 L
.45679 .34591 L
.45679 .34591 L
.45678 .34592 L
Mistroke
.45678 .34592 L
.45678 .34593 L
.45678 .34593 L
.45678 .34594 L
.45678 .34594 L
.45677 .34594 L
.45677 .34595 L
.45677 .34595 L
.45677 .34596 L
.45677 .34596 L
.45677 .34597 L
.45677 .34597 L
.45676 .34598 L
.45676 .34598 L
.45676 .34598 L
.45676 .34599 L
.45676 .34599 L
.45676 .346 L
.45675 .346 L
.45675 .34601 L
.45675 .34601 L
.45675 .34602 L
.45675 .34602 L
.45675 .34602 L
.45674 .34603 L
.45674 .34603 L
.45674 .34604 L
.45674 .34604 L
.45674 .34605 L
.45674 .34605 L
.45673 .34606 L
.45673 .34606 L
.45673 .34606 L
.45673 .34607 L
.45673 .34607 L
.45673 .34608 L
.45673 .34608 L
.45672 .34609 L
.45672 .34609 L
.45672 .34609 L
.45672 .3461 L
.45672 .3461 L
.45672 .34611 L
.45671 .34611 L
.45671 .34612 L
.45671 .34612 L
.45671 .34613 L
.45671 .34613 L
.4567 .34613 L
.4567 .34614 L
Mistroke
.4567 .34614 L
.4567 .34615 L
.4567 .34615 L
.4567 .34616 L
.45669 .34616 L
.45669 .34616 L
.45669 .34617 L
.45669 .34617 L
.45669 .34618 L
.45669 .34618 L
.45668 .34619 L
.45668 .34619 L
.45668 .3462 L
.45668 .3462 L
.45668 .3462 L
.45668 .34621 L
.45667 .34621 L
.45667 .34622 L
.45667 .34622 L
.45667 .34623 L
.45667 .34623 L
.45666 .34623 L
.45666 .34624 L
.45666 .34624 L
.45666 .34625 L
.45666 .34625 L
.45666 .34626 L
.45665 .34626 L
.45665 .34626 L
.45665 .34627 L
.45665 .34627 L
.45665 .34628 L
.45664 .34628 L
.45664 .34629 L
.45664 .34629 L
.45664 .3463 L
.45664 .3463 L
.45664 .3463 L
.45663 .34631 L
.45663 .34631 L
.45663 .34632 L
.45663 .34632 L
.45663 .34633 L
.45662 .34633 L
.45662 .34633 L
.45662 .34634 L
.45662 .34634 L
.45662 .34635 L
.45662 .34635 L
.45661 .34636 L
Mistroke
.45661 .34636 L
.45661 .34636 L
.45661 .34637 L
.45661 .34637 L
.4566 .34638 L
.4566 .34638 L
.4566 .34639 L
.4566 .34639 L
.4566 .34639 L
.45659 .3464 L
.45659 .3464 L
.45659 .34641 L
.45659 .34641 L
.45659 .34642 L
.45658 .34642 L
.45658 .34642 L
.45658 .34643 L
.45658 .34643 L
.45658 .34644 L
.45657 .34644 L
.45657 .34645 L
.45657 .34645 L
.45657 .34645 L
.45657 .34646 L
.45657 .34646 L
.45656 .34647 L
.45656 .34647 L
.45656 .34647 L
.45656 .34648 L
.45656 .34648 L
.45655 .34649 L
.45655 .34649 L
.45655 .3465 L
.45655 .3465 L
.45655 .3465 L
.45654 .34651 L
.45654 .34651 L
.45654 .34652 L
.45654 .34652 L
.45654 .34653 L
.45653 .34653 L
.45653 .34653 L
.45653 .34654 L
.45653 .34654 L
.45653 .34655 L
.45652 .34655 L
.45652 .34656 L
.45652 .34656 L
.45652 .34656 L
.45651 .34657 L
Mistroke
.45651 .34657 L
.45651 .34658 L
.45651 .34658 L
.45651 .34658 L
.4565 .34659 L
.4565 .34659 L
.4565 .3466 L
.4565 .3466 L
.4565 .34661 L
.45649 .34661 L
.45649 .34661 L
.45649 .34662 L
.45649 .34662 L
.45649 .34663 L
.45648 .34663 L
.45648 .34663 L
.45648 .34664 L
.45648 .34664 L
.45648 .34665 L
.45647 .34665 L
.45647 .34666 L
.45647 .34666 L
.45647 .34666 L
.45646 .34667 L
.45646 .34667 L
.45646 .34668 L
.45646 .34668 L
.45646 .34668 L
.45645 .34669 L
.45645 .34669 L
.45645 .3467 L
.45645 .3467 L
.45645 .34671 L
.45644 .34671 L
.45644 .34671 L
.45644 .34672 L
.45644 .34672 L
.45643 .34673 L
.45643 .34673 L
.45643 .34673 L
.45643 .34674 L
.45643 .34674 L
.45642 .34675 L
.45642 .34675 L
.45642 .34675 L
.45642 .34676 L
.45642 .34676 L
.45641 .34677 L
.45641 .34677 L
.45641 .34677 L
Mistroke
.45641 .34678 L
.4564 .34678 L
.4564 .34679 L
.4564 .34679 L
.4564 .3468 L
.4564 .3468 L
.45639 .3468 L
.45639 .34681 L
.45639 .34681 L
.45639 .34682 L
.45638 .34682 L
.45638 .34682 L
.45638 .34683 L
.45638 .34683 L
.45638 .34684 L
.45637 .34684 L
.45637 .34684 L
.45637 .34685 L
.45637 .34685 L
.45636 .34686 L
.45636 .34686 L
.45636 .34686 L
.45636 .34687 L
.45636 .34687 L
.45635 .34688 L
.45635 .34688 L
.45635 .34688 L
.45635 .34689 L
.45634 .34689 L
.45634 .3469 L
.45634 .3469 L
.45634 .3469 L
.45633 .34691 L
.45633 .34691 L
.45633 .34692 L
.45633 .34692 L
.45633 .34693 L
.45632 .34693 L
.45632 .34693 L
.45632 .34694 L
.45632 .34694 L
.45631 .34695 L
.45631 .34695 L
.45631 .34695 L
.45631 .34696 L
.4563 .34696 L
.4563 .34697 L
.4563 .34697 L
.4563 .34697 L
.4563 .34698 L
Mistroke
.45629 .34698 L
.45629 .34699 L
.45629 .34699 L
.45629 .34699 L
.45628 .347 L
.45628 .347 L
.45628 .347 L
.45628 .34701 L
.45627 .34701 L
.45627 .34702 L
.45627 .34702 L
.45627 .34702 L
.45626 .34703 L
.45626 .34703 L
.45626 .34704 L
.45626 .34704 L
.45626 .34704 L
.45625 .34705 L
.45625 .34705 L
.45625 .34706 L
.45625 .34706 L
.45624 .34706 L
.45624 .34707 L
.45624 .34707 L
.45624 .34708 L
.45623 .34708 L
.45623 .34708 L
.45623 .34709 L
.45623 .34709 L
.45622 .3471 L
.45622 .3471 L
.45622 .3471 L
.45622 .34711 L
.45621 .34711 L
.45621 .34712 L
.45621 .34712 L
.45621 .34712 L
.4562 .34713 L
.4562 .34713 L
.4562 .34713 L
.4562 .34714 L
.45619 .34714 L
.45619 .34715 L
.45619 .34715 L
.45619 .34715 L
.45619 .34716 L
.45618 .34716 L
.45618 .34717 L
.45618 .34717 L
.45618 .34717 L
Mistroke
.45617 .34718 L
.45617 .34718 L
.45617 .34719 L
.45617 .34719 L
.45616 .34719 L
.45616 .3472 L
.45616 .3472 L
.45616 .3472 L
.45615 .34721 L
.45615 .34721 L
.45615 .34722 L
.45615 .34722 L
.45614 .34722 L
.45614 .34723 L
.45614 .34723 L
.45614 .34724 L
.45613 .34724 L
.45613 .34724 L
.45613 .34725 L
.45613 .34725 L
.45612 .34725 L
.45612 .34726 L
.45612 .34726 L
.45612 .34727 L
.45611 .34727 L
.45611 .34727 L
.45611 .34728 L
.45611 .34728 L
.4561 .34728 L
.4561 .34729 L
.4561 .34729 L
.4561 .3473 L
.45609 .3473 L
.45609 .3473 L
.45609 .34731 L
.45609 .34731 L
.45608 .34732 L
.45608 .34732 L
.45608 .34732 L
.45608 .34733 L
.45607 .34733 L
.45607 .34733 L
.45607 .34734 L
.45606 .34734 L
.45606 .34735 L
.45606 .34735 L
.45606 .34735 L
.45605 .34736 L
.45605 .34736 L
.45605 .34736 L
Mistroke
.45605 .34737 L
.45604 .34737 L
.45604 .34738 L
.45604 .34738 L
.45604 .34738 L
.45603 .34739 L
.45603 .34739 L
.45603 .34739 L
.45603 .3474 L
.45602 .3474 L
.45602 .34741 L
.45602 .34741 L
.45602 .34741 L
.45601 .34742 L
.45601 .34742 L
.45601 .34742 L
.45601 .34743 L
.456 .34743 L
.456 .34744 L
.456 .34744 L
.456 .34744 L
.45599 .34745 L
.45599 .34745 L
.45599 .34745 L
.45598 .34746 L
.45598 .34746 L
.45598 .34746 L
.45598 .34747 L
.45597 .34747 L
.45597 .34748 L
.45597 .34748 L
.45597 .34748 L
.45596 .34749 L
.45596 .34749 L
.45596 .34749 L
.45596 .3475 L
.45595 .3475 L
.45595 .34751 L
.45595 .34751 L
.45595 .34751 L
.45594 .34752 L
.45594 .34752 L
.45594 .34752 L
.45593 .34753 L
.45593 .34753 L
.45593 .34753 L
.45593 .34754 L
.45592 .34754 L
.45592 .34755 L
.45592 .34755 L
Mistroke
.45592 .34755 L
.45591 .34756 L
.45591 .34756 L
.45591 .34756 L
.45591 .34757 L
.4559 .34757 L
.4559 .34757 L
.4559 .34758 L
.45589 .34758 L
.45589 .34758 L
.45589 .34759 L
.45589 .34759 L
.45588 .3476 L
.45588 .3476 L
.45588 .3476 L
.45588 .34761 L
.45587 .34761 L
.45587 .34761 L
.45587 .34762 L
.45586 .34762 L
.45586 .34762 L
.45586 .34763 L
.45586 .34763 L
.45585 .34764 L
.45585 .34764 L
.45585 .34764 L
.45585 .34765 L
.45584 .34765 L
.45584 .34765 L
.45584 .34766 L
.45583 .34766 L
.45583 .34766 L
.45583 .34767 L
.45583 .34767 L
.45582 .34767 L
.45582 .34768 L
.45582 .34768 L
.45582 .34768 L
.45581 .34769 L
.45581 .34769 L
.45581 .3477 L
.4558 .3477 L
.4558 .3477 L
.4558 .34771 L
.4558 .34771 L
.45579 .34771 L
.45579 .34772 L
.45579 .34772 L
.45579 .34772 L
.45578 .34773 L
Mistroke
.45578 .34773 L
.45578 .34773 L
.45577 .34774 L
.45577 .34774 L
.45577 .34774 L
.45577 .34775 L
.45576 .34775 L
.45576 .34775 L
.45576 .34776 L
.45576 .34776 L
.45575 .34777 L
.45575 .34777 L
.45575 .34777 L
.45574 .34778 L
.45574 .34778 L
.45574 .34778 L
.45574 .34779 L
.45573 .34779 L
.45573 .34779 L
.45573 .3478 L
.45572 .3478 L
.45572 .3478 L
.45572 .34781 L
.45572 .34781 L
.45571 .34781 L
.45571 .34782 L
.45571 .34782 L
.45571 .34782 L
.4557 .34783 L
.4557 .34783 L
.4557 .34783 L
.45569 .34784 L
.45569 .34784 L
.45569 .34784 L
.45569 .34785 L
.45568 .34785 L
.45568 .34785 L
.45568 .34786 L
.45567 .34786 L
.45567 .34786 L
.45567 .34787 L
.45567 .34787 L
.45566 .34787 L
.45566 .34788 L
.45566 .34788 L
.45565 .34788 L
.45565 .34789 L
.45565 .34789 L
.45565 .3479 L
.45564 .3479 L
Mistroke
.45564 .3479 L
.45564 .34791 L
.45563 .34791 L
.45563 .34791 L
.45563 .34792 L
.45563 .34792 L
.45562 .34792 L
.45562 .34793 L
.45562 .34793 L
.45562 .34793 L
.45561 .34794 L
.45561 .34794 L
.45561 .34794 L
.4556 .34795 L
.4556 .34795 L
.4556 .34795 L
.4556 .34796 L
.45559 .34796 L
.45559 .34796 L
.45559 .34797 L
.45558 .34797 L
.45558 .34797 L
.45558 .34797 L
.45558 .34798 L
.45557 .34798 L
.45557 .34798 L
.45557 .34799 L
.45556 .34799 L
.45556 .34799 L
.45556 .348 L
.45556 .348 L
.45555 .348 L
.45555 .34801 L
.45555 .34801 L
.45554 .34801 L
.45554 .34802 L
.45554 .34802 L
.45554 .34802 L
.45553 .34803 L
.45553 .34803 L
.45553 .34803 L
.45552 .34804 L
.45552 .34804 L
.45552 .34804 L
.45551 .34805 L
.45551 .34805 L
.45551 .34805 L
.45551 .34806 L
.4555 .34806 L
.4555 .34806 L
Mistroke
.4555 .34807 L
.45549 .34807 L
.45549 .34807 L
.45549 .34808 L
.45549 .34808 L
.45548 .34808 L
.45548 .34809 L
.45548 .34809 L
.45547 .34809 L
.45547 .3481 L
.45547 .3481 L
.45547 .3481 L
.45546 .3481 L
.45546 .34811 L
.45546 .34811 L
.45545 .34811 L
.45545 .34812 L
.45545 .34812 L
.45545 .34812 L
.45544 .34813 L
.45544 .34813 L
.45544 .34813 L
.45543 .34814 L
.45543 .34814 L
.45543 .34814 L
.45543 .34815 L
.45542 .34815 L
.45542 .34815 L
.45542 .34816 L
.45541 .34816 L
.45541 .34816 L
.45541 .34816 L
.4554 .34817 L
.4554 .34817 L
.4554 .34817 L
.4554 .34818 L
.45539 .34818 L
.45539 .34818 L
.45539 .34819 L
.45538 .34819 L
.45538 .34819 L
.45538 .3482 L
.45538 .3482 L
.45537 .3482 L
.45537 .34821 L
.45537 .34821 L
.45536 .34821 L
.45536 .34821 L
.45536 .34822 L
.45535 .34822 L
Mistroke
.45535 .34822 L
.45535 .34823 L
.45535 .34823 L
.45534 .34823 L
.45534 .34824 L
.45534 .34824 L
.45533 .34824 L
.45533 .34825 L
.45533 .34825 L
.45533 .34825 L
.45532 .34825 L
.45532 .34826 L
.45532 .34826 L
.45531 .34826 L
.45531 .34827 L
.45531 .34827 L
.4553 .34827 L
.4553 .34828 L
.4553 .34828 L
.4553 .34828 L
.45529 .34828 L
.45529 .34829 L
.45529 .34829 L
.45528 .34829 L
.45528 .3483 L
.45528 .3483 L
.45528 .3483 L
.45527 .34831 L
.45527 .34831 L
.45527 .34831 L
.45526 .34831 L
.45526 .34832 L
.45526 .34832 L
.45525 .34832 L
.45525 .34833 L
.45525 .34833 L
.45525 .34833 L
.45524 .34834 L
.45524 .34834 L
.45524 .34834 L
.45523 .34834 L
.45523 .34835 L
.45523 .34835 L
.45522 .34835 L
.45522 .34836 L
.45522 .34836 L
.45522 .34836 L
.45521 .34837 L
.45521 .34837 L
.45521 .34837 L
Mistroke
.4552 .34837 L
.4552 .34838 L
.4552 .34838 L
.4552 .34838 L
.45519 .34839 L
.45519 .34839 L
.45519 .34839 L
.45518 .34839 L
.45518 .3484 L
.45518 .3484 L
.45517 .3484 L
.45517 .34841 L
.45517 .34841 L
.45517 .34841 L
.45516 .34842 L
.45516 .34842 L
.45516 .34842 L
.45515 .34842 L
.45515 .34843 L
.45515 .34843 L
.45514 .34843 L
.45514 .34844 L
.45514 .34844 L
.45514 .34844 L
.45513 .34844 L
.45513 .34845 L
.45513 .34845 L
.45512 .34845 L
.45512 .34846 L
.45512 .34846 L
.45511 .34846 L
.45511 .34846 L
.45511 .34847 L
.45511 .34847 L
.4551 .34847 L
.4551 .34848 L
.4551 .34848 L
.45509 .34848 L
.45509 .34848 L
.45509 .34849 L
.45508 .34849 L
.45508 .34849 L
.45508 .3485 L
.45508 .3485 L
.45507 .3485 L
.45507 .3485 L
.45507 .34851 L
.45506 .34851 L
.45506 .34851 L
.45506 .34851 L
Mistroke
.45505 .34852 L
.45505 .34852 L
.45505 .34852 L
.45505 .34853 L
.45504 .34853 L
.45504 .34853 L
.45504 .34853 L
.45503 .34854 L
.45503 .34854 L
.45503 .34854 L
.45502 .34855 L
.45502 .34855 L
.45502 .34855 L
.45502 .34855 L
.45501 .34856 L
.45501 .34856 L
.45501 .34856 L
.455 .34856 L
.455 .34857 L
.455 .34857 L
.45499 .34857 L
.45499 .34858 L
.45499 .34858 L
.45499 .34858 L
.45498 .34858 L
.45498 .34859 L
.45498 .34859 L
.45497 .34859 L
.45497 .34859 L
.45497 .3486 L
.45496 .3486 L
.45496 .3486 L
.45496 .34861 L
.45496 .34861 L
.45495 .34861 L
.45495 .34861 L
.45495 .34862 L
.45494 .34862 L
.45494 .34862 L
.45494 .34862 L
.45493 .34863 L
.45493 .34863 L
.45493 .34863 L
.45493 .34863 L
.45492 .34864 L
.45492 .34864 L
.45492 .34864 L
.45491 .34865 L
.45491 .34865 L
.45491 .34865 L
Mistroke
.4549 .34865 L
.4549 .34866 L
.4549 .34866 L
.45489 .34866 L
.45489 .34866 L
.45489 .34867 L
.45489 .34867 L
.45488 .34867 L
.45488 .34867 L
.45488 .34868 L
.45487 .34868 L
.45487 .34868 L
.45487 .34868 L
.45486 .34869 L
.45486 .34869 L
.45486 .34869 L
.45486 .3487 L
.45485 .3487 L
.45485 .3487 L
.45485 .3487 L
.45484 .34871 L
.45484 .34871 L
.45484 .34871 L
.45483 .34871 L
.45483 .34872 L
.45483 .34872 L
.45483 .34872 L
.45482 .34872 L
.45482 .34873 L
.45482 .34873 L
.45481 .34873 L
.45481 .34873 L
.45481 .34874 L
.4548 .34874 L
.4548 .34874 L
.4548 .34874 L
.45479 .34875 L
.45479 .34875 L
.45479 .34875 L
.45479 .34875 L
.45478 .34876 L
.45478 .34876 L
.45478 .34876 L
.45477 .34876 L
.45477 .34877 L
.45477 .34877 L
.45476 .34877 L
.45476 .34877 L
.45476 .34878 L
.45476 .34878 L
Mistroke
.45475 .34878 L
.45475 .34878 L
.45475 .34879 L
.45474 .34879 L
.45474 .34879 L
.45474 .34879 L
.45473 .3488 L
.45473 .3488 L
.45473 .3488 L
.45473 .3488 L
.45472 .34881 L
.45472 .34881 L
.45472 .34881 L
.45471 .34881 L
.45471 .34882 L
.45471 .34882 L
.4547 .34882 L
.4547 .34882 L
.4547 .34883 L
.4547 .34883 L
.45469 .34883 L
.45469 .34883 L
.45469 .34884 L
.45468 .34884 L
.45468 .34884 L
.45468 .34884 L
.45467 .34885 L
.45467 .34885 L
.45467 .34885 L
.45466 .34885 L
.45466 .34886 L
.45466 .34886 L
.45466 .34886 L
.45465 .34886 L
.45465 .34887 L
.45465 .34887 L
.45464 .34887 L
.45464 .34887 L
.45464 .34887 L
.45463 .34888 L
.45463 .34888 L
.45463 .34888 L
.45463 .34888 L
.45462 .34889 L
.45462 .34889 L
.45462 .34889 L
.45461 .34889 L
.45461 .3489 L
.45461 .3489 L
.4546 .3489 L
Mistroke
.4546 .3489 L
.4546 .34891 L
.4546 .34891 L
.45459 .34891 L
.45459 .34891 L
.45459 .34891 L
.45458 .34892 L
.45458 .34892 L
.45458 .34892 L
.45457 .34892 L
.45457 .34893 L
.45457 .34893 L
.45456 .34893 L
.45456 .34893 L
.45456 .34894 L
.45456 .34894 L
.45455 .34894 L
.45455 .34894 L
.45455 .34895 L
.45454 .34895 L
.45454 .34895 L
.45454 .34895 L
.45453 .34895 L
.45453 .34896 L
.45453 .34896 L
.45453 .34896 L
.45452 .34896 L
.45452 .34897 L
.45452 .34897 L
.45451 .34897 L
.45451 .34897 L
.45451 .34897 L
.4545 .34898 L
.4545 .34898 L
.4545 .34898 L
.4545 .34898 L
.45449 .34899 L
.45449 .34899 L
.45449 .34899 L
.45448 .34899 L
.45448 .34899 L
.45448 .349 L
.45447 .349 L
.45447 .349 L
.45447 .349 L
.45446 .34901 L
.45446 .34901 L
.45446 .34901 L
.45446 .34901 L
.45445 .34901 L
Mistroke
.45445 .34902 L
.45445 .34902 L
.45444 .34902 L
.45444 .34902 L
.45444 .34903 L
.45443 .34903 L
.45443 .34903 L
.45443 .34903 L
.45443 .34903 L
.45442 .34904 L
.45442 .34904 L
.45442 .34904 L
.45441 .34904 L
.45441 .34905 L
.45441 .34905 L
.4544 .34905 L
.4544 .34905 L
.4544 .34905 L
.4544 .34906 L
.45439 .34906 L
.45439 .34906 L
.45439 .34906 L
.45438 .34906 L
.45438 .34907 L
.45438 .34907 L
.45437 .34907 L
.45437 .34907 L
.45437 .34908 L
.45437 .34908 L
.45436 .34908 L
.45436 .34908 L
.45436 .34908 L
.45435 .34909 L
.45435 .34909 L
.45435 .34909 L
.45434 .34909 L
.45434 .34909 L
.45434 .3491 L
.45434 .3491 L
.45433 .3491 L
.45433 .3491 L
.45433 .3491 L
.45432 .34911 L
.45432 .34911 L
.45432 .34911 L
.45431 .34911 L
.45431 .34912 L
.45431 .34912 L
.45431 .34912 L
.4543 .34912 L
Mistroke
.4543 .34912 L
.4543 .34913 L
.45429 .34913 L
.45429 .34913 L
.45429 .34913 L
.45428 .34913 L
.45428 .34914 L
.45428 .34914 L
.45428 .34914 L
.45427 .34914 L
.45427 .34914 L
.45427 .34915 L
.45426 .34915 L
.45426 .34915 L
.45426 .34915 L
.45425 .34915 L
.45425 .34916 L
.45425 .34916 L
.45425 .34916 L
.45424 .34916 L
.45424 .34916 L
.45424 .34917 L
.45423 .34917 L
.45423 .34917 L
.45423 .34917 L
.45422 .34917 L
.45422 .34918 L
.45422 .34918 L
.45422 .34918 L
.45421 .34918 L
.45421 .34918 L
.45421 .34919 L
.4542 .34919 L
.4542 .34919 L
.4542 .34919 L
.45419 .34919 L
.45419 .3492 L
.45419 .3492 L
.45419 .3492 L
.45418 .3492 L
.45418 .3492 L
.45418 .34921 L
.45417 .34921 L
.45417 .34921 L
.45417 .34921 L
.45416 .34921 L
.45416 .34922 L
.45416 .34922 L
.45416 .34922 L
.45415 .34922 L
Mistroke
.45415 .34922 L
.45415 .34922 L
.45414 .34923 L
.45414 .34923 L
.45414 .34923 L
.45414 .34923 L
.45413 .34923 L
.45413 .34924 L
.45413 .34924 L
.45412 .34924 L
.45412 .34924 L
.45412 .34924 L
.45411 .34925 L
.45411 .34925 L
.45411 .34925 L
.45411 .34925 L
.4541 .34925 L
.4541 .34925 L
.4541 .34926 L
.45409 .34926 L
.45409 .34926 L
.45409 .34926 L
.45408 .34926 L
.45408 .34927 L
.45408 .34927 L
.45408 .34927 L
.45407 .34927 L
.45407 .34927 L
.45407 .34928 L
.45406 .34928 L
.45406 .34928 L
.45406 .34928 L
.45406 .34928 L
.45405 .34928 L
.45405 .34929 L
.45405 .34929 L
.45404 .34929 L
.45404 .34929 L
.45404 .34929 L
.45403 .3493 L
.45403 .3493 L
.45403 .3493 L
.45403 .3493 L
.45402 .3493 L
.45402 .3493 L
.45402 .34931 L
.45401 .34931 L
.45401 .34931 L
.45401 .34931 L
.45401 .34931 L
Mistroke
.454 .34931 L
.454 .34932 L
.454 .34932 L
.45399 .34932 L
.45399 .34932 L
.45399 .34932 L
.45398 .34933 L
.45398 .34933 L
.45398 .34933 L
.45398 .34933 L
.45397 .34933 L
.45397 .34933 L
.45397 .34934 L
.45396 .34934 L
.45396 .34934 L
.45396 .34934 L
.45396 .34934 L
.45395 .34934 L
.45395 .34935 L
.45395 .34935 L
.45394 .34935 L
.45394 .34935 L
.45394 .34935 L
.45393 .34935 L
.45393 .34936 L
.45393 .34936 L
.45393 .34936 L
.45392 .34936 L
.45392 .34936 L
.45392 .34936 L
.45391 .34937 L
.45391 .34937 L
.45391 .34937 L
.45391 .34937 L
.4539 .34937 L
.4539 .34937 L
.4539 .34938 L
.45389 .34938 L
.45389 .34938 L
.45389 .34938 L
.45389 .34938 L
.45388 .34938 L
.45388 .34939 L
.45388 .34939 L
.45387 .34939 L
.45387 .34939 L
.45387 .34939 L
.45386 .34939 L
.45386 .3494 L
.45386 .3494 L
Mistroke
.45386 .3494 L
.45385 .3494 L
.45385 .3494 L
.45385 .3494 L
.45384 .34941 L
.45384 .34941 L
.45384 .34941 L
.45384 .34941 L
.45383 .34941 L
.45383 .34941 L
.45383 .34942 L
.45382 .34942 L
.45382 .34942 L
.45382 .34942 L
.45382 .34942 L
.45381 .34942 L
.45381 .34943 L
.45381 .34943 L
.4538 .34943 L
.4538 .34943 L
.4538 .34943 L
.4538 .34943 L
.45379 .34943 L
.45379 .34944 L
.45379 .34944 L
.45378 .34944 L
.45378 .34944 L
.45378 .34944 L
.45378 .34944 L
.45377 .34945 L
.45377 .34945 L
.45377 .34945 L
.45376 .34945 L
.45376 .34945 L
.45376 .34945 L
.45376 .34945 L
.45375 .34946 L
.45375 .34946 L
.45375 .34946 L
.45374 .34946 L
.45374 .34946 L
.45374 .34946 L
.45374 .34947 L
.45373 .34947 L
.45373 .34947 L
.45373 .34947 L
.45372 .34947 L
.45372 .34947 L
.45372 .34947 L
.45372 .34948 L
Mistroke
.45371 .34948 L
.45371 .34948 L
.45371 .34948 L
.4537 .34948 L
.4537 .34948 L
.4537 .34948 L
.4537 .34949 L
.45369 .34949 L
.45369 .34949 L
.45369 .34949 L
.45368 .34949 L
.45368 .34949 L
.45368 .34949 L
.45368 .3495 L
.45367 .3495 L
.45367 .3495 L
.45367 .3495 L
.45366 .3495 L
.45366 .3495 L
.45366 .3495 L
.45366 .34951 L
.45365 .34951 L
.45365 .34951 L
.45365 .34951 L
.45364 .34951 L
.45364 .34951 L
.45364 .34951 L
.45364 .34952 L
.45363 .34952 L
.45363 .34952 L
.45363 .34952 L
.45362 .34952 L
.45362 .34952 L
.45362 .34952 L
.45362 .34953 L
.45361 .34953 L
.45361 .34953 L
.45361 .34953 L
.4536 .34953 L
.4536 .34953 L
.4536 .34953 L
.4536 .34954 L
.45359 .34954 L
.45359 .34954 L
.45359 .34954 L
.45359 .34954 L
.45358 .34954 L
.45358 .34954 L
.45358 .34955 L
.45357 .34955 L
Mistroke
.45357 .34955 L
.45357 .34955 L
.45357 .34955 L
.45356 .34955 L
.45356 .34955 L
.45356 .34955 L
.45355 .34956 L
.45355 .34956 L
.45355 .34956 L
.45355 .34956 L
.45354 .34956 L
.45354 .34956 L
.45354 .34956 L
.45353 .34957 L
.45353 .34957 L
.45353 .34957 L
.45353 .34957 L
.45352 .34957 L
.45352 .34957 L
.45352 .34957 L
.45352 .34957 L
.45351 .34958 L
.45351 .34958 L
.45351 .34958 L
.4535 .34958 L
.4535 .34958 L
.4535 .34958 L
.4535 .34958 L
.45349 .34958 L
.45349 .34959 L
.45349 .34959 L
.45348 .34959 L
.45348 .34959 L
.45348 .34959 L
.45348 .34959 L
.45347 .34959 L
.45347 .34959 L
.45347 .3496 L
.45347 .3496 L
.45346 .3496 L
.45346 .3496 L
.45346 .3496 L
.45345 .3496 L
.45345 .3496 L
.45345 .3496 L
.45345 .34961 L
.45344 .34961 L
.45344 .34961 L
.45344 .34961 L
.45344 .34961 L
Mistroke
.45343 .34961 L
.45343 .34961 L
.45343 .34961 L
.45342 .34962 L
.45342 .34962 L
.45342 .34962 L
.45342 .34962 L
.45341 .34962 L
.45341 .34962 L
.45341 .34962 L
.45341 .34962 L
.4534 .34962 L
.4534 .34963 L
.4534 .34963 L
.45339 .34963 L
.45339 .34963 L
.45339 .34963 L
.45339 .34963 L
.45338 .34963 L
.45338 .34963 L
.45338 .34964 L
.45338 .34964 L
.45337 .34964 L
.45337 .34964 L
.45337 .34964 L
.45336 .34964 L
.45336 .34964 L
.45336 .34964 L
.45336 .34964 L
.45335 .34965 L
.45335 .34965 L
.45335 .34965 L
.45335 .34965 L
.45334 .34965 L
.45334 .34965 L
.45334 .34965 L
.45333 .34965 L
.45333 .34965 L
.45333 .34966 L
.45333 .34966 L
.45332 .34966 L
.45332 .34966 L
.45332 .34966 L
.45332 .34966 L
.45331 .34966 L
.45331 .34966 L
.45331 .34966 L
.45331 .34967 L
.4533 .34967 L
.4533 .34967 L
Mistroke
.4533 .34967 L
.45329 .34967 L
.45329 .34967 L
.45329 .34967 L
.45329 .34967 L
.45328 .34967 L
.45328 .34968 L
.45328 .34968 L
.45328 .34968 L
.45327 .34968 L
.45327 .34968 L
.45327 .34968 L
.45327 .34968 L
.45326 .34968 L
.45326 .34968 L
.45326 .34968 L
.45325 .34969 L
.45325 .34969 L
.45325 .34969 L
.45325 .34969 L
.45324 .34969 L
.45324 .34969 L
.45324 .34969 L
.45324 .34969 L
.45323 .34969 L
.45323 .34969 L
.45323 .3497 L
.45323 .3497 L
.45322 .3497 L
.45322 .3497 L
.45322 .3497 L
.45322 .3497 L
.45321 .3497 L
.45321 .3497 L
.45321 .3497 L
.4532 .3497 L
.4532 .34971 L
.4532 .34971 L
.4532 .34971 L
.45319 .34971 L
.45319 .34971 L
.45319 .34971 L
.45319 .34971 L
.45318 .34971 L
.45318 .34971 L
.45318 .34971 L
.45318 .34972 L
.45317 .34972 L
.45317 .34972 L
.45317 .34972 L
Mistroke
.45317 .34972 L
.45316 .34972 L
.45316 .34972 L
.45316 .34972 L
.45315 .34972 L
.45315 .34972 L
.45315 .34972 L
.45315 .34973 L
.45314 .34973 L
.45314 .34973 L
.45314 .34973 L
.45314 .34973 L
.45313 .34973 L
.45313 .34973 L
.45313 .34973 L
.45313 .34973 L
.45312 .34973 L
.45312 .34974 L
.45312 .34974 L
.45312 .34974 L
.45311 .34974 L
.45311 .34974 L
.45311 .34974 L
.45311 .34974 L
.4531 .34974 L
.4531 .34974 L
.4531 .34974 L
.4531 .34974 L
.45309 .34974 L
.45309 .34975 L
.45309 .34975 L
.45309 .34975 L
.45308 .34975 L
.45308 .34975 L
.45308 .34975 L
.45307 .34975 L
.45307 .34975 L
.45307 .34975 L
.45307 .34975 L
.45306 .34975 L
.45306 .34976 L
.45306 .34976 L
.45306 .34976 L
.45305 .34976 L
.45305 .34976 L
.45305 .34976 L
.45305 .34976 L
.45304 .34976 L
.45304 .34976 L
.45304 .34976 L
Mistroke
.45304 .34976 L
.45303 .34976 L
.45303 .34977 L
.45303 .34977 L
.45303 .34977 L
.45302 .34977 L
.45302 .34977 L
.45302 .34977 L
.45302 .34977 L
.45301 .34977 L
.45301 .34977 L
.45301 .34977 L
.45301 .34977 L
.453 .34977 L
.453 .34977 L
.453 .34978 L
.453 .34978 L
.45299 .34978 L
.45299 .34978 L
.45299 .34978 L
.45299 .34978 L
.45298 .34978 L
.45298 .34978 L
.45298 .34978 L
.45298 .34978 L
.45297 .34978 L
.45297 .34978 L
.45297 .34978 L
.45297 .34979 L
.45296 .34979 L
.45296 .34979 L
.45296 .34979 L
.45296 .34979 L
.45295 .34979 L
.45295 .34979 L
.45295 .34979 L
.45295 .34979 L
.45294 .34979 L
.45294 .34979 L
.45294 .34979 L
.45294 .34979 L
.45293 .3498 L
.45293 .3498 L
.45293 .3498 L
.45293 .3498 L
.45292 .3498 L
.45292 .3498 L
.45292 .3498 L
.45292 .3498 L
.45291 .3498 L
Mistroke
.45291 .3498 L
.45291 .3498 L
.45291 .3498 L
.4529 .3498 L
.4529 .3498 L
.4529 .34981 L
.4529 .34981 L
.45289 .34981 L
.45289 .34981 L
.45289 .34981 L
.45289 .34981 L
.45289 .34981 L
.45288 .34981 L
.45288 .34981 L
.45288 .34981 L
.45288 .34981 L
.45287 .34981 L
.45287 .34981 L
.45287 .34981 L
.45287 .34981 L
.45286 .34982 L
.45286 .34982 L
.45286 .34982 L
.45286 .34982 L
.45285 .34982 L
.45285 .34982 L
.45285 .34982 L
.45285 .34982 L
.45284 .34982 L
.45284 .34982 L
.45284 .34982 L
.45284 .34982 L
.45283 .34982 L
.45283 .34982 L
.45283 .34982 L
.45283 .34982 L
.45282 .34983 L
.45282 .34983 L
.45282 .34983 L
.45282 .34983 L
.45282 .34983 L
.45281 .34983 L
.45281 .34983 L
.45281 .34983 L
.45281 .34983 L
.4528 .34983 L
.4528 .34983 L
.4528 .34983 L
.4528 .34983 L
.45279 .34983 L
Mistroke
.45279 .34983 L
.45279 .34983 L
.45279 .34983 L
.45278 .34984 L
.45278 .34984 L
.45278 .34984 L
.45278 .34984 L
.45277 .34984 L
.45277 .34984 L
.45277 .34984 L
.45277 .34984 L
.45277 .34984 L
.45276 .34984 L
.45276 .34984 L
.45276 .34984 L
.45276 .34984 L
.45275 .34984 L
.45275 .34984 L
.45275 .34984 L
.45275 .34984 L
.45274 .34984 L
.45274 .34985 L
.45274 .34985 L
.45274 .34985 L
.45273 .34985 L
.45273 .34985 L
.45273 .34985 L
.45273 .34985 L
.45273 .34985 L
.45272 .34985 L
.45272 .34985 L
.45272 .34985 L
.45272 .34985 L
.45271 .34985 L
.45271 .34985 L
.45271 .34985 L
.45271 .34985 L
.4527 .34985 L
.4527 .34985 L
.4527 .34985 L
.4527 .34985 L
.4527 .34986 L
.45269 .34986 L
.45269 .34986 L
.45269 .34986 L
.45269 .34986 L
.45268 .34986 L
.45268 .34986 L
.45268 .34986 L
.45268 .34986 L
Mistroke
.45267 .34986 L
.45267 .34986 L
.45267 .34986 L
.45267 .34986 L
.45267 .34986 L
.45266 .34986 L
.45266 .34986 L
.45266 .34986 L
.45266 .34986 L
.45265 .34986 L
.45265 .34986 L
.45265 .34986 L
.45265 .34987 L
.45265 .34987 L
.45264 .34987 L
.45264 .34987 L
.45264 .34987 L
.45264 .34987 L
.45263 .34987 L
.45263 .34987 L
.45263 .34987 L
.45263 .34987 L
.45262 .34987 L
.45262 .34987 L
.45262 .34987 L
.45262 .34987 L
.45262 .34987 L
.45261 .34987 L
.45261 .34987 L
.45261 .34987 L
.45261 .34987 L
.4526 .34987 L
.4526 .34987 L
.4526 .34987 L
.4526 .34987 L
.4526 .34987 L
.45259 .34988 L
.45259 .34988 L
.45259 .34988 L
.45259 .34988 L
.45258 .34988 L
.45258 .34988 L
.45258 .34988 L
.45258 .34988 L
.45258 .34988 L
.45257 .34988 L
.45257 .34988 L
.45257 .34988 L
.45257 .34988 L
.45256 .34988 L
Mistroke
.45256 .34988 L
.45256 .34988 L
.45256 .34988 L
.45256 .34988 L
.45255 .34988 L
.45255 .34988 L
.45255 .34988 L
.45255 .34988 L
.45254 .34988 L
.45254 .34988 L
.45254 .34988 L
.45254 .34988 L
.45254 .34988 L
.45253 .34988 L
.45253 .34988 L
.45253 .34989 L
.45253 .34989 L
.45253 .34989 L
.45252 .34989 L
.45252 .34989 L
.45252 .34989 L
.45252 .34989 L
.45251 .34989 L
.45251 .34989 L
.45251 .34989 L
.45251 .34989 L
.45251 .34989 L
.4525 .34989 L
.4525 .34989 L
.4525 .34989 L
.4525 .34989 L
.45249 .34989 L
.45249 .34989 L
.45249 .34989 L
.45249 .34989 L
.45249 .34989 L
.45248 .34989 L
.45248 .34989 L
.45248 .34989 L
.45248 .34989 L
.45248 .34989 L
.45247 .34989 L
.45247 .34989 L
.45247 .34989 L
.45247 .34989 L
.45246 .34989 L
.45246 .34989 L
.45246 .34989 L
.45246 .34989 L
.45246 .3499 L
Mistroke
.45245 .3499 L
.45245 .3499 L
.45245 .3499 L
.45245 .3499 L
.45245 .3499 L
.45244 .3499 L
.45244 .3499 L
.45244 .3499 L
.45244 .3499 L
.45244 .3499 L
.45243 .3499 L
.45243 .3499 L
.45243 .3499 L
.45243 .3499 L
.45242 .3499 L
.45242 .3499 L
.45242 .3499 L
.45242 .3499 L
.45242 .3499 L
.45241 .3499 L
.45241 .3499 L
.45241 .3499 L
.45241 .3499 L
.45241 .3499 L
.4524 .3499 L
.4524 .3499 L
.4524 .3499 L
.4524 .3499 L
.4524 .3499 L
.45239 .3499 L
.45239 .3499 L
.45239 .3499 L
.45239 .3499 L
.45239 .3499 L
.45238 .3499 L
.45238 .3499 L
.45238 .3499 L
.45238 .3499 L
.45238 .3499 L
.45237 .3499 L
.45237 .3499 L
.45237 .3499 L
.45237 .3499 L
.45236 .3499 L
.45236 .3499 L
.45236 .3499 L
.45236 .3499 L
.45236 .3499 L
.45235 .3499 L
.45235 .34991 L
Mistroke
.45235 .34991 L
.45235 .34991 L
.45235 .34991 L
.45234 .34991 L
.45234 .34991 L
.45234 .34991 L
.45234 .34991 L
.45234 .34991 L
.45233 .34991 L
.45233 .34991 L
.45233 .34991 L
.45233 .34991 L
.45233 .34991 L
.45232 .34991 L
.45232 .34991 L
.45232 .34991 L
.45232 .34991 L
.45232 .34991 L
.45231 .34991 L
.45231 .34991 L
.45231 .34991 L
.45231 .34991 L
.45231 .34991 L
.4523 .34991 L
.4523 .34991 L
.4523 .34991 L
.4523 .34991 L
.4523 .34991 L
.45229 .34991 L
.45229 .34991 L
.45229 .34991 L
.45229 .34991 L
.45229 .34991 L
.45228 .34991 L
.45228 .34991 L
.45228 .34991 L
.45228 .34991 L
.45228 .34991 L
.45227 .34991 L
.45227 .34991 L
.45227 .34991 L
.45227 .34991 L
.45227 .34991 L
.45227 .34991 L
.45226 .34991 L
.45226 .34991 L
.45226 .34991 L
.45226 .34991 L
.45226 .34991 L
.45225 .34991 L
Mistroke
.45225 .34991 L
.45225 .34991 L
.45225 .34991 L
.45225 .34991 L
.45224 .34991 L
.45224 .34991 L
.45224 .34991 L
.45224 .34991 L
.45224 .34991 L
.45223 .34991 L
.45223 .34991 L
.45223 .34991 L
.45223 .34991 L
.45223 .34991 L
.45222 .34991 L
.45222 .34991 L
.45222 .34991 L
.45222 .34991 L
.45222 .34991 L
.45222 .34991 L
.45221 .34991 L
.45221 .34991 L
.45221 .34991 L
.45221 .34991 L
.45221 .34991 L
.4522 .34991 L
.4522 .34991 L
.4522 .34991 L
.4522 .34991 L
.4522 .34991 L
.45219 .34991 L
.45219 .34991 L
.45219 .34991 L
.45219 .34991 L
.45219 .34991 L
.45219 .34991 L
.45218 .34991 L
.45218 .34991 L
.45218 .34991 L
.45218 .34991 L
.45218 .34991 L
.45217 .34991 L
.45217 .34991 L
.45217 .34991 L
.45217 .34991 L
.45217 .34991 L
.45216 .34991 L
.45216 .34991 L
.45216 .34991 L
.45216 .34991 L
Mistroke
.45216 .34991 L
.45216 .34991 L
.45215 .34991 L
.45215 .34991 L
.45215 .34991 L
.45215 .34991 L
.45215 .34991 L
.45214 .34991 L
.45214 .34991 L
.45214 .34991 L
.45214 .34991 L
.45214 .34991 L
.45214 .34991 L
.45213 .34991 L
.45213 .34991 L
.45213 .34991 L
.45213 .34991 L
.45213 .34991 L
.45212 .34991 L
.45212 .34991 L
.45212 .34991 L
.45212 .34991 L
.45212 .34991 L
.45212 .34991 L
.45211 .34991 L
.45211 .34991 L
.45211 .34991 L
.45211 .34991 L
.45211 .34991 L
.4521 .34991 L
.4521 .34991 L
.4521 .34991 L
.4521 .34991 L
.4521 .34991 L
.4521 .34991 L
.45209 .34991 L
.45209 .34991 L
.45209 .34991 L
.45209 .34991 L
.45209 .34991 L
.45209 .34991 L
.45208 .34991 L
.45208 .34991 L
.45208 .34991 L
.45208 .34991 L
.45208 .34991 L
.45207 .34991 L
.45207 .34991 L
.45207 .34991 L
.45207 .34991 L
Mistroke
.45207 .34991 L
.45207 .34991 L
.45206 .34991 L
.45206 .34991 L
.45206 .34991 L
.45206 .34991 L
.45206 .34991 L
.45206 .34991 L
.45205 .34991 L
.45205 .3499 L
.45205 .3499 L
.45205 .3499 L
.45205 .3499 L
.45205 .3499 L
.45204 .3499 L
.45204 .3499 L
.45204 .3499 L
.45204 .3499 L
.45204 .3499 L
.45203 .3499 L
.45203 .3499 L
.45203 .3499 L
.45203 .3499 L
.45203 .3499 L
.45203 .3499 L
.45202 .3499 L
.45202 .3499 L
.45202 .3499 L
.45202 .3499 L
.45202 .3499 L
.45202 .3499 L
.45201 .3499 L
.45201 .3499 L
.45201 .3499 L
.45201 .3499 L
.45201 .3499 L
.45201 .3499 L
.452 .3499 L
.452 .3499 L
.452 .3499 L
.452 .3499 L
.452 .3499 L
.452 .3499 L
.45199 .3499 L
.45199 .3499 L
.45199 .3499 L
.45199 .3499 L
.45199 .3499 L
.45199 .3499 L
.45198 .3499 L
Mistroke
.45198 .3499 L
.45198 .3499 L
.45198 .3499 L
.45198 .3499 L
.45198 .3499 L
.45197 .3499 L
.45197 .3499 L
.45197 .3499 L
.45197 .3499 L
.45197 .3499 L
.45197 .3499 L
.45196 .3499 L
.45196 .34989 L
.45196 .34989 L
.45196 .34989 L
.45196 .34989 L
.45196 .34989 L
.45195 .34989 L
.45195 .34989 L
.45195 .34989 L
.45195 .34989 L
.45195 .34989 L
.45195 .34989 L
.45195 .34989 L
.45194 .34989 L
.45194 .34989 L
.45194 .34989 L
.45194 .34989 L
.45194 .34989 L
.45194 .34989 L
.45193 .34989 L
.45193 .34989 L
.45193 .34989 L
.45193 .34989 L
.45193 .34989 L
.45193 .34989 L
.45192 .34989 L
.45192 .34989 L
.45192 .34989 L
.45192 .34989 L
.45192 .34989 L
.45192 .34989 L
.45191 .34989 L
.45191 .34989 L
.45191 .34989 L
.45191 .34989 L
.45191 .34989 L
.45191 .34989 L
.45191 .34989 L
.4519 .34989 L
Mistroke
.4519 .34988 L
.4519 .34988 L
.4519 .34988 L
.4519 .34988 L
.4519 .34988 L
.45189 .34988 L
.45189 .34988 L
.45189 .34988 L
.45189 .34988 L
.45189 .34988 L
.45189 .34988 L
.45189 .34988 L
.45188 .34988 L
.45188 .34988 L
.45188 .34988 L
.45188 .34988 L
.45188 .34988 L
.45188 .34988 L
.45187 .34988 L
.45187 .34988 L
.45187 .34988 L
.45187 .34988 L
.45187 .34988 L
.45187 .34988 L
.45187 .34988 L
.45186 .34988 L
.45186 .34988 L
.45186 .34988 L
.45186 .34988 L
.45186 .34988 L
.45186 .34988 L
.45186 .34988 L
.45185 .34987 L
.45185 .34987 L
.45185 .34987 L
.45185 .34987 L
.45185 .34987 L
.45185 .34987 L
.45184 .34987 L
.45184 .34987 L
.45184 .34987 L
.45184 .34987 L
.45184 .34987 L
.45184 .34987 L
.45184 .34987 L
.45183 .34987 L
.45183 .34987 L
.45183 .34987 L
.45183 .34987 L
.45183 .34987 L
Mistroke
.45183 .34987 L
.45183 .34987 L
.45182 .34987 L
.45182 .34987 L
.45182 .34987 L
.45182 .34987 L
.45182 .34987 L
.45182 .34987 L
.45182 .34987 L
.45181 .34987 L
.45181 .34986 L
.45181 .34986 L
.45181 .34986 L
.45181 .34986 L
.45181 .34986 L
.45181 .34986 L
.4518 .34986 L
.4518 .34986 L
.4518 .34986 L
.4518 .34986 L
.4518 .34986 L
.4518 .34986 L
.4518 .34986 L
.45179 .34986 L
.45179 .34986 L
.45179 .34986 L
.45179 .34986 L
.45179 .34986 L
.45179 .34986 L
.45179 .34986 L
.45178 .34986 L
.45178 .34986 L
.45178 .34986 L
.45178 .34986 L
.45178 .34986 L
.45178 .34985 L
.45178 .34985 L
.45177 .34985 L
.45177 .34985 L
.45177 .34985 L
.45177 .34985 L
.45177 .34985 L
.45177 .34985 L
.45177 .34985 L
.45176 .34985 L
.45176 .34985 L
.45176 .34985 L
.45176 .34985 L
.45176 .34985 L
.45176 .34985 L
Mistroke
.45176 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34985 L
.45175 .34984 L
.45174 .34984 L
.45174 .34984 L
.45174 .34984 L
.45174 .34984 L
.45174 .34984 L
.45174 .34984 L
.45174 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45173 .34984 L
.45172 .34984 L
.45172 .34984 L
.45172 .34984 L
.45172 .34984 L
.45172 .34984 L
.45172 .34984 L
.45172 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.45171 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.4517 .34983 L
.45169 .34983 L
.45169 .34983 L
.45169 .34983 L
Mistroke
.45169 .34982 L
.45169 .34982 L
.45169 .34982 L
.45169 .34982 L
.45169 .34982 L
.45168 .34982 L
.45168 .34982 L
.45168 .34982 L
.45168 .34982 L
.45168 .34982 L
.45168 .34982 L
.45168 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34982 L
.45167 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45166 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45165 .34981 L
.45164 .34981 L
.45164 .3498 L
.45164 .3498 L
.45164 .3498 L
.45164 .3498 L
.45164 .3498 L
.45164 .3498 L
.45164 .3498 L
.45163 .3498 L
.45163 .3498 L
.45163 .3498 L
.45163 .3498 L
.45163 .3498 L
Mistroke
.45163 .3498 L
.45163 .3498 L
.45163 .3498 L
.45163 .3498 L
.45162 .3498 L
.45162 .3498 L
.45162 .34979 L
.45162 .34979 L
.45162 .34979 L
.45162 .34979 L
.45162 .34979 L
.45162 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.45161 .34979 L
.4516 .34979 L
.4516 .34979 L
.4516 .34979 L
.4516 .34978 L
.4516 .34978 L
.4516 .34978 L
.4516 .34978 L
.4516 .34978 L
.4516 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45159 .34978 L
.45158 .34978 L
.45158 .34978 L
.45158 .34977 L
.45158 .34977 L
.45158 .34977 L
.45158 .34977 L
.45158 .34977 L
.45158 .34977 L
.45158 .34977 L
.45157 .34977 L
.45157 .34977 L
Mistroke
.45157 .34977 L
.45157 .34977 L
.45157 .34977 L
.45157 .34977 L
.45157 .34977 L
.45157 .34977 L
.45157 .34977 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45156 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34976 L
.45155 .34975 L
.45155 .34975 L
.45155 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45154 .34975 L
.45153 .34975 L
.45153 .34975 L
.45153 .34974 L
.45153 .34974 L
.45153 .34974 L
.45153 .34974 L
.45153 .34974 L
.45153 .34974 L
.45153 .34974 L
.45152 .34974 L
.45152 .34974 L
.45152 .34974 L
.45152 .34974 L
.45152 .34974 L
Mistroke
.45152 .34974 L
.45152 .34974 L
.45152 .34974 L
.45152 .34973 L
.45152 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.45151 .34973 L
.4515 .34973 L
.4515 .34973 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.4515 .34972 L
.45149 .34972 L
.45149 .34972 L
.45149 .34972 L
.45149 .34972 L
.45149 .34972 L
.45149 .34972 L
.45149 .34971 L
.45149 .34971 L
.45149 .34971 L
.45149 .34971 L
.45149 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45148 .34971 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
Mistroke
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45147 .3497 L
.45146 .3497 L
.45146 .3497 L
.45146 .3497 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45146 .34969 L
.45145 .34969 L
.45145 .34969 L
.45145 .34969 L
.45145 .34969 L
.45145 .34968 L
.45145 .34968 L
.45145 .34968 L
.45145 .34968 L
.45145 .34968 L
.45145 .34968 L
.45145 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34968 L
.45144 .34967 L
.45144 .34967 L
.45144 .34967 L
.45144 .34967 L
.45144 .34967 L
.45143 .34967 L
.45143 .34967 L
.45143 .34967 L
.45143 .34967 L
.45143 .34967 L
.45143 .34967 L
.45143 .34967 L
Mistroke
.45143 .34967 L
.45143 .34966 L
.45143 .34966 L
.45143 .34966 L
.45143 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34966 L
.45142 .34965 L
.45142 .34965 L
.45142 .34965 L
.45142 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34965 L
.45141 .34964 L
.45141 .34964 L
.45141 .34964 L
.45141 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34964 L
.4514 .34963 L
.4514 .34963 L
.4514 .34963 L
.4514 .34963 L
.45139 .34963 L
.45139 .34963 L
.45139 .34963 L
.45139 .34963 L
.45139 .34963 L
.45139 .34963 L
Mistroke
.45139 .34963 L
.45139 .34963 L
.45139 .34963 L
.45139 .34962 L
.45139 .34962 L
.45139 .34962 L
.45139 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34962 L
.45138 .34961 L
.45138 .34961 L
.45138 .34961 L
.45138 .34961 L
.45138 .34961 L
.45138 .34961 L
.45137 .34961 L
.45137 .34961 L
.45137 .34961 L
.45137 .34961 L
.45137 .34961 L
.45137 .34961 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45137 .3496 L
.45136 .3496 L
.45136 .3496 L
.45136 .3496 L
.45136 .3496 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
.45136 .34959 L
Mistroke
.45136 .34959 L
.45135 .34959 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34958 L
.45135 .34957 L
.45135 .34957 L
.45135 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34957 L
.45134 .34956 L
.45134 .34956 L
.45134 .34956 L
.45134 .34956 L
.45134 .34956 L
.45134 .34956 L
.45134 .34956 L
.45133 .34956 L
.45133 .34956 L
.45133 .34956 L
.45133 .34956 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34955 L
.45133 .34954 L
Mistroke
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34954 L
.45132 .34953 L
.45132 .34953 L
.45132 .34953 L
.45132 .34953 L
.45132 .34953 L
.45132 .34953 L
.45132 .34953 L
.45131 .34953 L
.45131 .34953 L
.45131 .34953 L
.45131 .34953 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34952 L
.45131 .34951 L
.45131 .34951 L
.45131 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .34951 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
Mistroke
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .3495 L
.4513 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34949 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45129 .34948 L
.45128 .34948 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34947 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
.45128 .34946 L
Mistroke
.45128 .34946 L
.45128 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34945 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34944 L
.45127 .34943 L
.45127 .34943 L
.45127 .34943 L
.45127 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34943 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34942 L
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
Mistroke
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
.45126 .34941 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .3494 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34939 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45125 .34938 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34937 L
.45124 .34936 L
.45124 .34936 L
Mistroke
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34936 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34935 L
.45124 .34934 L
.45124 .34934 L
.45124 .34934 L
.45124 .34934 L
.45124 .34934 L
.45124 .34934 L
.45123 .34934 L
.45123 .34934 L
.45123 .34934 L
.45123 .34934 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34933 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
.45123 .34932 L
Mistroke
.45123 .34932 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .34931 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .3493 L
.45123 .34929 L
.45123 .34929 L
.45123 .34929 L
.45123 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34929 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34928 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
Mistroke
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34927 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34926 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34925 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34924 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34923 L
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
Mistroke
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
.45122 .34922 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .34921 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45122 .3492 L
.45121 .3492 L
.45121 .3492 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34919 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34918 L
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
Mistroke
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
.45121 .34917 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34916 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34915 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34914 L
.45121 .34913 L
.45121 .34913 L
.45121 .34913 L
.45121 .34913 L
.45121 .34913 L
.45122 .34913 L
.45122 .34913 L
.45122 .34913 L
.45122 .34913 L
.45122 .34913 L
.45122 .34913 L
.45122 .34912 L
Mistroke
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34912 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .34911 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .3491 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34909 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
.45122 .34908 L
Mistroke
.45122 .34908 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34907 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34906 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34905 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34904 L
.45122 .34903 L
.45122 .34903 L
.45122 .34903 L
.45122 .34903 L
.45122 .34903 L
.45123 .34903 L
.45123 .34903 L
.45123 .34903 L
Mistroke
.45123 .34903 L
.45123 .34903 L
.45123 .34903 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34902 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .34901 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .349 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34899 L
.45123 .34898 L
.45123 .34898 L
.45123 .34898 L
.45123 .34898 L
.45123 .34898 L
Mistroke
.45123 .34898 L
.45123 .34898 L
.45123 .34898 L
.45124 .34898 L
.45124 .34898 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34897 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34896 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34895 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45124 .34894 L
.45125 .34894 L
.45125 .34893 L
.45125 .34893 L
Mistroke
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34893 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34892 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .34891 L
.45125 .3489 L
.45125 .3489 L
.45125 .3489 L
.45125 .3489 L
.45125 .3489 L
.45126 .3489 L
.45126 .3489 L
.45126 .3489 L
.45126 .3489 L
.45126 .3489 L
.45126 .3489 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
.45126 .34889 L
Mistroke
.45126 .34889 L
.45126 .34889 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34888 L
.45126 .34887 L
.45126 .34887 L
.45126 .34887 L
.45126 .34887 L
.45126 .34887 L
.45126 .34887 L
.45127 .34887 L
.45127 .34887 L
.45127 .34887 L
.45127 .34887 L
.45127 .34887 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34886 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34885 L
.45127 .34884 L
.45127 .34884 L
.45127 .34884 L
.45127 .34884 L
Mistroke
.45128 .34884 L
.45128 .34884 L
.45128 .34884 L
.45128 .34884 L
.45128 .34884 L
.45128 .34884 L
.45128 .34884 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34883 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45128 .34882 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .34881 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
.45129 .3488 L
Mistroke
.45129 .3488 L
.45129 .34879 L
.45129 .34879 L
.45129 .34879 L
.45129 .34879 L
.45129 .34879 L
.45129 .34879 L
.4513 .34879 L
.4513 .34879 L
.4513 .34879 L
.4513 .34879 L
.4513 .34879 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34878 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.4513 .34877 L
.45131 .34877 L
.45131 .34877 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34876 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
Mistroke
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45131 .34875 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34874 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34873 L
.45132 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34872 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
Mistroke
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45133 .34871 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .3487 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45134 .34869 L
.45135 .34869 L
.45135 .34869 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34868 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45135 .34867 L
.45136 .34867 L
Mistroke
.45136 .34867 L
.45136 .34867 L
.45136 .34867 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34866 L
.45136 .34865 L
.45136 .34865 L
.45136 .34865 L
.45136 .34865 L
.45136 .34865 L
.45136 .34865 L
.45137 .34865 L
.45137 .34865 L
.45137 .34865 L
.45137 .34865 L
.45137 .34865 L
.45137 .34865 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34864 L
.45137 .34863 L
.45137 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
.45138 .34863 L
Mistroke
.45138 .34863 L
.45138 .34863 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45138 .34862 L
.45139 .34862 L
.45139 .34862 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .34861 L
.45139 .3486 L
.45139 .3486 L
.45139 .3486 L
.45139 .3486 L
.45139 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .3486 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
.4514 .34859 L
Mistroke
.4514 .34859 L
.45141 .34859 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34858 L
.45141 .34857 L
.45141 .34857 L
.45141 .34857 L
.45141 .34857 L
.45141 .34857 L
.45141 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34857 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45142 .34856 L
.45143 .34856 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
Mistroke
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34855 L
.45143 .34854 L
.45143 .34854 L
.45143 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34854 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45144 .34853 L
.45145 .34853 L
.45145 .34853 L
.45145 .34853 L
.45145 .34853 L
.45145 .34853 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45145 .34852 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
Mistroke
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .34851 L
.45146 .3485 L
.45146 .3485 L
.45146 .3485 L
.45146 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .3485 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45147 .34849 L
.45148 .34849 L
.45148 .34849 L
.45148 .34849 L
.45148 .34849 L
.45148 .34849 L
.45148 .34849 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45148 .34848 L
.45149 .34848 L
Mistroke
.45149 .34848 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.45149 .34847 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34846 L
.4515 .34845 L
.4515 .34845 L
.4515 .34845 L
.4515 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34845 L
.45151 .34844 L
.45151 .34844 L
.45151 .34844 L
.45151 .34844 L
.45151 .34844 L
Mistroke
.45151 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34844 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45152 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34843 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45153 .34842 L
.45154 .34842 L
.45154 .34842 L
.45154 .34842 L
.45154 .34842 L
.45154 .34842 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
.45154 .34841 L
Mistroke
.45154 .34841 L
.45154 .34841 L
.45155 .34841 L
.45155 .34841 L
.45155 .34841 L
.45155 .34841 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45155 .3484 L
.45156 .3484 L
.45156 .3484 L
.45156 .3484 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45156 .34839 L
.45157 .34839 L
.45157 .34839 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
.45157 .34838 L
Mistroke
.45157 .34838 L
.45157 .34838 L
.45158 .34838 L
.45158 .34838 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45158 .34837 L
.45159 .34837 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.45159 .34836 L
.4516 .34836 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
.4516 .34835 L
Mistroke
.4516 .34835 L
.4516 .34835 L
.45161 .34835 L
.45161 .34835 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45161 .34834 L
.45162 .34834 L
.45162 .34834 L
.45162 .34834 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45162 .34833 L
.45163 .34833 L
.45163 .34833 L
.45163 .34833 L
.45163 .34833 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
.45163 .34832 L
Mistroke
.45163 .34832 L
.45164 .34832 L
.45164 .34832 L
.45164 .34832 L
.45164 .34832 L
.45164 .34832 L
.45164 .34832 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45164 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .34831 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45165 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .3483 L
.45166 .34829 L
.45166 .34829 L
.45166 .34829 L
.45166 .34829 L
.45166 .34829 L
.45166 .34829 L
Mistroke
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34829 L
.45167 .34828 L
.45167 .34828 L
.45167 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45168 .34828 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.45169 .34827 L
.4517 .34827 L
Mistroke
.4517 .34827 L
.4517 .34827 L
.4517 .34827 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.4517 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34826 L
.45171 .34825 L
.45171 .34825 L
.45171 .34825 L
.45171 .34825 L
.45171 .34825 L
.45171 .34825 L
.45171 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34825 L
.45172 .34824 L
.45172 .34824 L
.45172 .34824 L
.45173 .34824 L
.45173 .34824 L
Mistroke
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45173 .34824 L
.45174 .34824 L
.45174 .34824 L
.45174 .34824 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45174 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34823 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
Mistroke
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34822 L
.45176 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45177 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .34821 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45178 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
Mistroke
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .3482 L
.45179 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.4518 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34819 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45181 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
Mistroke
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45182 .34818 L
.45183 .34818 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45183 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34817 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
Mistroke
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45185 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34816 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45187 .34815 L
.45188 .34815 L
.45188 .34815 L
.45188 .34815 L
Mistroke
.45188 .34815 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45188 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.45189 .34814 L
.4519 .34814 L
.4519 .34814 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.4519 .34813 L
.45191 .34813 L
.45191 .34813 L
Mistroke
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45191 .34813 L
.45192 .34813 L
.45192 .34813 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45192 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
.45193 .34812 L
Mistroke
.45193 .34812 L
.45194 .34812 L
.45194 .34812 L
.45194 .34812 L
.45194 .34812 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45195 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .34811 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
Mistroke
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45197 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .3481 L
.45198 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
Mistroke
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.45199 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.452 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34809 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45202 .34808 L
Mistroke
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45202 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45203 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
.45204 .34808 L
Mistroke
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45205 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45206 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
Mistroke
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45207 .34807 L
.45208 .34807 L
.45208 .34807 L
.45208 .34807 L
.45208 .34807 L
.45208 .34807 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
Mistroke
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.45209 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.4521 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
.45211 .34806 L
Mistroke
.45211 .34806 L
.45211 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45212 .34806 L
.45213 .34806 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
Mistroke
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45214 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45215 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
Mistroke
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45216 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45217 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
Mistroke
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45218 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.45219 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
Mistroke
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.4522 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45221 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
Mistroke
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45222 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
.45223 .34805 L
Mistroke
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45224 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
Mistroke
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45225 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
Mistroke
.45227 .34805 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45227 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
Mistroke
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45228 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.45229 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
Mistroke
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.4523 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
Mistroke
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45231 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
Mistroke
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34807 L
.45232 .34808 L
.45232 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
Mistroke
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45233 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
Mistroke
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45234 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
Mistroke
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .34809 L
.45235 .3481 L
.45235 .3481 L
.45235 .3481 L
.45235 .3481 L
.45235 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
Mistroke
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .3481 L
.45236 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
Mistroke
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34811 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45237 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
Mistroke
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
Mistroke
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45238 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34814 L
Mistroke
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
Mistroke
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
Mistroke
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34815 L
.45239 .34816 L
.45239 .34816 L
.45239 .34816 L
.45239 .34816 L
.45239 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
Mistroke
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
Mistroke
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
Mistroke
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34818 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
Mistroke
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .34819 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
Mistroke
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .3482 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
Mistroke
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34821 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
Mistroke
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
Mistroke
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
Mistroke
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
Mistroke
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34825 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
Mistroke
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
Mistroke
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
Mistroke
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34828 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
Mistroke
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
Mistroke
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
Mistroke
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
Mistroke
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45236 .34831 L
.45236 .34831 L
.45236 .34831 L
.45236 .34831 L
.45236 .34831 L
.45236 .34831 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
Mistroke
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
Mistroke
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
Mistroke
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
Mistroke
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34834 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
Mistroke
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34835 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
Mistroke
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
Mistroke
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34836 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
Mistroke
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
Mistroke
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34837 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
Mistroke
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
Mistroke
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.45229 .34839 L
Mistroke
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
Mistroke
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
Mistroke
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
Mistroke
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
Mistroke
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
Mistroke
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
Mistroke
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
Mistroke
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34841 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
Mistroke
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
Mistroke
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
Mistroke
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
Mistroke
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
Mistroke
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
Mistroke
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34842 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
Mistroke
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
Mistroke
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
Mistroke
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
Mistroke
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
Mistroke
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
Mistroke
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
Mistroke
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
Mistroke
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
Mistroke
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
Mistroke
.45218 .34842 L
.45218 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
Mistroke
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45217 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
Mistroke
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
Mistroke
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
Mistroke
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
Mfstroke
.165 0 1 r
.24721 .26683 m
.24746 .26667 L
.24772 .26651 L
.24798 .26636 L
.24823 .2662 L
.24849 .26605 L
.24875 .26589 L
.249 .26574 L
.24926 .26558 L
.24952 .26543 L
.24977 .26528 L
.25003 .26512 L
.25028 .26497 L
.25054 .26482 L
.2508 .26466 L
.25105 .26451 L
.25131 .26436 L
.25156 .26421 L
.25182 .26405 L
.25207 .2639 L
.25233 .26375 L
.25258 .2636 L
.25284 .26345 L
.25309 .2633 L
.25335 .26315 L
.2536 .263 L
.25386 .26285 L
.25411 .2627 L
.25437 .26255 L
.25462 .2624 L
.25488 .26225 L
.25513 .26211 L
.25539 .26196 L
.25564 .26181 L
.25589 .26166 L
.25615 .26152 L
.2564 .26137 L
.25666 .26122 L
.25691 .26108 L
.25716 .26093 L
.25742 .26078 L
.25767 .26064 L
.25792 .26049 L
.25818 .26035 L
.25843 .2602 L
.25868 .26006 L
.25894 .25992 L
.25919 .25977 L
.25944 .25963 L
.25969 .25948 L
Mistroke
.25995 .25934 L
.2602 .2592 L
.26045 .25906 L
.2607 .25891 L
.26096 .25877 L
.26121 .25863 L
.26146 .25849 L
.26171 .25835 L
.26196 .2582 L
.26222 .25806 L
.26247 .25792 L
.26272 .25778 L
.26297 .25764 L
.26322 .2575 L
.26347 .25736 L
.26373 .25722 L
.26398 .25709 L
.26423 .25695 L
.26448 .25681 L
.26473 .25667 L
.26498 .25653 L
.26523 .25639 L
.26548 .25626 L
.26573 .25612 L
.26598 .25598 L
.26623 .25585 L
.26648 .25571 L
.26673 .25557 L
.26698 .25544 L
.26723 .2553 L
.26748 .25516 L
.26773 .25503 L
.26798 .25489 L
.26823 .25476 L
.26848 .25463 L
.26873 .25449 L
.26898 .25436 L
.26923 .25422 L
.26948 .25409 L
.26973 .25396 L
.26998 .25382 L
.27023 .25369 L
.27048 .25356 L
.27073 .25343 L
.27098 .25329 L
.27122 .25316 L
.27147 .25303 L
.27172 .2529 L
.27197 .25277 L
.27222 .25264 L
Mistroke
.27247 .25251 L
.27271 .25238 L
.27296 .25225 L
.27321 .25212 L
.27346 .25199 L
.27371 .25186 L
.27395 .25173 L
.2742 .2516 L
.27445 .25147 L
.2747 .25134 L
.27494 .25121 L
.27519 .25109 L
.27544 .25096 L
.27569 .25083 L
.27593 .2507 L
.27618 .25058 L
.27643 .25045 L
.27667 .25032 L
.27692 .2502 L
.27717 .25007 L
.27741 .24994 L
.27766 .24982 L
.27791 .24969 L
.27815 .24957 L
.2784 .24944 L
.27865 .24932 L
.27889 .24919 L
.27914 .24907 L
.27938 .24895 L
.27963 .24882 L
.27988 .2487 L
.28012 .24857 L
.28037 .24845 L
.28061 .24833 L
.28086 .24821 L
.2811 .24808 L
.28135 .24796 L
.28159 .24784 L
.28184 .24772 L
.28208 .2476 L
.28233 .24748 L
.28257 .24735 L
.28282 .24723 L
.28306 .24711 L
.28331 .24699 L
.28355 .24687 L
.2838 .24675 L
.28404 .24663 L
.28428 .24651 L
.28453 .2464 L
Mistroke
.28477 .24628 L
.28502 .24616 L
.28526 .24604 L
.2855 .24592 L
.28575 .2458 L
.28599 .24568 L
.28624 .24557 L
.28648 .24545 L
.28672 .24533 L
.28697 .24522 L
.28721 .2451 L
.28745 .24498 L
.2877 .24487 L
.28794 .24475 L
.28818 .24463 L
.28842 .24452 L
.28867 .2444 L
.28891 .24429 L
.28915 .24417 L
.28939 .24406 L
.28964 .24394 L
.28988 .24383 L
.29012 .24372 L
.29036 .2436 L
.29061 .24349 L
.29085 .24338 L
.29109 .24326 L
.29133 .24315 L
.29157 .24304 L
.29182 .24292 L
.29206 .24281 L
.2923 .2427 L
.29254 .24259 L
.29278 .24248 L
.29302 .24236 L
.29326 .24225 L
.2935 .24214 L
.29375 .24203 L
.29399 .24192 L
.29423 .24181 L
.29447 .2417 L
.29471 .24159 L
.29495 .24148 L
.29519 .24137 L
.29543 .24126 L
.29567 .24115 L
.29591 .24104 L
.29615 .24093 L
.29639 .24083 L
.29663 .24072 L
Mistroke
.29687 .24061 L
.29711 .2405 L
.29735 .24039 L
.29759 .24029 L
.29783 .24018 L
.29807 .24007 L
.29831 .23997 L
.29855 .23986 L
.29879 .23975 L
.29903 .23965 L
.29927 .23954 L
.29951 .23944 L
.29975 .23933 L
.29998 .23922 L
.30022 .23912 L
.30046 .23901 L
.3007 .23891 L
.30094 .23881 L
.30118 .2387 L
.30142 .2386 L
.30165 .23849 L
.30189 .23839 L
.30213 .23829 L
.30237 .23818 L
.30261 .23808 L
.30285 .23798 L
.30308 .23787 L
.30332 .23777 L
.30356 .23767 L
.3038 .23757 L
.30403 .23747 L
.30427 .23736 L
.30451 .23726 L
.30475 .23716 L
.30498 .23706 L
.30522 .23696 L
.30546 .23686 L
.30569 .23676 L
.30593 .23666 L
.30617 .23656 L
.3064 .23646 L
.30664 .23636 L
.30688 .23626 L
.30711 .23616 L
.30735 .23606 L
.30759 .23596 L
.30782 .23586 L
.30806 .23577 L
.3083 .23567 L
.30853 .23557 L
Mistroke
.30877 .23547 L
.309 .23537 L
.30924 .23528 L
.30948 .23518 L
.30971 .23508 L
.30995 .23499 L
.31018 .23489 L
.31042 .23479 L
.31065 .2347 L
.31089 .2346 L
.31112 .2345 L
.31136 .23441 L
.31159 .23431 L
.31183 .23422 L
.31206 .23412 L
.3123 .23403 L
.31253 .23393 L
.31277 .23384 L
.313 .23374 L
.31324 .23365 L
.31347 .23356 L
.3137 .23346 L
.31394 .23337 L
.31417 .23328 L
.31441 .23318 L
.31464 .23309 L
.31487 .233 L
.31511 .2329 L
.31534 .23281 L
.31558 .23272 L
.31581 .23263 L
.31604 .23254 L
.31628 .23244 L
.31651 .23235 L
.31674 .23226 L
.31698 .23217 L
.31721 .23208 L
.31744 .23199 L
.31767 .2319 L
.31791 .23181 L
.31814 .23172 L
.31837 .23163 L
.31861 .23154 L
.31884 .23145 L
.31907 .23136 L
.3193 .23127 L
.31953 .23118 L
.31977 .23109 L
.32 .231 L
.32023 .23092 L
Mistroke
.32046 .23083 L
.32069 .23074 L
.32093 .23065 L
.32116 .23056 L
.32139 .23048 L
.32162 .23039 L
.32185 .2303 L
.32208 .23021 L
.32232 .23013 L
.32255 .23004 L
.32278 .22995 L
.32301 .22987 L
.32324 .22978 L
.32347 .2297 L
.3237 .22961 L
.32393 .22953 L
.32416 .22944 L
.32439 .22936 L
.32462 .22927 L
.32485 .22919 L
.32508 .2291 L
.32532 .22902 L
.32555 .22893 L
.32578 .22885 L
.32601 .22876 L
.32624 .22868 L
.32647 .2286 L
.3267 .22851 L
.32692 .22843 L
.32715 .22835 L
.32738 .22826 L
.32761 .22818 L
.32784 .2281 L
.32807 .22802 L
.3283 .22794 L
.32853 .22785 L
.32876 .22777 L
.32899 .22769 L
.32922 .22761 L
.32945 .22753 L
.32967 .22745 L
.3299 .22737 L
.33013 .22729 L
.33036 .22721 L
.33059 .22712 L
.33082 .22704 L
.33105 .22696 L
.33127 .22689 L
.3315 .22681 L
.33173 .22673 L
Mistroke
.33196 .22665 L
.33219 .22657 L
.33241 .22649 L
.33264 .22641 L
.33287 .22633 L
.3331 .22625 L
.33332 .22618 L
.33355 .2261 L
.33378 .22602 L
.33401 .22594 L
.33423 .22586 L
.33446 .22579 L
.33469 .22571 L
.33491 .22563 L
.33514 .22556 L
.33537 .22548 L
.33559 .2254 L
.33582 .22533 L
.33605 .22525 L
.33627 .22517 L
.3365 .2251 L
.33673 .22502 L
.33695 .22495 L
.33718 .22487 L
.3374 .2248 L
.33763 .22472 L
.33786 .22465 L
.33808 .22457 L
.33831 .2245 L
.33853 .22442 L
.33876 .22435 L
.33898 .22428 L
.33921 .2242 L
.33943 .22413 L
.33966 .22406 L
.33989 .22398 L
.34011 .22391 L
.34034 .22384 L
.34056 .22376 L
.34078 .22369 L
.34101 .22362 L
.34123 .22355 L
.34146 .22347 L
.34168 .2234 L
.34191 .22333 L
.34213 .22326 L
.34236 .22319 L
.34258 .22312 L
.3428 .22305 L
.34303 .22297 L
Mistroke
.34325 .2229 L
.34348 .22283 L
.3437 .22276 L
.34392 .22269 L
.34415 .22262 L
.34437 .22255 L
.34459 .22248 L
.34482 .22241 L
.34504 .22234 L
.34526 .22228 L
.34549 .22221 L
.34571 .22214 L
.34593 .22207 L
.34616 .222 L
.34638 .22193 L
.3466 .22186 L
.34682 .22179 L
.34705 .22173 L
.34727 .22166 L
.34749 .22159 L
.34771 .22152 L
.34794 .22146 L
.34816 .22139 L
.34838 .22132 L
.3486 .22126 L
.34882 .22119 L
.34905 .22112 L
.34927 .22106 L
.34949 .22099 L
.34971 .22092 L
.34993 .22086 L
.35015 .22079 L
.35037 .22073 L
.3506 .22066 L
.35082 .2206 L
.35104 .22053 L
.35126 .22047 L
.35148 .2204 L
.3517 .22034 L
.35192 .22027 L
.35214 .22021 L
.35236 .22014 L
.35258 .22008 L
.3528 .22002 L
.35302 .21995 L
.35324 .21989 L
.35346 .21983 L
.35368 .21976 L
.3539 .2197 L
.35412 .21964 L
Mistroke
.35434 .21958 L
.35456 .21951 L
.35478 .21945 L
.355 .21939 L
.35522 .21933 L
.35544 .21926 L
.35566 .2192 L
.35588 .21914 L
.3561 .21908 L
.35632 .21902 L
.35654 .21896 L
.35676 .2189 L
.35698 .21884 L
.3572 .21877 L
.35741 .21871 L
.35763 .21865 L
.35785 .21859 L
.35807 .21853 L
.35829 .21847 L
.35851 .21841 L
.35872 .21835 L
.35894 .21829 L
.35916 .21824 L
.35938 .21818 L
.3596 .21812 L
.35981 .21806 L
.36003 .218 L
.36025 .21794 L
.36047 .21788 L
.36068 .21782 L
.3609 .21777 L
.36112 .21771 L
.36134 .21765 L
.36155 .21759 L
.36177 .21754 L
.36199 .21748 L
.3622 .21742 L
.36242 .21736 L
.36264 .21731 L
.36285 .21725 L
.36307 .21719 L
.36329 .21714 L
.3635 .21708 L
.36372 .21703 L
.36394 .21697 L
.36415 .21691 L
.36437 .21686 L
.36459 .2168 L
.3648 .21675 L
.36502 .21669 L
Mistroke
.36523 .21664 L
.36545 .21658 L
.36566 .21653 L
.36588 .21647 L
.36609 .21642 L
.36631 .21636 L
.36653 .21631 L
.36674 .21626 L
.36696 .2162 L
.36717 .21615 L
.36739 .2161 L
.3676 .21604 L
.36781 .21599 L
.36803 .21594 L
.36824 .21588 L
.36846 .21583 L
.36867 .21578 L
.36889 .21572 L
.3691 .21567 L
.36932 .21562 L
.36953 .21557 L
.36974 .21552 L
.36996 .21546 L
.37017 .21541 L
.37039 .21536 L
.3706 .21531 L
.37081 .21526 L
.37103 .21521 L
.37124 .21516 L
.37145 .21511 L
.37167 .21505 L
.37188 .215 L
.37209 .21495 L
.3723 .2149 L
.37252 .21485 L
.37273 .2148 L
.37294 .21475 L
.37316 .2147 L
.37337 .21465 L
.37358 .21461 L
.37379 .21456 L
.37401 .21451 L
.37422 .21446 L
.37443 .21441 L
.37464 .21436 L
.37485 .21431 L
.37507 .21426 L
.37528 .21422 L
.37549 .21417 L
.3757 .21412 L
Mistroke
.37591 .21407 L
.37612 .21402 L
.37634 .21398 L
.37655 .21393 L
.37676 .21388 L
.37697 .21384 L
.37718 .21379 L
.37739 .21374 L
.3776 .2137 L
.37781 .21365 L
.37802 .2136 L
.37823 .21356 L
.37844 .21351 L
.37865 .21346 L
.37886 .21342 L
.37908 .21337 L
.37929 .21333 L
.3795 .21328 L
.37971 .21324 L
.37992 .21319 L
.38013 .21315 L
.38033 .2131 L
.38054 .21306 L
.38075 .21301 L
.38096 .21297 L
.38117 .21292 L
.38138 .21288 L
.38159 .21284 L
.3818 .21279 L
.38201 .21275 L
.38222 .2127 L
.38243 .21266 L
.38264 .21262 L
.38284 .21257 L
.38305 .21253 L
.38326 .21249 L
.38347 .21245 L
.38368 .2124 L
.38389 .21236 L
.3841 .21232 L
.3843 .21228 L
.38451 .21223 L
.38472 .21219 L
.38493 .21215 L
.38514 .21211 L
.38534 .21207 L
.38555 .21203 L
.38576 .21198 L
.38597 .21194 L
.38617 .2119 L
Mistroke
.38638 .21186 L
.38659 .21182 L
.38679 .21178 L
.387 .21174 L
.38721 .2117 L
.38741 .21166 L
.38762 .21162 L
.38783 .21158 L
.38803 .21154 L
.38824 .2115 L
.38845 .21146 L
.38865 .21142 L
.38886 .21138 L
.38907 .21134 L
.38927 .2113 L
.38948 .21126 L
.38968 .21123 L
.38989 .21119 L
.3901 .21115 L
.3903 .21111 L
.39051 .21107 L
.39071 .21103 L
.39092 .211 L
.39112 .21096 L
.39133 .21092 L
.39153 .21088 L
.39174 .21085 L
.39194 .21081 L
.39215 .21077 L
.39235 .21073 L
.39256 .2107 L
.39276 .21066 L
.39297 .21062 L
.39317 .21059 L
.39337 .21055 L
.39358 .21052 L
.39378 .21048 L
.39399 .21044 L
.39419 .21041 L
.39439 .21037 L
.3946 .21034 L
.3948 .2103 L
.39501 .21027 L
.39521 .21023 L
.39541 .2102 L
.39562 .21016 L
.39582 .21013 L
.39602 .21009 L
.39622 .21006 L
.39643 .21002 L
Mistroke
.39663 .20999 L
.39683 .20995 L
.39704 .20992 L
.39724 .20989 L
.39744 .20985 L
.39764 .20982 L
.39785 .20979 L
.39805 .20975 L
.39825 .20972 L
.39845 .20969 L
.39865 .20965 L
.39886 .20962 L
.39906 .20959 L
.39926 .20956 L
.39946 .20952 L
.39966 .20949 L
.39986 .20946 L
.40006 .20943 L
.40027 .20939 L
.40047 .20936 L
.40067 .20933 L
.40087 .2093 L
.40107 .20927 L
.40127 .20924 L
.40147 .20921 L
.40167 .20917 L
.40187 .20914 L
.40207 .20911 L
.40227 .20908 L
.40247 .20905 L
.40267 .20902 L
.40287 .20899 L
.40307 .20896 L
.40327 .20893 L
.40347 .2089 L
.40367 .20887 L
.40387 .20884 L
.40407 .20881 L
.40427 .20878 L
.40447 .20875 L
.40467 .20872 L
.40487 .2087 L
.40507 .20867 L
.40527 .20864 L
.40547 .20861 L
.40567 .20858 L
.40586 .20855 L
.40606 .20852 L
.40626 .2085 L
.40646 .20847 L
Mistroke
.40666 .20844 L
.40686 .20841 L
.40705 .20838 L
.40725 .20836 L
.40745 .20833 L
.40765 .2083 L
.40785 .20828 L
.40804 .20825 L
.40824 .20822 L
.40844 .20819 L
.40864 .20817 L
.40883 .20814 L
.40903 .20811 L
.40923 .20809 L
.40943 .20806 L
.40962 .20804 L
.40982 .20801 L
.41002 .20798 L
.41021 .20796 L
.41041 .20793 L
.41061 .20791 L
.4108 .20788 L
.411 .20786 L
.41119 .20783 L
.41139 .20781 L
.41159 .20778 L
.41178 .20776 L
.41198 .20773 L
.41217 .20771 L
.41237 .20768 L
.41257 .20766 L
.41276 .20764 L
.41296 .20761 L
.41315 .20759 L
.41335 .20756 L
.41354 .20754 L
.41374 .20752 L
.41393 .20749 L
.41413 .20747 L
.41432 .20745 L
.41452 .20743 L
.41471 .2074 L
.4149 .20738 L
.4151 .20736 L
.41529 .20733 L
.41549 .20731 L
.41568 .20729 L
.41588 .20727 L
.41607 .20725 L
.41626 .20722 L
Mistroke
.41646 .2072 L
.41665 .20718 L
.41684 .20716 L
.41704 .20714 L
.41723 .20712 L
.41742 .20709 L
.41762 .20707 L
.41781 .20705 L
.418 .20703 L
.4182 .20701 L
.41839 .20699 L
.41858 .20697 L
.41877 .20695 L
.41897 .20693 L
.41916 .20691 L
.41935 .20689 L
.41954 .20687 L
.41974 .20685 L
.41993 .20683 L
.42012 .20681 L
.42031 .20679 L
.4205 .20677 L
.42069 .20675 L
.42089 .20673 L
.42108 .20671 L
.42127 .2067 L
.42146 .20668 L
.42165 .20666 L
.42184 .20664 L
.42203 .20662 L
.42222 .2066 L
.42241 .20659 L
.42261 .20657 L
.4228 .20655 L
.42299 .20653 L
.42318 .20651 L
.42337 .2065 L
.42356 .20648 L
.42375 .20646 L
.42394 .20644 L
.42413 .20643 L
.42432 .20641 L
.42451 .20639 L
.4247 .20638 L
.42489 .20636 L
.42508 .20634 L
.42526 .20633 L
.42545 .20631 L
.42564 .20629 L
.42583 .20628 L
Mistroke
.42602 .20626 L
.42621 .20625 L
.4264 .20623 L
.42659 .20622 L
.42678 .2062 L
.42696 .20618 L
.42715 .20617 L
.42734 .20615 L
.42753 .20614 L
.42772 .20612 L
.4279 .20611 L
.42809 .2061 L
.42828 .20608 L
.42847 .20607 L
.42866 .20605 L
.42884 .20604 L
.42903 .20602 L
.42922 .20601 L
.4294 .206 L
.42959 .20598 L
.42978 .20597 L
.42997 .20595 L
.43015 .20594 L
.43034 .20593 L
.43053 .20591 L
.43071 .2059 L
.4309 .20589 L
.43108 .20588 L
.43127 .20586 L
.43146 .20585 L
.43164 .20584 L
.43183 .20583 L
.43201 .20581 L
.4322 .2058 L
.43239 .20579 L
.43257 .20578 L
.43276 .20577 L
.43294 .20575 L
.43313 .20574 L
.43331 .20573 L
.4335 .20572 L
.43368 .20571 L
.43387 .2057 L
.43405 .20569 L
.43424 .20567 L
.43442 .20566 L
.43461 .20565 L
.43479 .20564 L
.43497 .20563 L
.43516 .20562 L
Mistroke
.43534 .20561 L
.43553 .2056 L
.43571 .20559 L
.43589 .20558 L
.43608 .20557 L
.43626 .20556 L
.43644 .20555 L
.43663 .20554 L
.43681 .20553 L
.43699 .20552 L
.43718 .20552 L
.43736 .20551 L
.43754 .2055 L
.43773 .20549 L
.43791 .20548 L
.43809 .20547 L
.43827 .20546 L
.43846 .20545 L
.43864 .20545 L
.43882 .20544 L
.439 .20543 L
.43918 .20542 L
.43937 .20541 L
.43955 .20541 L
.43973 .2054 L
.43991 .20539 L
.44009 .20538 L
.44027 .20538 L
.44045 .20537 L
.44063 .20536 L
.44082 .20536 L
.441 .20535 L
.44118 .20534 L
.44136 .20533 L
.44154 .20533 L
.44172 .20532 L
.4419 .20532 L
.44208 .20531 L
.44226 .2053 L
.44244 .2053 L
.44262 .20529 L
.4428 .20529 L
.44298 .20528 L
.44316 .20527 L
.44334 .20527 L
.44352 .20526 L
.4437 .20526 L
.44388 .20525 L
.44406 .20525 L
.44424 .20524 L
Mistroke
.44441 .20524 L
.44459 .20523 L
.44477 .20523 L
.44495 .20523 L
.44513 .20522 L
.44531 .20522 L
.44549 .20521 L
.44566 .20521 L
.44584 .2052 L
.44602 .2052 L
.4462 .2052 L
.44638 .20519 L
.44655 .20519 L
.44673 .20519 L
.44691 .20518 L
.44709 .20518 L
.44726 .20518 L
.44744 .20517 L
.44762 .20517 L
.44779 .20517 L
.44797 .20517 L
.44815 .20516 L
.44832 .20516 L
.4485 .20516 L
.44868 .20516 L
.44885 .20515 L
.44903 .20515 L
.44921 .20515 L
.44938 .20515 L
.44956 .20515 L
.44973 .20514 L
.44991 .20514 L
.45009 .20514 L
.45026 .20514 L
.45044 .20514 L
.45061 .20514 L
.45079 .20514 L
.45096 .20514 L
.45114 .20514 L
.45131 .20514 L
.45149 .20513 L
.45166 .20513 L
.45184 .20513 L
.45201 .20513 L
.45219 .20513 L
.45236 .20513 L
.45253 .20513 L
.45271 .20513 L
.45288 .20513 L
.45306 .20513 L
Mistroke
.45323 .20514 L
.4534 .20514 L
.45358 .20514 L
.45375 .20514 L
.45392 .20514 L
.4541 .20514 L
.45427 .20514 L
.45444 .20514 L
.45462 .20514 L
.45479 .20514 L
.45496 .20515 L
.45513 .20515 L
.45531 .20515 L
.45548 .20515 L
.45565 .20515 L
.45582 .20516 L
.45599 .20516 L
.45617 .20516 L
.45634 .20516 L
.45651 .20516 L
.45668 .20517 L
.45685 .20517 L
.45702 .20517 L
.4572 .20518 L
.45737 .20518 L
.45754 .20518 L
.45771 .20519 L
.45788 .20519 L
.45805 .20519 L
.45822 .2052 L
.45839 .2052 L
.45856 .2052 L
.45873 .20521 L
.4589 .20521 L
.45907 .20521 L
.45924 .20522 L
.45941 .20522 L
.45958 .20523 L
.45975 .20523 L
.45992 .20524 L
.46009 .20524 L
.46026 .20525 L
.46043 .20525 L
.4606 .20526 L
.46077 .20526 L
.46094 .20527 L
.4611 .20527 L
.46127 .20528 L
.46144 .20528 L
.46161 .20529 L
Mistroke
.46178 .20529 L
.46195 .2053 L
.46212 .2053 L
.46228 .20531 L
.46245 .20532 L
.46262 .20532 L
.46279 .20533 L
.46295 .20534 L
.46312 .20534 L
.46329 .20535 L
.46346 .20535 L
.46362 .20536 L
.46379 .20537 L
.46396 .20538 L
.46412 .20538 L
.46429 .20539 L
.46446 .2054 L
.46462 .2054 L
.46479 .20541 L
.46496 .20542 L
.46512 .20543 L
.46529 .20543 L
.46545 .20544 L
.46562 .20545 L
.46579 .20546 L
.46595 .20547 L
.46612 .20548 L
.46628 .20548 L
.46645 .20549 L
.46661 .2055 L
.46678 .20551 L
.46694 .20552 L
.46711 .20553 L
.46727 .20554 L
.46744 .20555 L
.4676 .20555 L
.46777 .20556 L
.46793 .20557 L
.46809 .20558 L
.46826 .20559 L
.46842 .2056 L
.46859 .20561 L
.46875 .20562 L
.46891 .20563 L
.46908 .20564 L
.46924 .20565 L
.4694 .20566 L
.46957 .20567 L
.46973 .20568 L
.46989 .20569 L
Mistroke
.47006 .2057 L
.47022 .20571 L
.47038 .20573 L
.47054 .20574 L
.47071 .20575 L
.47087 .20576 L
.47103 .20577 L
.47119 .20578 L
.47135 .20579 L
.47152 .2058 L
.47168 .20582 L
.47184 .20583 L
.472 .20584 L
.47216 .20585 L
.47232 .20586 L
.47248 .20588 L
.47265 .20589 L
.47281 .2059 L
.47297 .20591 L
.47313 .20592 L
.47329 .20594 L
.47345 .20595 L
.47361 .20596 L
.47377 .20598 L
.47393 .20599 L
.47409 .206 L
.47425 .20602 L
.47441 .20603 L
.47457 .20604 L
.47473 .20606 L
.47489 .20607 L
.47505 .20608 L
.47521 .2061 L
.47537 .20611 L
.47552 .20612 L
.47568 .20614 L
.47584 .20615 L
.476 .20617 L
.47616 .20618 L
.47632 .2062 L
.47648 .20621 L
.47663 .20622 L
.47679 .20624 L
.47695 .20625 L
.47711 .20627 L
.47726 .20628 L
.47742 .2063 L
.47758 .20631 L
.47774 .20633 L
.47789 .20635 L
Mistroke
.47805 .20636 L
.47821 .20638 L
.47837 .20639 L
.47852 .20641 L
.47868 .20642 L
.47884 .20644 L
.47899 .20646 L
.47915 .20647 L
.4793 .20649 L
.47946 .20651 L
.47962 .20652 L
.47977 .20654 L
.47993 .20655 L
.48008 .20657 L
.48024 .20659 L
.48039 .20661 L
.48055 .20662 L
.4807 .20664 L
.48086 .20666 L
.48101 .20667 L
.48117 .20669 L
.48132 .20671 L
.48148 .20673 L
.48163 .20674 L
.48179 .20676 L
.48194 .20678 L
.4821 .2068 L
.48225 .20682 L
.4824 .20683 L
.48256 .20685 L
.48271 .20687 L
.48286 .20689 L
.48302 .20691 L
.48317 .20693 L
.48332 .20695 L
.48348 .20696 L
.48363 .20698 L
.48378 .207 L
.48394 .20702 L
.48409 .20704 L
.48424 .20706 L
.48439 .20708 L
.48454 .2071 L
.4847 .20712 L
.48485 .20714 L
.485 .20716 L
.48515 .20718 L
.4853 .2072 L
.48546 .20722 L
.48561 .20724 L
Mistroke
.48576 .20726 L
.48591 .20728 L
.48606 .2073 L
.48621 .20732 L
.48636 .20734 L
.48651 .20736 L
.48666 .20738 L
.48681 .2074 L
.48696 .20742 L
.48711 .20745 L
.48726 .20747 L
.48741 .20749 L
.48756 .20751 L
.48771 .20753 L
.48786 .20755 L
.48801 .20757 L
.48816 .2076 L
.48831 .20762 L
.48846 .20764 L
.48861 .20766 L
.48876 .20768 L
.48891 .20771 L
.48906 .20773 L
.4892 .20775 L
.48935 .20777 L
.4895 .2078 L
.48965 .20782 L
.4898 .20784 L
.48994 .20786 L
.49009 .20789 L
.49024 .20791 L
.49039 .20793 L
.49053 .20796 L
.49068 .20798 L
.49083 .208 L
.49098 .20803 L
.49112 .20805 L
.49127 .20807 L
.49142 .2081 L
.49156 .20812 L
.49171 .20815 L
.49186 .20817 L
.492 .20819 L
.49215 .20822 L
.49229 .20824 L
.49244 .20827 L
.49259 .20829 L
.49273 .20832 L
.49288 .20834 L
.49302 .20836 L
Mistroke
.49317 .20839 L
.49331 .20841 L
.49346 .20844 L
.4936 .20847 L
.49375 .20849 L
.49389 .20852 L
.49404 .20854 L
.49418 .20857 L
.49432 .20859 L
.49447 .20862 L
.49461 .20864 L
.49476 .20867 L
.4949 .2087 L
.49504 .20872 L
.49519 .20875 L
.49533 .20877 L
.49547 .2088 L
.49562 .20883 L
.49576 .20885 L
.4959 .20888 L
.49605 .20891 L
.49619 .20893 L
.49633 .20896 L
.49647 .20899 L
.49662 .20901 L
.49676 .20904 L
.4969 .20907 L
.49704 .2091 L
.49718 .20912 L
.49732 .20915 L
.49747 .20918 L
.49761 .20921 L
.49775 .20923 L
.49789 .20926 L
.49803 .20929 L
.49817 .20932 L
.49831 .20935 L
.49845 .20937 L
.49859 .2094 L
.49873 .20943 L
.49887 .20946 L
.49901 .20949 L
.49915 .20952 L
.49929 .20955 L
.49943 .20957 L
.49957 .2096 L
.49971 .20963 L
.49985 .20966 L
.49999 .20969 L
.50013 .20972 L
Mistroke
.50027 .20975 L
.50041 .20978 L
.50055 .20981 L
.50069 .20984 L
.50082 .20987 L
.50096 .2099 L
.5011 .20993 L
.50124 .20996 L
.50138 .20999 L
.50152 .21002 L
.50165 .21005 L
.50179 .21008 L
.50193 .21011 L
.50207 .21014 L
.5022 .21017 L
.50234 .2102 L
.50248 .21023 L
.50261 .21026 L
.50275 .21029 L
.50289 .21032 L
.50302 .21036 L
.50316 .21039 L
.5033 .21042 L
.50343 .21045 L
.50357 .21048 L
.5037 .21051 L
.50384 .21054 L
.50398 .21058 L
.50411 .21061 L
.50425 .21064 L
.50438 .21067 L
.50452 .2107 L
.50465 .21074 L
.50479 .21077 L
.50492 .2108 L
.50506 .21083 L
.50519 .21087 L
.50532 .2109 L
.50546 .21093 L
.50559 .21096 L
.50573 .211 L
.50586 .21103 L
.50599 .21106 L
.50613 .2111 L
.50626 .21113 L
.5064 .21116 L
.50653 .2112 L
.50666 .21123 L
.50679 .21126 L
.50693 .2113 L
Mistroke
.50706 .21133 L
.50719 .21136 L
.50732 .2114 L
.50746 .21143 L
.50759 .21147 L
.50772 .2115 L
.50785 .21154 L
.50798 .21157 L
.50812 .2116 L
.50825 .21164 L
.50838 .21167 L
.50851 .21171 L
.50864 .21174 L
.50877 .21178 L
.5089 .21181 L
.50903 .21185 L
.50916 .21188 L
.5093 .21192 L
.50943 .21195 L
.50956 .21199 L
.50969 .21202 L
.50982 .21206 L
.50995 .2121 L
.51008 .21213 L
.5102 .21217 L
.51033 .2122 L
.51046 .21224 L
.51059 .21228 L
.51072 .21231 L
.51085 .21235 L
.51098 .21238 L
.51111 .21242 L
.51124 .21246 L
.51137 .21249 L
.51149 .21253 L
.51162 .21257 L
.51175 .2126 L
.51188 .21264 L
.512 .21268 L
.51213 .21271 L
.51226 .21275 L
.51239 .21279 L
.51251 .21283 L
.51264 .21286 L
.51277 .2129 L
.5129 .21294 L
.51302 .21298 L
.51315 .21301 L
.51328 .21305 L
.5134 .21309 L
Mistroke
.51353 .21313 L
.51365 .21317 L
.51378 .21321 L
.51391 .21324 L
.51403 .21328 L
.51416 .21332 L
.51428 .21336 L
.51441 .2134 L
.51453 .21344 L
.51466 .21348 L
.51478 .21351 L
.51491 .21355 L
.51503 .21359 L
.51516 .21363 L
.51528 .21367 L
.5154 .21371 L
.51553 .21375 L
.51565 .21379 L
.51578 .21383 L
.5159 .21387 L
.51602 .21391 L
.51615 .21395 L
.51627 .21399 L
.51639 .21403 L
.51652 .21407 L
.51664 .21411 L
.51676 .21415 L
.51688 .21419 L
.51701 .21423 L
.51713 .21427 L
.51725 .21431 L
.51737 .21435 L
.51749 .21439 L
.51762 .21443 L
.51774 .21447 L
.51786 .21451 L
.51798 .21455 L
.5181 .2146 L
.51822 .21464 L
.51834 .21468 L
.51847 .21472 L
.51859 .21476 L
.51871 .2148 L
.51883 .21484 L
.51895 .21489 L
.51907 .21493 L
.51919 .21497 L
.51931 .21501 L
.51943 .21505 L
.51955 .2151 L
Mistroke
.51967 .21514 L
.51979 .21518 L
.51991 .21522 L
.52002 .21527 L
.52014 .21531 L
.52026 .21535 L
.52038 .21539 L
.5205 .21544 L
.52062 .21548 L
.52074 .21552 L
.52085 .21557 L
.52097 .21561 L
.52109 .21565 L
.52121 .2157 L
.52133 .21574 L
.52144 .21578 L
.52156 .21583 L
.52168 .21587 L
.52179 .21591 L
.52191 .21596 L
.52203 .216 L
.52214 .21604 L
.52226 .21609 L
.52238 .21613 L
.52249 .21618 L
.52261 .21622 L
.52273 .21627 L
.52284 .21631 L
.52296 .21635 L
.52307 .2164 L
.52319 .21644 L
.5233 .21649 L
.52342 .21653 L
.52353 .21658 L
.52365 .21662 L
.52376 .21667 L
.52388 .21671 L
.52399 .21676 L
.52411 .2168 L
.52422 .21685 L
.52434 .2169 L
.52445 .21694 L
.52456 .21699 L
.52468 .21703 L
.52479 .21708 L
.5249 .21712 L
.52502 .21717 L
.52513 .21722 L
.52524 .21726 L
.52536 .21731 L
Mistroke
.52547 .21735 L
.52558 .2174 L
.52569 .21745 L
.52581 .21749 L
.52592 .21754 L
.52603 .21759 L
.52614 .21763 L
.52625 .21768 L
.52637 .21773 L
.52648 .21777 L
.52659 .21782 L
.5267 .21787 L
.52681 .21792 L
.52692 .21796 L
.52703 .21801 L
.52714 .21806 L
.52725 .21811 L
.52736 .21815 L
.52747 .2182 L
.52758 .21825 L
.52769 .2183 L
.5278 .21835 L
.52791 .21839 L
.52802 .21844 L
.52813 .21849 L
.52824 .21854 L
.52835 .21859 L
.52846 .21863 L
.52857 .21868 L
.52868 .21873 L
.52879 .21878 L
.52889 .21883 L
.529 .21888 L
.52911 .21893 L
.52922 .21898 L
.52933 .21903 L
.52943 .21907 L
.52954 .21912 L
.52965 .21917 L
.52976 .21922 L
.52986 .21927 L
.52997 .21932 L
.53008 .21937 L
.53018 .21942 L
.53029 .21947 L
.5304 .21952 L
.5305 .21957 L
.53061 .21962 L
.53072 .21967 L
.53082 .21972 L
Mistroke
.53093 .21977 L
.53103 .21982 L
.53114 .21987 L
.53124 .21992 L
.53135 .21997 L
.53145 .22002 L
.53156 .22007 L
.53166 .22013 L
.53177 .22018 L
.53187 .22023 L
.53198 .22028 L
.53208 .22033 L
.53219 .22038 L
.53229 .22043 L
.53239 .22048 L
.5325 .22053 L
.5326 .22059 L
.5327 .22064 L
.53281 .22069 L
.53291 .22074 L
.53301 .22079 L
.53312 .22084 L
.53322 .2209 L
.53332 .22095 L
.53342 .221 L
.53353 .22105 L
.53363 .22111 L
.53373 .22116 L
.53383 .22121 L
.53393 .22126 L
.53404 .22132 L
.53414 .22137 L
.53424 .22142 L
.53434 .22147 L
.53444 .22153 L
.53454 .22158 L
.53464 .22163 L
.53474 .22169 L
.53484 .22174 L
.53494 .22179 L
.53504 .22185 L
.53514 .2219 L
.53524 .22195 L
.53534 .22201 L
.53544 .22206 L
.53554 .22211 L
.53564 .22217 L
.53574 .22222 L
.53584 .22227 L
.53594 .22233 L
Mistroke
.53604 .22238 L
.53614 .22244 L
.53623 .22249 L
.53633 .22255 L
.53643 .2226 L
.53653 .22265 L
.53663 .22271 L
.53672 .22276 L
.53682 .22282 L
.53692 .22287 L
.53702 .22293 L
.53711 .22298 L
.53721 .22304 L
.53731 .22309 L
.5374 .22315 L
.5375 .2232 L
.5376 .22326 L
.53769 .22331 L
.53779 .22337 L
.53789 .22343 L
.53798 .22348 L
.53808 .22354 L
.53817 .22359 L
.53827 .22365 L
.53836 .2237 L
.53846 .22376 L
.53855 .22382 L
.53865 .22387 L
.53874 .22393 L
.53884 .22398 L
.53893 .22404 L
.53903 .2241 L
.53912 .22415 L
.53922 .22421 L
.53931 .22427 L
.5394 .22432 L
.5395 .22438 L
.53959 .22444 L
.53968 .22449 L
.53978 .22455 L
.53987 .22461 L
.53996 .22467 L
.54006 .22472 L
.54015 .22478 L
.54024 .22484 L
.54033 .2249 L
.54042 .22495 L
.54052 .22501 L
.54061 .22507 L
.5407 .22513 L
Mistroke
.54079 .22518 L
.54088 .22524 L
.54097 .2253 L
.54107 .22536 L
.54116 .22542 L
.54125 .22547 L
.54134 .22553 L
.54143 .22559 L
.54152 .22565 L
.54161 .22571 L
.5417 .22577 L
.54179 .22582 L
.54188 .22588 L
.54197 .22594 L
.54206 .226 L
.54215 .22606 L
.54224 .22612 L
.54233 .22618 L
.54241 .22624 L
.5425 .2263 L
.54259 .22636 L
.54268 .22641 L
.54277 .22647 L
.54286 .22653 L
.54295 .22659 L
.54303 .22665 L
.54312 .22671 L
.54321 .22677 L
.5433 .22683 L
.54338 .22689 L
.54347 .22695 L
.54356 .22701 L
.54365 .22707 L
.54373 .22713 L
.54382 .22719 L
.54391 .22725 L
.54399 .22731 L
.54408 .22737 L
.54416 .22743 L
.54425 .2275 L
.54434 .22756 L
.54442 .22762 L
.54451 .22768 L
.54459 .22774 L
.54468 .2278 L
.54476 .22786 L
.54485 .22792 L
.54493 .22798 L
.54502 .22804 L
.5451 .22811 L
Mistroke
.54518 .22817 L
.54527 .22823 L
.54535 .22829 L
.54544 .22835 L
.54552 .22841 L
.5456 .22848 L
.54569 .22854 L
.54577 .2286 L
.54585 .22866 L
.54594 .22872 L
.54602 .22879 L
.5461 .22885 L
.54619 .22891 L
.54627 .22897 L
.54635 .22903 L
.54643 .2291 L
.54651 .22916 L
.5466 .22922 L
.54668 .22929 L
.54676 .22935 L
.54684 .22941 L
.54692 .22947 L
.547 .22954 L
.54708 .2296 L
.54716 .22966 L
.54724 .22973 L
.54733 .22979 L
.54741 .22985 L
.54749 .22992 L
.54757 .22998 L
.54765 .23004 L
.54773 .23011 L
.54781 .23017 L
.54788 .23023 L
.54796 .2303 L
.54804 .23036 L
.54812 .23043 L
.5482 .23049 L
.54828 .23055 L
.54836 .23062 L
.54844 .23068 L
.54851 .23075 L
.54859 .23081 L
.54867 .23088 L
.54875 .23094 L
.54883 .231 L
.5489 .23107 L
.54898 .23113 L
.54906 .2312 L
.54914 .23126 L
Mistroke
.54921 .23133 L
.54929 .23139 L
.54937 .23146 L
.54944 .23152 L
.54952 .23159 L
.5496 .23165 L
.54967 .23172 L
.54975 .23178 L
.54982 .23185 L
.5499 .23192 L
.54997 .23198 L
.55005 .23205 L
.55012 .23211 L
.5502 .23218 L
.55027 .23224 L
.55035 .23231 L
.55042 .23238 L
.5505 .23244 L
.55057 .23251 L
.55065 .23257 L
.55072 .23264 L
.55079 .23271 L
.55087 .23277 L
.55094 .23284 L
.55102 .23291 L
.55109 .23297 L
.55116 .23304 L
.55123 .23311 L
.55131 .23317 L
.55138 .23324 L
.55145 .23331 L
.55153 .23337 L
.5516 .23344 L
.55167 .23351 L
.55174 .23358 L
.55181 .23364 L
.55188 .23371 L
.55196 .23378 L
.55203 .23384 L
.5521 .23391 L
.55217 .23398 L
.55224 .23405 L
.55231 .23412 L
.55238 .23418 L
.55245 .23425 L
.55252 .23432 L
.55259 .23439 L
.55266 .23445 L
.55273 .23452 L
.5528 .23459 L
Mistroke
.55287 .23466 L
.55294 .23473 L
.55301 .2348 L
.55308 .23486 L
.55315 .23493 L
.55322 .235 L
.55329 .23507 L
.55335 .23514 L
.55342 .23521 L
.55349 .23528 L
.55356 .23535 L
.55363 .23541 L
.55369 .23548 L
.55376 .23555 L
.55383 .23562 L
.5539 .23569 L
.55396 .23576 L
.55403 .23583 L
.5541 .2359 L
.55416 .23597 L
.55423 .23604 L
.5543 .23611 L
.55436 .23618 L
.55443 .23625 L
.5545 .23632 L
.55456 .23639 L
.55463 .23646 L
.55469 .23653 L
.55476 .2366 L
.55482 .23667 L
.55489 .23674 L
.55495 .23681 L
.55502 .23688 L
.55508 .23695 L
.55515 .23702 L
.55521 .23709 L
.55528 .23716 L
.55534 .23723 L
.5554 .2373 L
.55547 .23737 L
.55553 .23744 L
.55559 .23751 L
.55566 .23758 L
.55572 .23765 L
.55578 .23773 L
.55585 .2378 L
.55591 .23787 L
.55597 .23794 L
.55603 .23801 L
.5561 .23808 L
Mistroke
.55616 .23815 L
.55622 .23822 L
.55628 .2383 L
.55634 .23837 L
.55641 .23844 L
.55647 .23851 L
.55653 .23858 L
.55659 .23866 L
.55665 .23873 L
.55671 .2388 L
.55677 .23887 L
.55683 .23894 L
.55689 .23902 L
.55695 .23909 L
.55701 .23916 L
.55707 .23923 L
.55713 .2393 L
.55719 .23938 L
.55725 .23945 L
.55731 .23952 L
.55737 .2396 L
.55743 .23967 L
.55749 .23974 L
.55754 .23981 L
.5576 .23989 L
.55766 .23996 L
.55772 .24003 L
.55778 .24011 L
.55784 .24018 L
.55789 .24025 L
.55795 .24032 L
.55801 .2404 L
.55807 .24047 L
.55812 .24055 L
.55818 .24062 L
.55824 .24069 L
.55829 .24077 L
.55835 .24084 L
.55841 .24091 L
.55846 .24099 L
.55852 .24106 L
.55857 .24113 L
.55863 .24121 L
.55869 .24128 L
.55874 .24136 L
.5588 .24143 L
.55885 .24151 L
.55891 .24158 L
.55896 .24165 L
.55902 .24173 L
Mistroke
.55907 .2418 L
.55913 .24188 L
.55918 .24195 L
.55923 .24203 L
.55929 .2421 L
.55934 .24218 L
.5594 .24225 L
.55945 .24233 L
.5595 .2424 L
.55956 .24248 L
.55961 .24255 L
.55966 .24263 L
.55971 .2427 L
.55977 .24278 L
.55982 .24285 L
.55987 .24293 L
.55992 .243 L
.55998 .24308 L
.56003 .24315 L
.56008 .24323 L
.56013 .2433 L
.56018 .24338 L
.56023 .24346 L
.56029 .24353 L
.56034 .24361 L
.56039 .24368 L
.56044 .24376 L
.56049 .24384 L
.56054 .24391 L
.56059 .24399 L
.56064 .24406 L
.56069 .24414 L
.56074 .24422 L
.56079 .24429 L
.56084 .24437 L
.56089 .24445 L
.56094 .24452 L
.56099 .2446 L
.56103 .24468 L
.56108 .24475 L
.56113 .24483 L
.56118 .24491 L
.56123 .24498 L
.56128 .24506 L
.56132 .24514 L
.56137 .24521 L
.56142 .24529 L
.56147 .24537 L
.56151 .24545 L
.56156 .24552 L
Mistroke
.56161 .2456 L
.56166 .24568 L
.5617 .24575 L
.56175 .24583 L
.5618 .24591 L
.56184 .24599 L
.56189 .24606 L
.56193 .24614 L
.56198 .24622 L
.56203 .2463 L
.56207 .24638 L
.56212 .24645 L
.56216 .24653 L
.56221 .24661 L
.56225 .24669 L
.5623 .24677 L
.56234 .24684 L
.56239 .24692 L
.56243 .247 L
.56247 .24708 L
.56252 .24716 L
.56256 .24724 L
.56261 .24731 L
.56265 .24739 L
.56269 .24747 L
.56274 .24755 L
.56278 .24763 L
.56282 .24771 L
.56287 .24779 L
.56291 .24787 L
.56295 .24795 L
.56299 .24802 L
.56304 .2481 L
.56308 .24818 L
.56312 .24826 L
.56316 .24834 L
.5632 .24842 L
.56325 .2485 L
.56329 .24858 L
.56333 .24866 L
.56337 .24874 L
.56341 .24882 L
.56345 .2489 L
.56349 .24898 L
.56353 .24906 L
.56357 .24914 L
.56361 .24922 L
.56365 .2493 L
.56369 .24938 L
.56373 .24946 L
Mistroke
.56377 .24954 L
.56381 .24962 L
.56385 .2497 L
.56389 .24978 L
.56393 .24986 L
.56397 .24994 L
.56401 .25002 L
.56404 .2501 L
.56408 .25018 L
.56412 .25026 L
.56416 .25034 L
.5642 .25042 L
.56423 .2505 L
.56427 .25058 L
.56431 .25066 L
.56435 .25074 L
.56438 .25082 L
.56442 .2509 L
.56446 .25098 L
.56449 .25107 L
.56453 .25115 L
.56457 .25123 L
.5646 .25131 L
.56464 .25139 L
.56468 .25147 L
.56471 .25155 L
.56475 .25163 L
.56478 .25172 L
.56482 .2518 L
.56485 .25188 L
.56489 .25196 L
.56492 .25204 L
.56496 .25212 L
.56499 .2522 L
.56503 .25229 L
.56506 .25237 L
.5651 .25245 L
.56513 .25253 L
.56516 .25261 L
.5652 .2527 L
.56523 .25278 L
.56527 .25286 L
.5653 .25294 L
.56533 .25302 L
.56536 .25311 L
.5654 .25319 L
.56543 .25327 L
.56546 .25335 L
.5655 .25344 L
.56553 .25352 L
Mistroke
.56556 .2536 L
.56559 .25368 L
.56562 .25377 L
.56566 .25385 L
.56569 .25393 L
.56572 .25401 L
.56575 .2541 L
.56578 .25418 L
.56581 .25426 L
.56584 .25435 L
.56587 .25443 L
.5659 .25451 L
.56593 .25459 L
.56596 .25468 L
.56599 .25476 L
.56602 .25484 L
.56605 .25493 L
.56608 .25501 L
.56611 .25509 L
.56614 .25518 L
.56617 .25526 L
.5662 .25534 L
.56623 .25543 L
.56626 .25551 L
.56629 .2556 L
.56631 .25568 L
.56634 .25576 L
.56637 .25585 L
.5664 .25593 L
.56643 .25601 L
.56645 .2561 L
.56648 .25618 L
.56651 .25627 L
.56654 .25635 L
.56656 .25643 L
.56659 .25652 L
.56662 .2566 L
.56664 .25669 L
.56667 .25677 L
.5667 .25686 L
.56672 .25694 L
.56675 .25702 L
.56677 .25711 L
.5668 .25719 L
.56683 .25728 L
.56685 .25736 L
.56688 .25745 L
.5669 .25753 L
.56693 .25762 L
.56695 .2577 L
Mistroke
.56698 .25779 L
.567 .25787 L
.56703 .25796 L
.56705 .25804 L
.56707 .25813 L
.5671 .25821 L
.56712 .2583 L
.56715 .25838 L
.56717 .25847 L
.56719 .25855 L
.56722 .25864 L
.56724 .25872 L
.56726 .25881 L
.56728 .25889 L
.56731 .25898 L
.56733 .25906 L
.56735 .25915 L
.56737 .25923 L
.5674 .25932 L
.56742 .25941 L
.56744 .25949 L
.56746 .25958 L
.56748 .25966 L
.5675 .25975 L
.56753 .25983 L
.56755 .25992 L
.56757 .26001 L
.56759 .26009 L
.56761 .26018 L
.56763 .26026 L
.56765 .26035 L
.56767 .26044 L
.56769 .26052 L
.56771 .26061 L
.56773 .26069 L
.56775 .26078 L
.56777 .26087 L
.56779 .26095 L
.56781 .26104 L
.56783 .26113 L
.56784 .26121 L
.56786 .2613 L
.56788 .26139 L
.5679 .26147 L
.56792 .26156 L
.56794 .26165 L
.56795 .26173 L
.56797 .26182 L
.56799 .26191 L
.56801 .26199 L
Mistroke
.56802 .26208 L
.56804 .26217 L
.56806 .26225 L
.56808 .26234 L
.56809 .26243 L
.56811 .26252 L
.56813 .2626 L
.56814 .26269 L
.56816 .26278 L
.56817 .26286 L
.56819 .26295 L
.56821 .26304 L
.56822 .26313 L
.56824 .26321 L
.56825 .2633 L
.56827 .26339 L
.56828 .26348 L
.5683 .26356 L
.56831 .26365 L
.56833 .26374 L
.56834 .26383 L
.56836 .26391 L
.56837 .264 L
.56838 .26409 L
.5684 .26418 L
.56841 .26427 L
.56843 .26435 L
.56844 .26444 L
.56845 .26453 L
.56847 .26462 L
.56848 .26471 L
.56849 .26479 L
.5685 .26488 L
.56852 .26497 L
.56853 .26506 L
.56854 .26515 L
.56855 .26523 L
.56857 .26532 L
.56858 .26541 L
.56859 .2655 L
.5686 .26559 L
.56861 .26568 L
.56862 .26576 L
.56863 .26585 L
.56865 .26594 L
.56866 .26603 L
.56867 .26612 L
.56868 .26621 L
.56869 .2663 L
.5687 .26638 L
Mistroke
.56871 .26647 L
.56872 .26656 L
.56873 .26665 L
.56874 .26674 L
.56875 .26683 L
.56876 .26692 L
.56877 .26701 L
.56878 .2671 L
.56878 .26718 L
.56879 .26727 L
.5688 .26736 L
.56881 .26745 L
.56882 .26754 L
.56883 .26763 L
.56884 .26772 L
.56884 .26781 L
.56885 .2679 L
.56886 .26799 L
.56887 .26808 L
.56887 .26817 L
.56888 .26826 L
.56889 .26835 L
.5689 .26843 L
.5689 .26852 L
.56891 .26861 L
.56892 .2687 L
.56892 .26879 L
.56893 .26888 L
.56894 .26897 L
.56894 .26906 L
.56895 .26915 L
.56895 .26924 L
.56896 .26933 L
.56896 .26942 L
.56897 .26951 L
.56897 .2696 L
.56898 .26969 L
.56898 .26978 L
.56899 .26987 L
.56899 .26996 L
.569 .27005 L
.569 .27014 L
.56901 .27023 L
.56901 .27032 L
.56901 .27041 L
.56902 .2705 L
.56902 .27059 L
.56903 .27068 L
.56903 .27077 L
.56903 .27086 L
Mistroke
.56903 .27095 L
.56904 .27104 L
.56904 .27113 L
.56904 .27123 L
.56905 .27132 L
.56905 .27141 L
.56905 .2715 L
.56905 .27159 L
.56905 .27168 L
.56906 .27177 L
.56906 .27186 L
.56906 .27195 L
.56906 .27204 L
.56906 .27213 L
.56906 .27222 L
.56906 .27231 L
.56906 .2724 L
.56907 .2725 L
.56907 .27259 L
.56907 .27268 L
.56907 .27277 L
.56907 .27286 L
.56907 .27295 L
.56907 .27304 L
.56907 .27313 L
.56907 .27322 L
.56907 .27331 L
.56906 .27341 L
.56906 .2735 L
.56906 .27359 L
.56906 .27368 L
.56906 .27377 L
.56906 .27386 L
.56906 .27395 L
.56906 .27404 L
.56905 .27414 L
.56905 .27423 L
.56905 .27432 L
.56905 .27441 L
.56905 .2745 L
.56904 .27459 L
.56904 .27468 L
.56904 .27478 L
.56903 .27487 L
.56903 .27496 L
.56903 .27505 L
.56903 .27514 L
.56902 .27523 L
.56902 .27533 L
.56901 .27542 L
Mistroke
.56901 .27551 L
.56901 .2756 L
.569 .27569 L
.569 .27579 L
.56899 .27588 L
.56899 .27597 L
.56898 .27606 L
.56898 .27615 L
.56897 .27624 L
.56897 .27634 L
.56896 .27643 L
.56896 .27652 L
.56895 .27661 L
.56895 .27671 L
.56894 .2768 L
.56894 .27689 L
.56893 .27698 L
.56892 .27707 L
.56892 .27717 L
.56891 .27726 L
.5689 .27735 L
.5689 .27744 L
.56889 .27753 L
.56888 .27763 L
.56888 .27772 L
.56887 .27781 L
.56886 .2779 L
.56885 .278 L
.56885 .27809 L
.56884 .27818 L
.56883 .27827 L
.56882 .27837 L
.56881 .27846 L
.56881 .27855 L
.5688 .27864 L
.56879 .27874 L
.56878 .27883 L
.56877 .27892 L
.56876 .27901 L
.56875 .27911 L
.56874 .2792 L
.56873 .27929 L
.56873 .27939 L
.56872 .27948 L
.56871 .27957 L
.5687 .27966 L
.56869 .27976 L
.56868 .27985 L
.56866 .27994 L
.56865 .28004 L
Mistroke
.56864 .28013 L
.56863 .28022 L
.56862 .28031 L
.56861 .28041 L
.5686 .2805 L
.56859 .28059 L
.56858 .28069 L
.56857 .28078 L
.56855 .28087 L
.56854 .28097 L
.56853 .28106 L
.56852 .28115 L
.56851 .28124 L
.56849 .28134 L
.56848 .28143 L
.56847 .28152 L
.56846 .28162 L
.56844 .28171 L
.56843 .2818 L
.56842 .2819 L
.5684 .28199 L
.56839 .28208 L
.56838 .28218 L
.56836 .28227 L
.56835 .28236 L
.56833 .28246 L
.56832 .28255 L
.56831 .28264 L
.56829 .28274 L
.56828 .28283 L
.56826 .28292 L
.56825 .28302 L
.56823 .28311 L
.56822 .2832 L
.5682 .2833 L
.56819 .28339 L
.56817 .28349 L
.56816 .28358 L
.56814 .28367 L
.56813 .28377 L
.56811 .28386 L
.56809 .28395 L
.56808 .28405 L
.56806 .28414 L
.56805 .28423 L
.56803 .28433 L
.56801 .28442 L
.568 .28452 L
.56798 .28461 L
.56796 .2847 L
Mistroke
.56794 .2848 L
.56793 .28489 L
.56791 .28498 L
.56789 .28508 L
.56787 .28517 L
.56786 .28527 L
.56784 .28536 L
.56782 .28545 L
.5678 .28555 L
.56778 .28564 L
.56777 .28574 L
.56775 .28583 L
.56773 .28592 L
.56771 .28602 L
.56769 .28611 L
.56767 .2862 L
.56765 .2863 L
.56763 .28639 L
.56761 .28649 L
.56759 .28658 L
.56757 .28667 L
.56755 .28677 L
.56753 .28686 L
.56751 .28696 L
.56749 .28705 L
.56747 .28715 L
.56745 .28724 L
.56743 .28733 L
.56741 .28743 L
.56739 .28752 L
.56737 .28762 L
.56735 .28771 L
.56733 .2878 L
.56731 .2879 L
.56728 .28799 L
.56726 .28809 L
.56724 .28818 L
.56722 .28828 L
.5672 .28837 L
.56717 .28846 L
.56715 .28856 L
.56713 .28865 L
.56711 .28875 L
.56708 .28884 L
.56706 .28894 L
.56704 .28903 L
.56702 .28912 L
.56699 .28922 L
.56697 .28931 L
.56695 .28941 L
Mistroke
.56692 .2895 L
.5669 .2896 L
.56688 .28969 L
.56685 .28978 L
.56683 .28988 L
.5668 .28997 L
.56678 .29007 L
.56675 .29016 L
.56673 .29026 L
.56671 .29035 L
.56668 .29045 L
.56666 .29054 L
.56663 .29063 L
.56661 .29073 L
.56658 .29082 L
.56656 .29092 L
.56653 .29101 L
.5665 .29111 L
.56648 .2912 L
.56645 .2913 L
.56643 .29139 L
.5664 .29149 L
.56637 .29158 L
.56635 .29167 L
.56632 .29177 L
.56629 .29186 L
.56627 .29196 L
.56624 .29205 L
.56621 .29215 L
.56619 .29224 L
.56616 .29234 L
.56613 .29243 L
.56611 .29253 L
.56608 .29262 L
.56605 .29271 L
.56602 .29281 L
.56599 .2929 L
.56597 .293 L
.56594 .29309 L
.56591 .29319 L
.56588 .29328 L
.56585 .29338 L
.56582 .29347 L
.5658 .29357 L
.56577 .29366 L
.56574 .29376 L
.56571 .29385 L
.56568 .29395 L
.56565 .29404 L
.56562 .29413 L
Mistroke
.56559 .29423 L
.56556 .29432 L
.56553 .29442 L
.5655 .29451 L
.56547 .29461 L
.56544 .2947 L
.56541 .2948 L
.56538 .29489 L
.56535 .29499 L
.56532 .29508 L
.56529 .29518 L
.56526 .29527 L
.56523 .29537 L
.5652 .29546 L
.56516 .29555 L
.56513 .29565 L
.5651 .29574 L
.56507 .29584 L
.56504 .29593 L
.56501 .29603 L
.56497 .29612 L
.56494 .29622 L
.56491 .29631 L
.56488 .29641 L
.56485 .2965 L
.56481 .2966 L
.56478 .29669 L
.56475 .29679 L
.56471 .29688 L
.56468 .29698 L
.56465 .29707 L
.56462 .29717 L
.56458 .29726 L
.56455 .29735 L
.56452 .29745 L
.56448 .29754 L
.56445 .29764 L
.56441 .29773 L
.56438 .29783 L
.56435 .29792 L
.56431 .29802 L
.56428 .29811 L
.56424 .29821 L
.56421 .2983 L
.56417 .2984 L
.56414 .29849 L
.5641 .29859 L
.56407 .29868 L
.56403 .29878 L
.564 .29887 L
Mistroke
.56396 .29897 L
.56393 .29906 L
.56389 .29915 L
.56386 .29925 L
.56382 .29934 L
.56378 .29944 L
.56375 .29953 L
.56371 .29963 L
.56368 .29972 L
.56364 .29982 L
.5636 .29991 L
.56357 .30001 L
.56353 .3001 L
.56349 .3002 L
.56346 .30029 L
.56342 .30039 L
.56338 .30048 L
.56334 .30058 L
.56331 .30067 L
.56327 .30076 L
.56323 .30086 L
.56319 .30095 L
.56316 .30105 L
.56312 .30114 L
.56308 .30124 L
.56304 .30133 L
.563 .30143 L
.56297 .30152 L
.56293 .30162 L
.56289 .30171 L
.56285 .30181 L
.56281 .3019 L
.56277 .30199 L
.56273 .30209 L
.56269 .30218 L
.56265 .30228 L
.56261 .30237 L
.56258 .30247 L
.56254 .30256 L
.5625 .30266 L
.56246 .30275 L
.56242 .30285 L
.56238 .30294 L
.56234 .30303 L
.5623 .30313 L
.56226 .30322 L
.56221 .30332 L
.56217 .30341 L
.56213 .30351 L
.56209 .3036 L
Mistroke
.56205 .3037 L
.56201 .30379 L
.56197 .30389 L
.56193 .30398 L
.56189 .30407 L
.56185 .30417 L
.5618 .30426 L
.56176 .30436 L
.56172 .30445 L
.56168 .30455 L
.56164 .30464 L
.5616 .30474 L
.56155 .30483 L
.56151 .30492 L
.56147 .30502 L
.56143 .30511 L
.56138 .30521 L
.56134 .3053 L
.5613 .3054 L
.56125 .30549 L
.56121 .30558 L
.56117 .30568 L
.56113 .30577 L
.56108 .30587 L
.56104 .30596 L
.561 .30606 L
.56095 .30615 L
.56091 .30624 L
.56086 .30634 L
.56082 .30643 L
.56078 .30653 L
.56073 .30662 L
.56069 .30671 L
.56064 .30681 L
.5606 .3069 L
.56055 .307 L
.56051 .30709 L
.56047 .30719 L
.56042 .30728 L
.56038 .30737 L
.56033 .30747 L
.56028 .30756 L
.56024 .30766 L
.56019 .30775 L
.56015 .30784 L
.5601 .30794 L
.56006 .30803 L
.56001 .30813 L
.55997 .30822 L
.55992 .30831 L
Mistroke
.55987 .30841 L
.55983 .3085 L
.55978 .3086 L
.55974 .30869 L
.55969 .30878 L
.55964 .30888 L
.5596 .30897 L
.55955 .30906 L
.5595 .30916 L
.55945 .30925 L
.55941 .30935 L
.55936 .30944 L
.55931 .30953 L
.55927 .30963 L
.55922 .30972 L
.55917 .30982 L
.55912 .30991 L
.55908 .31 L
.55903 .3101 L
.55898 .31019 L
.55893 .31028 L
.55888 .31038 L
.55883 .31047 L
.55879 .31056 L
.55874 .31066 L
.55869 .31075 L
.55864 .31084 L
.55859 .31094 L
.55854 .31103 L
.55849 .31113 L
.55845 .31122 L
.5584 .31131 L
.55835 .31141 L
.5583 .3115 L
.55825 .31159 L
.5582 .31169 L
.55815 .31178 L
.5581 .31187 L
.55805 .31197 L
.558 .31206 L
.55795 .31215 L
.5579 .31225 L
.55785 .31234 L
.5578 .31243 L
.55775 .31253 L
.5577 .31262 L
.55765 .31271 L
.5576 .31281 L
.55755 .3129 L
.5575 .31299 L
Mistroke
.55744 .31308 L
.55739 .31318 L
.55734 .31327 L
.55729 .31336 L
.55724 .31346 L
.55719 .31355 L
.55714 .31364 L
.55709 .31374 L
.55703 .31383 L
.55698 .31392 L
.55693 .31402 L
.55688 .31411 L
.55683 .3142 L
.55677 .31429 L
.55672 .31439 L
.55667 .31448 L
.55662 .31457 L
.55656 .31466 L
.55651 .31476 L
.55646 .31485 L
.55641 .31494 L
.55635 .31504 L
.5563 .31513 L
.55625 .31522 L
.55619 .31531 L
.55614 .31541 L
.55609 .3155 L
.55603 .31559 L
.55598 .31568 L
.55593 .31578 L
.55587 .31587 L
.55582 .31596 L
.55577 .31605 L
.55571 .31615 L
.55566 .31624 L
.5556 .31633 L
.55555 .31642 L
.55549 .31652 L
.55544 .31661 L
.55539 .3167 L
.55533 .31679 L
.55528 .31688 L
.55522 .31698 L
.55517 .31707 L
.55511 .31716 L
.55506 .31725 L
.555 .31735 L
.55495 .31744 L
.55489 .31753 L
.55484 .31762 L
Mistroke
.55478 .31771 L
.55472 .31781 L
.55467 .3179 L
.55461 .31799 L
.55456 .31808 L
.5545 .31817 L
.55445 .31827 L
.55439 .31836 L
.55433 .31845 L
.55428 .31854 L
.55422 .31863 L
.55416 .31872 L
.55411 .31882 L
.55405 .31891 L
.55399 .319 L
.55394 .31909 L
.55388 .31918 L
.55382 .31927 L
.55377 .31937 L
.55371 .31946 L
.55365 .31955 L
.5536 .31964 L
.55354 .31973 L
.55348 .31982 L
.55342 .31991 L
.55337 .32001 L
.55331 .3201 L
.55325 .32019 L
.55319 .32028 L
.55313 .32037 L
.55308 .32046 L
.55302 .32055 L
.55296 .32064 L
.5529 .32074 L
.55284 .32083 L
.55279 .32092 L
.55273 .32101 L
.55267 .3211 L
.55261 .32119 L
.55255 .32128 L
.55249 .32137 L
.55243 .32146 L
.55237 .32155 L
.55232 .32165 L
.55226 .32174 L
.5522 .32183 L
.55214 .32192 L
.55208 .32201 L
.55202 .3221 L
.55196 .32219 L
Mistroke
.5519 .32228 L
.55184 .32237 L
.55178 .32246 L
.55172 .32255 L
.55166 .32264 L
.5516 .32273 L
.55154 .32282 L
.55148 .32291 L
.55142 .323 L
.55136 .3231 L
.5513 .32319 L
.55124 .32328 L
.55118 .32337 L
.55112 .32346 L
.55106 .32355 L
.551 .32364 L
.55093 .32373 L
.55087 .32382 L
.55081 .32391 L
.55075 .324 L
.55069 .32409 L
.55063 .32418 L
.55057 .32427 L
.55051 .32436 L
.55045 .32445 L
.55038 .32454 L
.55032 .32463 L
.55026 .32472 L
.5502 .32481 L
.55014 .3249 L
.55007 .32499 L
.55001 .32507 L
.54995 .32516 L
.54989 .32525 L
.54983 .32534 L
.54976 .32543 L
.5497 .32552 L
.54964 .32561 L
.54958 .3257 L
.54951 .32579 L
.54945 .32588 L
.54939 .32597 L
.54933 .32606 L
.54926 .32615 L
.5492 .32624 L
.54914 .32633 L
.54907 .32642 L
.54901 .3265 L
.54895 .32659 L
.54888 .32668 L
Mistroke
.54882 .32677 L
.54876 .32686 L
.54869 .32695 L
.54863 .32704 L
.54857 .32713 L
.5485 .32722 L
.54844 .3273 L
.54837 .32739 L
.54831 .32748 L
.54825 .32757 L
.54818 .32766 L
.54812 .32775 L
.54805 .32784 L
.54799 .32792 L
.54792 .32801 L
.54786 .3281 L
.5478 .32819 L
.54773 .32828 L
.54767 .32837 L
.5476 .32846 L
.54754 .32854 L
.54747 .32863 L
.54741 .32872 L
.54734 .32881 L
.54728 .3289 L
.54721 .32898 L
.54715 .32907 L
.54708 .32916 L
.54702 .32925 L
.54695 .32934 L
.54688 .32942 L
.54682 .32951 L
.54675 .3296 L
.54669 .32969 L
.54662 .32977 L
.54656 .32986 L
.54649 .32995 L
.54642 .33004 L
.54636 .33013 L
.54629 .33021 L
.54623 .3303 L
.54616 .33039 L
.54609 .33048 L
.54603 .33056 L
.54596 .33065 L
.54589 .33074 L
.54583 .33082 L
.54576 .33091 L
.54569 .331 L
.54563 .33109 L
Mistroke
.54556 .33117 L
.54549 .33126 L
.54543 .33135 L
.54536 .33143 L
.54529 .33152 L
.54522 .33161 L
.54516 .33169 L
.54509 .33178 L
.54502 .33187 L
.54496 .33195 L
.54489 .33204 L
.54482 .33213 L
.54475 .33221 L
.54469 .3323 L
.54462 .33239 L
.54455 .33247 L
.54448 .33256 L
.54441 .33265 L
.54435 .33273 L
.54428 .33282 L
.54421 .33291 L
.54414 .33299 L
.54407 .33308 L
.544 .33316 L
.54394 .33325 L
.54387 .33334 L
.5438 .33342 L
.54373 .33351 L
.54366 .33359 L
.54359 .33368 L
.54353 .33377 L
.54346 .33385 L
.54339 .33394 L
.54332 .33402 L
.54325 .33411 L
.54318 .33419 L
.54311 .33428 L
.54304 .33436 L
.54297 .33445 L
.5429 .33454 L
.54283 .33462 L
.54277 .33471 L
.5427 .33479 L
.54263 .33488 L
.54256 .33496 L
.54249 .33505 L
.54242 .33513 L
.54235 .33522 L
.54228 .3353 L
.54221 .33539 L
Mistroke
.54214 .33547 L
.54207 .33556 L
.542 .33564 L
.54193 .33573 L
.54186 .33581 L
.54179 .3359 L
.54172 .33598 L
.54165 .33606 L
.54158 .33615 L
.54151 .33623 L
.54144 .33632 L
.54137 .3364 L
.5413 .33649 L
.54122 .33657 L
.54115 .33666 L
.54108 .33674 L
.54101 .33682 L
.54094 .33691 L
.54087 .33699 L
.5408 .33708 L
.54073 .33716 L
.54066 .33724 L
.54059 .33733 L
.54052 .33741 L
.54044 .3375 L
.54037 .33758 L
.5403 .33766 L
.54023 .33775 L
.54016 .33783 L
.54009 .33791 L
.54002 .338 L
.53994 .33808 L
.53987 .33816 L
.5398 .33825 L
.53973 .33833 L
.53966 .33841 L
.53959 .3385 L
.53951 .33858 L
.53944 .33866 L
.53937 .33875 L
.5393 .33883 L
.53923 .33891 L
.53915 .33899 L
.53908 .33908 L
.53901 .33916 L
.53894 .33924 L
.53886 .33933 L
.53879 .33941 L
.53872 .33949 L
.53865 .33957 L
Mistroke
.53857 .33966 L
.5385 .33974 L
.53843 .33982 L
.53836 .3399 L
.53828 .33999 L
.53821 .34007 L
.53814 .34015 L
.53806 .34023 L
.53799 .34031 L
.53792 .3404 L
.53785 .34048 L
.53777 .34056 L
.5377 .34064 L
.53763 .34072 L
.53755 .34081 L
.53748 .34089 L
.53741 .34097 L
.53733 .34105 L
.53726 .34113 L
.53719 .34121 L
.53711 .3413 L
.53704 .34138 L
.53697 .34146 L
.53689 .34154 L
.53682 .34162 L
.53674 .3417 L
.53667 .34178 L
.5366 .34186 L
.53652 .34194 L
.53645 .34203 L
.53638 .34211 L
.5363 .34219 L
.53623 .34227 L
.53615 .34235 L
.53608 .34243 L
.536 .34251 L
.53593 .34259 L
.53586 .34267 L
.53578 .34275 L
.53571 .34283 L
.53563 .34291 L
.53556 .34299 L
.53548 .34307 L
.53541 .34315 L
.53534 .34323 L
.53526 .34331 L
.53519 .34339 L
.53511 .34347 L
.53504 .34355 L
.53496 .34363 L
Mistroke
.53489 .34371 L
.53481 .34379 L
.53474 .34387 L
.53466 .34395 L
.53459 .34403 L
.53451 .34411 L
.53444 .34419 L
.53436 .34427 L
.53429 .34435 L
.53421 .34443 L
.53414 .34451 L
.53406 .34459 L
.53399 .34467 L
.53391 .34475 L
.53383 .34483 L
.53376 .34491 L
.53368 .34498 L
.53361 .34506 L
.53353 .34514 L
.53346 .34522 L
.53338 .3453 L
.53331 .34538 L
.53323 .34546 L
.53315 .34554 L
.53308 .34561 L
.533 .34569 L
.53293 .34577 L
.53285 .34585 L
.53277 .34593 L
.5327 .34601 L
.53262 .34608 L
.53255 .34616 L
.53247 .34624 L
.53239 .34632 L
.53232 .3464 L
.53224 .34647 L
.53217 .34655 L
.53209 .34663 L
.53201 .34671 L
.53194 .34679 L
.53186 .34686 L
.53178 .34694 L
.53171 .34702 L
.53163 .3471 L
.53155 .34717 L
.53148 .34725 L
.5314 .34733 L
.53132 .3474 L
.53125 .34748 L
.53117 .34756 L
Mistroke
.53109 .34764 L
.53102 .34771 L
.53094 .34779 L
.53086 .34787 L
.53079 .34794 L
.53071 .34802 L
.53063 .3481 L
.53056 .34817 L
.53048 .34825 L
.5304 .34833 L
.53033 .3484 L
.53025 .34848 L
.53017 .34855 L
.53009 .34863 L
.53002 .34871 L
.52994 .34878 L
.52986 .34886 L
.52979 .34894 L
.52971 .34901 L
.52963 .34909 L
.52955 .34916 L
.52948 .34924 L
.5294 .34931 L
.52932 .34939 L
.52924 .34947 L
.52917 .34954 L
.52909 .34962 L
.52901 .34969 L
.52893 .34977 L
.52885 .34984 L
.52878 .34992 L
.5287 .34999 L
.52862 .35007 L
.52854 .35014 L
.52847 .35022 L
.52839 .35029 L
.52831 .35037 L
.52823 .35044 L
.52815 .35052 L
.52808 .35059 L
.528 .35067 L
.52792 .35074 L
.52784 .35082 L
.52776 .35089 L
.52769 .35096 L
.52761 .35104 L
.52753 .35111 L
.52745 .35119 L
.52737 .35126 L
.5273 .35134 L
Mistroke
.52722 .35141 L
.52714 .35148 L
.52706 .35156 L
.52698 .35163 L
.5269 .3517 L
.52683 .35178 L
.52675 .35185 L
.52667 .35193 L
.52659 .352 L
.52651 .35207 L
.52643 .35215 L
.52635 .35222 L
.52628 .35229 L
.5262 .35237 L
.52612 .35244 L
.52604 .35251 L
.52596 .35258 L
.52588 .35266 L
.5258 .35273 L
.52572 .3528 L
.52565 .35288 L
.52557 .35295 L
.52549 .35302 L
.52541 .35309 L
.52533 .35317 L
.52525 .35324 L
.52517 .35331 L
.52509 .35338 L
.52501 .35346 L
.52494 .35353 L
.52486 .3536 L
.52478 .35367 L
.5247 .35374 L
.52462 .35382 L
.52454 .35389 L
.52446 .35396 L
.52438 .35403 L
.5243 .3541 L
.52422 .35417 L
.52414 .35425 L
.52407 .35432 L
.52399 .35439 L
.52391 .35446 L
.52383 .35453 L
.52375 .3546 L
.52367 .35467 L
.52359 .35474 L
.52351 .35481 L
.52343 .35489 L
.52335 .35496 L
Mistroke
.52327 .35503 L
.52319 .3551 L
.52311 .35517 L
.52303 .35524 L
.52295 .35531 L
.52287 .35538 L
.52279 .35545 L
.52272 .35552 L
.52264 .35559 L
.52256 .35566 L
.52248 .35573 L
.5224 .3558 L
.52232 .35587 L
.52224 .35594 L
.52216 .35601 L
.52208 .35608 L
.522 .35615 L
.52192 .35622 L
.52184 .35629 L
.52176 .35636 L
.52168 .35643 L
.5216 .3565 L
.52152 .35657 L
.52144 .35664 L
.52136 .35671 L
.52128 .35677 L
.5212 .35684 L
.52112 .35691 L
.52104 .35698 L
.52096 .35705 L
.52088 .35712 L
.5208 .35719 L
.52072 .35726 L
.52064 .35733 L
.52056 .35739 L
.52048 .35746 L
.5204 .35753 L
.52032 .3576 L
.52024 .35767 L
.52016 .35774 L
.52008 .3578 L
.52 .35787 L
.51992 .35794 L
.51984 .35801 L
.51976 .35808 L
.51968 .35814 L
.5196 .35821 L
.51952 .35828 L
.51944 .35835 L
.51936 .35841 L
Mistroke
.51928 .35848 L
.5192 .35855 L
.51912 .35862 L
.51904 .35868 L
.51896 .35875 L
.51888 .35882 L
.5188 .35888 L
.51872 .35895 L
.51864 .35902 L
.51855 .35908 L
.51847 .35915 L
.51839 .35922 L
.51831 .35928 L
.51823 .35935 L
.51815 .35942 L
.51807 .35948 L
.51799 .35955 L
.51791 .35962 L
.51783 .35968 L
.51775 .35975 L
.51767 .35981 L
.51759 .35988 L
.51751 .35995 L
.51743 .36001 L
.51735 .36008 L
.51727 .36014 L
.51719 .36021 L
.51711 .36027 L
.51703 .36034 L
.51695 .36041 L
.51686 .36047 L
.51678 .36054 L
.5167 .3606 L
.51662 .36067 L
.51654 .36073 L
.51646 .3608 L
.51638 .36086 L
.5163 .36093 L
.51622 .36099 L
.51614 .36106 L
.51606 .36112 L
.51598 .36118 L
.5159 .36125 L
.51582 .36131 L
.51574 .36138 L
.51566 .36144 L
.51557 .36151 L
.51549 .36157 L
.51541 .36163 L
.51533 .3617 L
Mistroke
.51525 .36176 L
.51517 .36183 L
.51509 .36189 L
.51501 .36195 L
.51493 .36202 L
.51485 .36208 L
.51477 .36214 L
.51469 .36221 L
.51461 .36227 L
.51452 .36233 L
.51444 .3624 L
.51436 .36246 L
.51428 .36252 L
.5142 .36259 L
.51412 .36265 L
.51404 .36271 L
.51396 .36278 L
.51388 .36284 L
.5138 .3629 L
.51372 .36296 L
.51364 .36303 L
.51356 .36309 L
.51347 .36315 L
.51339 .36321 L
.51331 .36327 L
.51323 .36334 L
.51315 .3634 L
.51307 .36346 L
.51299 .36352 L
.51291 .36358 L
.51283 .36365 L
.51275 .36371 L
.51267 .36377 L
.51259 .36383 L
.5125 .36389 L
.51242 .36395 L
.51234 .36402 L
.51226 .36408 L
.51218 .36414 L
.5121 .3642 L
.51202 .36426 L
.51194 .36432 L
.51186 .36438 L
.51178 .36444 L
.5117 .3645 L
.51161 .36456 L
.51153 .36462 L
.51145 .36469 L
.51137 .36475 L
.51129 .36481 L
Mistroke
.51121 .36487 L
.51113 .36493 L
.51105 .36499 L
.51097 .36505 L
.51089 .36511 L
.51081 .36517 L
.51073 .36523 L
.51064 .36529 L
.51056 .36535 L
.51048 .36541 L
.5104 .36547 L
.51032 .36552 L
.51024 .36558 L
.51016 .36564 L
.51008 .3657 L
.51 .36576 L
.50992 .36582 L
.50984 .36588 L
.50976 .36594 L
.50967 .366 L
.50959 .36606 L
.50951 .36612 L
.50943 .36617 L
.50935 .36623 L
.50927 .36629 L
.50919 .36635 L
.50911 .36641 L
.50903 .36647 L
.50895 .36653 L
.50887 .36658 L
.50879 .36664 L
.5087 .3667 L
.50862 .36676 L
.50854 .36682 L
.50846 .36687 L
.50838 .36693 L
.5083 .36699 L
.50822 .36705 L
.50814 .3671 L
.50806 .36716 L
.50798 .36722 L
.5079 .36728 L
.50782 .36733 L
.50774 .36739 L
.50765 .36745 L
.50757 .3675 L
.50749 .36756 L
.50741 .36762 L
.50733 .36767 L
.50725 .36773 L
Mistroke
.50717 .36779 L
.50709 .36784 L
.50701 .3679 L
.50693 .36796 L
.50685 .36801 L
.50677 .36807 L
.50669 .36813 L
.50661 .36818 L
.50653 .36824 L
.50644 .36829 L
.50636 .36835 L
.50628 .36841 L
.5062 .36846 L
.50612 .36852 L
.50604 .36857 L
.50596 .36863 L
.50588 .36868 L
.5058 .36874 L
.50572 .36879 L
.50564 .36885 L
.50556 .3689 L
.50548 .36896 L
.5054 .36901 L
.50532 .36907 L
.50524 .36912 L
.50516 .36918 L
.50508 .36923 L
.505 .36929 L
.50491 .36934 L
.50483 .3694 L
.50475 .36945 L
.50467 .36951 L
.50459 .36956 L
.50451 .36961 L
.50443 .36967 L
.50435 .36972 L
.50427 .36978 L
.50419 .36983 L
.50411 .36988 L
.50403 .36994 L
.50395 .36999 L
.50387 .37004 L
.50379 .3701 L
.50371 .37015 L
.50363 .3702 L
.50355 .37026 L
.50347 .37031 L
.50339 .37036 L
.50331 .37042 L
.50323 .37047 L
Mistroke
.50315 .37052 L
.50307 .37057 L
.50299 .37063 L
.50291 .37068 L
.50283 .37073 L
.50275 .37078 L
.50267 .37084 L
.50259 .37089 L
.50251 .37094 L
.50243 .37099 L
.50235 .37105 L
.50227 .3711 L
.50219 .37115 L
.50211 .3712 L
.50203 .37125 L
.50195 .37131 L
.50187 .37136 L
.50179 .37141 L
.50171 .37146 L
.50163 .37151 L
.50155 .37156 L
.50147 .37161 L
.50139 .37167 L
.50131 .37172 L
.50123 .37177 L
.50115 .37182 L
.50107 .37187 L
.50099 .37192 L
.50091 .37197 L
.50083 .37202 L
.50075 .37207 L
.50067 .37212 L
.50059 .37217 L
.50051 .37222 L
.50043 .37227 L
.50035 .37232 L
.50027 .37237 L
.50019 .37242 L
.50011 .37247 L
.50003 .37252 L
.49995 .37257 L
.49987 .37262 L
.49979 .37267 L
.49971 .37272 L
.49963 .37277 L
.49955 .37282 L
.49947 .37287 L
.49939 .37292 L
.49931 .37297 L
.49923 .37302 L
Mistroke
.49915 .37307 L
.49908 .37312 L
.499 .37316 L
.49892 .37321 L
.49884 .37326 L
.49876 .37331 L
.49868 .37336 L
.4986 .37341 L
.49852 .37346 L
.49844 .3735 L
.49836 .37355 L
.49828 .3736 L
.4982 .37365 L
.49812 .3737 L
.49804 .37374 L
.49797 .37379 L
.49789 .37384 L
.49781 .37389 L
.49773 .37394 L
.49765 .37398 L
.49757 .37403 L
.49749 .37408 L
.49741 .37413 L
.49733 .37417 L
.49725 .37422 L
.49717 .37427 L
.4971 .37431 L
.49702 .37436 L
.49694 .37441 L
.49686 .37445 L
.49678 .3745 L
.4967 .37455 L
.49662 .37459 L
.49654 .37464 L
.49646 .37469 L
.49639 .37473 L
.49631 .37478 L
.49623 .37483 L
.49615 .37487 L
.49607 .37492 L
.49599 .37496 L
.49591 .37501 L
.49583 .37506 L
.49576 .3751 L
.49568 .37515 L
.4956 .37519 L
.49552 .37524 L
.49544 .37528 L
.49536 .37533 L
.49529 .37537 L
Mistroke
.49521 .37542 L
.49513 .37546 L
.49505 .37551 L
.49497 .37555 L
.49489 .3756 L
.49481 .37564 L
.49474 .37569 L
.49466 .37573 L
.49458 .37578 L
.4945 .37582 L
.49442 .37587 L
.49435 .37591 L
.49427 .37595 L
.49419 .376 L
.49411 .37604 L
.49403 .37609 L
.49395 .37613 L
.49388 .37618 L
.4938 .37622 L
.49372 .37626 L
.49364 .37631 L
.49356 .37635 L
.49349 .37639 L
.49341 .37644 L
.49333 .37648 L
.49325 .37652 L
.49318 .37657 L
.4931 .37661 L
.49302 .37665 L
.49294 .3767 L
.49286 .37674 L
.49279 .37678 L
.49271 .37682 L
.49263 .37687 L
.49255 .37691 L
.49248 .37695 L
.4924 .37699 L
.49232 .37704 L
.49224 .37708 L
.49217 .37712 L
.49209 .37716 L
.49201 .3772 L
.49193 .37725 L
.49186 .37729 L
.49178 .37733 L
.4917 .37737 L
.49162 .37741 L
.49155 .37745 L
.49147 .3775 L
.49139 .37754 L
Mistroke
.49132 .37758 L
.49124 .37762 L
.49116 .37766 L
.49108 .3777 L
.49101 .37774 L
.49093 .37778 L
.49085 .37783 L
.49078 .37787 L
.4907 .37791 L
.49062 .37795 L
.49055 .37799 L
.49047 .37803 L
.49039 .37807 L
.49032 .37811 L
.49024 .37815 L
.49016 .37819 L
.49008 .37823 L
.49001 .37827 L
.48993 .37831 L
.48985 .37835 L
.48978 .37839 L
.4897 .37843 L
.48963 .37847 L
.48955 .37851 L
.48947 .37855 L
.4894 .37859 L
.48932 .37863 L
.48924 .37867 L
.48917 .3787 L
.48909 .37874 L
.48901 .37878 L
.48894 .37882 L
.48886 .37886 L
.48878 .3789 L
.48871 .37894 L
.48863 .37898 L
.48856 .37901 L
.48848 .37905 L
.4884 .37909 L
.48833 .37913 L
.48825 .37917 L
.48818 .37921 L
.4881 .37924 L
.48802 .37928 L
.48795 .37932 L
.48787 .37936 L
.4878 .3794 L
.48772 .37943 L
.48765 .37947 L
.48757 .37951 L
Mistroke
.48749 .37955 L
.48742 .37958 L
.48734 .37962 L
.48727 .37966 L
.48719 .3797 L
.48712 .37973 L
.48704 .37977 L
.48696 .37981 L
.48689 .37984 L
.48681 .37988 L
.48674 .37992 L
.48666 .37995 L
.48659 .37999 L
.48651 .38003 L
.48644 .38006 L
.48636 .3801 L
.48629 .38014 L
.48621 .38017 L
.48614 .38021 L
.48606 .38024 L
.48599 .38028 L
.48591 .38032 L
.48584 .38035 L
.48576 .38039 L
.48569 .38042 L
.48561 .38046 L
.48554 .38049 L
.48546 .38053 L
.48539 .38056 L
.48531 .3806 L
.48524 .38063 L
.48516 .38067 L
.48509 .3807 L
.48501 .38074 L
.48494 .38077 L
.48487 .38081 L
.48479 .38084 L
.48472 .38088 L
.48464 .38091 L
.48457 .38095 L
.48449 .38098 L
.48442 .38102 L
.48434 .38105 L
.48427 .38108 L
.4842 .38112 L
.48412 .38115 L
.48405 .38119 L
.48397 .38122 L
.4839 .38125 L
.48383 .38129 L
Mistroke
.48375 .38132 L
.48368 .38136 L
.4836 .38139 L
.48353 .38142 L
.48346 .38146 L
.48338 .38149 L
.48331 .38152 L
.48323 .38156 L
.48316 .38159 L
.48309 .38162 L
.48301 .38165 L
.48294 .38169 L
.48287 .38172 L
.48279 .38175 L
.48272 .38178 L
.48265 .38182 L
.48257 .38185 L
.4825 .38188 L
.48243 .38191 L
.48235 .38195 L
.48228 .38198 L
.48221 .38201 L
.48213 .38204 L
.48206 .38207 L
.48199 .38211 L
.48191 .38214 L
.48184 .38217 L
.48177 .3822 L
.48169 .38223 L
.48162 .38226 L
.48155 .3823 L
.48148 .38233 L
.4814 .38236 L
.48133 .38239 L
.48126 .38242 L
.48118 .38245 L
.48111 .38248 L
.48104 .38251 L
.48097 .38254 L
.48089 .38257 L
.48082 .38261 L
.48075 .38264 L
.48068 .38267 L
.4806 .3827 L
.48053 .38273 L
.48046 .38276 L
.48039 .38279 L
.48031 .38282 L
.48024 .38285 L
.48017 .38288 L
Mistroke
.4801 .38291 L
.48003 .38294 L
.47995 .38297 L
.47988 .383 L
.47981 .38303 L
.47974 .38306 L
.47967 .38309 L
.47959 .38311 L
.47952 .38314 L
.47945 .38317 L
.47938 .3832 L
.47931 .38323 L
.47924 .38326 L
.47916 .38329 L
.47909 .38332 L
.47902 .38335 L
.47895 .38338 L
.47888 .3834 L
.47881 .38343 L
.47873 .38346 L
.47866 .38349 L
.47859 .38352 L
.47852 .38355 L
.47845 .38357 L
.47838 .3836 L
.47831 .38363 L
.47824 .38366 L
.47817 .38369 L
.47809 .38371 L
.47802 .38374 L
.47795 .38377 L
.47788 .3838 L
.47781 .38382 L
.47774 .38385 L
.47767 .38388 L
.4776 .38391 L
.47753 .38393 L
.47746 .38396 L
.47739 .38399 L
.47732 .38401 L
.47725 .38404 L
.47717 .38407 L
.4771 .38409 L
.47703 .38412 L
.47696 .38415 L
.47689 .38417 L
.47682 .3842 L
.47675 .38423 L
.47668 .38425 L
.47661 .38428 L
Mistroke
.47654 .38431 L
.47647 .38433 L
.4764 .38436 L
.47633 .38438 L
.47626 .38441 L
.47619 .38444 L
.47612 .38446 L
.47605 .38449 L
.47598 .38451 L
.47591 .38454 L
.47584 .38456 L
.47577 .38459 L
.4757 .38461 L
.47563 .38464 L
.47557 .38466 L
.4755 .38469 L
.47543 .38471 L
.47536 .38474 L
.47529 .38476 L
.47522 .38479 L
.47515 .38481 L
.47508 .38484 L
.47501 .38486 L
.47494 .38489 L
.47487 .38491 L
.4748 .38494 L
.47473 .38496 L
.47467 .38498 L
.4746 .38501 L
.47453 .38503 L
.47446 .38506 L
.47439 .38508 L
.47432 .3851 L
.47425 .38513 L
.47418 .38515 L
.47412 .38518 L
.47405 .3852 L
.47398 .38522 L
.47391 .38525 L
.47384 .38527 L
.47377 .38529 L
.47371 .38532 L
.47364 .38534 L
.47357 .38536 L
.4735 .38539 L
.47343 .38541 L
.47336 .38543 L
.4733 .38545 L
.47323 .38548 L
.47316 .3855 L
Mistroke
.47309 .38552 L
.47302 .38554 L
.47296 .38557 L
.47289 .38559 L
.47282 .38561 L
.47275 .38563 L
.47269 .38566 L
.47262 .38568 L
.47255 .3857 L
.47248 .38572 L
.47242 .38574 L
.47235 .38576 L
.47228 .38579 L
.47221 .38581 L
.47215 .38583 L
.47208 .38585 L
.47201 .38587 L
.47194 .38589 L
.47188 .38591 L
.47181 .38594 L
.47174 .38596 L
.47168 .38598 L
.47161 .386 L
.47154 .38602 L
.47148 .38604 L
.47141 .38606 L
.47134 .38608 L
.47128 .3861 L
.47121 .38612 L
.47114 .38614 L
.47108 .38616 L
.47101 .38618 L
.47094 .3862 L
.47088 .38622 L
.47081 .38624 L
.47074 .38626 L
.47068 .38628 L
.47061 .3863 L
.47055 .38632 L
.47048 .38634 L
.47041 .38636 L
.47035 .38638 L
.47028 .3864 L
.47022 .38642 L
.47015 .38644 L
.47008 .38646 L
.47002 .38648 L
.46995 .3865 L
.46989 .38652 L
.46982 .38654 L
Mistroke
.46976 .38656 L
.46969 .38658 L
.46962 .38659 L
.46956 .38661 L
.46949 .38663 L
.46943 .38665 L
.46936 .38667 L
.4693 .38669 L
.46923 .38671 L
.46917 .38672 L
.4691 .38674 L
.46904 .38676 L
.46897 .38678 L
.46891 .3868 L
.46884 .38682 L
.46878 .38683 L
.46871 .38685 L
.46865 .38687 L
.46858 .38689 L
.46852 .3869 L
.46845 .38692 L
.46839 .38694 L
.46832 .38696 L
.46826 .38697 L
.4682 .38699 L
.46813 .38701 L
.46807 .38703 L
.468 .38704 L
.46794 .38706 L
.46787 .38708 L
.46781 .38709 L
.46775 .38711 L
.46768 .38713 L
.46762 .38714 L
.46755 .38716 L
.46749 .38718 L
.46743 .38719 L
.46736 .38721 L
.4673 .38723 L
.46723 .38724 L
.46717 .38726 L
.46711 .38728 L
.46704 .38729 L
.46698 .38731 L
.46692 .38732 L
.46685 .38734 L
.46679 .38736 L
.46673 .38737 L
.46666 .38739 L
.4666 .3874 L
Mistroke
.46654 .38742 L
.46647 .38743 L
.46641 .38745 L
.46635 .38746 L
.46628 .38748 L
.46622 .3875 L
.46616 .38751 L
.4661 .38753 L
.46603 .38754 L
.46597 .38756 L
.46591 .38757 L
.46584 .38758 L
.46578 .3876 L
.46572 .38761 L
.46566 .38763 L
.46559 .38764 L
.46553 .38766 L
.46547 .38767 L
.46541 .38769 L
.46535 .3877 L
.46528 .38772 L
.46522 .38773 L
.46516 .38774 L
.4651 .38776 L
.46503 .38777 L
.46497 .38779 L
.46491 .3878 L
.46485 .38781 L
.46479 .38783 L
.46473 .38784 L
.46466 .38785 L
.4646 .38787 L
.46454 .38788 L
.46448 .38789 L
.46442 .38791 L
.46436 .38792 L
.46429 .38793 L
.46423 .38795 L
.46417 .38796 L
.46411 .38797 L
.46405 .38799 L
.46399 .388 L
.46393 .38801 L
.46387 .38802 L
.46381 .38804 L
.46374 .38805 L
.46368 .38806 L
.46362 .38807 L
.46356 .38809 L
.4635 .3881 L
Mistroke
.46344 .38811 L
.46338 .38812 L
.46332 .38813 L
.46326 .38815 L
.4632 .38816 L
.46314 .38817 L
.46308 .38818 L
.46302 .38819 L
.46296 .38821 L
.4629 .38822 L
.46284 .38823 L
.46278 .38824 L
.46272 .38825 L
.46266 .38826 L
.4626 .38827 L
.46254 .38829 L
.46248 .3883 L
.46242 .38831 L
.46236 .38832 L
.4623 .38833 L
.46224 .38834 L
.46218 .38835 L
.46212 .38836 L
.46206 .38837 L
.462 .38838 L
.46194 .3884 L
.46188 .38841 L
.46182 .38842 L
.46176 .38843 L
.4617 .38844 L
.46164 .38845 L
.46159 .38846 L
.46153 .38847 L
.46147 .38848 L
.46141 .38849 L
.46135 .3885 L
.46129 .38851 L
.46123 .38852 L
.46117 .38853 L
.46111 .38854 L
.46106 .38855 L
.461 .38856 L
.46094 .38857 L
.46088 .38858 L
.46082 .38858 L
.46076 .38859 L
.46071 .3886 L
.46065 .38861 L
.46059 .38862 L
.46053 .38863 L
Mistroke
.46047 .38864 L
.46041 .38865 L
.46036 .38866 L
.4603 .38867 L
.46024 .38868 L
.46018 .38868 L
.46012 .38869 L
.46007 .3887 L
.46001 .38871 L
.45995 .38872 L
.45989 .38873 L
.45984 .38873 L
.45978 .38874 L
.45972 .38875 L
.45966 .38876 L
.45961 .38877 L
.45955 .38878 L
.45949 .38878 L
.45944 .38879 L
.45938 .3888 L
.45932 .38881 L
.45926 .38881 L
.45921 .38882 L
.45915 .38883 L
.45909 .38884 L
.45904 .38884 L
.45898 .38885 L
.45892 .38886 L
.45887 .38887 L
.45881 .38887 L
.45875 .38888 L
.4587 .38889 L
.45864 .3889 L
.45858 .3889 L
.45853 .38891 L
.45847 .38892 L
.45842 .38892 L
.45836 .38893 L
.4583 .38894 L
.45825 .38894 L
.45819 .38895 L
.45814 .38896 L
.45808 .38896 L
.45802 .38897 L
.45797 .38898 L
.45791 .38898 L
.45786 .38899 L
.4578 .38899 L
.45775 .389 L
.45769 .38901 L
Mistroke
.45763 .38901 L
.45758 .38902 L
.45752 .38902 L
.45747 .38903 L
.45741 .38904 L
.45736 .38904 L
.4573 .38905 L
.45725 .38905 L
.45719 .38906 L
.45714 .38906 L
.45708 .38907 L
.45703 .38907 L
.45697 .38908 L
.45692 .38908 L
.45686 .38909 L
.45681 .38909 L
.45675 .3891 L
.4567 .3891 L
.45665 .38911 L
.45659 .38911 L
.45654 .38912 L
.45648 .38912 L
.45643 .38913 L
.45637 .38913 L
.45632 .38914 L
.45627 .38914 L
.45621 .38915 L
.45616 .38915 L
.4561 .38915 L
.45605 .38916 L
.456 .38916 L
.45594 .38917 L
.45589 .38917 L
.45584 .38917 L
.45578 .38918 L
.45573 .38918 L
.45567 .38919 L
.45562 .38919 L
.45557 .38919 L
.45551 .3892 L
.45546 .3892 L
.45541 .3892 L
.45535 .38921 L
.4553 .38921 L
.45525 .38922 L
.4552 .38922 L
.45514 .38922 L
.45509 .38922 L
.45504 .38923 L
.45498 .38923 L
Mistroke
.45493 .38923 L
.45488 .38924 L
.45483 .38924 L
.45477 .38924 L
.45472 .38925 L
.45467 .38925 L
.45462 .38925 L
.45456 .38925 L
.45451 .38926 L
.45446 .38926 L
.45441 .38926 L
.45435 .38926 L
.4543 .38927 L
.45425 .38927 L
.4542 .38927 L
.45415 .38927 L
.45409 .38927 L
.45404 .38928 L
.45399 .38928 L
.45394 .38928 L
.45389 .38928 L
.45384 .38928 L
.45378 .38929 L
.45373 .38929 L
.45368 .38929 L
.45363 .38929 L
.45358 .38929 L
.45353 .38929 L
.45348 .3893 L
.45342 .3893 L
.45337 .3893 L
.45332 .3893 L
.45327 .3893 L
.45322 .3893 L
.45317 .3893 L
.45312 .3893 L
.45307 .38931 L
.45302 .38931 L
.45297 .38931 L
.45292 .38931 L
.45286 .38931 L
.45281 .38931 L
.45276 .38931 L
.45271 .38931 L
.45266 .38931 L
.45261 .38931 L
.45256 .38931 L
.45251 .38931 L
.45246 .38931 L
.45241 .38931 L
Mistroke
.45236 .38931 L
.45231 .38931 L
.45226 .38931 L
.45221 .38931 L
.45216 .38931 L
.45211 .38931 L
.45206 .38931 L
.45201 .38931 L
.45196 .38931 L
.45191 .38931 L
.45186 .38931 L
.45181 .38931 L
.45177 .38931 L
.45172 .38931 L
.45167 .38931 L
.45162 .38931 L
.45157 .38931 L
.45152 .38931 L
.45147 .38931 L
.45142 .38931 L
.45137 .38931 L
.45132 .38931 L
.45127 .3893 L
.45123 .3893 L
.45118 .3893 L
.45113 .3893 L
.45108 .3893 L
.45103 .3893 L
.45098 .3893 L
.45093 .3893 L
.45089 .3893 L
.45084 .38929 L
.45079 .38929 L
.45074 .38929 L
.45069 .38929 L
.45064 .38929 L
.4506 .38929 L
.45055 .38928 L
.4505 .38928 L
.45045 .38928 L
.4504 .38928 L
.45036 .38928 L
.45031 .38927 L
.45026 .38927 L
.45021 .38927 L
.45017 .38927 L
.45012 .38927 L
.45007 .38926 L
.45002 .38926 L
.44998 .38926 L
Mistroke
.44993 .38926 L
.44988 .38925 L
.44983 .38925 L
.44979 .38925 L
.44974 .38925 L
.44969 .38924 L
.44965 .38924 L
.4496 .38924 L
.44955 .38924 L
.44951 .38923 L
.44946 .38923 L
.44941 .38923 L
.44937 .38922 L
.44932 .38922 L
.44927 .38922 L
.44923 .38921 L
.44918 .38921 L
.44913 .38921 L
.44909 .3892 L
.44904 .3892 L
.44899 .3892 L
.44895 .38919 L
.4489 .38919 L
.44886 .38919 L
.44881 .38918 L
.44876 .38918 L
.44872 .38918 L
.44867 .38917 L
.44863 .38917 L
.44858 .38916 L
.44853 .38916 L
.44849 .38916 L
.44844 .38915 L
.4484 .38915 L
.44835 .38914 L
.44831 .38914 L
.44826 .38914 L
.44822 .38913 L
.44817 .38913 L
.44813 .38912 L
.44808 .38912 L
.44804 .38911 L
.44799 .38911 L
.44795 .38911 L
.4479 .3891 L
.44786 .3891 L
.44781 .38909 L
.44777 .38909 L
.44772 .38908 L
.44768 .38908 L
Mistroke
.44763 .38907 L
.44759 .38907 L
.44754 .38906 L
.4475 .38906 L
.44745 .38905 L
.44741 .38905 L
.44737 .38904 L
.44732 .38904 L
.44728 .38903 L
.44723 .38903 L
.44719 .38902 L
.44715 .38901 L
.4471 .38901 L
.44706 .389 L
.44701 .389 L
.44697 .38899 L
.44693 .38899 L
.44688 .38898 L
.44684 .38898 L
.4468 .38897 L
.44675 .38896 L
.44671 .38896 L
.44667 .38895 L
.44662 .38895 L
.44658 .38894 L
.44654 .38893 L
.44649 .38893 L
.44645 .38892 L
.44641 .38892 L
.44636 .38891 L
.44632 .3889 L
.44628 .3889 L
.44623 .38889 L
.44619 .38888 L
.44615 .38888 L
.44611 .38887 L
.44606 .38886 L
.44602 .38886 L
.44598 .38885 L
.44594 .38884 L
.44589 .38884 L
.44585 .38883 L
.44581 .38882 L
.44577 .38882 L
.44573 .38881 L
.44568 .3888 L
.44564 .38879 L
.4456 .38879 L
.44556 .38878 L
.44552 .38877 L
Mistroke
.44547 .38877 L
.44543 .38876 L
.44539 .38875 L
.44535 .38874 L
.44531 .38874 L
.44526 .38873 L
.44522 .38872 L
.44518 .38871 L
.44514 .38871 L
.4451 .3887 L
.44506 .38869 L
.44502 .38868 L
.44498 .38868 L
.44493 .38867 L
.44489 .38866 L
.44485 .38865 L
.44481 .38864 L
.44477 .38864 L
.44473 .38863 L
.44469 .38862 L
.44465 .38861 L
.44461 .3886 L
.44457 .3886 L
.44453 .38859 L
.44449 .38858 L
.44444 .38857 L
.4444 .38856 L
.44436 .38855 L
.44432 .38855 L
.44428 .38854 L
.44424 .38853 L
.4442 .38852 L
.44416 .38851 L
.44412 .3885 L
.44408 .38849 L
.44404 .38848 L
.444 .38848 L
.44396 .38847 L
.44392 .38846 L
.44388 .38845 L
.44384 .38844 L
.4438 .38843 L
.44376 .38842 L
.44373 .38841 L
.44369 .3884 L
.44365 .38839 L
.44361 .38839 L
.44357 .38838 L
.44353 .38837 L
.44349 .38836 L
Mistroke
.44345 .38835 L
.44341 .38834 L
.44337 .38833 L
.44333 .38832 L
.44329 .38831 L
.44326 .3883 L
.44322 .38829 L
.44318 .38828 L
.44314 .38827 L
.4431 .38826 L
.44306 .38825 L
.44302 .38824 L
.44298 .38823 L
.44295 .38822 L
.44291 .38821 L
.44287 .3882 L
.44283 .38819 L
.44279 .38818 L
.44275 .38817 L
.44272 .38816 L
.44268 .38815 L
.44264 .38814 L
.4426 .38813 L
.44256 .38812 L
.44253 .38811 L
.44249 .3881 L
.44245 .38809 L
.44241 .38808 L
.44238 .38807 L
.44234 .38806 L
.4423 .38805 L
.44226 .38803 L
.44223 .38802 L
.44219 .38801 L
.44215 .388 L
.44211 .38799 L
.44208 .38798 L
.44204 .38797 L
.442 .38796 L
.44197 .38795 L
.44193 .38794 L
.44189 .38793 L
.44185 .38791 L
.44182 .3879 L
.44178 .38789 L
.44174 .38788 L
.44171 .38787 L
.44167 .38786 L
.44163 .38785 L
.4416 .38784 L
Mistroke
.44156 .38782 L
.44153 .38781 L
.44149 .3878 L
.44145 .38779 L
.44142 .38778 L
.44138 .38777 L
.44134 .38775 L
.44131 .38774 L
.44127 .38773 L
.44124 .38772 L
.4412 .38771 L
.44116 .3877 L
.44113 .38768 L
.44109 .38767 L
.44106 .38766 L
.44102 .38765 L
.44099 .38764 L
.44095 .38762 L
.44091 .38761 L
.44088 .3876 L
.44084 .38759 L
.44081 .38757 L
.44077 .38756 L
.44074 .38755 L
.4407 .38754 L
.44067 .38752 L
.44063 .38751 L
.4406 .3875 L
.44056 .38749 L
.44053 .38747 L
.44049 .38746 L
.44046 .38745 L
.44042 .38744 L
.44039 .38742 L
.44035 .38741 L
.44032 .3874 L
.44028 .38739 L
.44025 .38737 L
.44022 .38736 L
.44018 .38735 L
.44015 .38733 L
.44011 .38732 L
.44008 .38731 L
.44004 .38729 L
.44001 .38728 L
.43998 .38727 L
.43994 .38726 L
.43991 .38724 L
.43987 .38723 L
.43984 .38722 L
Mistroke
.43981 .3872 L
.43977 .38719 L
.43974 .38718 L
.43971 .38716 L
.43967 .38715 L
.43964 .38713 L
.43961 .38712 L
.43957 .38711 L
.43954 .38709 L
.4395 .38708 L
.43947 .38707 L
.43944 .38705 L
.43941 .38704 L
.43937 .38703 L
.43934 .38701 L
.43931 .387 L
.43927 .38698 L
.43924 .38697 L
.43921 .38696 L
.43917 .38694 L
.43914 .38693 L
.43911 .38691 L
.43908 .3869 L
.43904 .38689 L
.43901 .38687 L
.43898 .38686 L
.43895 .38684 L
.43891 .38683 L
.43888 .38681 L
.43885 .3868 L
.43882 .38679 L
.43878 .38677 L
.43875 .38676 L
.43872 .38674 L
.43869 .38673 L
.43866 .38671 L
.43862 .3867 L
.43859 .38668 L
.43856 .38667 L
.43853 .38665 L
.4385 .38664 L
.43847 .38662 L
.43843 .38661 L
.4384 .3866 L
.43837 .38658 L
.43834 .38657 L
.43831 .38655 L
.43828 .38654 L
.43825 .38652 L
.43821 .38651 L
Mistroke
.43818 .38649 L
.43815 .38648 L
.43812 .38646 L
.43809 .38644 L
.43806 .38643 L
.43803 .38641 L
.438 .3864 L
.43797 .38638 L
.43794 .38637 L
.4379 .38635 L
.43787 .38634 L
.43784 .38632 L
.43781 .38631 L
.43778 .38629 L
.43775 .38628 L
.43772 .38626 L
.43769 .38624 L
.43766 .38623 L
.43763 .38621 L
.4376 .3862 L
.43757 .38618 L
.43754 .38617 L
.43751 .38615 L
.43748 .38613 L
.43745 .38612 L
.43742 .3861 L
.43739 .38609 L
.43736 .38607 L
.43733 .38606 L
.4373 .38604 L
.43727 .38602 L
.43724 .38601 L
.43721 .38599 L
.43718 .38597 L
.43715 .38596 L
.43712 .38594 L
.43709 .38593 L
.43707 .38591 L
.43704 .38589 L
.43701 .38588 L
.43698 .38586 L
.43695 .38584 L
.43692 .38583 L
.43689 .38581 L
.43686 .3858 L
.43683 .38578 L
.4368 .38576 L
.43678 .38575 L
.43675 .38573 L
.43672 .38571 L
Mistroke
.43669 .3857 L
.43666 .38568 L
.43663 .38566 L
.4366 .38565 L
.43658 .38563 L
.43655 .38561 L
.43652 .3856 L
.43649 .38558 L
.43646 .38556 L
.43643 .38554 L
.43641 .38553 L
.43638 .38551 L
.43635 .38549 L
.43632 .38548 L
.43629 .38546 L
.43627 .38544 L
.43624 .38543 L
.43621 .38541 L
.43618 .38539 L
.43615 .38537 L
.43613 .38536 L
.4361 .38534 L
.43607 .38532 L
.43604 .3853 L
.43602 .38529 L
.43599 .38527 L
.43596 .38525 L
.43594 .38524 L
.43591 .38522 L
.43588 .3852 L
.43585 .38518 L
.43583 .38516 L
.4358 .38515 L
.43577 .38513 L
.43575 .38511 L
.43572 .38509 L
.43569 .38508 L
.43567 .38506 L
.43564 .38504 L
.43561 .38502 L
.43559 .38501 L
.43556 .38499 L
.43553 .38497 L
.43551 .38495 L
.43548 .38493 L
.43545 .38492 L
.43543 .3849 L
.4354 .38488 L
.43537 .38486 L
.43535 .38484 L
Mistroke
.43532 .38483 L
.4353 .38481 L
.43527 .38479 L
.43524 .38477 L
.43522 .38475 L
.43519 .38474 L
.43517 .38472 L
.43514 .3847 L
.43511 .38468 L
.43509 .38466 L
.43506 .38464 L
.43504 .38463 L
.43501 .38461 L
.43499 .38459 L
.43496 .38457 L
.43494 .38455 L
.43491 .38453 L
.43489 .38451 L
.43486 .3845 L
.43483 .38448 L
.43481 .38446 L
.43478 .38444 L
.43476 .38442 L
.43473 .3844 L
.43471 .38438 L
.43468 .38437 L
.43466 .38435 L
.43463 .38433 L
.43461 .38431 L
.43459 .38429 L
.43456 .38427 L
.43454 .38425 L
.43451 .38423 L
.43449 .38421 L
.43446 .3842 L
.43444 .38418 L
.43441 .38416 L
.43439 .38414 L
.43437 .38412 L
.43434 .3841 L
.43432 .38408 L
.43429 .38406 L
.43427 .38404 L
.43424 .38402 L
.43422 .384 L
.4342 .38398 L
.43417 .38397 L
.43415 .38395 L
.43413 .38393 L
.4341 .38391 L
Mistroke
.43408 .38389 L
.43405 .38387 L
.43403 .38385 L
.43401 .38383 L
.43398 .38381 L
.43396 .38379 L
.43394 .38377 L
.43391 .38375 L
.43389 .38373 L
.43387 .38371 L
.43384 .38369 L
.43382 .38367 L
.4338 .38365 L
.43377 .38363 L
.43375 .38361 L
.43373 .38359 L
.43371 .38357 L
.43368 .38356 L
.43366 .38354 L
.43364 .38352 L
.43361 .3835 L
.43359 .38348 L
.43357 .38346 L
.43355 .38344 L
.43352 .38342 L
.4335 .3834 L
.43348 .38338 L
.43346 .38336 L
.43343 .38334 L
.43341 .38332 L
.43339 .3833 L
.43337 .38328 L
.43335 .38326 L
.43332 .38324 L
.4333 .38322 L
.43328 .38319 L
.43326 .38317 L
.43324 .38315 L
.43321 .38313 L
.43319 .38311 L
.43317 .38309 L
.43315 .38307 L
.43313 .38305 L
.4331 .38303 L
.43308 .38301 L
.43306 .38299 L
.43304 .38297 L
.43302 .38295 L
.433 .38293 L
.43298 .38291 L
Mistroke
.43295 .38289 L
.43293 .38287 L
.43291 .38285 L
.43289 .38283 L
.43287 .38281 L
.43285 .38279 L
.43283 .38277 L
.43281 .38274 L
.43279 .38272 L
.43276 .3827 L
.43274 .38268 L
.43272 .38266 L
.4327 .38264 L
.43268 .38262 L
.43266 .3826 L
.43264 .38258 L
.43262 .38256 L
.4326 .38254 L
.43258 .38252 L
.43256 .38249 L
.43254 .38247 L
.43252 .38245 L
.4325 .38243 L
.43248 .38241 L
.43246 .38239 L
.43244 .38237 L
.43242 .38235 L
.4324 .38233 L
.43238 .38231 L
.43236 .38228 L
.43234 .38226 L
.43232 .38224 L
.4323 .38222 L
.43228 .3822 L
.43226 .38218 L
.43224 .38216 L
.43222 .38214 L
.4322 .38211 L
.43218 .38209 L
.43216 .38207 L
.43214 .38205 L
.43212 .38203 L
.4321 .38201 L
.43208 .38199 L
.43206 .38196 L
.43204 .38194 L
.43202 .38192 L
.43201 .3819 L
.43199 .38188 L
.43197 .38186 L
Mistroke
.43195 .38184 L
.43193 .38181 L
.43191 .38179 L
.43189 .38177 L
.43187 .38175 L
.43185 .38173 L
.43184 .38171 L
.43182 .38168 L
.4318 .38166 L
.43178 .38164 L
.43176 .38162 L
.43174 .3816 L
.43172 .38158 L
.43171 .38155 L
.43169 .38153 L
.43167 .38151 L
.43165 .38149 L
.43163 .38147 L
.43161 .38144 L
.4316 .38142 L
.43158 .3814 L
.43156 .38138 L
.43154 .38136 L
.43152 .38133 L
.43151 .38131 L
.43149 .38129 L
.43147 .38127 L
.43145 .38125 L
.43143 .38122 L
.43142 .3812 L
.4314 .38118 L
.43138 .38116 L
.43136 .38114 L
.43135 .38111 L
.43133 .38109 L
.43131 .38107 L
.43129 .38105 L
.43128 .38103 L
.43126 .381 L
.43124 .38098 L
.43123 .38096 L
.43121 .38094 L
.43119 .38091 L
.43117 .38089 L
.43116 .38087 L
.43114 .38085 L
.43112 .38082 L
.43111 .3808 L
.43109 .38078 L
.43107 .38076 L
Mistroke
.43106 .38073 L
.43104 .38071 L
.43102 .38069 L
.43101 .38067 L
.43099 .38064 L
.43097 .38062 L
.43096 .3806 L
.43094 .38058 L
.43092 .38055 L
.43091 .38053 L
.43089 .38051 L
.43087 .38049 L
.43086 .38046 L
.43084 .38044 L
.43083 .38042 L
.43081 .3804 L
.43079 .38037 L
.43078 .38035 L
.43076 .38033 L
.43075 .38031 L
.43073 .38028 L
.43071 .38026 L
.4307 .38024 L
.43068 .38021 L
.43067 .38019 L
.43065 .38017 L
.43064 .38015 L
.43062 .38012 L
.4306 .3801 L
.43059 .38008 L
.43057 .38005 L
.43056 .38003 L
.43054 .38001 L
.43053 .37999 L
.43051 .37996 L
.4305 .37994 L
.43048 .37992 L
.43047 .37989 L
.43045 .37987 L
.43044 .37985 L
.43042 .37982 L
.43041 .3798 L
.43039 .37978 L
.43038 .37975 L
.43036 .37973 L
.43035 .37971 L
.43033 .37969 L
.43032 .37966 L
.4303 .37964 L
.43029 .37962 L
Mistroke
.43027 .37959 L
.43026 .37957 L
.43024 .37955 L
.43023 .37952 L
.43022 .3795 L
.4302 .37948 L
.43019 .37945 L
.43017 .37943 L
.43016 .37941 L
.43014 .37938 L
.43013 .37936 L
.43012 .37934 L
.4301 .37931 L
.43009 .37929 L
.43007 .37927 L
.43006 .37924 L
.43005 .37922 L
.43003 .3792 L
.43002 .37917 L
.43 .37915 L
.42999 .37913 L
.42998 .3791 L
.42996 .37908 L
.42995 .37905 L
.42994 .37903 L
.42992 .37901 L
.42991 .37898 L
.4299 .37896 L
.42988 .37894 L
.42987 .37891 L
.42986 .37889 L
.42984 .37887 L
.42983 .37884 L
.42982 .37882 L
.4298 .3788 L
.42979 .37877 L
.42978 .37875 L
.42976 .37872 L
.42975 .3787 L
.42974 .37868 L
.42972 .37865 L
.42971 .37863 L
.4297 .37861 L
.42969 .37858 L
.42967 .37856 L
.42966 .37853 L
.42965 .37851 L
.42964 .37849 L
.42962 .37846 L
.42961 .37844 L
Mistroke
.4296 .37841 L
.42959 .37839 L
.42957 .37837 L
.42956 .37834 L
.42955 .37832 L
.42954 .3783 L
.42952 .37827 L
.42951 .37825 L
.4295 .37822 L
.42949 .3782 L
.42947 .37818 L
.42946 .37815 L
.42945 .37813 L
.42944 .3781 L
.42943 .37808 L
.42942 .37806 L
.4294 .37803 L
.42939 .37801 L
.42938 .37798 L
.42937 .37796 L
.42936 .37793 L
.42934 .37791 L
.42933 .37789 L
.42932 .37786 L
.42931 .37784 L
.4293 .37781 L
.42929 .37779 L
.42928 .37777 L
.42926 .37774 L
.42925 .37772 L
.42924 .37769 L
.42923 .37767 L
.42922 .37765 L
.42921 .37762 L
.4292 .3776 L
.42919 .37757 L
.42917 .37755 L
.42916 .37752 L
.42915 .3775 L
.42914 .37748 L
.42913 .37745 L
.42912 .37743 L
.42911 .3774 L
.4291 .37738 L
.42909 .37735 L
.42908 .37733 L
.42907 .3773 L
.42906 .37728 L
.42904 .37726 L
.42903 .37723 L
Mistroke
.42902 .37721 L
.42901 .37718 L
.429 .37716 L
.42899 .37713 L
.42898 .37711 L
.42897 .37709 L
.42896 .37706 L
.42895 .37704 L
.42894 .37701 L
.42893 .37699 L
.42892 .37696 L
.42891 .37694 L
.4289 .37691 L
.42889 .37689 L
.42888 .37686 L
.42887 .37684 L
.42886 .37682 L
.42885 .37679 L
.42884 .37677 L
.42883 .37674 L
.42882 .37672 L
.42881 .37669 L
.4288 .37667 L
.42879 .37664 L
.42878 .37662 L
.42877 .37659 L
.42876 .37657 L
.42876 .37655 L
.42875 .37652 L
.42874 .3765 L
.42873 .37647 L
.42872 .37645 L
.42871 .37642 L
.4287 .3764 L
.42869 .37637 L
.42868 .37635 L
.42867 .37632 L
.42866 .3763 L
.42865 .37627 L
.42864 .37625 L
.42864 .37622 L
.42863 .3762 L
.42862 .37617 L
.42861 .37615 L
.4286 .37612 L
.42859 .3761 L
.42858 .37608 L
.42857 .37605 L
.42857 .37603 L
.42856 .376 L
Mistroke
.42855 .37598 L
.42854 .37595 L
.42853 .37593 L
.42852 .3759 L
.42851 .37588 L
.42851 .37585 L
.4285 .37583 L
.42849 .3758 L
.42848 .37578 L
.42847 .37575 L
.42846 .37573 L
.42846 .3757 L
.42845 .37568 L
.42844 .37565 L
.42843 .37563 L
.42842 .3756 L
.42842 .37558 L
.42841 .37555 L
.4284 .37553 L
.42839 .3755 L
.42839 .37548 L
.42838 .37545 L
.42837 .37543 L
.42836 .3754 L
.42835 .37538 L
.42835 .37535 L
.42834 .37533 L
.42833 .3753 L
.42832 .37528 L
.42832 .37525 L
.42831 .37523 L
.4283 .3752 L
.42829 .37518 L
.42829 .37515 L
.42828 .37513 L
.42827 .3751 L
.42826 .37508 L
.42826 .37505 L
.42825 .37503 L
.42824 .375 L
.42824 .37498 L
.42823 .37495 L
.42822 .37493 L
.42822 .3749 L
.42821 .37488 L
.4282 .37485 L
.42819 .37483 L
.42819 .3748 L
.42818 .37478 L
.42817 .37475 L
Mistroke
.42817 .37473 L
.42816 .3747 L
.42815 .37468 L
.42815 .37465 L
.42814 .37463 L
.42813 .3746 L
.42813 .37458 L
.42812 .37455 L
.42811 .37452 L
.42811 .3745 L
.4281 .37447 L
.4281 .37445 L
.42809 .37442 L
.42808 .3744 L
.42808 .37437 L
.42807 .37435 L
.42806 .37432 L
.42806 .3743 L
.42805 .37427 L
.42805 .37425 L
.42804 .37422 L
.42803 .3742 L
.42803 .37417 L
.42802 .37415 L
.42802 .37412 L
.42801 .3741 L
.42801 .37407 L
.428 .37405 L
.42799 .37402 L
.42799 .37399 L
.42798 .37397 L
.42798 .37394 L
.42797 .37392 L
.42797 .37389 L
.42796 .37387 L
.42795 .37384 L
.42795 .37382 L
.42794 .37379 L
.42794 .37377 L
.42793 .37374 L
.42793 .37372 L
.42792 .37369 L
.42792 .37367 L
.42791 .37364 L
.42791 .37361 L
.4279 .37359 L
.4279 .37356 L
.42789 .37354 L
.42789 .37351 L
.42788 .37349 L
Mistroke
.42788 .37346 L
.42787 .37344 L
.42787 .37341 L
.42786 .37339 L
.42786 .37336 L
.42785 .37334 L
.42785 .37331 L
.42784 .37328 L
.42784 .37326 L
.42783 .37323 L
.42783 .37321 L
.42782 .37318 L
.42782 .37316 L
.42782 .37313 L
.42781 .37311 L
.42781 .37308 L
.4278 .37306 L
.4278 .37303 L
.42779 .37301 L
.42779 .37298 L
.42778 .37295 L
.42778 .37293 L
.42778 .3729 L
.42777 .37288 L
.42777 .37285 L
.42776 .37283 L
.42776 .3728 L
.42776 .37278 L
.42775 .37275 L
.42775 .37273 L
.42774 .3727 L
.42774 .37267 L
.42774 .37265 L
.42773 .37262 L
.42773 .3726 L
.42772 .37257 L
.42772 .37255 L
.42772 .37252 L
.42771 .3725 L
.42771 .37247 L
.42771 .37245 L
.4277 .37242 L
.4277 .37239 L
.4277 .37237 L
.42769 .37234 L
.42769 .37232 L
.42769 .37229 L
.42768 .37227 L
.42768 .37224 L
.42768 .37222 L
Mistroke
.42767 .37219 L
.42767 .37216 L
.42767 .37214 L
.42766 .37211 L
.42766 .37209 L
.42766 .37206 L
.42765 .37204 L
.42765 .37201 L
.42765 .37199 L
.42764 .37196 L
.42764 .37194 L
.42764 .37191 L
.42764 .37188 L
.42763 .37186 L
.42763 .37183 L
.42763 .37181 L
.42762 .37178 L
.42762 .37176 L
.42762 .37173 L
.42762 .37171 L
.42761 .37168 L
.42761 .37165 L
.42761 .37163 L
.42761 .3716 L
.4276 .37158 L
.4276 .37155 L
.4276 .37153 L
.4276 .3715 L
.42759 .37148 L
.42759 .37145 L
.42759 .37142 L
.42759 .3714 L
.42758 .37137 L
.42758 .37135 L
.42758 .37132 L
.42758 .3713 L
.42758 .37127 L
.42757 .37125 L
.42757 .37122 L
.42757 .37119 L
.42757 .37117 L
.42757 .37114 L
.42756 .37112 L
.42756 .37109 L
.42756 .37107 L
.42756 .37104 L
.42756 .37102 L
.42755 .37099 L
.42755 .37096 L
.42755 .37094 L
Mistroke
.42755 .37091 L
.42755 .37089 L
.42755 .37086 L
.42754 .37084 L
.42754 .37081 L
.42754 .37079 L
.42754 .37076 L
.42754 .37073 L
.42754 .37071 L
.42754 .37068 L
.42753 .37066 L
.42753 .37063 L
.42753 .37061 L
.42753 .37058 L
.42753 .37056 L
.42753 .37053 L
.42753 .3705 L
.42753 .37048 L
.42752 .37045 L
.42752 .37043 L
.42752 .3704 L
.42752 .37038 L
.42752 .37035 L
.42752 .37033 L
.42752 .3703 L
.42752 .37027 L
.42752 .37025 L
.42752 .37022 L
.42751 .3702 L
.42751 .37017 L
.42751 .37015 L
.42751 .37012 L
.42751 .3701 L
.42751 .37007 L
.42751 .37004 L
.42751 .37002 L
.42751 .36999 L
.42751 .36997 L
.42751 .36994 L
.42751 .36992 L
.42751 .36989 L
.42751 .36987 L
.42751 .36984 L
.42751 .36981 L
.42751 .36979 L
.42751 .36976 L
.42751 .36974 L
.4275 .36971 L
.4275 .36969 L
.4275 .36966 L
Mistroke
.4275 .36964 L
.4275 .36961 L
.4275 .36959 L
.4275 .36956 L
.4275 .36953 L
.4275 .36951 L
.4275 .36948 L
.4275 .36946 L
.4275 .36943 L
.4275 .36941 L
.4275 .36938 L
.4275 .36936 L
.4275 .36933 L
.4275 .3693 L
.42751 .36928 L
.42751 .36925 L
.42751 .36923 L
.42751 .3692 L
.42751 .36918 L
.42751 .36915 L
.42751 .36913 L
.42751 .3691 L
.42751 .36908 L
.42751 .36905 L
.42751 .36902 L
.42751 .369 L
.42751 .36897 L
.42751 .36895 L
.42751 .36892 L
.42751 .3689 L
.42751 .36887 L
.42751 .36885 L
.42751 .36882 L
.42752 .3688 L
.42752 .36877 L
.42752 .36874 L
.42752 .36872 L
.42752 .36869 L
.42752 .36867 L
.42752 .36864 L
.42752 .36862 L
.42752 .36859 L
.42752 .36857 L
.42753 .36854 L
.42753 .36852 L
.42753 .36849 L
.42753 .36846 L
.42753 .36844 L
.42753 .36841 L
.42753 .36839 L
Mistroke
.42753 .36836 L
.42753 .36834 L
.42754 .36831 L
.42754 .36829 L
.42754 .36826 L
.42754 .36824 L
.42754 .36821 L
.42754 .36819 L
.42754 .36816 L
.42755 .36813 L
.42755 .36811 L
.42755 .36808 L
.42755 .36806 L
.42755 .36803 L
.42755 .36801 L
.42756 .36798 L
.42756 .36796 L
.42756 .36793 L
.42756 .36791 L
.42756 .36788 L
.42756 .36786 L
.42757 .36783 L
.42757 .3678 L
.42757 .36778 L
.42757 .36775 L
.42757 .36773 L
.42758 .3677 L
.42758 .36768 L
.42758 .36765 L
.42758 .36763 L
.42758 .3676 L
.42759 .36758 L
.42759 .36755 L
.42759 .36753 L
.42759 .3675 L
.4276 .36748 L
.4276 .36745 L
.4276 .36743 L
.4276 .3674 L
.4276 .36737 L
.42761 .36735 L
.42761 .36732 L
.42761 .3673 L
.42761 .36727 L
.42762 .36725 L
.42762 .36722 L
.42762 .3672 L
.42762 .36717 L
.42763 .36715 L
.42763 .36712 L
Mistroke
.42763 .3671 L
.42763 .36707 L
.42764 .36705 L
.42764 .36702 L
.42764 .367 L
.42765 .36697 L
.42765 .36695 L
.42765 .36692 L
.42765 .3669 L
.42766 .36687 L
.42766 .36684 L
.42766 .36682 L
.42767 .36679 L
.42767 .36677 L
.42767 .36674 L
.42767 .36672 L
.42768 .36669 L
.42768 .36667 L
.42768 .36664 L
.42769 .36662 L
.42769 .36659 L
.42769 .36657 L
.4277 .36654 L
.4277 .36652 L
.4277 .36649 L
.42771 .36647 L
.42771 .36644 L
.42771 .36642 L
.42772 .36639 L
.42772 .36637 L
.42772 .36634 L
.42773 .36632 L
.42773 .36629 L
.42773 .36627 L
.42774 .36624 L
.42774 .36622 L
.42774 .36619 L
.42775 .36617 L
.42775 .36614 L
.42776 .36612 L
.42776 .36609 L
.42776 .36607 L
.42777 .36604 L
.42777 .36602 L
.42777 .36599 L
.42778 .36597 L
.42778 .36594 L
.42779 .36592 L
.42779 .36589 L
.42779 .36587 L
Mistroke
.4278 .36584 L
.4278 .36582 L
.4278 .36579 L
.42781 .36577 L
.42781 .36574 L
.42782 .36572 L
.42782 .36569 L
.42782 .36567 L
.42783 .36564 L
.42783 .36562 L
.42784 .36559 L
.42784 .36557 L
.42785 .36554 L
.42785 .36552 L
.42785 .36549 L
.42786 .36547 L
.42786 .36544 L
.42787 .36542 L
.42787 .36539 L
.42788 .36537 L
.42788 .36534 L
.42788 .36532 L
.42789 .36529 L
.42789 .36527 L
.4279 .36524 L
.4279 .36522 L
.42791 .36519 L
.42791 .36517 L
.42792 .36514 L
.42792 .36512 L
.42793 .3651 L
.42793 .36507 L
.42793 .36505 L
.42794 .36502 L
.42794 .365 L
.42795 .36497 L
.42795 .36495 L
.42796 .36492 L
.42796 .3649 L
.42797 .36487 L
.42797 .36485 L
.42798 .36482 L
.42798 .3648 L
.42799 .36477 L
.42799 .36475 L
.428 .36472 L
.428 .3647 L
.42801 .36467 L
.42801 .36465 L
.42802 .36463 L
Mistroke
.42802 .3646 L
.42803 .36458 L
.42803 .36455 L
.42804 .36453 L
.42804 .3645 L
.42805 .36448 L
.42805 .36445 L
.42806 .36443 L
.42807 .3644 L
.42807 .36438 L
.42808 .36435 L
.42808 .36433 L
.42809 .3643 L
.42809 .36428 L
.4281 .36426 L
.4281 .36423 L
.42811 .36421 L
.42811 .36418 L
.42812 .36416 L
.42812 .36413 L
.42813 .36411 L
.42814 .36408 L
.42814 .36406 L
.42815 .36404 L
.42815 .36401 L
.42816 .36399 L
.42816 .36396 L
.42817 .36394 L
.42818 .36391 L
.42818 .36389 L
.42819 .36386 L
.42819 .36384 L
.4282 .36381 L
.4282 .36379 L
.42821 .36377 L
.42822 .36374 L
.42822 .36372 L
.42823 .36369 L
.42823 .36367 L
.42824 .36364 L
.42825 .36362 L
.42825 .3636 L
.42826 .36357 L
.42826 .36355 L
.42827 .36352 L
.42828 .3635 L
.42828 .36347 L
.42829 .36345 L
.4283 .36342 L
.4283 .3634 L
Mistroke
.42831 .36338 L
.42831 .36335 L
.42832 .36333 L
.42833 .3633 L
.42833 .36328 L
.42834 .36325 L
.42835 .36323 L
.42835 .36321 L
.42836 .36318 L
.42836 .36316 L
.42837 .36313 L
.42838 .36311 L
.42838 .36309 L
.42839 .36306 L
.4284 .36304 L
.4284 .36301 L
.42841 .36299 L
.42842 .36296 L
.42842 .36294 L
.42843 .36292 L
.42844 .36289 L
.42844 .36287 L
.42845 .36284 L
.42846 .36282 L
.42846 .3628 L
.42847 .36277 L
.42848 .36275 L
.42848 .36272 L
.42849 .3627 L
.4285 .36267 L
.4285 .36265 L
.42851 .36263 L
.42852 .3626 L
.42853 .36258 L
.42853 .36255 L
.42854 .36253 L
.42855 .36251 L
.42855 .36248 L
.42856 .36246 L
.42857 .36243 L
.42857 .36241 L
.42858 .36239 L
.42859 .36236 L
.4286 .36234 L
.4286 .36231 L
.42861 .36229 L
.42862 .36227 L
.42862 .36224 L
.42863 .36222 L
.42864 .3622 L
Mistroke
.42865 .36217 L
.42865 .36215 L
.42866 .36212 L
.42867 .3621 L
.42868 .36208 L
.42868 .36205 L
.42869 .36203 L
.4287 .362 L
.42871 .36198 L
.42871 .36196 L
.42872 .36193 L
.42873 .36191 L
.42874 .36189 L
.42874 .36186 L
.42875 .36184 L
.42876 .36181 L
.42877 .36179 L
.42877 .36177 L
.42878 .36174 L
.42879 .36172 L
.4288 .3617 L
.4288 .36167 L
.42881 .36165 L
.42882 .36162 L
.42883 .3616 L
.42883 .36158 L
.42884 .36155 L
.42885 .36153 L
.42886 .36151 L
.42887 .36148 L
.42887 .36146 L
.42888 .36144 L
.42889 .36141 L
.4289 .36139 L
.42891 .36136 L
.42891 .36134 L
.42892 .36132 L
.42893 .36129 L
.42894 .36127 L
.42895 .36125 L
.42895 .36122 L
.42896 .3612 L
.42897 .36118 L
.42898 .36115 L
.42899 .36113 L
.42899 .36111 L
.429 .36108 L
.42901 .36106 L
.42902 .36104 L
.42903 .36101 L
Mistroke
.42904 .36099 L
.42904 .36097 L
.42905 .36094 L
.42906 .36092 L
.42907 .3609 L
.42908 .36087 L
.42908 .36085 L
.42909 .36083 L
.4291 .3608 L
.42911 .36078 L
.42912 .36076 L
.42913 .36073 L
.42914 .36071 L
.42914 .36069 L
.42915 .36066 L
.42916 .36064 L
.42917 .36062 L
.42918 .36059 L
.42919 .36057 L
.4292 .36055 L
.4292 .36052 L
.42921 .3605 L
.42922 .36048 L
.42923 .36045 L
.42924 .36043 L
.42925 .36041 L
.42926 .36038 L
.42926 .36036 L
.42927 .36034 L
.42928 .36031 L
.42929 .36029 L
.4293 .36027 L
.42931 .36024 L
.42932 .36022 L
.42933 .3602 L
.42934 .36018 L
.42934 .36015 L
.42935 .36013 L
.42936 .36011 L
.42937 .36008 L
.42938 .36006 L
.42939 .36004 L
.4294 .36001 L
.42941 .35999 L
.42942 .35997 L
.42942 .35995 L
.42943 .35992 L
.42944 .3599 L
.42945 .35988 L
.42946 .35985 L
Mistroke
.42947 .35983 L
.42948 .35981 L
.42949 .35979 L
.4295 .35976 L
.42951 .35974 L
.42952 .35972 L
.42953 .35969 L
.42953 .35967 L
.42954 .35965 L
.42955 .35963 L
.42956 .3596 L
.42957 .35958 L
.42958 .35956 L
.42959 .35953 L
.4296 .35951 L
.42961 .35949 L
.42962 .35947 L
.42963 .35944 L
.42964 .35942 L
.42965 .3594 L
.42966 .35937 L
.42967 .35935 L
.42968 .35933 L
.42969 .35931 L
.42969 .35928 L
.4297 .35926 L
.42971 .35924 L
.42972 .35922 L
.42973 .35919 L
.42974 .35917 L
.42975 .35915 L
.42976 .35913 L
.42977 .3591 L
.42978 .35908 L
.42979 .35906 L
.4298 .35904 L
.42981 .35901 L
.42982 .35899 L
.42983 .35897 L
.42984 .35895 L
.42985 .35892 L
.42986 .3589 L
.42987 .35888 L
.42988 .35886 L
.42989 .35883 L
.4299 .35881 L
.42991 .35879 L
.42992 .35877 L
.42993 .35874 L
.42994 .35872 L
Mistroke
.42995 .3587 L
.42996 .35868 L
.42997 .35865 L
.42998 .35863 L
.42999 .35861 L
.43 .35859 L
.43001 .35857 L
.43002 .35854 L
.43003 .35852 L
.43004 .3585 L
.43005 .35848 L
.43006 .35845 L
.43007 .35843 L
.43008 .35841 L
.43009 .35839 L
.4301 .35837 L
.43011 .35834 L
.43012 .35832 L
.43013 .3583 L
.43014 .35828 L
.43015 .35825 L
.43016 .35823 L
.43017 .35821 L
.43018 .35819 L
.43019 .35817 L
.4302 .35814 L
.43021 .35812 L
.43022 .3581 L
.43023 .35808 L
.43024 .35806 L
.43026 .35803 L
.43027 .35801 L
.43028 .35799 L
.43029 .35797 L
.4303 .35795 L
.43031 .35792 L
.43032 .3579 L
.43033 .35788 L
.43034 .35786 L
.43035 .35784 L
.43036 .35781 L
.43037 .35779 L
.43038 .35777 L
.43039 .35775 L
.4304 .35773 L
.43041 .3577 L
.43042 .35768 L
.43043 .35766 L
.43045 .35764 L
.43046 .35762 L
Mistroke
.43047 .3576 L
.43048 .35757 L
.43049 .35755 L
.4305 .35753 L
.43051 .35751 L
.43052 .35749 L
.43053 .35747 L
.43054 .35744 L
.43055 .35742 L
.43056 .3574 L
.43057 .35738 L
.43059 .35736 L
.4306 .35734 L
.43061 .35731 L
.43062 .35729 L
.43063 .35727 L
.43064 .35725 L
.43065 .35723 L
.43066 .35721 L
.43067 .35718 L
.43068 .35716 L
.4307 .35714 L
.43071 .35712 L
.43072 .3571 L
.43073 .35708 L
.43074 .35706 L
.43075 .35703 L
.43076 .35701 L
.43077 .35699 L
.43078 .35697 L
.43079 .35695 L
.43081 .35693 L
.43082 .35691 L
.43083 .35688 L
.43084 .35686 L
.43085 .35684 L
.43086 .35682 L
.43087 .3568 L
.43088 .35678 L
.4309 .35676 L
.43091 .35673 L
.43092 .35671 L
.43093 .35669 L
.43094 .35667 L
.43095 .35665 L
.43096 .35663 L
.43098 .35661 L
.43099 .35659 L
.431 .35656 L
.43101 .35654 L
Mistroke
.43102 .35652 L
.43103 .3565 L
.43104 .35648 L
.43105 .35646 L
.43107 .35644 L
.43108 .35642 L
.43109 .3564 L
.4311 .35637 L
.43111 .35635 L
.43112 .35633 L
.43114 .35631 L
.43115 .35629 L
.43116 .35627 L
.43117 .35625 L
.43118 .35623 L
.43119 .35621 L
.4312 .35619 L
.43122 .35616 L
.43123 .35614 L
.43124 .35612 L
.43125 .3561 L
.43126 .35608 L
.43127 .35606 L
.43129 .35604 L
.4313 .35602 L
.43131 .356 L
.43132 .35598 L
.43133 .35596 L
.43135 .35593 L
.43136 .35591 L
.43137 .35589 L
.43138 .35587 L
.43139 .35585 L
.4314 .35583 L
.43142 .35581 L
.43143 .35579 L
.43144 .35577 L
.43145 .35575 L
.43146 .35573 L
.43148 .35571 L
.43149 .35569 L
.4315 .35567 L
.43151 .35564 L
.43152 .35562 L
.43154 .3556 L
.43155 .35558 L
.43156 .35556 L
.43157 .35554 L
.43158 .35552 L
.4316 .3555 L
Mistroke
.43161 .35548 L
.43162 .35546 L
.43163 .35544 L
.43164 .35542 L
.43166 .3554 L
.43167 .35538 L
.43168 .35536 L
.43169 .35534 L
.4317 .35532 L
.43172 .3553 L
.43173 .35528 L
.43174 .35526 L
.43175 .35523 L
.43176 .35521 L
.43178 .35519 L
.43179 .35517 L
.4318 .35515 L
.43181 .35513 L
.43183 .35511 L
.43184 .35509 L
.43185 .35507 L
.43186 .35505 L
.43187 .35503 L
.43189 .35501 L
.4319 .35499 L
.43191 .35497 L
.43192 .35495 L
.43194 .35493 L
.43195 .35491 L
.43196 .35489 L
.43197 .35487 L
.43199 .35485 L
.432 .35483 L
.43201 .35481 L
.43202 .35479 L
.43204 .35477 L
.43205 .35475 L
.43206 .35473 L
.43207 .35471 L
.43209 .35469 L
.4321 .35467 L
.43211 .35465 L
.43212 .35463 L
.43214 .35461 L
.43215 .35459 L
.43216 .35457 L
.43217 .35455 L
.43219 .35453 L
.4322 .35451 L
.43221 .35449 L
Mistroke
.43222 .35447 L
.43224 .35445 L
.43225 .35443 L
.43226 .35441 L
.43227 .35439 L
.43229 .35437 L
.4323 .35435 L
.43231 .35433 L
.43232 .35431 L
.43234 .35429 L
.43235 .35427 L
.43236 .35425 L
.43237 .35423 L
.43239 .35421 L
.4324 .35419 L
.43241 .35417 L
.43243 .35415 L
.43244 .35414 L
.43245 .35412 L
.43246 .3541 L
.43248 .35408 L
.43249 .35406 L
.4325 .35404 L
.43252 .35402 L
.43253 .354 L
.43254 .35398 L
.43255 .35396 L
.43257 .35394 L
.43258 .35392 L
.43259 .3539 L
.43261 .35388 L
.43262 .35386 L
.43263 .35384 L
.43264 .35382 L
.43266 .3538 L
.43267 .35378 L
.43268 .35376 L
.4327 .35375 L
.43271 .35373 L
.43272 .35371 L
.43273 .35369 L
.43275 .35367 L
.43276 .35365 L
.43277 .35363 L
.43279 .35361 L
.4328 .35359 L
.43281 .35357 L
.43283 .35355 L
.43284 .35353 L
.43285 .35351 L
Mistroke
.43287 .3535 L
.43288 .35348 L
.43289 .35346 L
.4329 .35344 L
.43292 .35342 L
.43293 .3534 L
.43294 .35338 L
.43296 .35336 L
.43297 .35334 L
.43298 .35332 L
.433 .3533 L
.43301 .35329 L
.43302 .35327 L
.43304 .35325 L
.43305 .35323 L
.43306 .35321 L
.43308 .35319 L
.43309 .35317 L
.4331 .35315 L
.43312 .35313 L
.43313 .35311 L
.43314 .3531 L
.43316 .35308 L
.43317 .35306 L
.43318 .35304 L
.4332 .35302 L
.43321 .353 L
.43322 .35298 L
.43324 .35296 L
.43325 .35295 L
.43326 .35293 L
.43328 .35291 L
.43329 .35289 L
.4333 .35287 L
.43332 .35285 L
.43333 .35283 L
.43334 .35281 L
.43336 .3528 L
.43337 .35278 L
.43338 .35276 L
.4334 .35274 L
.43341 .35272 L
.43342 .3527 L
.43344 .35268 L
.43345 .35267 L
.43346 .35265 L
.43348 .35263 L
.43349 .35261 L
.4335 .35259 L
.43352 .35257 L
Mistroke
.43353 .35255 L
.43354 .35254 L
.43356 .35252 L
.43357 .3525 L
.43358 .35248 L
.4336 .35246 L
.43361 .35244 L
.43363 .35243 L
.43364 .35241 L
.43365 .35239 L
.43367 .35237 L
.43368 .35235 L
.43369 .35233 L
.43371 .35232 L
.43372 .3523 L
.43373 .35228 L
.43375 .35226 L
.43376 .35224 L
.43378 .35222 L
.43379 .35221 L
.4338 .35219 L
.43382 .35217 L
.43383 .35215 L
.43384 .35213 L
.43386 .35212 L
.43387 .3521 L
.43388 .35208 L
.4339 .35206 L
.43391 .35204 L
.43393 .35203 L
.43394 .35201 L
.43395 .35199 L
.43397 .35197 L
.43398 .35195 L
.43399 .35194 L
.43401 .35192 L
.43402 .3519 L
.43404 .35188 L
.43405 .35186 L
.43406 .35185 L
.43408 .35183 L
.43409 .35181 L
.43411 .35179 L
.43412 .35177 L
.43413 .35176 L
.43415 .35174 L
.43416 .35172 L
.43417 .3517 L
.43419 .35169 L
.4342 .35167 L
Mistroke
.43422 .35165 L
.43423 .35163 L
.43424 .35161 L
.43426 .3516 L
.43427 .35158 L
.43429 .35156 L
.4343 .35154 L
.43431 .35153 L
.43433 .35151 L
.43434 .35149 L
.43436 .35147 L
.43437 .35146 L
.43438 .35144 L
.4344 .35142 L
.43441 .3514 L
.43443 .35139 L
.43444 .35137 L
.43445 .35135 L
.43447 .35133 L
.43448 .35132 L
.4345 .3513 L
.43451 .35128 L
.43452 .35126 L
.43454 .35125 L
.43455 .35123 L
.43457 .35121 L
.43458 .35119 L
.43459 .35118 L
.43461 .35116 L
.43462 .35114 L
.43464 .35112 L
.43465 .35111 L
.43466 .35109 L
.43468 .35107 L
.43469 .35105 L
.43471 .35104 L
.43472 .35102 L
.43473 .351 L
.43475 .35099 L
.43476 .35097 L
.43478 .35095 L
.43479 .35093 L
.43481 .35092 L
.43482 .3509 L
.43483 .35088 L
.43485 .35087 L
.43486 .35085 L
.43488 .35083 L
.43489 .35081 L
.4349 .3508 L
Mistroke
.43492 .35078 L
.43493 .35076 L
.43495 .35075 L
.43496 .35073 L
.43498 .35071 L
.43499 .3507 L
.435 .35068 L
.43502 .35066 L
.43503 .35065 L
.43505 .35063 L
.43506 .35061 L
.43508 .35059 L
.43509 .35058 L
.4351 .35056 L
.43512 .35054 L
.43513 .35053 L
.43515 .35051 L
.43516 .35049 L
.43518 .35048 L
.43519 .35046 L
.4352 .35044 L
.43522 .35043 L
.43523 .35041 L
.43525 .35039 L
.43526 .35038 L
.43528 .35036 L
.43529 .35034 L
.4353 .35033 L
.43532 .35031 L
.43533 .35029 L
.43535 .35028 L
.43536 .35026 L
.43538 .35024 L
.43539 .35023 L
.43541 .35021 L
.43542 .35019 L
.43543 .35018 L
.43545 .35016 L
.43546 .35015 L
.43548 .35013 L
.43549 .35011 L
.43551 .3501 L
.43552 .35008 L
.43554 .35006 L
.43555 .35005 L
.43556 .35003 L
.43558 .35001 L
.43559 .35 L
.43561 .34998 L
.43562 .34997 L
Mistroke
.43564 .34995 L
.43565 .34993 L
.43567 .34992 L
.43568 .3499 L
.43569 .34988 L
.43571 .34987 L
.43572 .34985 L
.43574 .34984 L
.43575 .34982 L
.43577 .3498 L
.43578 .34979 L
.4358 .34977 L
.43581 .34975 L
.43582 .34974 L
.43584 .34972 L
.43585 .34971 L
.43587 .34969 L
.43588 .34967 L
.4359 .34966 L
.43591 .34964 L
.43593 .34963 L
.43594 .34961 L
.43596 .34959 L
.43597 .34958 L
.43599 .34956 L
.436 .34955 L
.43601 .34953 L
.43603 .34952 L
.43604 .3495 L
.43606 .34948 L
.43607 .34947 L
.43609 .34945 L
.4361 .34944 L
.43612 .34942 L
.43613 .3494 L
.43615 .34939 L
.43616 .34937 L
.43618 .34936 L
.43619 .34934 L
.4362 .34933 L
.43622 .34931 L
.43623 .34929 L
.43625 .34928 L
.43626 .34926 L
.43628 .34925 L
.43629 .34923 L
.43631 .34922 L
.43632 .3492 L
.43634 .34919 L
.43635 .34917 L
Mistroke
.43637 .34915 L
.43638 .34914 L
.4364 .34912 L
.43641 .34911 L
.43642 .34909 L
.43644 .34908 L
.43645 .34906 L
.43647 .34905 L
.43648 .34903 L
.4365 .34902 L
.43651 .349 L
.43653 .34898 L
.43654 .34897 L
.43656 .34895 L
.43657 .34894 L
.43659 .34892 L
.4366 .34891 L
.43662 .34889 L
.43663 .34888 L
.43665 .34886 L
.43666 .34885 L
.43667 .34883 L
.43669 .34882 L
.4367 .3488 L
.43672 .34879 L
.43673 .34877 L
.43675 .34876 L
.43676 .34874 L
.43678 .34873 L
.43679 .34871 L
.43681 .3487 L
.43682 .34868 L
.43684 .34867 L
.43685 .34865 L
.43687 .34864 L
.43688 .34862 L
.4369 .34861 L
.43691 .34859 L
.43693 .34858 L
.43694 .34856 L
.43696 .34855 L
.43697 .34853 L
.43699 .34852 L
.437 .3485 L
.43702 .34849 L
.43703 .34847 L
.43704 .34846 L
.43706 .34844 L
.43707 .34843 L
.43709 .34841 L
Mistroke
.4371 .3484 L
.43712 .34838 L
.43713 .34837 L
.43715 .34835 L
.43716 .34834 L
.43718 .34832 L
.43719 .34831 L
.43721 .34829 L
.43722 .34828 L
.43724 .34827 L
.43725 .34825 L
.43727 .34824 L
.43728 .34822 L
.4373 .34821 L
.43731 .34819 L
.43733 .34818 L
.43734 .34816 L
.43736 .34815 L
.43737 .34813 L
.43739 .34812 L
.4374 .34811 L
.43742 .34809 L
.43743 .34808 L
.43745 .34806 L
.43746 .34805 L
.43748 .34803 L
.43749 .34802 L
.43751 .348 L
.43752 .34799 L
.43754 .34798 L
.43755 .34796 L
.43757 .34795 L
.43758 .34793 L
.4376 .34792 L
.43761 .3479 L
.43763 .34789 L
.43764 .34788 L
.43766 .34786 L
.43767 .34785 L
.43769 .34783 L
.4377 .34782 L
.43772 .3478 L
.43773 .34779 L
.43774 .34778 L
.43776 .34776 L
.43777 .34775 L
.43779 .34773 L
.4378 .34772 L
.43782 .34771 L
.43783 .34769 L
Mistroke
.43785 .34768 L
.43786 .34766 L
.43788 .34765 L
.43789 .34764 L
.43791 .34762 L
.43792 .34761 L
.43794 .34759 L
.43795 .34758 L
.43797 .34757 L
.43798 .34755 L
.438 .34754 L
.43801 .34753 L
.43803 .34751 L
.43804 .3475 L
.43806 .34748 L
.43807 .34747 L
.43809 .34746 L
.4381 .34744 L
.43812 .34743 L
.43813 .34741 L
.43815 .3474 L
.43816 .34739 L
.43818 .34737 L
.43819 .34736 L
.43821 .34735 L
.43822 .34733 L
.43824 .34732 L
.43825 .34731 L
.43827 .34729 L
.43828 .34728 L
.4383 .34726 L
.43831 .34725 L
.43833 .34724 L
.43834 .34722 L
.43836 .34721 L
.43837 .3472 L
.43839 .34718 L
.4384 .34717 L
.43842 .34716 L
.43843 .34714 L
.43845 .34713 L
.43846 .34712 L
.43848 .3471 L
.43849 .34709 L
.43851 .34708 L
.43852 .34706 L
.43854 .34705 L
.43855 .34704 L
.43857 .34702 L
.43858 .34701 L
Mistroke
.4386 .347 L
.43861 .34698 L
.43863 .34697 L
.43864 .34696 L
.43866 .34694 L
.43867 .34693 L
.43869 .34692 L
.4387 .3469 L
.43872 .34689 L
.43873 .34688 L
.43875 .34686 L
.43876 .34685 L
.43878 .34684 L
.43879 .34683 L
.43881 .34681 L
.43882 .3468 L
.43884 .34679 L
.43886 .34677 L
.43887 .34676 L
.43889 .34675 L
.4389 .34673 L
.43892 .34672 L
.43893 .34671 L
.43895 .3467 L
.43896 .34668 L
.43898 .34667 L
.43899 .34666 L
.43901 .34664 L
.43902 .34663 L
.43904 .34662 L
.43905 .34661 L
.43907 .34659 L
.43908 .34658 L
.4391 .34657 L
.43911 .34655 L
.43913 .34654 L
.43914 .34653 L
.43916 .34652 L
.43917 .3465 L
.43919 .34649 L
.4392 .34648 L
.43922 .34647 L
.43923 .34645 L
.43925 .34644 L
.43926 .34643 L
.43928 .34642 L
.43929 .3464 L
.43931 .34639 L
.43932 .34638 L
.43934 .34637 L
Mistroke
.43935 .34635 L
.43937 .34634 L
.43938 .34633 L
.4394 .34632 L
.43941 .3463 L
.43943 .34629 L
.43944 .34628 L
.43946 .34627 L
.43947 .34625 L
.43949 .34624 L
.4395 .34623 L
.43952 .34622 L
.43953 .3462 L
.43955 .34619 L
.43956 .34618 L
.43958 .34617 L
.43959 .34615 L
.43961 .34614 L
.43962 .34613 L
.43964 .34612 L
.43965 .34611 L
.43967 .34609 L
.43968 .34608 L
.4397 .34607 L
.43971 .34606 L
.43973 .34605 L
.43974 .34603 L
.43976 .34602 L
.43977 .34601 L
.43979 .346 L
.4398 .34598 L
.43982 .34597 L
.43983 .34596 L
.43985 .34595 L
.43986 .34594 L
.43988 .34592 L
.43989 .34591 L
.43991 .3459 L
.43992 .34589 L
.43994 .34588 L
.43995 .34587 L
.43997 .34585 L
.43998 .34584 L
.44 .34583 L
.44001 .34582 L
.44003 .34581 L
.44004 .34579 L
.44006 .34578 L
.44007 .34577 L
.44009 .34576 L
Mistroke
.4401 .34575 L
.44012 .34574 L
.44013 .34572 L
.44015 .34571 L
.44016 .3457 L
.44018 .34569 L
.44019 .34568 L
.44021 .34567 L
.44022 .34565 L
.44024 .34564 L
.44025 .34563 L
.44027 .34562 L
.44028 .34561 L
.4403 .3456 L
.44031 .34558 L
.44033 .34557 L
.44034 .34556 L
.44036 .34555 L
.44037 .34554 L
.44039 .34553 L
.4404 .34551 L
.44042 .3455 L
.44043 .34549 L
.44045 .34548 L
.44046 .34547 L
.44048 .34546 L
.44049 .34545 L
.44051 .34544 L
.44052 .34542 L
.44054 .34541 L
.44055 .3454 L
.44057 .34539 L
.44058 .34538 L
.4406 .34537 L
.44061 .34536 L
.44063 .34534 L
.44064 .34533 L
.44066 .34532 L
.44067 .34531 L
.44069 .3453 L
.4407 .34529 L
.44072 .34528 L
.44073 .34527 L
.44075 .34526 L
.44076 .34524 L
.44078 .34523 L
.44079 .34522 L
.44081 .34521 L
.44082 .3452 L
.44084 .34519 L
Mistroke
.44085 .34518 L
.44087 .34517 L
.44088 .34516 L
.4409 .34515 L
.44091 .34513 L
.44093 .34512 L
.44094 .34511 L
.44096 .3451 L
.44097 .34509 L
.44099 .34508 L
.441 .34507 L
.44102 .34506 L
.44103 .34505 L
.44105 .34504 L
.44106 .34503 L
.44108 .34501 L
.44109 .345 L
.44111 .34499 L
.44112 .34498 L
.44114 .34497 L
.44115 .34496 L
.44117 .34495 L
.44118 .34494 L
.4412 .34493 L
.44121 .34492 L
.44123 .34491 L
.44124 .3449 L
.44126 .34489 L
.44127 .34488 L
.44129 .34487 L
.4413 .34485 L
.44132 .34484 L
.44133 .34483 L
.44135 .34482 L
.44136 .34481 L
.44138 .3448 L
.44139 .34479 L
.44141 .34478 L
.44142 .34477 L
.44144 .34476 L
.44145 .34475 L
.44147 .34474 L
.44148 .34473 L
.4415 .34472 L
.44151 .34471 L
.44153 .3447 L
.44154 .34469 L
.44156 .34468 L
.44157 .34467 L
.44159 .34466 L
Mistroke
.4416 .34465 L
.44162 .34464 L
.44163 .34463 L
.44164 .34462 L
.44166 .34461 L
.44167 .3446 L
.44169 .34459 L
.4417 .34458 L
.44172 .34456 L
.44173 .34455 L
.44175 .34454 L
.44176 .34453 L
.44178 .34452 L
.44179 .34451 L
.44181 .3445 L
.44182 .34449 L
.44184 .34448 L
.44185 .34447 L
.44187 .34446 L
.44188 .34445 L
.4419 .34444 L
.44191 .34443 L
.44193 .34442 L
.44194 .34441 L
.44196 .3444 L
.44197 .34439 L
.44199 .34438 L
.442 .34437 L
.44202 .34436 L
.44203 .34436 L
.44205 .34435 L
.44206 .34434 L
.44207 .34433 L
.44209 .34432 L
.4421 .34431 L
.44212 .3443 L
.44213 .34429 L
.44215 .34428 L
.44216 .34427 L
.44218 .34426 L
.44219 .34425 L
.44221 .34424 L
.44222 .34423 L
.44224 .34422 L
.44225 .34421 L
.44227 .3442 L
.44228 .34419 L
.4423 .34418 L
.44231 .34417 L
.44233 .34416 L
Mistroke
.44234 .34415 L
.44236 .34414 L
.44237 .34413 L
.44238 .34412 L
.4424 .34411 L
.44241 .3441 L
.44243 .34409 L
.44244 .34409 L
.44246 .34408 L
.44247 .34407 L
.44249 .34406 L
.4425 .34405 L
.44252 .34404 L
.44253 .34403 L
.44255 .34402 L
.44256 .34401 L
.44258 .344 L
.44259 .34399 L
.44261 .34398 L
.44262 .34397 L
.44263 .34396 L
.44265 .34395 L
.44266 .34395 L
.44268 .34394 L
.44269 .34393 L
.44271 .34392 L
.44272 .34391 L
.44274 .3439 L
.44275 .34389 L
.44277 .34388 L
.44278 .34387 L
.4428 .34386 L
.44281 .34385 L
.44283 .34384 L
.44284 .34384 L
.44285 .34383 L
.44287 .34382 L
.44288 .34381 L
.4429 .3438 L
.44291 .34379 L
.44293 .34378 L
.44294 .34377 L
.44296 .34376 L
.44297 .34376 L
.44299 .34375 L
.443 .34374 L
.44302 .34373 L
.44303 .34372 L
.44304 .34371 L
.44306 .3437 L
Mistroke
.44307 .34369 L
.44309 .34368 L
.4431 .34368 L
.44312 .34367 L
.44313 .34366 L
.44315 .34365 L
.44316 .34364 L
.44318 .34363 L
.44319 .34362 L
.4432 .34361 L
.44322 .34361 L
.44323 .3436 L
.44325 .34359 L
.44326 .34358 L
.44328 .34357 L
.44329 .34356 L
.44331 .34355 L
.44332 .34355 L
.44334 .34354 L
.44335 .34353 L
.44336 .34352 L
.44338 .34351 L
.44339 .3435 L
.44341 .34349 L
.44342 .34349 L
.44344 .34348 L
.44345 .34347 L
.44347 .34346 L
.44348 .34345 L
.44349 .34344 L
.44351 .34343 L
.44352 .34343 L
.44354 .34342 L
.44355 .34341 L
.44357 .3434 L
.44358 .34339 L
.4436 .34338 L
.44361 .34338 L
.44362 .34337 L
.44364 .34336 L
.44365 .34335 L
.44367 .34334 L
.44368 .34334 L
.4437 .34333 L
.44371 .34332 L
.44373 .34331 L
.44374 .3433 L
.44375 .34329 L
.44377 .34329 L
.44378 .34328 L
Mistroke
.4438 .34327 L
.44381 .34326 L
.44383 .34325 L
.44384 .34325 L
.44385 .34324 L
.44387 .34323 L
.44388 .34322 L
.4439 .34321 L
.44391 .34321 L
.44393 .3432 L
.44394 .34319 L
.44396 .34318 L
.44397 .34317 L
.44398 .34317 L
.444 .34316 L
.44401 .34315 L
.44403 .34314 L
.44404 .34313 L
.44406 .34313 L
.44407 .34312 L
.44408 .34311 L
.4441 .3431 L
.44411 .34309 L
.44413 .34309 L
.44414 .34308 L
.44416 .34307 L
.44417 .34306 L
.44418 .34306 L
.4442 .34305 L
.44421 .34304 L
.44423 .34303 L
.44424 .34303 L
.44425 .34302 L
.44427 .34301 L
.44428 .343 L
.4443 .34299 L
.44431 .34299 L
.44433 .34298 L
.44434 .34297 L
.44435 .34296 L
.44437 .34296 L
.44438 .34295 L
.4444 .34294 L
.44441 .34293 L
.44443 .34293 L
.44444 .34292 L
.44445 .34291 L
.44447 .3429 L
.44448 .3429 L
.4445 .34289 L
Mistroke
.44451 .34288 L
.44452 .34287 L
.44454 .34287 L
.44455 .34286 L
.44457 .34285 L
.44458 .34285 L
.4446 .34284 L
.44461 .34283 L
.44462 .34282 L
.44464 .34282 L
.44465 .34281 L
.44467 .3428 L
.44468 .34279 L
.44469 .34279 L
.44471 .34278 L
.44472 .34277 L
.44474 .34277 L
.44475 .34276 L
.44476 .34275 L
.44478 .34274 L
.44479 .34274 L
.44481 .34273 L
.44482 .34272 L
.44483 .34272 L
.44485 .34271 L
.44486 .3427 L
.44488 .34269 L
.44489 .34269 L
.4449 .34268 L
.44492 .34267 L
.44493 .34267 L
.44495 .34266 L
.44496 .34265 L
.44497 .34264 L
.44499 .34264 L
.445 .34263 L
.44502 .34262 L
.44503 .34262 L
.44504 .34261 L
.44506 .3426 L
.44507 .3426 L
.44509 .34259 L
.4451 .34258 L
.44511 .34258 L
.44513 .34257 L
.44514 .34256 L
.44516 .34256 L
.44517 .34255 L
.44518 .34254 L
.4452 .34254 L
Mistroke
.44521 .34253 L
.44523 .34252 L
.44524 .34252 L
.44525 .34251 L
.44527 .3425 L
.44528 .3425 L
.44529 .34249 L
.44531 .34248 L
.44532 .34248 L
.44534 .34247 L
.44535 .34246 L
.44536 .34246 L
.44538 .34245 L
.44539 .34244 L
.44541 .34244 L
.44542 .34243 L
.44543 .34242 L
.44545 .34242 L
.44546 .34241 L
.44547 .3424 L
.44549 .3424 L
.4455 .34239 L
.44552 .34238 L
.44553 .34238 L
.44554 .34237 L
.44556 .34236 L
.44557 .34236 L
.44558 .34235 L
.4456 .34235 L
.44561 .34234 L
.44563 .34233 L
.44564 .34233 L
.44565 .34232 L
.44567 .34231 L
.44568 .34231 L
.44569 .3423 L
.44571 .34229 L
.44572 .34229 L
.44573 .34228 L
.44575 .34228 L
.44576 .34227 L
.44578 .34226 L
.44579 .34226 L
.4458 .34225 L
.44582 .34225 L
.44583 .34224 L
.44584 .34223 L
.44586 .34223 L
.44587 .34222 L
.44588 .34221 L
Mistroke
.4459 .34221 L
.44591 .3422 L
.44593 .3422 L
.44594 .34219 L
.44595 .34218 L
.44597 .34218 L
.44598 .34217 L
.44599 .34217 L
.44601 .34216 L
.44602 .34215 L
.44603 .34215 L
.44605 .34214 L
.44606 .34214 L
.44607 .34213 L
.44609 .34213 L
.4461 .34212 L
.44612 .34211 L
.44613 .34211 L
.44614 .3421 L
.44616 .3421 L
.44617 .34209 L
.44618 .34208 L
.4462 .34208 L
.44621 .34207 L
.44622 .34207 L
.44624 .34206 L
.44625 .34206 L
.44626 .34205 L
.44628 .34204 L
.44629 .34204 L
.4463 .34203 L
.44632 .34203 L
.44633 .34202 L
.44634 .34202 L
.44636 .34201 L
.44637 .342 L
.44638 .342 L
.4464 .34199 L
.44641 .34199 L
.44642 .34198 L
.44644 .34198 L
.44645 .34197 L
.44646 .34197 L
.44648 .34196 L
.44649 .34195 L
.4465 .34195 L
.44652 .34194 L
.44653 .34194 L
.44654 .34193 L
.44656 .34193 L
Mistroke
.44657 .34192 L
.44658 .34192 L
.4466 .34191 L
.44661 .34191 L
.44662 .3419 L
.44664 .34189 L
.44665 .34189 L
.44666 .34188 L
.44668 .34188 L
.44669 .34187 L
.4467 .34187 L
.44672 .34186 L
.44673 .34186 L
.44674 .34185 L
.44676 .34185 L
.44677 .34184 L
.44678 .34184 L
.4468 .34183 L
.44681 .34183 L
.44682 .34182 L
.44684 .34182 L
.44685 .34181 L
.44686 .34181 L
.44688 .3418 L
.44689 .3418 L
.4469 .34179 L
.44691 .34179 L
.44693 .34178 L
.44694 .34178 L
.44695 .34177 L
.44697 .34177 L
.44698 .34176 L
.44699 .34176 L
.44701 .34175 L
.44702 .34175 L
.44703 .34174 L
.44705 .34174 L
.44706 .34173 L
.44707 .34173 L
.44708 .34172 L
.4471 .34172 L
.44711 .34171 L
.44712 .34171 L
.44714 .3417 L
.44715 .3417 L
.44716 .34169 L
.44718 .34169 L
.44719 .34168 L
.4472 .34168 L
.44721 .34167 L
Mistroke
.44723 .34167 L
.44724 .34166 L
.44725 .34166 L
.44727 .34165 L
.44728 .34165 L
.44729 .34164 L
.44731 .34164 L
.44732 .34163 L
.44733 .34163 L
.44734 .34162 L
.44736 .34162 L
.44737 .34162 L
.44738 .34161 L
.4474 .34161 L
.44741 .3416 L
.44742 .3416 L
.44743 .34159 L
.44745 .34159 L
.44746 .34158 L
.44747 .34158 L
.44749 .34157 L
.4475 .34157 L
.44751 .34156 L
.44752 .34156 L
.44754 .34156 L
.44755 .34155 L
.44756 .34155 L
.44758 .34154 L
.44759 .34154 L
.4476 .34153 L
.44761 .34153 L
.44763 .34152 L
.44764 .34152 L
.44765 .34152 L
.44766 .34151 L
.44768 .34151 L
.44769 .3415 L
.4477 .3415 L
.44772 .34149 L
.44773 .34149 L
.44774 .34149 L
.44775 .34148 L
.44777 .34148 L
.44778 .34147 L
.44779 .34147 L
.4478 .34146 L
.44782 .34146 L
.44783 .34146 L
.44784 .34145 L
.44785 .34145 L
Mistroke
.44787 .34144 L
.44788 .34144 L
.44789 .34144 L
.44791 .34143 L
.44792 .34143 L
.44793 .34142 L
.44794 .34142 L
.44796 .34141 L
.44797 .34141 L
.44798 .34141 L
.44799 .3414 L
.44801 .3414 L
.44802 .34139 L
.44803 .34139 L
.44804 .34139 L
.44806 .34138 L
.44807 .34138 L
.44808 .34137 L
.44809 .34137 L
.44811 .34137 L
.44812 .34136 L
.44813 .34136 L
.44814 .34135 L
.44816 .34135 L
.44817 .34135 L
.44818 .34134 L
.44819 .34134 L
.44821 .34134 L
.44822 .34133 L
.44823 .34133 L
.44824 .34132 L
.44825 .34132 L
.44827 .34132 L
.44828 .34131 L
.44829 .34131 L
.4483 .34131 L
.44832 .3413 L
.44833 .3413 L
.44834 .34129 L
.44835 .34129 L
.44837 .34129 L
.44838 .34128 L
.44839 .34128 L
.4484 .34128 L
.44842 .34127 L
.44843 .34127 L
.44844 .34126 L
.44845 .34126 L
.44846 .34126 L
.44848 .34125 L
Mistroke
.44849 .34125 L
.4485 .34125 L
.44851 .34124 L
.44853 .34124 L
.44854 .34124 L
.44855 .34123 L
.44856 .34123 L
.44857 .34123 L
.44859 .34122 L
.4486 .34122 L
.44861 .34122 L
.44862 .34121 L
.44864 .34121 L
.44865 .34121 L
.44866 .3412 L
.44867 .3412 L
.44868 .3412 L
.4487 .34119 L
.44871 .34119 L
.44872 .34118 L
.44873 .34118 L
.44874 .34118 L
.44876 .34117 L
.44877 .34117 L
.44878 .34117 L
.44879 .34117 L
.4488 .34116 L
.44882 .34116 L
.44883 .34116 L
.44884 .34115 L
.44885 .34115 L
.44886 .34115 L
.44888 .34114 L
.44889 .34114 L
.4489 .34114 L
.44891 .34113 L
.44892 .34113 L
.44894 .34113 L
.44895 .34112 L
.44896 .34112 L
.44897 .34112 L
.44898 .34111 L
.449 .34111 L
.44901 .34111 L
.44902 .34111 L
.44903 .3411 L
.44904 .3411 L
.44906 .3411 L
.44907 .34109 L
.44908 .34109 L
Mistroke
.44909 .34109 L
.4491 .34108 L
.44912 .34108 L
.44913 .34108 L
.44914 .34108 L
.44915 .34107 L
.44916 .34107 L
.44917 .34107 L
.44919 .34106 L
.4492 .34106 L
.44921 .34106 L
.44922 .34105 L
.44923 .34105 L
.44925 .34105 L
.44926 .34105 L
.44927 .34104 L
.44928 .34104 L
.44929 .34104 L
.4493 .34104 L
.44932 .34103 L
.44933 .34103 L
.44934 .34103 L
.44935 .34102 L
.44936 .34102 L
.44937 .34102 L
.44939 .34102 L
.4494 .34101 L
.44941 .34101 L
.44942 .34101 L
.44943 .34101 L
.44944 .341 L
.44946 .341 L
.44947 .341 L
.44948 .34099 L
.44949 .34099 L
.4495 .34099 L
.44951 .34099 L
.44953 .34098 L
.44954 .34098 L
.44955 .34098 L
.44956 .34098 L
.44957 .34097 L
.44958 .34097 L
.44959 .34097 L
.44961 .34097 L
.44962 .34096 L
.44963 .34096 L
.44964 .34096 L
.44965 .34096 L
.44966 .34095 L
Mistroke
.44967 .34095 L
.44969 .34095 L
.4497 .34095 L
.44971 .34094 L
.44972 .34094 L
.44973 .34094 L
.44974 .34094 L
.44975 .34094 L
.44977 .34093 L
.44978 .34093 L
.44979 .34093 L
.4498 .34093 L
.44981 .34092 L
.44982 .34092 L
.44983 .34092 L
.44985 .34092 L
.44986 .34091 L
.44987 .34091 L
.44988 .34091 L
.44989 .34091 L
.4499 .34091 L
.44991 .3409 L
.44993 .3409 L
.44994 .3409 L
.44995 .3409 L
.44996 .34089 L
.44997 .34089 L
.44998 .34089 L
.44999 .34089 L
.45 .34089 L
.45002 .34088 L
.45003 .34088 L
.45004 .34088 L
.45005 .34088 L
.45006 .34088 L
.45007 .34087 L
.45008 .34087 L
.45009 .34087 L
.4501 .34087 L
.45012 .34087 L
.45013 .34086 L
.45014 .34086 L
.45015 .34086 L
.45016 .34086 L
.45017 .34086 L
.45018 .34085 L
.45019 .34085 L
.4502 .34085 L
.45022 .34085 L
.45023 .34085 L
Mistroke
.45024 .34084 L
.45025 .34084 L
.45026 .34084 L
.45027 .34084 L
.45028 .34084 L
.45029 .34083 L
.4503 .34083 L
.45031 .34083 L
.45033 .34083 L
.45034 .34083 L
.45035 .34083 L
.45036 .34082 L
.45037 .34082 L
.45038 .34082 L
.45039 .34082 L
.4504 .34082 L
.45041 .34082 L
.45042 .34081 L
.45044 .34081 L
.45045 .34081 L
.45046 .34081 L
.45047 .34081 L
.45048 .34081 L
.45049 .3408 L
.4505 .3408 L
.45051 .3408 L
.45052 .3408 L
.45053 .3408 L
.45054 .3408 L
.45055 .34079 L
.45057 .34079 L
.45058 .34079 L
.45059 .34079 L
.4506 .34079 L
.45061 .34079 L
.45062 .34078 L
.45063 .34078 L
.45064 .34078 L
.45065 .34078 L
.45066 .34078 L
.45067 .34078 L
.45068 .34078 L
.45069 .34077 L
.4507 .34077 L
.45072 .34077 L
.45073 .34077 L
.45074 .34077 L
.45075 .34077 L
.45076 .34077 L
.45077 .34076 L
Mistroke
.45078 .34076 L
.45079 .34076 L
.4508 .34076 L
.45081 .34076 L
.45082 .34076 L
.45083 .34076 L
.45084 .34075 L
.45085 .34075 L
.45086 .34075 L
.45087 .34075 L
.45089 .34075 L
.4509 .34075 L
.45091 .34075 L
.45092 .34075 L
.45093 .34074 L
.45094 .34074 L
.45095 .34074 L
.45096 .34074 L
.45097 .34074 L
.45098 .34074 L
.45099 .34074 L
.451 .34074 L
.45101 .34074 L
.45102 .34073 L
.45103 .34073 L
.45104 .34073 L
.45105 .34073 L
.45106 .34073 L
.45107 .34073 L
.45108 .34073 L
.45109 .34073 L
.4511 .34073 L
.45112 .34072 L
.45113 .34072 L
.45114 .34072 L
.45115 .34072 L
.45116 .34072 L
.45117 .34072 L
.45118 .34072 L
.45119 .34072 L
.4512 .34072 L
.45121 .34072 L
.45122 .34071 L
.45123 .34071 L
.45124 .34071 L
.45125 .34071 L
.45126 .34071 L
.45127 .34071 L
.45128 .34071 L
.45129 .34071 L
Mistroke
.4513 .34071 L
.45131 .34071 L
.45132 .34071 L
.45133 .3407 L
.45134 .3407 L
.45135 .3407 L
.45136 .3407 L
.45137 .3407 L
.45138 .3407 L
.45139 .3407 L
.4514 .3407 L
.45141 .3407 L
.45142 .3407 L
.45143 .3407 L
.45144 .3407 L
.45145 .3407 L
.45146 .34069 L
.45147 .34069 L
.45148 .34069 L
.45149 .34069 L
.4515 .34069 L
.45151 .34069 L
.45152 .34069 L
.45153 .34069 L
.45154 .34069 L
.45155 .34069 L
.45156 .34069 L
.45157 .34069 L
.45158 .34069 L
.45159 .34069 L
.4516 .34069 L
.45161 .34068 L
.45162 .34068 L
.45163 .34068 L
.45164 .34068 L
.45165 .34068 L
.45166 .34068 L
.45167 .34068 L
.45168 .34068 L
.45169 .34068 L
.4517 .34068 L
.45171 .34068 L
.45172 .34068 L
.45173 .34068 L
.45174 .34068 L
.45175 .34068 L
.45176 .34068 L
.45177 .34068 L
.45178 .34068 L
.45179 .34068 L
Mistroke
.4518 .34068 L
.45181 .34068 L
.45182 .34068 L
.45183 .34067 L
.45184 .34067 L
.45185 .34067 L
.45186 .34067 L
.45187 .34067 L
.45188 .34067 L
.45189 .34067 L
.4519 .34067 L
.4519 .34067 L
.45191 .34067 L
.45192 .34067 L
.45193 .34067 L
.45194 .34067 L
.45195 .34067 L
.45196 .34067 L
.45197 .34067 L
.45198 .34067 L
.45199 .34067 L
.452 .34067 L
.45201 .34067 L
.45202 .34067 L
.45203 .34067 L
.45204 .34067 L
.45205 .34067 L
.45206 .34067 L
.45207 .34067 L
.45208 .34067 L
.45209 .34067 L
.4521 .34067 L
.45211 .34067 L
.45211 .34067 L
.45212 .34067 L
.45213 .34067 L
.45214 .34067 L
.45215 .34067 L
.45216 .34067 L
.45217 .34067 L
.45218 .34067 L
.45219 .34067 L
.4522 .34067 L
.45221 .34067 L
.45222 .34067 L
.45223 .34067 L
.45224 .34067 L
.45225 .34067 L
.45226 .34067 L
.45226 .34067 L
Mistroke
.45227 .34067 L
.45228 .34067 L
.45229 .34067 L
.4523 .34067 L
.45231 .34067 L
.45232 .34067 L
.45233 .34067 L
.45234 .34067 L
.45235 .34067 L
.45236 .34067 L
.45237 .34067 L
.45238 .34067 L
.45239 .34067 L
.45239 .34067 L
.4524 .34067 L
.45241 .34067 L
.45242 .34067 L
.45243 .34067 L
.45244 .34067 L
.45245 .34067 L
.45246 .34067 L
.45247 .34067 L
.45248 .34067 L
.45249 .34067 L
.45249 .34067 L
.4525 .34067 L
.45251 .34067 L
.45252 .34067 L
.45253 .34067 L
.45254 .34067 L
.45255 .34067 L
.45256 .34067 L
.45257 .34067 L
.45258 .34067 L
.45258 .34068 L
.45259 .34068 L
.4526 .34068 L
.45261 .34068 L
.45262 .34068 L
.45263 .34068 L
.45264 .34068 L
.45265 .34068 L
.45266 .34068 L
.45267 .34068 L
.45267 .34068 L
.45268 .34068 L
.45269 .34068 L
.4527 .34068 L
.45271 .34068 L
.45272 .34068 L
Mistroke
.45273 .34068 L
.45274 .34068 L
.45275 .34068 L
.45275 .34068 L
.45276 .34068 L
.45277 .34068 L
.45278 .34069 L
.45279 .34069 L
.4528 .34069 L
.45281 .34069 L
.45282 .34069 L
.45282 .34069 L
.45283 .34069 L
.45284 .34069 L
.45285 .34069 L
.45286 .34069 L
.45287 .34069 L
.45288 .34069 L
.45289 .34069 L
.45289 .34069 L
.4529 .34069 L
.45291 .34069 L
.45292 .3407 L
.45293 .3407 L
.45294 .3407 L
.45295 .3407 L
.45295 .3407 L
.45296 .3407 L
.45297 .3407 L
.45298 .3407 L
.45299 .3407 L
.453 .3407 L
.45301 .3407 L
.45301 .3407 L
.45302 .3407 L
.45303 .3407 L
.45304 .34071 L
.45305 .34071 L
.45306 .34071 L
.45307 .34071 L
.45307 .34071 L
.45308 .34071 L
.45309 .34071 L
.4531 .34071 L
.45311 .34071 L
.45312 .34071 L
.45312 .34071 L
.45313 .34071 L
.45314 .34072 L
.45315 .34072 L
Mistroke
.45316 .34072 L
.45317 .34072 L
.45317 .34072 L
.45318 .34072 L
.45319 .34072 L
.4532 .34072 L
.45321 .34072 L
.45322 .34072 L
.45322 .34072 L
.45323 .34073 L
.45324 .34073 L
.45325 .34073 L
.45326 .34073 L
.45327 .34073 L
.45327 .34073 L
.45328 .34073 L
.45329 .34073 L
.4533 .34073 L
.45331 .34074 L
.45332 .34074 L
.45332 .34074 L
.45333 .34074 L
.45334 .34074 L
.45335 .34074 L
.45336 .34074 L
.45336 .34074 L
.45337 .34074 L
.45338 .34074 L
.45339 .34075 L
.4534 .34075 L
.45341 .34075 L
.45341 .34075 L
.45342 .34075 L
.45343 .34075 L
.45344 .34075 L
.45345 .34075 L
.45345 .34076 L
.45346 .34076 L
.45347 .34076 L
.45348 .34076 L
.45349 .34076 L
.45349 .34076 L
.4535 .34076 L
.45351 .34076 L
.45352 .34077 L
.45353 .34077 L
.45353 .34077 L
.45354 .34077 L
.45355 .34077 L
.45356 .34077 L
Mistroke
.45357 .34077 L
.45357 .34077 L
.45358 .34078 L
.45359 .34078 L
.4536 .34078 L
.45361 .34078 L
.45361 .34078 L
.45362 .34078 L
.45363 .34078 L
.45364 .34078 L
.45364 .34079 L
.45365 .34079 L
.45366 .34079 L
.45367 .34079 L
.45368 .34079 L
.45368 .34079 L
.45369 .34079 L
.4537 .3408 L
.45371 .3408 L
.45371 .3408 L
.45372 .3408 L
.45373 .3408 L
.45374 .3408 L
.45375 .3408 L
.45375 .34081 L
.45376 .34081 L
.45377 .34081 L
.45378 .34081 L
.45378 .34081 L
.45379 .34081 L
.4538 .34082 L
.45381 .34082 L
.45381 .34082 L
.45382 .34082 L
.45383 .34082 L
.45384 .34082 L
.45384 .34082 L
.45385 .34083 L
.45386 .34083 L
.45387 .34083 L
.45388 .34083 L
.45388 .34083 L
.45389 .34083 L
.4539 .34084 L
.45391 .34084 L
.45391 .34084 L
.45392 .34084 L
.45393 .34084 L
.45394 .34084 L
.45394 .34085 L
Mistroke
.45395 .34085 L
.45396 .34085 L
.45396 .34085 L
.45397 .34085 L
.45398 .34085 L
.45399 .34086 L
.45399 .34086 L
.454 .34086 L
.45401 .34086 L
.45402 .34086 L
.45402 .34086 L
.45403 .34087 L
.45404 .34087 L
.45405 .34087 L
.45405 .34087 L
.45406 .34087 L
.45407 .34088 L
.45408 .34088 L
.45408 .34088 L
.45409 .34088 L
.4541 .34088 L
.4541 .34088 L
.45411 .34089 L
.45412 .34089 L
.45413 .34089 L
.45413 .34089 L
.45414 .34089 L
.45415 .3409 L
.45416 .3409 L
.45416 .3409 L
.45417 .3409 L
.45418 .3409 L
.45418 .3409 L
.45419 .34091 L
.4542 .34091 L
.45421 .34091 L
.45421 .34091 L
.45422 .34091 L
.45423 .34092 L
.45423 .34092 L
.45424 .34092 L
.45425 .34092 L
.45426 .34092 L
.45426 .34093 L
.45427 .34093 L
.45428 .34093 L
.45428 .34093 L
.45429 .34093 L
.4543 .34094 L
.4543 .34094 L
Mistroke
.45431 .34094 L
.45432 .34094 L
.45433 .34094 L
.45433 .34095 L
.45434 .34095 L
.45435 .34095 L
.45435 .34095 L
.45436 .34095 L
.45437 .34096 L
.45437 .34096 L
.45438 .34096 L
.45439 .34096 L
.45439 .34096 L
.4544 .34097 L
.45441 .34097 L
.45442 .34097 L
.45442 .34097 L
.45443 .34097 L
.45444 .34098 L
.45444 .34098 L
.45445 .34098 L
.45446 .34098 L
.45446 .34099 L
.45447 .34099 L
.45448 .34099 L
.45448 .34099 L
.45449 .34099 L
.4545 .341 L
.4545 .341 L
.45451 .341 L
.45452 .341 L
.45452 .34101 L
.45453 .34101 L
.45454 .34101 L
.45454 .34101 L
.45455 .34101 L
.45456 .34102 L
.45456 .34102 L
.45457 .34102 L
.45458 .34102 L
.45458 .34103 L
.45459 .34103 L
.4546 .34103 L
.4546 .34103 L
.45461 .34103 L
.45462 .34104 L
.45462 .34104 L
.45463 .34104 L
.45464 .34104 L
.45464 .34105 L
Mistroke
.45465 .34105 L
.45466 .34105 L
.45466 .34105 L
.45467 .34106 L
.45468 .34106 L
.45468 .34106 L
.45469 .34106 L
.4547 .34107 L
.4547 .34107 L
.45471 .34107 L
.45471 .34107 L
.45472 .34107 L
.45473 .34108 L
.45473 .34108 L
.45474 .34108 L
.45475 .34108 L
.45475 .34109 L
.45476 .34109 L
.45477 .34109 L
.45477 .34109 L
.45478 .3411 L
.45478 .3411 L
.45479 .3411 L
.4548 .3411 L
.4548 .34111 L
.45481 .34111 L
.45482 .34111 L
.45482 .34111 L
.45483 .34112 L
.45484 .34112 L
.45484 .34112 L
.45485 .34112 L
.45485 .34113 L
.45486 .34113 L
.45487 .34113 L
.45487 .34113 L
.45488 .34114 L
.45489 .34114 L
.45489 .34114 L
.4549 .34114 L
.4549 .34115 L
.45491 .34115 L
.45492 .34115 L
.45492 .34116 L
.45493 .34116 L
.45493 .34116 L
.45494 .34116 L
.45495 .34117 L
.45495 .34117 L
.45496 .34117 L
Mistroke
.45496 .34117 L
.45497 .34118 L
.45498 .34118 L
.45498 .34118 L
.45499 .34118 L
.455 .34119 L
.455 .34119 L
.45501 .34119 L
.45501 .34119 L
.45502 .3412 L
.45503 .3412 L
.45503 .3412 L
.45504 .34121 L
.45504 .34121 L
.45505 .34121 L
.45505 .34121 L
.45506 .34122 L
.45507 .34122 L
.45507 .34122 L
.45508 .34122 L
.45508 .34123 L
.45509 .34123 L
.4551 .34123 L
.4551 .34124 L
.45511 .34124 L
.45511 .34124 L
.45512 .34124 L
.45513 .34125 L
.45513 .34125 L
.45514 .34125 L
.45514 .34126 L
.45515 .34126 L
.45515 .34126 L
.45516 .34126 L
.45517 .34127 L
.45517 .34127 L
.45518 .34127 L
.45518 .34128 L
.45519 .34128 L
.45519 .34128 L
.4552 .34128 L
.45521 .34129 L
.45521 .34129 L
.45522 .34129 L
.45522 .3413 L
.45523 .3413 L
.45523 .3413 L
.45524 .3413 L
.45525 .34131 L
.45525 .34131 L
Mistroke
.45526 .34131 L
.45526 .34132 L
.45527 .34132 L
.45527 .34132 L
.45528 .34132 L
.45529 .34133 L
.45529 .34133 L
.4553 .34133 L
.4553 .34134 L
.45531 .34134 L
.45531 .34134 L
.45532 .34135 L
.45532 .34135 L
.45533 .34135 L
.45534 .34135 L
.45534 .34136 L
.45535 .34136 L
.45535 .34136 L
.45536 .34137 L
.45536 .34137 L
.45537 .34137 L
.45537 .34138 L
.45538 .34138 L
.45538 .34138 L
.45539 .34138 L
.4554 .34139 L
.4554 .34139 L
.45541 .34139 L
.45541 .3414 L
.45542 .3414 L
.45542 .3414 L
.45543 .34141 L
.45543 .34141 L
.45544 .34141 L
.45544 .34142 L
.45545 .34142 L
.45545 .34142 L
.45546 .34143 L
.45546 .34143 L
.45547 .34143 L
.45548 .34143 L
.45548 .34144 L
.45549 .34144 L
.45549 .34144 L
.4555 .34145 L
.4555 .34145 L
.45551 .34145 L
.45551 .34146 L
.45552 .34146 L
.45552 .34146 L
Mistroke
.45553 .34147 L
.45553 .34147 L
.45554 .34147 L
.45554 .34148 L
.45555 .34148 L
.45555 .34148 L
.45556 .34149 L
.45556 .34149 L
.45557 .34149 L
.45557 .34149 L
.45558 .3415 L
.45558 .3415 L
.45559 .3415 L
.45559 .34151 L
.4556 .34151 L
.4556 .34151 L
.45561 .34152 L
.45561 .34152 L
.45562 .34152 L
.45562 .34153 L
.45563 .34153 L
.45563 .34153 L
.45564 .34154 L
.45564 .34154 L
.45565 .34154 L
.45565 .34155 L
.45566 .34155 L
.45566 .34155 L
.45567 .34156 L
.45567 .34156 L
.45568 .34156 L
.45568 .34157 L
.45569 .34157 L
.45569 .34157 L
.4557 .34158 L
.4557 .34158 L
.45571 .34158 L
.45571 .34159 L
.45572 .34159 L
.45572 .34159 L
.45573 .3416 L
.45573 .3416 L
.45574 .3416 L
.45574 .34161 L
.45575 .34161 L
.45575 .34161 L
.45576 .34162 L
.45576 .34162 L
.45577 .34162 L
.45577 .34163 L
Mistroke
.45577 .34163 L
.45578 .34163 L
.45578 .34164 L
.45579 .34164 L
.45579 .34165 L
.4558 .34165 L
.4558 .34165 L
.45581 .34166 L
.45581 .34166 L
.45582 .34166 L
.45582 .34167 L
.45583 .34167 L
.45583 .34167 L
.45584 .34168 L
.45584 .34168 L
.45584 .34168 L
.45585 .34169 L
.45585 .34169 L
.45586 .34169 L
.45586 .3417 L
.45587 .3417 L
.45587 .3417 L
.45588 .34171 L
.45588 .34171 L
.45589 .34172 L
.45589 .34172 L
.45589 .34172 L
.4559 .34173 L
.4559 .34173 L
.45591 .34173 L
.45591 .34174 L
.45592 .34174 L
.45592 .34174 L
.45593 .34175 L
.45593 .34175 L
.45594 .34175 L
.45594 .34176 L
.45594 .34176 L
.45595 .34177 L
.45595 .34177 L
.45596 .34177 L
.45596 .34178 L
.45597 .34178 L
.45597 .34178 L
.45597 .34179 L
.45598 .34179 L
.45598 .34179 L
.45599 .3418 L
.45599 .3418 L
.456 .3418 L
Mistroke
.456 .34181 L
.456 .34181 L
.45601 .34182 L
.45601 .34182 L
.45602 .34182 L
.45602 .34183 L
.45603 .34183 L
.45603 .34183 L
.45603 .34184 L
.45604 .34184 L
.45604 .34185 L
.45605 .34185 L
.45605 .34185 L
.45606 .34186 L
.45606 .34186 L
.45606 .34186 L
.45607 .34187 L
.45607 .34187 L
.45608 .34187 L
.45608 .34188 L
.45608 .34188 L
.45609 .34189 L
.45609 .34189 L
.4561 .34189 L
.4561 .3419 L
.45611 .3419 L
.45611 .3419 L
.45611 .34191 L
.45612 .34191 L
.45612 .34192 L
.45613 .34192 L
.45613 .34192 L
.45613 .34193 L
.45614 .34193 L
.45614 .34193 L
.45615 .34194 L
.45615 .34194 L
.45615 .34195 L
.45616 .34195 L
.45616 .34195 L
.45617 .34196 L
.45617 .34196 L
.45617 .34197 L
.45618 .34197 L
.45618 .34197 L
.45619 .34198 L
.45619 .34198 L
.45619 .34198 L
.4562 .34199 L
.4562 .34199 L
Mistroke
.4562 .342 L
.45621 .342 L
.45621 .342 L
.45622 .34201 L
.45622 .34201 L
.45622 .34202 L
.45623 .34202 L
.45623 .34202 L
.45624 .34203 L
.45624 .34203 L
.45624 .34203 L
.45625 .34204 L
.45625 .34204 L
.45625 .34205 L
.45626 .34205 L
.45626 .34205 L
.45627 .34206 L
.45627 .34206 L
.45627 .34207 L
.45628 .34207 L
.45628 .34207 L
.45628 .34208 L
.45629 .34208 L
.45629 .34209 L
.4563 .34209 L
.4563 .34209 L
.4563 .3421 L
.45631 .3421 L
.45631 .3421 L
.45631 .34211 L
.45632 .34211 L
.45632 .34212 L
.45632 .34212 L
.45633 .34212 L
.45633 .34213 L
.45633 .34213 L
.45634 .34214 L
.45634 .34214 L
.45635 .34214 L
.45635 .34215 L
.45635 .34215 L
.45636 .34216 L
.45636 .34216 L
.45636 .34216 L
.45637 .34217 L
.45637 .34217 L
.45637 .34218 L
.45638 .34218 L
.45638 .34218 L
.45638 .34219 L
Mistroke
.45639 .34219 L
.45639 .3422 L
.45639 .3422 L
.4564 .3422 L
.4564 .34221 L
.4564 .34221 L
.45641 .34222 L
.45641 .34222 L
.45641 .34222 L
.45642 .34223 L
.45642 .34223 L
.45643 .34224 L
.45643 .34224 L
.45643 .34225 L
.45644 .34225 L
.45644 .34225 L
.45644 .34226 L
.45645 .34226 L
.45645 .34227 L
.45645 .34227 L
.45645 .34227 L
.45646 .34228 L
.45646 .34228 L
.45646 .34229 L
.45647 .34229 L
.45647 .34229 L
.45647 .3423 L
.45648 .3423 L
.45648 .34231 L
.45648 .34231 L
.45649 .34231 L
.45649 .34232 L
.45649 .34232 L
.4565 .34233 L
.4565 .34233 L
.4565 .34234 L
.45651 .34234 L
.45651 .34234 L
.45651 .34235 L
.45652 .34235 L
.45652 .34236 L
.45652 .34236 L
.45653 .34236 L
.45653 .34237 L
.45653 .34237 L
.45653 .34238 L
.45654 .34238 L
.45654 .34239 L
.45654 .34239 L
.45655 .34239 L
Mistroke
.45655 .3424 L
.45655 .3424 L
.45656 .34241 L
.45656 .34241 L
.45656 .34241 L
.45656 .34242 L
.45657 .34242 L
.45657 .34243 L
.45657 .34243 L
.45658 .34244 L
.45658 .34244 L
.45658 .34244 L
.45659 .34245 L
.45659 .34245 L
.45659 .34246 L
.45659 .34246 L
.4566 .34246 L
.4566 .34247 L
.4566 .34247 L
.45661 .34248 L
.45661 .34248 L
.45661 .34249 L
.45661 .34249 L
.45662 .34249 L
.45662 .3425 L
.45662 .3425 L
.45663 .34251 L
.45663 .34251 L
.45663 .34252 L
.45663 .34252 L
.45664 .34252 L
.45664 .34253 L
.45664 .34253 L
.45665 .34254 L
.45665 .34254 L
.45665 .34255 L
.45665 .34255 L
.45666 .34255 L
.45666 .34256 L
.45666 .34256 L
.45666 .34257 L
.45667 .34257 L
.45667 .34258 L
.45667 .34258 L
.45668 .34258 L
.45668 .34259 L
.45668 .34259 L
.45668 .3426 L
.45669 .3426 L
.45669 .34261 L
Mistroke
.45669 .34261 L
.45669 .34261 L
.4567 .34262 L
.4567 .34262 L
.4567 .34263 L
.4567 .34263 L
.45671 .34264 L
.45671 .34264 L
.45671 .34264 L
.45672 .34265 L
.45672 .34265 L
.45672 .34266 L
.45672 .34266 L
.45673 .34267 L
.45673 .34267 L
.45673 .34268 L
.45673 .34268 L
.45674 .34268 L
.45674 .34269 L
.45674 .34269 L
.45674 .3427 L
.45675 .3427 L
.45675 .34271 L
.45675 .34271 L
.45675 .34271 L
.45676 .34272 L
.45676 .34272 L
.45676 .34273 L
.45676 .34273 L
.45677 .34274 L
.45677 .34274 L
.45677 .34275 L
.45677 .34275 L
.45677 .34275 L
.45678 .34276 L
.45678 .34276 L
.45678 .34277 L
.45678 .34277 L
.45679 .34278 L
.45679 .34278 L
.45679 .34279 L
.45679 .34279 L
.4568 .34279 L
.4568 .3428 L
.4568 .3428 L
.4568 .34281 L
.45681 .34281 L
.45681 .34282 L
.45681 .34282 L
.45681 .34282 L
Mistroke
.45681 .34283 L
.45682 .34283 L
.45682 .34284 L
.45682 .34284 L
.45682 .34285 L
.45683 .34285 L
.45683 .34286 L
.45683 .34286 L
.45683 .34287 L
.45683 .34287 L
.45684 .34287 L
.45684 .34288 L
.45684 .34288 L
.45684 .34289 L
.45684 .34289 L
.45685 .3429 L
.45685 .3429 L
.45685 .34291 L
.45685 .34291 L
.45686 .34291 L
.45686 .34292 L
.45686 .34292 L
.45686 .34293 L
.45686 .34293 L
.45687 .34294 L
.45687 .34294 L
.45687 .34295 L
.45687 .34295 L
.45687 .34295 L
.45688 .34296 L
.45688 .34296 L
.45688 .34297 L
.45688 .34297 L
.45688 .34298 L
.45689 .34298 L
.45689 .34299 L
.45689 .34299 L
.45689 .343 L
.45689 .343 L
.4569 .343 L
.4569 .34301 L
.4569 .34301 L
.4569 .34302 L
.4569 .34302 L
.45691 .34303 L
.45691 .34303 L
.45691 .34304 L
.45691 .34304 L
.45691 .34304 L
.45692 .34305 L
Mistroke
.45692 .34305 L
.45692 .34306 L
.45692 .34306 L
.45692 .34307 L
.45692 .34307 L
.45693 .34308 L
.45693 .34308 L
.45693 .34309 L
.45693 .34309 L
.45693 .3431 L
.45694 .3431 L
.45694 .3431 L
.45694 .34311 L
.45694 .34311 L
.45694 .34312 L
.45694 .34312 L
.45695 .34313 L
.45695 .34313 L
.45695 .34314 L
.45695 .34314 L
.45695 .34315 L
.45696 .34315 L
.45696 .34315 L
.45696 .34316 L
.45696 .34316 L
.45696 .34317 L
.45696 .34317 L
.45697 .34318 L
.45697 .34318 L
.45697 .34319 L
.45697 .34319 L
.45697 .3432 L
.45697 .3432 L
.45698 .3432 L
.45698 .34321 L
.45698 .34321 L
.45698 .34322 L
.45698 .34322 L
.45698 .34323 L
.45698 .34323 L
.45699 .34324 L
.45699 .34324 L
.45699 .34325 L
.45699 .34325 L
.45699 .34326 L
.45699 .34326 L
.457 .34326 L
.457 .34327 L
.457 .34327 L
.457 .34328 L
Mistroke
.457 .34328 L
.457 .34329 L
.457 .34329 L
.45701 .3433 L
.45701 .3433 L
.45701 .34331 L
.45701 .34331 L
.45701 .34332 L
.45701 .34332 L
.45702 .34333 L
.45702 .34333 L
.45702 .34333 L
.45702 .34334 L
.45702 .34334 L
.45702 .34335 L
.45702 .34335 L
.45703 .34336 L
.45703 .34336 L
.45703 .34337 L
.45703 .34337 L
.45703 .34338 L
.45703 .34338 L
.45703 .34339 L
.45703 .34339 L
.45704 .34339 L
.45704 .3434 L
.45704 .3434 L
.45704 .34341 L
.45704 .34341 L
.45704 .34342 L
.45704 .34342 L
.45705 .34343 L
.45705 .34343 L
.45705 .34344 L
.45705 .34344 L
.45705 .34345 L
.45705 .34345 L
.45705 .34346 L
.45705 .34346 L
.45706 .34346 L
.45706 .34347 L
.45706 .34347 L
.45706 .34348 L
.45706 .34348 L
.45706 .34349 L
.45706 .34349 L
.45706 .3435 L
.45707 .3435 L
.45707 .34351 L
.45707 .34351 L
Mistroke
.45707 .34352 L
.45707 .34352 L
.45707 .34353 L
.45707 .34353 L
.45707 .34354 L
.45707 .34354 L
.45708 .34354 L
.45708 .34355 L
.45708 .34355 L
.45708 .34356 L
.45708 .34356 L
.45708 .34357 L
.45708 .34357 L
.45708 .34358 L
.45708 .34358 L
.45709 .34359 L
.45709 .34359 L
.45709 .3436 L
.45709 .3436 L
.45709 .34361 L
.45709 .34361 L
.45709 .34362 L
.45709 .34362 L
.45709 .34362 L
.45709 .34363 L
.4571 .34363 L
.4571 .34364 L
.4571 .34364 L
.4571 .34365 L
.4571 .34365 L
.4571 .34366 L
.4571 .34366 L
.4571 .34367 L
.4571 .34367 L
.4571 .34368 L
.45711 .34368 L
.45711 .34369 L
.45711 .34369 L
.45711 .3437 L
.45711 .3437 L
.45711 .34371 L
.45711 .34371 L
.45711 .34371 L
.45711 .34372 L
.45711 .34372 L
.45711 .34373 L
.45711 .34373 L
.45712 .34374 L
.45712 .34374 L
.45712 .34375 L
Mistroke
.45712 .34375 L
.45712 .34376 L
.45712 .34376 L
.45712 .34377 L
.45712 .34377 L
.45712 .34378 L
.45712 .34378 L
.45712 .34379 L
.45712 .34379 L
.45713 .3438 L
.45713 .3438 L
.45713 .3438 L
.45713 .34381 L
.45713 .34381 L
.45713 .34382 L
.45713 .34382 L
.45713 .34383 L
.45713 .34383 L
.45713 .34384 L
.45713 .34384 L
.45713 .34385 L
.45713 .34385 L
.45713 .34386 L
.45714 .34386 L
.45714 .34387 L
.45714 .34387 L
.45714 .34388 L
.45714 .34388 L
.45714 .34389 L
.45714 .34389 L
.45714 .3439 L
.45714 .3439 L
.45714 .3439 L
.45714 .34391 L
.45714 .34391 L
.45714 .34392 L
.45714 .34392 L
.45714 .34393 L
.45714 .34393 L
.45715 .34394 L
.45715 .34394 L
.45715 .34395 L
.45715 .34395 L
.45715 .34396 L
.45715 .34396 L
.45715 .34397 L
.45715 .34397 L
.45715 .34398 L
.45715 .34398 L
.45715 .34399 L
Mistroke
.45715 .34399 L
.45715 .344 L
.45715 .344 L
.45715 .34401 L
.45715 .34401 L
.45715 .34401 L
.45715 .34402 L
.45715 .34402 L
.45715 .34403 L
.45716 .34403 L
.45716 .34404 L
.45716 .34404 L
.45716 .34405 L
.45716 .34405 L
.45716 .34406 L
.45716 .34406 L
.45716 .34407 L
.45716 .34407 L
.45716 .34408 L
.45716 .34408 L
.45716 .34409 L
.45716 .34409 L
.45716 .3441 L
.45716 .3441 L
.45716 .34411 L
.45716 .34411 L
.45716 .34412 L
.45716 .34412 L
.45716 .34412 L
.45716 .34413 L
.45716 .34413 L
.45716 .34414 L
.45716 .34414 L
.45716 .34415 L
.45716 .34415 L
.45716 .34416 L
.45716 .34416 L
.45717 .34417 L
.45717 .34417 L
.45717 .34418 L
.45717 .34418 L
.45717 .34419 L
.45717 .34419 L
.45717 .3442 L
.45717 .3442 L
.45717 .34421 L
.45717 .34421 L
.45717 .34422 L
.45717 .34422 L
.45717 .34423 L
Mistroke
.45717 .34423 L
.45717 .34424 L
.45717 .34424 L
.45717 .34424 L
.45717 .34425 L
.45717 .34425 L
.45717 .34426 L
.45717 .34426 L
.45717 .34427 L
.45717 .34427 L
.45717 .34428 L
.45717 .34428 L
.45717 .34429 L
.45717 .34429 L
.45717 .3443 L
.45717 .3443 L
.45717 .34431 L
.45717 .34431 L
.45717 .34432 L
.45717 .34432 L
.45717 .34433 L
.45717 .34433 L
.45717 .34434 L
.45717 .34434 L
.45717 .34435 L
.45717 .34435 L
.45717 .34436 L
.45717 .34436 L
.45717 .34436 L
.45717 .34437 L
.45717 .34437 L
.45717 .34438 L
.45717 .34438 L
.45717 .34439 L
.45717 .34439 L
.45717 .3444 L
.45717 .3444 L
.45717 .34441 L
.45717 .34441 L
.45717 .34442 L
.45717 .34442 L
.45717 .34443 L
.45717 .34443 L
.45717 .34444 L
.45717 .34444 L
.45717 .34445 L
.45717 .34445 L
.45717 .34446 L
.45717 .34446 L
.45717 .34447 L
Mistroke
.45717 .34447 L
.45717 .34448 L
.45717 .34448 L
.45717 .34449 L
.45717 .34449 L
.45717 .34449 L
.45717 .3445 L
.45717 .3445 L
.45717 .34451 L
.45717 .34451 L
.45717 .34452 L
.45717 .34452 L
.45717 .34453 L
.45717 .34453 L
.45717 .34454 L
.45717 .34454 L
.45717 .34455 L
.45717 .34455 L
.45717 .34456 L
.45717 .34456 L
.45717 .34457 L
.45717 .34457 L
.45717 .34458 L
.45717 .34458 L
.45717 .34459 L
.45717 .34459 L
.45717 .3446 L
.45716 .3446 L
.45716 .34461 L
.45716 .34461 L
.45716 .34461 L
.45716 .34462 L
.45716 .34462 L
.45716 .34463 L
.45716 .34463 L
.45716 .34464 L
.45716 .34464 L
.45716 .34465 L
.45716 .34465 L
.45716 .34466 L
.45716 .34466 L
.45716 .34467 L
.45716 .34467 L
.45716 .34468 L
.45716 .34468 L
.45716 .34469 L
.45716 .34469 L
.45716 .3447 L
.45716 .3447 L
.45716 .34471 L
Mistroke
.45716 .34471 L
.45716 .34472 L
.45716 .34472 L
.45716 .34473 L
.45716 .34473 L
.45716 .34473 L
.45715 .34474 L
.45715 .34474 L
.45715 .34475 L
.45715 .34475 L
.45715 .34476 L
.45715 .34476 L
.45715 .34477 L
.45715 .34477 L
.45715 .34478 L
.45715 .34478 L
.45715 .34479 L
.45715 .34479 L
.45715 .3448 L
.45715 .3448 L
.45715 .34481 L
.45715 .34481 L
.45715 .34482 L
.45715 .34482 L
.45715 .34483 L
.45715 .34483 L
.45715 .34484 L
.45714 .34484 L
.45714 .34484 L
.45714 .34485 L
.45714 .34485 L
.45714 .34486 L
.45714 .34486 L
.45714 .34487 L
.45714 .34487 L
.45714 .34488 L
.45714 .34488 L
.45714 .34489 L
.45714 .34489 L
.45714 .3449 L
.45714 .3449 L
.45714 .34491 L
.45714 .34491 L
.45714 .34492 L
.45713 .34492 L
.45713 .34493 L
.45713 .34493 L
.45713 .34494 L
.45713 .34494 L
.45713 .34495 L
Mistroke
.45713 .34495 L
.45713 .34495 L
.45713 .34496 L
.45713 .34496 L
.45713 .34497 L
.45713 .34497 L
.45713 .34498 L
.45713 .34498 L
.45713 .34499 L
.45712 .34499 L
.45712 .345 L
.45712 .345 L
.45712 .34501 L
.45712 .34501 L
.45712 .34502 L
.45712 .34502 L
.45712 .34503 L
.45712 .34503 L
.45712 .34504 L
.45712 .34504 L
.45712 .34505 L
.45712 .34505 L
.45711 .34505 L
.45711 .34506 L
.45711 .34506 L
.45711 .34507 L
.45711 .34507 L
.45711 .34508 L
.45711 .34508 L
.45711 .34509 L
.45711 .34509 L
.45711 .3451 L
.45711 .3451 L
.45711 .34511 L
.45711 .34511 L
.4571 .34512 L
.4571 .34512 L
.4571 .34513 L
.4571 .34513 L
.4571 .34514 L
.4571 .34514 L
.4571 .34515 L
.4571 .34515 L
.4571 .34515 L
.4571 .34516 L
.4571 .34516 L
.45709 .34517 L
.45709 .34517 L
.45709 .34518 L
.45709 .34518 L
Mistroke
.45709 .34519 L
.45709 .34519 L
.45709 .3452 L
.45709 .3452 L
.45709 .34521 L
.45709 .34521 L
.45709 .34522 L
.45708 .34522 L
.45708 .34523 L
.45708 .34523 L
.45708 .34524 L
.45708 .34524 L
.45708 .34524 L
.45708 .34525 L
.45708 .34525 L
.45708 .34526 L
.45708 .34526 L
.45707 .34527 L
.45707 .34527 L
.45707 .34528 L
.45707 .34528 L
.45707 .34529 L
.45707 .34529 L
.45707 .3453 L
.45707 .3453 L
.45707 .34531 L
.45707 .34531 L
.45706 .34532 L
.45706 .34532 L
.45706 .34533 L
.45706 .34533 L
.45706 .34533 L
.45706 .34534 L
.45706 .34534 L
.45706 .34535 L
.45706 .34535 L
.45705 .34536 L
.45705 .34536 L
.45705 .34537 L
.45705 .34537 L
.45705 .34538 L
.45705 .34538 L
.45705 .34539 L
.45705 .34539 L
.45705 .3454 L
.45704 .3454 L
.45704 .34541 L
.45704 .34541 L
.45704 .34541 L
.45704 .34542 L
Mistroke
.45704 .34542 L
.45704 .34543 L
.45704 .34543 L
.45704 .34544 L
.45703 .34544 L
.45703 .34545 L
.45703 .34545 L
.45703 .34546 L
.45703 .34546 L
.45703 .34547 L
.45703 .34547 L
.45703 .34548 L
.45702 .34548 L
.45702 .34548 L
.45702 .34549 L
.45702 .34549 L
.45702 .3455 L
.45702 .3455 L
.45702 .34551 L
.45702 .34551 L
.45702 .34552 L
.45701 .34552 L
.45701 .34553 L
.45701 .34553 L
.45701 .34554 L
.45701 .34554 L
.45701 .34555 L
.45701 .34555 L
.457 .34555 L
.457 .34556 L
.457 .34556 L
.457 .34557 L
.457 .34557 L
.457 .34558 L
.457 .34558 L
.457 .34559 L
.45699 .34559 L
.45699 .3456 L
.45699 .3456 L
.45699 .34561 L
.45699 .34561 L
.45699 .34562 L
.45699 .34562 L
.45699 .34562 L
.45698 .34563 L
.45698 .34563 L
.45698 .34564 L
.45698 .34564 L
.45698 .34565 L
.45698 .34565 L
Mistroke
.45698 .34566 L
.45697 .34566 L
.45697 .34567 L
.45697 .34567 L
.45697 .34568 L
.45697 .34568 L
.45697 .34568 L
.45697 .34569 L
.45696 .34569 L
.45696 .3457 L
.45696 .3457 L
.45696 .34571 L
.45696 .34571 L
.45696 .34572 L
.45696 .34572 L
.45695 .34573 L
.45695 .34573 L
.45695 .34574 L
.45695 .34574 L
.45695 .34574 L
.45695 .34575 L
.45695 .34575 L
.45694 .34576 L
.45694 .34576 L
.45694 .34577 L
.45694 .34577 L
.45694 .34578 L
.45694 .34578 L
.45694 .34579 L
.45693 .34579 L
.45693 .3458 L
.45693 .3458 L
.45693 .3458 L
.45693 .34581 L
.45693 .34581 L
.45692 .34582 L
.45692 .34582 L
.45692 .34583 L
.45692 .34583 L
.45692 .34584 L
.45692 .34584 L
.45692 .34585 L
.45691 .34585 L
.45691 .34585 L
.45691 .34586 L
.45691 .34586 L
.45691 .34587 L
.45691 .34587 L
.4569 .34588 L
.4569 .34588 L
Mistroke
.4569 .34589 L
.4569 .34589 L
.4569 .3459 L
.4569 .3459 L
.45689 .34591 L
.45689 .34591 L
.45689 .34591 L
.45689 .34592 L
.45689 .34592 L
.45689 .34593 L
.45689 .34593 L
.45688 .34594 L
.45688 .34594 L
.45688 .34595 L
.45688 .34595 L
.45688 .34596 L
.45688 .34596 L
.45687 .34596 L
.45687 .34597 L
.45687 .34597 L
.45687 .34598 L
.45687 .34598 L
.45687 .34599 L
.45686 .34599 L
.45686 .346 L
.45686 .346 L
.45686 .34601 L
.45686 .34601 L
.45686 .34601 L
.45685 .34602 L
.45685 .34602 L
.45685 .34603 L
.45685 .34603 L
.45685 .34604 L
.45684 .34604 L
.45684 .34605 L
.45684 .34605 L
.45684 .34605 L
.45684 .34606 L
.45684 .34606 L
.45683 .34607 L
.45683 .34607 L
.45683 .34608 L
.45683 .34608 L
.45683 .34609 L
.45683 .34609 L
.45682 .3461 L
.45682 .3461 L
.45682 .3461 L
.45682 .34611 L
Mistroke
.45682 .34611 L
.45681 .34612 L
.45681 .34612 L
.45681 .34613 L
.45681 .34613 L
.45681 .34614 L
.45681 .34614 L
.4568 .34614 L
.4568 .34615 L
.4568 .34615 L
.4568 .34616 L
.4568 .34616 L
.4568 .34617 L
.45679 .34617 L
.45679 .34618 L
.45679 .34618 L
.45679 .34618 L
.45679 .34619 L
.45678 .34619 L
.45678 .3462 L
.45678 .3462 L
.45678 .34621 L
.45678 .34621 L
.45677 .34622 L
.45677 .34622 L
.45677 .34622 L
.45677 .34623 L
.45677 .34623 L
.45677 .34624 L
.45676 .34624 L
.45676 .34625 L
.45676 .34625 L
.45676 .34626 L
.45676 .34626 L
.45675 .34626 L
.45675 .34627 L
.45675 .34627 L
.45675 .34628 L
.45675 .34628 L
.45674 .34629 L
.45674 .34629 L
.45674 .3463 L
.45674 .3463 L
.45674 .3463 L
.45673 .34631 L
.45673 .34631 L
.45673 .34632 L
.45673 .34632 L
.45673 .34633 L
.45672 .34633 L
Mistroke
.45672 .34634 L
.45672 .34634 L
.45672 .34634 L
.45672 .34635 L
.45671 .34635 L
.45671 .34636 L
.45671 .34636 L
.45671 .34637 L
.45671 .34637 L
.45671 .34637 L
.4567 .34638 L
.4567 .34638 L
.4567 .34639 L
.4567 .34639 L
.45669 .3464 L
.45669 .3464 L
.45669 .34641 L
.45669 .34641 L
.45669 .34641 L
.45668 .34642 L
.45668 .34642 L
.45668 .34643 L
.45668 .34643 L
.45668 .34644 L
.45667 .34644 L
.45667 .34644 L
.45667 .34645 L
.45667 .34645 L
.45667 .34646 L
.45666 .34646 L
.45666 .34647 L
.45666 .34647 L
.45666 .34648 L
.45666 .34648 L
.45665 .34648 L
.45665 .34649 L
.45665 .34649 L
.45665 .3465 L
.45665 .3465 L
.45664 .34651 L
.45664 .34651 L
.45664 .34651 L
.45664 .34652 L
.45664 .34652 L
.45663 .34653 L
.45663 .34653 L
.45663 .34654 L
.45663 .34654 L
.45662 .34654 L
.45662 .34655 L
Mistroke
.45662 .34655 L
.45662 .34656 L
.45662 .34656 L
.45661 .34657 L
.45661 .34657 L
.45661 .34657 L
.45661 .34658 L
.45661 .34658 L
.4566 .34659 L
.4566 .34659 L
.4566 .3466 L
.4566 .3466 L
.45659 .3466 L
.45659 .34661 L
.45659 .34661 L
.45659 .34662 L
.45659 .34662 L
.45658 .34663 L
.45658 .34663 L
.45658 .34663 L
.45658 .34664 L
.45657 .34664 L
.45657 .34665 L
.45657 .34665 L
.45657 .34666 L
.45657 .34666 L
.45656 .34666 L
.45656 .34667 L
.45656 .34667 L
.45656 .34668 L
.45655 .34668 L
.45655 .34669 L
.45655 .34669 L
.45655 .34669 L
.45655 .3467 L
.45654 .3467 L
.45654 .34671 L
.45654 .34671 L
.45654 .34671 L
.45653 .34672 L
.45653 .34672 L
.45653 .34673 L
.45653 .34673 L
.45653 .34674 L
.45652 .34674 L
.45652 .34674 L
.45652 .34675 L
.45652 .34675 L
.45651 .34676 L
.45651 .34676 L
Mistroke
.45651 .34677 L
.45651 .34677 L
.45651 .34677 L
.4565 .34678 L
.4565 .34678 L
.4565 .34679 L
.4565 .34679 L
.45649 .34679 L
.45649 .3468 L
.45649 .3468 L
.45649 .34681 L
.45648 .34681 L
.45648 .34682 L
.45648 .34682 L
.45648 .34682 L
.45648 .34683 L
.45647 .34683 L
.45647 .34684 L
.45647 .34684 L
.45647 .34684 L
.45646 .34685 L
.45646 .34685 L
.45646 .34686 L
.45646 .34686 L
.45645 .34687 L
.45645 .34687 L
.45645 .34687 L
.45645 .34688 L
.45644 .34688 L
.45644 .34689 L
.45644 .34689 L
.45644 .34689 L
.45644 .3469 L
.45643 .3469 L
.45643 .34691 L
.45643 .34691 L
.45643 .34691 L
.45642 .34692 L
.45642 .34692 L
.45642 .34693 L
.45642 .34693 L
.45641 .34694 L
.45641 .34694 L
.45641 .34694 L
.45641 .34695 L
.4564 .34695 L
.4564 .34696 L
.4564 .34696 L
.4564 .34696 L
.45639 .34697 L
Mistroke
.45639 .34697 L
.45639 .34698 L
.45639 .34698 L
.45638 .34698 L
.45638 .34699 L
.45638 .34699 L
.45638 .347 L
.45637 .347 L
.45637 .347 L
.45637 .34701 L
.45637 .34701 L
.45637 .34702 L
.45636 .34702 L
.45636 .34702 L
.45636 .34703 L
.45636 .34703 L
.45635 .34704 L
.45635 .34704 L
.45635 .34705 L
.45635 .34705 L
.45634 .34705 L
.45634 .34706 L
.45634 .34706 L
.45634 .34707 L
.45633 .34707 L
.45633 .34707 L
.45633 .34708 L
.45633 .34708 L
.45632 .34709 L
.45632 .34709 L
.45632 .34709 L
.45632 .3471 L
.45631 .3471 L
.45631 .34711 L
.45631 .34711 L
.45631 .34711 L
.4563 .34712 L
.4563 .34712 L
.4563 .34713 L
.4563 .34713 L
.45629 .34713 L
.45629 .34714 L
.45629 .34714 L
.45629 .34715 L
.45628 .34715 L
.45628 .34715 L
.45628 .34716 L
.45628 .34716 L
.45627 .34717 L
.45627 .34717 L
Mistroke
.45627 .34717 L
.45626 .34718 L
.45626 .34718 L
.45626 .34719 L
.45626 .34719 L
.45625 .34719 L
.45625 .3472 L
.45625 .3472 L
.45625 .3472 L
.45624 .34721 L
.45624 .34721 L
.45624 .34722 L
.45624 .34722 L
.45623 .34722 L
.45623 .34723 L
.45623 .34723 L
.45623 .34724 L
.45622 .34724 L
.45622 .34724 L
.45622 .34725 L
.45622 .34725 L
.45621 .34726 L
.45621 .34726 L
.45621 .34726 L
.45621 .34727 L
.4562 .34727 L
.4562 .34728 L
.4562 .34728 L
.4562 .34728 L
.45619 .34729 L
.45619 .34729 L
.45619 .34729 L
.45618 .3473 L
.45618 .3473 L
.45618 .34731 L
.45618 .34731 L
.45617 .34731 L
.45617 .34732 L
.45617 .34732 L
.45617 .34733 L
.45616 .34733 L
.45616 .34733 L
.45616 .34734 L
.45616 .34734 L
.45615 .34735 L
.45615 .34735 L
.45615 .34735 L
.45615 .34736 L
.45614 .34736 L
.45614 .34736 L
Mistroke
.45614 .34737 L
.45613 .34737 L
.45613 .34738 L
.45613 .34738 L
.45613 .34738 L
.45612 .34739 L
.45612 .34739 L
.45612 .3474 L
.45612 .3474 L
.45611 .3474 L
.45611 .34741 L
.45611 .34741 L
.45611 .34741 L
.4561 .34742 L
.4561 .34742 L
.4561 .34743 L
.45609 .34743 L
.45609 .34743 L
.45609 .34744 L
.45609 .34744 L
.45608 .34744 L
.45608 .34745 L
.45608 .34745 L
.45608 .34746 L
.45607 .34746 L
.45607 .34746 L
.45607 .34747 L
.45606 .34747 L
.45606 .34747 L
.45606 .34748 L
.45606 .34748 L
.45605 .34749 L
.45605 .34749 L
.45605 .34749 L
.45605 .3475 L
.45604 .3475 L
.45604 .3475 L
.45604 .34751 L
.45603 .34751 L
.45603 .34752 L
.45603 .34752 L
.45603 .34752 L
.45602 .34753 L
.45602 .34753 L
.45602 .34753 L
.45602 .34754 L
.45601 .34754 L
.45601 .34755 L
.45601 .34755 L
.456 .34755 L
Mistroke
.456 .34756 L
.456 .34756 L
.456 .34756 L
.45599 .34757 L
.45599 .34757 L
.45599 .34758 L
.45598 .34758 L
.45598 .34758 L
.45598 .34759 L
.45598 .34759 L
.45597 .34759 L
.45597 .3476 L
.45597 .3476 L
.45597 .3476 L
.45596 .34761 L
.45596 .34761 L
.45596 .34762 L
.45595 .34762 L
.45595 .34762 L
.45595 .34763 L
.45595 .34763 L
.45594 .34763 L
.45594 .34764 L
.45594 .34764 L
.45593 .34765 L
.45593 .34765 L
.45593 .34765 L
.45593 .34766 L
.45592 .34766 L
.45592 .34766 L
.45592 .34767 L
.45592 .34767 L
.45591 .34767 L
.45591 .34768 L
.45591 .34768 L
.4559 .34769 L
.4559 .34769 L
.4559 .34769 L
.4559 .3477 L
.45589 .3477 L
.45589 .3477 L
.45589 .34771 L
.45588 .34771 L
.45588 .34771 L
.45588 .34772 L
.45588 .34772 L
.45587 .34772 L
.45587 .34773 L
.45587 .34773 L
.45586 .34774 L
Mistroke
.45586 .34774 L
.45586 .34774 L
.45586 .34775 L
.45585 .34775 L
.45585 .34775 L
.45585 .34776 L
.45584 .34776 L
.45584 .34776 L
.45584 .34777 L
.45584 .34777 L
.45583 .34777 L
.45583 .34778 L
.45583 .34778 L
.45582 .34779 L
.45582 .34779 L
.45582 .34779 L
.45582 .3478 L
.45581 .3478 L
.45581 .3478 L
.45581 .34781 L
.4558 .34781 L
.4558 .34781 L
.4558 .34782 L
.4558 .34782 L
.45579 .34782 L
.45579 .34783 L
.45579 .34783 L
.45578 .34783 L
.45578 .34784 L
.45578 .34784 L
.45578 .34784 L
.45577 .34785 L
.45577 .34785 L
.45577 .34786 L
.45576 .34786 L
.45576 .34786 L
.45576 .34787 L
.45576 .34787 L
.45575 .34787 L
.45575 .34788 L
.45575 .34788 L
.45574 .34788 L
.45574 .34789 L
.45574 .34789 L
.45573 .34789 L
.45573 .3479 L
.45573 .3479 L
.45573 .3479 L
.45572 .34791 L
.45572 .34791 L
Mistroke
.45572 .34791 L
.45571 .34792 L
.45571 .34792 L
.45571 .34792 L
.45571 .34793 L
.4557 .34793 L
.4557 .34793 L
.4557 .34794 L
.45569 .34794 L
.45569 .34794 L
.45569 .34795 L
.45569 .34795 L
.45568 .34796 L
.45568 .34796 L
.45568 .34796 L
.45567 .34797 L
.45567 .34797 L
.45567 .34797 L
.45566 .34798 L
.45566 .34798 L
.45566 .34798 L
.45566 .34799 L
.45565 .34799 L
.45565 .34799 L
.45565 .348 L
.45564 .348 L
.45564 .348 L
.45564 .34801 L
.45564 .34801 L
.45563 .34801 L
.45563 .34802 L
.45563 .34802 L
.45562 .34802 L
.45562 .34803 L
.45562 .34803 L
.45561 .34803 L
.45561 .34804 L
.45561 .34804 L
.45561 .34804 L
.4556 .34805 L
.4556 .34805 L
.4556 .34805 L
.45559 .34806 L
.45559 .34806 L
.45559 .34806 L
.45558 .34807 L
.45558 .34807 L
.45558 .34807 L
.45558 .34808 L
.45557 .34808 L
Mistroke
.45557 .34808 L
.45557 .34809 L
.45556 .34809 L
.45556 .34809 L
.45556 .3481 L
.45555 .3481 L
.45555 .3481 L
.45555 .34811 L
.45555 .34811 L
.45554 .34811 L
.45554 .34812 L
.45554 .34812 L
.45553 .34812 L
.45553 .34812 L
.45553 .34813 L
.45553 .34813 L
.45552 .34813 L
.45552 .34814 L
.45552 .34814 L
.45551 .34814 L
.45551 .34815 L
.45551 .34815 L
.4555 .34815 L
.4555 .34816 L
.4555 .34816 L
.4555 .34816 L
.45549 .34817 L
.45549 .34817 L
.45549 .34817 L
.45548 .34818 L
.45548 .34818 L
.45548 .34818 L
.45547 .34819 L
.45547 .34819 L
.45547 .34819 L
.45546 .3482 L
.45546 .3482 L
.45546 .3482 L
.45546 .34821 L
.45545 .34821 L
.45545 .34821 L
.45545 .34821 L
.45544 .34822 L
.45544 .34822 L
.45544 .34822 L
.45543 .34823 L
.45543 .34823 L
.45543 .34823 L
.45543 .34824 L
.45542 .34824 L
Mistroke
.45542 .34824 L
.45542 .34825 L
.45541 .34825 L
.45541 .34825 L
.45541 .34826 L
.4554 .34826 L
.4554 .34826 L
.4554 .34827 L
.4554 .34827 L
.45539 .34827 L
.45539 .34827 L
.45539 .34828 L
.45538 .34828 L
.45538 .34828 L
.45538 .34829 L
.45537 .34829 L
.45537 .34829 L
.45537 .3483 L
.45536 .3483 L
.45536 .3483 L
.45536 .34831 L
.45536 .34831 L
.45535 .34831 L
.45535 .34831 L
.45535 .34832 L
.45534 .34832 L
.45534 .34832 L
.45534 .34833 L
.45533 .34833 L
.45533 .34833 L
.45533 .34834 L
.45533 .34834 L
.45532 .34834 L
.45532 .34835 L
.45532 .34835 L
.45531 .34835 L
.45531 .34835 L
.45531 .34836 L
.4553 .34836 L
.4553 .34836 L
.4553 .34837 L
.45529 .34837 L
.45529 .34837 L
.45529 .34838 L
.45529 .34838 L
.45528 .34838 L
.45528 .34838 L
.45528 .34839 L
.45527 .34839 L
.45527 .34839 L
Mistroke
.45527 .3484 L
.45526 .3484 L
.45526 .3484 L
.45526 .34841 L
.45525 .34841 L
.45525 .34841 L
.45525 .34841 L
.45525 .34842 L
.45524 .34842 L
.45524 .34842 L
.45524 .34843 L
.45523 .34843 L
.45523 .34843 L
.45523 .34844 L
.45522 .34844 L
.45522 .34844 L
.45522 .34844 L
.45522 .34845 L
.45521 .34845 L
.45521 .34845 L
.45521 .34846 L
.4552 .34846 L
.4552 .34846 L
.4552 .34847 L
.45519 .34847 L
.45519 .34847 L
.45519 .34847 L
.45518 .34848 L
.45518 .34848 L
.45518 .34848 L
.45517 .34849 L
.45517 .34849 L
.45517 .34849 L
.45517 .34849 L
.45516 .3485 L
.45516 .3485 L
.45516 .3485 L
.45515 .34851 L
.45515 .34851 L
.45515 .34851 L
.45514 .34851 L
.45514 .34852 L
.45514 .34852 L
.45513 .34852 L
.45513 .34853 L
.45513 .34853 L
.45513 .34853 L
.45512 .34853 L
.45512 .34854 L
.45512 .34854 L
Mistroke
.45511 .34854 L
.45511 .34855 L
.45511 .34855 L
.4551 .34855 L
.4551 .34855 L
.4551 .34856 L
.45509 .34856 L
.45509 .34856 L
.45509 .34857 L
.45509 .34857 L
.45508 .34857 L
.45508 .34857 L
.45508 .34858 L
.45507 .34858 L
.45507 .34858 L
.45507 .34859 L
.45506 .34859 L
.45506 .34859 L
.45506 .34859 L
.45505 .3486 L
.45505 .3486 L
.45505 .3486 L
.45505 .34861 L
.45504 .34861 L
.45504 .34861 L
.45504 .34861 L
.45503 .34862 L
.45503 .34862 L
.45503 .34862 L
.45502 .34862 L
.45502 .34863 L
.45502 .34863 L
.45501 .34863 L
.45501 .34864 L
.45501 .34864 L
.455 .34864 L
.455 .34864 L
.455 .34865 L
.455 .34865 L
.45499 .34865 L
.45499 .34865 L
.45499 .34866 L
.45498 .34866 L
.45498 .34866 L
.45498 .34867 L
.45497 .34867 L
.45497 .34867 L
.45497 .34867 L
.45496 .34868 L
.45496 .34868 L
Mistroke
.45496 .34868 L
.45495 .34868 L
.45495 .34869 L
.45495 .34869 L
.45495 .34869 L
.45494 .3487 L
.45494 .3487 L
.45494 .3487 L
.45493 .3487 L
.45493 .34871 L
.45493 .34871 L
.45492 .34871 L
.45492 .34871 L
.45492 .34872 L
.45491 .34872 L
.45491 .34872 L
.45491 .34872 L
.45491 .34873 L
.4549 .34873 L
.4549 .34873 L
.4549 .34874 L
.45489 .34874 L
.45489 .34874 L
.45489 .34874 L
.45488 .34875 L
.45488 .34875 L
.45488 .34875 L
.45487 .34875 L
.45487 .34876 L
.45487 .34876 L
.45486 .34876 L
.45486 .34876 L
.45486 .34877 L
.45486 .34877 L
.45485 .34877 L
.45485 .34877 L
.45485 .34878 L
.45484 .34878 L
.45484 .34878 L
.45484 .34878 L
.45483 .34879 L
.45483 .34879 L
.45483 .34879 L
.45482 .34879 L
.45482 .3488 L
.45482 .3488 L
.45481 .3488 L
.45481 .34881 L
.45481 .34881 L
.45481 .34881 L
Mistroke
.4548 .34881 L
.4548 .34882 L
.4548 .34882 L
.45479 .34882 L
.45479 .34882 L
.45479 .34883 L
.45478 .34883 L
.45478 .34883 L
.45478 .34883 L
.45477 .34884 L
.45477 .34884 L
.45477 .34884 L
.45476 .34884 L
.45476 .34885 L
.45476 .34885 L
.45476 .34885 L
.45475 .34885 L
.45475 .34886 L
.45475 .34886 L
.45474 .34886 L
.45474 .34886 L
.45474 .34887 L
.45473 .34887 L
.45473 .34887 L
.45473 .34887 L
.45472 .34888 L
.45472 .34888 L
.45472 .34888 L
.45472 .34888 L
.45471 .34889 L
.45471 .34889 L
.45471 .34889 L
.4547 .34889 L
.4547 .3489 L
.4547 .3489 L
.45469 .3489 L
.45469 .3489 L
.45469 .34891 L
.45468 .34891 L
.45468 .34891 L
.45468 .34891 L
.45467 .34891 L
.45467 .34892 L
.45467 .34892 L
.45467 .34892 L
.45466 .34892 L
.45466 .34893 L
.45466 .34893 L
.45465 .34893 L
.45465 .34893 L
Mistroke
.45465 .34894 L
.45464 .34894 L
.45464 .34894 L
.45464 .34894 L
.45463 .34895 L
.45463 .34895 L
.45463 .34895 L
.45462 .34895 L
.45462 .34896 L
.45462 .34896 L
.45462 .34896 L
.45461 .34896 L
.45461 .34896 L
.45461 .34897 L
.4546 .34897 L
.4546 .34897 L
.4546 .34897 L
.45459 .34898 L
.45459 .34898 L
.45459 .34898 L
.45458 .34898 L
.45458 .34899 L
.45458 .34899 L
.45458 .34899 L
.45457 .34899 L
.45457 .349 L
.45457 .349 L
.45456 .349 L
.45456 .349 L
.45456 .349 L
.45455 .34901 L
.45455 .34901 L
.45455 .34901 L
.45454 .34901 L
.45454 .34902 L
.45454 .34902 L
.45453 .34902 L
.45453 .34902 L
.45453 .34903 L
.45453 .34903 L
.45452 .34903 L
.45452 .34903 L
.45452 .34903 L
.45451 .34904 L
.45451 .34904 L
.45451 .34904 L
.4545 .34904 L
.4545 .34905 L
.4545 .34905 L
.45449 .34905 L
Mistroke
.45449 .34905 L
.45449 .34905 L
.45448 .34906 L
.45448 .34906 L
.45448 .34906 L
.45448 .34906 L
.45447 .34907 L
.45447 .34907 L
.45447 .34907 L
.45446 .34907 L
.45446 .34907 L
.45446 .34908 L
.45445 .34908 L
.45445 .34908 L
.45445 .34908 L
.45444 .34909 L
.45444 .34909 L
.45444 .34909 L
.45444 .34909 L
.45443 .34909 L
.45443 .3491 L
.45443 .3491 L
.45442 .3491 L
.45442 .3491 L
.45442 .34911 L
.45441 .34911 L
.45441 .34911 L
.45441 .34911 L
.4544 .34911 L
.4544 .34912 L
.4544 .34912 L
.4544 .34912 L
.45439 .34912 L
.45439 .34912 L
.45439 .34913 L
.45438 .34913 L
.45438 .34913 L
.45438 .34913 L
.45437 .34914 L
.45437 .34914 L
.45437 .34914 L
.45436 .34914 L
.45436 .34914 L
.45436 .34915 L
.45435 .34915 L
.45435 .34915 L
.45435 .34915 L
.45435 .34915 L
.45434 .34916 L
.45434 .34916 L
Mistroke
.45434 .34916 L
.45433 .34916 L
.45433 .34917 L
.45433 .34917 L
.45432 .34917 L
.45432 .34917 L
.45432 .34917 L
.45431 .34918 L
.45431 .34918 L
.45431 .34918 L
.45431 .34918 L
.4543 .34918 L
.4543 .34919 L
.4543 .34919 L
.45429 .34919 L
.45429 .34919 L
.45429 .34919 L
.45428 .3492 L
.45428 .3492 L
.45428 .3492 L
.45427 .3492 L
.45427 .3492 L
.45427 .34921 L
.45427 .34921 L
.45426 .34921 L
.45426 .34921 L
.45426 .34921 L
.45425 .34922 L
.45425 .34922 L
.45425 .34922 L
.45424 .34922 L
.45424 .34922 L
.45424 .34923 L
.45424 .34923 L
.45423 .34923 L
.45423 .34923 L
.45423 .34923 L
.45422 .34924 L
.45422 .34924 L
.45422 .34924 L
.45421 .34924 L
.45421 .34924 L
.45421 .34925 L
.4542 .34925 L
.4542 .34925 L
.4542 .34925 L
.4542 .34925 L
.45419 .34926 L
.45419 .34926 L
.45419 .34926 L
Mistroke
.45418 .34926 L
.45418 .34926 L
.45418 .34927 L
.45417 .34927 L
.45417 .34927 L
.45417 .34927 L
.45416 .34927 L
.45416 .34928 L
.45416 .34928 L
.45416 .34928 L
.45415 .34928 L
.45415 .34928 L
.45415 .34928 L
.45414 .34929 L
.45414 .34929 L
.45414 .34929 L
.45413 .34929 L
.45413 .34929 L
.45413 .3493 L
.45413 .3493 L
.45412 .3493 L
.45412 .3493 L
.45412 .3493 L
.45411 .34931 L
.45411 .34931 L
.45411 .34931 L
.4541 .34931 L
.4541 .34931 L
.4541 .34932 L
.45409 .34932 L
.45409 .34932 L
.45409 .34932 L
.45409 .34932 L
.45408 .34932 L
.45408 .34933 L
.45408 .34933 L
.45407 .34933 L
.45407 .34933 L
.45407 .34933 L
.45406 .34934 L
.45406 .34934 L
.45406 .34934 L
.45406 .34934 L
.45405 .34934 L
.45405 .34934 L
.45405 .34935 L
.45404 .34935 L
.45404 .34935 L
.45404 .34935 L
.45403 .34935 L
Mistroke
.45403 .34936 L
.45403 .34936 L
.45403 .34936 L
.45402 .34936 L
.45402 .34936 L
.45402 .34936 L
.45401 .34937 L
.45401 .34937 L
.45401 .34937 L
.454 .34937 L
.454 .34937 L
.454 .34937 L
.454 .34938 L
.45399 .34938 L
.45399 .34938 L
.45399 .34938 L
.45398 .34938 L
.45398 .34939 L
.45398 .34939 L
.45397 .34939 L
.45397 .34939 L
.45397 .34939 L
.45397 .34939 L
.45396 .3494 L
.45396 .3494 L
.45396 .3494 L
.45395 .3494 L
.45395 .3494 L
.45395 .3494 L
.45394 .34941 L
.45394 .34941 L
.45394 .34941 L
.45394 .34941 L
.45393 .34941 L
.45393 .34941 L
.45393 .34942 L
.45392 .34942 L
.45392 .34942 L
.45392 .34942 L
.45391 .34942 L
.45391 .34942 L
.45391 .34943 L
.45391 .34943 L
.4539 .34943 L
.4539 .34943 L
.4539 .34943 L
.45389 .34943 L
.45389 .34944 L
.45389 .34944 L
.45388 .34944 L
Mistroke
.45388 .34944 L
.45388 .34944 L
.45388 .34944 L
.45387 .34945 L
.45387 .34945 L
.45387 .34945 L
.45386 .34945 L
.45386 .34945 L
.45386 .34945 L
.45385 .34946 L
.45385 .34946 L
.45385 .34946 L
.45385 .34946 L
.45384 .34946 L
.45384 .34946 L
.45384 .34947 L
.45383 .34947 L
.45383 .34947 L
.45383 .34947 L
.45383 .34947 L
.45382 .34947 L
.45382 .34948 L
.45382 .34948 L
.45381 .34948 L
.45381 .34948 L
.45381 .34948 L
.4538 .34948 L
.4538 .34948 L
.4538 .34949 L
.4538 .34949 L
.45379 .34949 L
.45379 .34949 L
.45379 .34949 L
.45378 .34949 L
.45378 .3495 L
.45378 .3495 L
.45377 .3495 L
.45377 .3495 L
.45377 .3495 L
.45377 .3495 L
.45376 .3495 L
.45376 .34951 L
.45376 .34951 L
.45375 .34951 L
.45375 .34951 L
.45375 .34951 L
.45375 .34951 L
.45374 .34952 L
.45374 .34952 L
.45374 .34952 L
Mistroke
.45373 .34952 L
.45373 .34952 L
.45373 .34952 L
.45373 .34952 L
.45372 .34953 L
.45372 .34953 L
.45372 .34953 L
.45371 .34953 L
.45371 .34953 L
.45371 .34953 L
.4537 .34954 L
.4537 .34954 L
.4537 .34954 L
.4537 .34954 L
.45369 .34954 L
.45369 .34954 L
.45369 .34954 L
.45368 .34955 L
.45368 .34955 L
.45368 .34955 L
.45368 .34955 L
.45367 .34955 L
.45367 .34955 L
.45367 .34955 L
.45366 .34956 L
.45366 .34956 L
.45366 .34956 L
.45366 .34956 L
.45365 .34956 L
.45365 .34956 L
.45365 .34956 L
.45364 .34957 L
.45364 .34957 L
.45364 .34957 L
.45364 .34957 L
.45363 .34957 L
.45363 .34957 L
.45363 .34957 L
.45362 .34958 L
.45362 .34958 L
.45362 .34958 L
.45361 .34958 L
.45361 .34958 L
.45361 .34958 L
.45361 .34958 L
.4536 .34958 L
.4536 .34959 L
.4536 .34959 L
.45359 .34959 L
.45359 .34959 L
Mistroke
.45359 .34959 L
.45359 .34959 L
.45358 .34959 L
.45358 .3496 L
.45358 .3496 L
.45357 .3496 L
.45357 .3496 L
.45357 .3496 L
.45357 .3496 L
.45356 .3496 L
.45356 .34961 L
.45356 .34961 L
.45355 .34961 L
.45355 .34961 L
.45355 .34961 L
.45355 .34961 L
.45354 .34961 L
.45354 .34961 L
.45354 .34962 L
.45353 .34962 L
.45353 .34962 L
.45353 .34962 L
.45353 .34962 L
.45352 .34962 L
.45352 .34962 L
.45352 .34963 L
.45351 .34963 L
.45351 .34963 L
.45351 .34963 L
.45351 .34963 L
.4535 .34963 L
.4535 .34963 L
.4535 .34963 L
.45349 .34964 L
.45349 .34964 L
.45349 .34964 L
.45349 .34964 L
.45348 .34964 L
.45348 .34964 L
.45348 .34964 L
.45348 .34964 L
.45347 .34965 L
.45347 .34965 L
.45347 .34965 L
.45346 .34965 L
.45346 .34965 L
.45346 .34965 L
.45346 .34965 L
.45345 .34965 L
.45345 .34966 L
Mistroke
.45345 .34966 L
.45344 .34966 L
.45344 .34966 L
.45344 .34966 L
.45344 .34966 L
.45343 .34966 L
.45343 .34966 L
.45343 .34966 L
.45342 .34967 L
.45342 .34967 L
.45342 .34967 L
.45342 .34967 L
.45341 .34967 L
.45341 .34967 L
.45341 .34967 L
.45341 .34967 L
.4534 .34968 L
.4534 .34968 L
.4534 .34968 L
.45339 .34968 L
.45339 .34968 L
.45339 .34968 L
.45339 .34968 L
.45338 .34968 L
.45338 .34969 L
.45338 .34969 L
.45337 .34969 L
.45337 .34969 L
.45337 .34969 L
.45337 .34969 L
.45336 .34969 L
.45336 .34969 L
.45336 .34969 L
.45336 .3497 L
.45335 .3497 L
.45335 .3497 L
.45335 .3497 L
.45334 .3497 L
.45334 .3497 L
.45334 .3497 L
.45334 .3497 L
.45333 .3497 L
.45333 .34971 L
.45333 .34971 L
.45332 .34971 L
.45332 .34971 L
.45332 .34971 L
.45332 .34971 L
.45331 .34971 L
.45331 .34971 L
Mistroke
.45331 .34971 L
.45331 .34972 L
.4533 .34972 L
.4533 .34972 L
.4533 .34972 L
.45329 .34972 L
.45329 .34972 L
.45329 .34972 L
.45329 .34972 L
.45328 .34972 L
.45328 .34972 L
.45328 .34973 L
.45328 .34973 L
.45327 .34973 L
.45327 .34973 L
.45327 .34973 L
.45326 .34973 L
.45326 .34973 L
.45326 .34973 L
.45326 .34973 L
.45325 .34974 L
.45325 .34974 L
.45325 .34974 L
.45325 .34974 L
.45324 .34974 L
.45324 .34974 L
.45324 .34974 L
.45323 .34974 L
.45323 .34974 L
.45323 .34974 L
.45323 .34975 L
.45322 .34975 L
.45322 .34975 L
.45322 .34975 L
.45322 .34975 L
.45321 .34975 L
.45321 .34975 L
.45321 .34975 L
.45321 .34975 L
.4532 .34975 L
.4532 .34976 L
.4532 .34976 L
.45319 .34976 L
.45319 .34976 L
.45319 .34976 L
.45319 .34976 L
.45318 .34976 L
.45318 .34976 L
.45318 .34976 L
.45318 .34976 L
Mistroke
.45317 .34977 L
.45317 .34977 L
.45317 .34977 L
.45316 .34977 L
.45316 .34977 L
.45316 .34977 L
.45316 .34977 L
.45315 .34977 L
.45315 .34977 L
.45315 .34977 L
.45315 .34977 L
.45314 .34978 L
.45314 .34978 L
.45314 .34978 L
.45314 .34978 L
.45313 .34978 L
.45313 .34978 L
.45313 .34978 L
.45313 .34978 L
.45312 .34978 L
.45312 .34978 L
.45312 .34978 L
.45311 .34979 L
.45311 .34979 L
.45311 .34979 L
.45311 .34979 L
.4531 .34979 L
.4531 .34979 L
.4531 .34979 L
.4531 .34979 L
.45309 .34979 L
.45309 .34979 L
.45309 .34979 L
.45309 .3498 L
.45308 .3498 L
.45308 .3498 L
.45308 .3498 L
.45308 .3498 L
.45307 .3498 L
.45307 .3498 L
.45307 .3498 L
.45306 .3498 L
.45306 .3498 L
.45306 .3498 L
.45306 .3498 L
.45305 .34981 L
.45305 .34981 L
.45305 .34981 L
.45305 .34981 L
.45304 .34981 L
Mistroke
.45304 .34981 L
.45304 .34981 L
.45304 .34981 L
.45303 .34981 L
.45303 .34981 L
.45303 .34981 L
.45303 .34981 L
.45302 .34982 L
.45302 .34982 L
.45302 .34982 L
.45302 .34982 L
.45301 .34982 L
.45301 .34982 L
.45301 .34982 L
.45301 .34982 L
.453 .34982 L
.453 .34982 L
.453 .34982 L
.45299 .34982 L
.45299 .34983 L
.45299 .34983 L
.45299 .34983 L
.45298 .34983 L
.45298 .34983 L
.45298 .34983 L
.45298 .34983 L
.45297 .34983 L
.45297 .34983 L
.45297 .34983 L
.45297 .34983 L
.45296 .34983 L
.45296 .34983 L
.45296 .34983 L
.45296 .34984 L
.45295 .34984 L
.45295 .34984 L
.45295 .34984 L
.45295 .34984 L
.45294 .34984 L
.45294 .34984 L
.45294 .34984 L
.45294 .34984 L
.45293 .34984 L
.45293 .34984 L
.45293 .34984 L
.45293 .34984 L
.45292 .34985 L
.45292 .34985 L
.45292 .34985 L
.45292 .34985 L
Mistroke
.45291 .34985 L
.45291 .34985 L
.45291 .34985 L
.45291 .34985 L
.4529 .34985 L
.4529 .34985 L
.4529 .34985 L
.4529 .34985 L
.45289 .34985 L
.45289 .34985 L
.45289 .34985 L
.45289 .34986 L
.45288 .34986 L
.45288 .34986 L
.45288 .34986 L
.45288 .34986 L
.45287 .34986 L
.45287 .34986 L
.45287 .34986 L
.45287 .34986 L
.45286 .34986 L
.45286 .34986 L
.45286 .34986 L
.45286 .34986 L
.45285 .34986 L
.45285 .34986 L
.45285 .34987 L
.45285 .34987 L
.45284 .34987 L
.45284 .34987 L
.45284 .34987 L
.45284 .34987 L
.45283 .34987 L
.45283 .34987 L
.45283 .34987 L
.45283 .34987 L
.45282 .34987 L
.45282 .34987 L
.45282 .34987 L
.45282 .34987 L
.45281 .34987 L
.45281 .34987 L
.45281 .34988 L
.45281 .34988 L
.4528 .34988 L
.4528 .34988 L
.4528 .34988 L
.4528 .34988 L
.45279 .34988 L
.45279 .34988 L
Mistroke
.45279 .34988 L
.45279 .34988 L
.45279 .34988 L
.45278 .34988 L
.45278 .34988 L
.45278 .34988 L
.45278 .34988 L
.45277 .34988 L
.45277 .34988 L
.45277 .34989 L
.45277 .34989 L
.45276 .34989 L
.45276 .34989 L
.45276 .34989 L
.45276 .34989 L
.45275 .34989 L
.45275 .34989 L
.45275 .34989 L
.45275 .34989 L
.45274 .34989 L
.45274 .34989 L
.45274 .34989 L
.45274 .34989 L
.45273 .34989 L
.45273 .34989 L
.45273 .34989 L
.45273 .34989 L
.45273 .34989 L
.45272 .3499 L
.45272 .3499 L
.45272 .3499 L
.45272 .3499 L
.45271 .3499 L
.45271 .3499 L
.45271 .3499 L
.45271 .3499 L
.4527 .3499 L
.4527 .3499 L
.4527 .3499 L
.4527 .3499 L
.45269 .3499 L
.45269 .3499 L
.45269 .3499 L
.45269 .3499 L
.45268 .3499 L
.45268 .3499 L
.45268 .3499 L
.45268 .3499 L
.45268 .34991 L
.45267 .34991 L
Mistroke
.45267 .34991 L
.45267 .34991 L
.45267 .34991 L
.45266 .34991 L
.45266 .34991 L
.45266 .34991 L
.45266 .34991 L
.45265 .34991 L
.45265 .34991 L
.45265 .34991 L
.45265 .34991 L
.45265 .34991 L
.45264 .34991 L
.45264 .34991 L
.45264 .34991 L
.45264 .34991 L
.45263 .34991 L
.45263 .34991 L
.45263 .34991 L
.45263 .34991 L
.45262 .34991 L
.45262 .34992 L
.45262 .34992 L
.45262 .34992 L
.45261 .34992 L
.45261 .34992 L
.45261 .34992 L
.45261 .34992 L
.45261 .34992 L
.4526 .34992 L
.4526 .34992 L
.4526 .34992 L
.4526 .34992 L
.45259 .34992 L
.45259 .34992 L
.45259 .34992 L
.45259 .34992 L
.45259 .34992 L
.45258 .34992 L
.45258 .34992 L
.45258 .34992 L
.45258 .34992 L
.45257 .34992 L
.45257 .34992 L
.45257 .34992 L
.45257 .34992 L
.45256 .34992 L
.45256 .34993 L
.45256 .34993 L
.45256 .34993 L
Mistroke
.45256 .34993 L
.45255 .34993 L
.45255 .34993 L
.45255 .34993 L
.45255 .34993 L
.45254 .34993 L
.45254 .34993 L
.45254 .34993 L
.45254 .34993 L
.45254 .34993 L
.45253 .34993 L
.45253 .34993 L
.45253 .34993 L
.45253 .34993 L
.45252 .34993 L
.45252 .34993 L
.45252 .34993 L
.45252 .34993 L
.45252 .34993 L
.45251 .34993 L
.45251 .34993 L
.45251 .34993 L
.45251 .34993 L
.4525 .34993 L
.4525 .34993 L
.4525 .34993 L
.4525 .34993 L
.4525 .34993 L
.45249 .34994 L
.45249 .34994 L
.45249 .34994 L
.45249 .34994 L
.45248 .34994 L
.45248 .34994 L
.45248 .34994 L
.45248 .34994 L
.45248 .34994 L
.45247 .34994 L
.45247 .34994 L
.45247 .34994 L
.45247 .34994 L
.45246 .34994 L
.45246 .34994 L
.45246 .34994 L
.45246 .34994 L
.45246 .34994 L
.45245 .34994 L
.45245 .34994 L
.45245 .34994 L
.45245 .34994 L
Mistroke
.45245 .34994 L
.45244 .34994 L
.45244 .34994 L
.45244 .34994 L
.45244 .34994 L
.45243 .34994 L
.45243 .34994 L
.45243 .34994 L
.45243 .34994 L
.45243 .34994 L
.45242 .34994 L
.45242 .34994 L
.45242 .34994 L
.45242 .34994 L
.45242 .34994 L
.45241 .34994 L
.45241 .34994 L
.45241 .34994 L
.45241 .34994 L
.4524 .34995 L
.4524 .34995 L
.4524 .34995 L
.4524 .34995 L
.4524 .34995 L
.45239 .34995 L
.45239 .34995 L
.45239 .34995 L
.45239 .34995 L
.45239 .34995 L
.45238 .34995 L
.45238 .34995 L
.45238 .34995 L
.45238 .34995 L
.45237 .34995 L
.45237 .34995 L
.45237 .34995 L
.45237 .34995 L
.45237 .34995 L
.45236 .34995 L
.45236 .34995 L
.45236 .34995 L
.45236 .34995 L
.45236 .34995 L
.45235 .34995 L
.45235 .34995 L
.45235 .34995 L
.45235 .34995 L
.45235 .34995 L
.45234 .34995 L
.45234 .34995 L
Mistroke
.45234 .34995 L
.45234 .34995 L
.45234 .34995 L
.45233 .34995 L
.45233 .34995 L
.45233 .34995 L
.45233 .34995 L
.45233 .34995 L
.45232 .34995 L
.45232 .34995 L
.45232 .34995 L
.45232 .34995 L
.45231 .34995 L
.45231 .34995 L
.45231 .34995 L
.45231 .34995 L
.45231 .34995 L
.4523 .34995 L
.4523 .34995 L
.4523 .34995 L
.4523 .34995 L
.4523 .34995 L
.45229 .34995 L
.45229 .34995 L
.45229 .34995 L
.45229 .34995 L
.45229 .34995 L
.45228 .34995 L
.45228 .34995 L
.45228 .34995 L
.45228 .34995 L
.45228 .34995 L
.45227 .34995 L
.45227 .34995 L
.45227 .34995 L
.45227 .34995 L
.45227 .34995 L
.45226 .34995 L
.45226 .34995 L
.45226 .34995 L
.45226 .34995 L
.45226 .34995 L
.45225 .34995 L
.45225 .34995 L
.45225 .34995 L
.45225 .34995 L
.45225 .34995 L
.45224 .34995 L
.45224 .34995 L
.45224 .34995 L
Mistroke
.45224 .34995 L
.45224 .34995 L
.45223 .34995 L
.45223 .34995 L
.45223 .34995 L
.45223 .34995 L
.45223 .34995 L
.45222 .34996 L
.45222 .34996 L
.45222 .34996 L
.45222 .34996 L
.45222 .34996 L
.45221 .34996 L
.45221 .34996 L
.45221 .34996 L
.45221 .34996 L
.45221 .34996 L
.45221 .34996 L
.4522 .34996 L
.4522 .34996 L
.4522 .34996 L
.4522 .34996 L
.4522 .34996 L
.45219 .34996 L
.45219 .34996 L
.45219 .34996 L
.45219 .34996 L
.45219 .34996 L
.45218 .34996 L
.45218 .34996 L
.45218 .34996 L
.45218 .34996 L
.45218 .34996 L
.45217 .34995 L
.45217 .34995 L
.45217 .34995 L
.45217 .34995 L
.45217 .34995 L
.45216 .34995 L
.45216 .34995 L
.45216 .34995 L
.45216 .34995 L
.45216 .34995 L
.45216 .34995 L
.45215 .34995 L
.45215 .34995 L
.45215 .34995 L
.45215 .34995 L
.45215 .34995 L
.45214 .34995 L
Mistroke
.45214 .34995 L
.45214 .34995 L
.45214 .34995 L
.45214 .34995 L
.45213 .34995 L
.45213 .34995 L
.45213 .34995 L
.45213 .34995 L
.45213 .34995 L
.45213 .34995 L
.45212 .34995 L
.45212 .34995 L
.45212 .34995 L
.45212 .34995 L
.45212 .34995 L
.45211 .34995 L
.45211 .34995 L
.45211 .34995 L
.45211 .34995 L
.45211 .34995 L
.4521 .34995 L
.4521 .34995 L
.4521 .34995 L
.4521 .34995 L
.4521 .34995 L
.4521 .34995 L
.45209 .34995 L
.45209 .34995 L
.45209 .34995 L
.45209 .34995 L
.45209 .34995 L
.45208 .34995 L
.45208 .34995 L
.45208 .34995 L
.45208 .34995 L
.45208 .34995 L
.45208 .34995 L
.45207 .34995 L
.45207 .34995 L
.45207 .34995 L
.45207 .34995 L
.45207 .34995 L
.45206 .34995 L
.45206 .34995 L
.45206 .34995 L
.45206 .34995 L
.45206 .34995 L
.45206 .34995 L
.45205 .34995 L
.45205 .34995 L
Mistroke
.45205 .34995 L
.45205 .34995 L
.45205 .34995 L
.45205 .34995 L
.45204 .34995 L
.45204 .34995 L
.45204 .34995 L
.45204 .34995 L
.45204 .34995 L
.45203 .34995 L
.45203 .34995 L
.45203 .34995 L
.45203 .34995 L
.45203 .34995 L
.45203 .34995 L
.45202 .34995 L
.45202 .34995 L
.45202 .34995 L
.45202 .34995 L
.45202 .34995 L
.45202 .34995 L
.45201 .34995 L
.45201 .34995 L
.45201 .34995 L
.45201 .34995 L
.45201 .34994 L
.452 .34994 L
.452 .34994 L
.452 .34994 L
.452 .34994 L
.452 .34994 L
.452 .34994 L
.45199 .34994 L
.45199 .34994 L
.45199 .34994 L
.45199 .34994 L
.45199 .34994 L
.45199 .34994 L
.45198 .34994 L
.45198 .34994 L
.45198 .34994 L
.45198 .34994 L
.45198 .34994 L
.45198 .34994 L
.45197 .34994 L
.45197 .34994 L
.45197 .34994 L
.45197 .34994 L
.45197 .34994 L
.45197 .34994 L
Mistroke
.45196 .34994 L
.45196 .34994 L
.45196 .34994 L
.45196 .34994 L
.45196 .34994 L
.45196 .34994 L
.45195 .34994 L
.45195 .34994 L
.45195 .34994 L
.45195 .34994 L
.45195 .34994 L
.45195 .34994 L
.45194 .34994 L
.45194 .34994 L
.45194 .34994 L
.45194 .34994 L
.45194 .34994 L
.45194 .34994 L
.45193 .34994 L
.45193 .34994 L
.45193 .34993 L
.45193 .34993 L
.45193 .34993 L
.45193 .34993 L
.45192 .34993 L
.45192 .34993 L
.45192 .34993 L
.45192 .34993 L
.45192 .34993 L
.45192 .34993 L
.45191 .34993 L
.45191 .34993 L
.45191 .34993 L
.45191 .34993 L
.45191 .34993 L
.45191 .34993 L
.4519 .34993 L
.4519 .34993 L
.4519 .34993 L
.4519 .34993 L
.4519 .34993 L
.4519 .34993 L
.45189 .34993 L
.45189 .34993 L
.45189 .34993 L
.45189 .34993 L
.45189 .34993 L
.45189 .34993 L
.45189 .34993 L
.45188 .34993 L
Mistroke
.45188 .34993 L
.45188 .34993 L
.45188 .34993 L
.45188 .34993 L
.45188 .34992 L
.45187 .34992 L
.45187 .34992 L
.45187 .34992 L
.45187 .34992 L
.45187 .34992 L
.45187 .34992 L
.45186 .34992 L
.45186 .34992 L
.45186 .34992 L
.45186 .34992 L
.45186 .34992 L
.45186 .34992 L
.45186 .34992 L
.45185 .34992 L
.45185 .34992 L
.45185 .34992 L
.45185 .34992 L
.45185 .34992 L
.45185 .34992 L
.45184 .34992 L
.45184 .34992 L
.45184 .34992 L
.45184 .34992 L
.45184 .34992 L
.45184 .34992 L
.45184 .34992 L
.45183 .34992 L
.45183 .34992 L
.45183 .34991 L
.45183 .34991 L
.45183 .34991 L
.45183 .34991 L
.45182 .34991 L
.45182 .34991 L
.45182 .34991 L
.45182 .34991 L
.45182 .34991 L
.45182 .34991 L
.45182 .34991 L
.45181 .34991 L
.45181 .34991 L
.45181 .34991 L
.45181 .34991 L
.45181 .34991 L
.45181 .34991 L
Mistroke
.45181 .34991 L
.4518 .34991 L
.4518 .34991 L
.4518 .34991 L
.4518 .34991 L
.4518 .34991 L
.4518 .34991 L
.45179 .34991 L
.45179 .34991 L
.45179 .34991 L
.45179 .3499 L
.45179 .3499 L
.45179 .3499 L
.45179 .3499 L
.45178 .3499 L
.45178 .3499 L
.45178 .3499 L
.45178 .3499 L
.45178 .3499 L
.45178 .3499 L
.45178 .3499 L
.45177 .3499 L
.45177 .3499 L
.45177 .3499 L
.45177 .3499 L
.45177 .3499 L
.45177 .3499 L
.45177 .3499 L
.45176 .3499 L
.45176 .3499 L
.45176 .3499 L
.45176 .3499 L
.45176 .3499 L
.45176 .3499 L
.45176 .34989 L
.45175 .34989 L
.45175 .34989 L
.45175 .34989 L
.45175 .34989 L
.45175 .34989 L
.45175 .34989 L
.45175 .34989 L
.45174 .34989 L
.45174 .34989 L
.45174 .34989 L
.45174 .34989 L
.45174 .34989 L
.45174 .34989 L
.45174 .34989 L
.45173 .34989 L
Mistroke
.45173 .34989 L
.45173 .34989 L
.45173 .34989 L
.45173 .34989 L
.45173 .34989 L
.45173 .34989 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45172 .34988 L
.45171 .34988 L
.45171 .34988 L
.45171 .34988 L
.45171 .34988 L
.45171 .34988 L
.45171 .34988 L
.45171 .34988 L
.4517 .34988 L
.4517 .34988 L
.4517 .34988 L
.4517 .34988 L
.4517 .34988 L
.4517 .34988 L
.4517 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45169 .34987 L
.45168 .34987 L
.45168 .34987 L
.45168 .34987 L
.45168 .34987 L
.45168 .34987 L
.45168 .34987 L
.45168 .34987 L
.45167 .34987 L
.45167 .34987 L
.45167 .34987 L
.45167 .34986 L
.45167 .34986 L
.45167 .34986 L
.45167 .34986 L
Mistroke
.45167 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45166 .34986 L
.45165 .34986 L
.45165 .34986 L
.45165 .34986 L
.45165 .34986 L
.45165 .34986 L
.45165 .34986 L
.45165 .34985 L
.45165 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45164 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45163 .34985 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45162 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.45161 .34984 L
.4516 .34984 L
Mistroke
.4516 .34984 L
.4516 .34983 L
.4516 .34983 L
.4516 .34983 L
.4516 .34983 L
.4516 .34983 L
.4516 .34983 L
.4516 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45159 .34983 L
.45158 .34983 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45158 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45157 .34982 L
.45156 .34982 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45156 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .34981 L
.45155 .3498 L
Mistroke
.45155 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45154 .3498 L
.45153 .3498 L
.45153 .3498 L
.45153 .3498 L
.45153 .3498 L
.45153 .3498 L
.45153 .34979 L
.45153 .34979 L
.45153 .34979 L
.45153 .34979 L
.45153 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45152 .34979 L
.45151 .34979 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.45151 .34978 L
.4515 .34978 L
.4515 .34978 L
.4515 .34978 L
.4515 .34978 L
.4515 .34978 L
.4515 .34978 L
.4515 .34977 L
.4515 .34977 L
.4515 .34977 L
.45149 .34977 L
.45149 .34977 L
Mistroke
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45149 .34977 L
.45148 .34977 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45148 .34976 L
.45147 .34976 L
.45147 .34976 L
.45147 .34976 L
.45147 .34976 L
.45147 .34976 L
.45147 .34975 L
.45147 .34975 L
.45147 .34975 L
.45147 .34975 L
.45147 .34975 L
.45147 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34975 L
.45146 .34974 L
.45146 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
.45145 .34974 L
Mistroke
.45144 .34974 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45144 .34973 L
.45143 .34973 L
.45143 .34973 L
.45143 .34973 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45143 .34972 L
.45142 .34972 L
.45142 .34972 L
.45142 .34972 L
.45142 .34972 L
.45142 .34972 L
.45142 .34971 L
.45142 .34971 L
.45142 .34971 L
.45142 .34971 L
.45142 .34971 L
.45142 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .34971 L
.45141 .3497 L
.45141 .3497 L
.45141 .3497 L
.45141 .3497 L
.45141 .3497 L
.4514 .3497 L
.4514 .3497 L
.4514 .3497 L
.4514 .3497 L
.4514 .3497 L
Mistroke
.4514 .3497 L
.4514 .3497 L
.4514 .3497 L
.4514 .34969 L
.4514 .34969 L
.4514 .34969 L
.4514 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34969 L
.45139 .34968 L
.45139 .34968 L
.45139 .34968 L
.45139 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34968 L
.45138 .34967 L
.45138 .34967 L
.45138 .34967 L
.45138 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34967 L
.45137 .34966 L
.45137 .34966 L
.45137 .34966 L
.45137 .34966 L
.45137 .34966 L
.45136 .34966 L
.45136 .34966 L
.45136 .34966 L
.45136 .34966 L
.45136 .34966 L
Mistroke
.45136 .34966 L
.45136 .34966 L
.45136 .34966 L
.45136 .34965 L
.45136 .34965 L
.45136 .34965 L
.45136 .34965 L
.45136 .34965 L
.45136 .34965 L
.45135 .34965 L
.45135 .34965 L
.45135 .34965 L
.45135 .34965 L
.45135 .34965 L
.45135 .34965 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45135 .34964 L
.45134 .34964 L
.45134 .34964 L
.45134 .34964 L
.45134 .34964 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45134 .34963 L
.45133 .34963 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
.45133 .34962 L
Mistroke
.45133 .34961 L
.45133 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .34961 L
.45132 .3496 L
.45132 .3496 L
.45132 .3496 L
.45132 .3496 L
.45132 .3496 L
.45132 .3496 L
.45131 .3496 L
.45131 .3496 L
.45131 .3496 L
.45131 .3496 L
.45131 .3496 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.45131 .34959 L
.4513 .34959 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34958 L
.4513 .34957 L
.4513 .34957 L
.4513 .34957 L
.4513 .34957 L
Mistroke
.4513 .34957 L
.45129 .34957 L
.45129 .34957 L
.45129 .34957 L
.45129 .34957 L
.45129 .34957 L
.45129 .34957 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34956 L
.45129 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34955 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45128 .34954 L
.45127 .34954 L
.45127 .34954 L
.45127 .34954 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
.45127 .34953 L
Mistroke
.45127 .34953 L
.45127 .34953 L
.45127 .34952 L
.45127 .34952 L
.45127 .34952 L
.45127 .34952 L
.45127 .34952 L
.45127 .34952 L
.45126 .34952 L
.45126 .34952 L
.45126 .34952 L
.45126 .34952 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .34951 L
.45126 .3495 L
.45126 .3495 L
.45126 .3495 L
.45126 .3495 L
.45126 .3495 L
.45126 .3495 L
.45125 .3495 L
.45125 .3495 L
.45125 .3495 L
.45125 .3495 L
.45125 .3495 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34949 L
.45125 .34948 L
.45125 .34948 L
.45125 .34948 L
.45125 .34948 L
.45125 .34948 L
Mistroke
.45125 .34948 L
.45125 .34948 L
.45125 .34948 L
.45124 .34948 L
.45124 .34948 L
.45124 .34948 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34947 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34946 L
.45124 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34945 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34944 L
.45123 .34943 L
.45123 .34943 L
Mistroke
.45123 .34943 L
.45123 .34943 L
.45123 .34943 L
.45123 .34943 L
.45123 .34943 L
.45123 .34943 L
.45123 .34943 L
.45122 .34943 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34942 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .34941 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .3494 L
.45122 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
.45121 .34939 L
Mistroke
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34938 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34937 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.45121 .34936 L
.4512 .34936 L
.4512 .34936 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34935 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
.4512 .34934 L
Mistroke
.4512 .34934 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34933 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34932 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.4512 .34931 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .3493 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
.45119 .34929 L
Mistroke
.45119 .34929 L
.45119 .34929 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34928 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34927 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34926 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34925 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
.45119 .34924 L
Mistroke
.45119 .34924 L
.45119 .34924 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34923 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34922 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .34921 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .3492 L
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
Mistroke
.45119 .34919 L
.45119 .34919 L
.45119 .34919 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34918 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34917 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34916 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34915 L
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
Mistroke
.45119 .34914 L
.45119 .34914 L
.45119 .34914 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34913 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34912 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .34911 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .3491 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
Mistroke
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34909 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34908 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34907 L
.45119 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34906 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34905 L
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
Mistroke
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
.4512 .34904 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34903 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34902 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.4512 .34901 L
.45121 .34901 L
.45121 .34901 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .349 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
Mistroke
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34899 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34898 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34897 L
.45121 .34896 L
.45121 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34896 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34895 L
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
Mistroke
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
.45122 .34894 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45122 .34893 L
.45123 .34893 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34892 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .34891 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .3489 L
.45123 .34889 L
Mistroke
.45123 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34889 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34888 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34887 L
.45124 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34886 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
Mistroke
.45125 .34885 L
.45125 .34885 L
.45125 .34885 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45125 .34884 L
.45126 .34884 L
.45126 .34884 L
.45126 .34884 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34883 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34882 L
.45126 .34881 L
.45126 .34881 L
.45126 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .34881 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
Mistroke
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .3488 L
.45127 .34879 L
.45127 .34879 L
.45127 .34879 L
.45127 .34879 L
.45127 .34879 L
.45127 .34879 L
.45127 .34879 L
.45128 .34879 L
.45128 .34879 L
.45128 .34879 L
.45128 .34879 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34878 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45128 .34877 L
.45129 .34877 L
.45129 .34877 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
.45129 .34876 L
Mistroke
.45129 .34876 L
.45129 .34876 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.45129 .34875 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34874 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.4513 .34873 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34872 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
Mistroke
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45131 .34871 L
.45132 .34871 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .3487 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45132 .34869 L
.45133 .34869 L
.45133 .34869 L
.45133 .34869 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34868 L
.45133 .34867 L
.45133 .34867 L
.45133 .34867 L
.45133 .34867 L
.45133 .34867 L
.45133 .34867 L
Mistroke
.45134 .34867 L
.45134 .34867 L
.45134 .34867 L
.45134 .34867 L
.45134 .34867 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34866 L
.45134 .34865 L
.45134 .34865 L
.45134 .34865 L
.45134 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34865 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45135 .34864 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
Mistroke
.45136 .34863 L
.45136 .34863 L
.45136 .34863 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45136 .34862 L
.45137 .34862 L
.45137 .34862 L
.45137 .34862 L
.45137 .34862 L
.45137 .34862 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .34861 L
.45137 .3486 L
.45137 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .3486 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45138 .34859 L
.45139 .34859 L
Mistroke
.45139 .34859 L
.45139 .34859 L
.45139 .34859 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34858 L
.45139 .34857 L
.45139 .34857 L
.45139 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34857 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.4514 .34856 L
.45141 .34856 L
.45141 .34856 L
.45141 .34856 L
.45141 .34856 L
.45141 .34856 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
Mistroke
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45141 .34855 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34854 L
.45142 .34853 L
.45142 .34853 L
.45142 .34853 L
.45142 .34853 L
.45142 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34853 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45143 .34852 L
.45144 .34852 L
.45144 .34852 L
.45144 .34852 L
.45144 .34852 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
Mistroke
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .34851 L
.45144 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .3485 L
.45145 .34849 L
.45145 .34849 L
.45145 .34849 L
.45145 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34849 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45146 .34848 L
.45147 .34848 L
.45147 .34848 L
.45147 .34848 L
.45147 .34848 L
.45147 .34848 L
.45147 .34848 L
.45147 .34847 L
.45147 .34847 L
Mistroke
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45147 .34847 L
.45148 .34847 L
.45148 .34847 L
.45148 .34847 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45148 .34846 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34845 L
.45149 .34844 L
.45149 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
Mistroke
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34844 L
.4515 .34843 L
.4515 .34843 L
.4515 .34843 L
.4515 .34843 L
.4515 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34843 L
.45151 .34842 L
.45151 .34842 L
.45151 .34842 L
.45151 .34842 L
.45151 .34842 L
.45151 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34842 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45152 .34841 L
.45153 .34841 L
.45153 .34841 L
.45153 .34841 L
.45153 .34841 L
.45153 .34841 L
.45153 .34841 L
.45153 .34841 L
Mistroke
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45153 .3484 L
.45154 .3484 L
.45154 .3484 L
.45154 .3484 L
.45154 .3484 L
.45154 .3484 L
.45154 .3484 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45154 .34839 L
.45155 .34839 L
.45155 .34839 L
.45155 .34839 L
.45155 .34839 L
.45155 .34839 L
.45155 .34839 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45155 .34838 L
.45156 .34838 L
.45156 .34838 L
.45156 .34838 L
.45156 .34838 L
.45156 .34838 L
.45156 .34838 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
Mistroke
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45156 .34837 L
.45157 .34837 L
.45157 .34837 L
.45157 .34837 L
.45157 .34837 L
.45157 .34837 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45157 .34836 L
.45158 .34836 L
.45158 .34836 L
.45158 .34836 L
.45158 .34836 L
.45158 .34836 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45158 .34835 L
.45159 .34835 L
.45159 .34835 L
.45159 .34835 L
.45159 .34835 L
.45159 .34835 L
.45159 .34835 L
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
Mistroke
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
.45159 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34834 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.4516 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34833 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45161 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34832 L
.45162 .34831 L
.45162 .34831 L
.45162 .34831 L
Mistroke
.45162 .34831 L
.45162 .34831 L
.45162 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .34831 L
.45163 .3483 L
.45163 .3483 L
.45163 .3483 L
.45163 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .3483 L
.45164 .34829 L
.45164 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
.45165 .34829 L
Mistroke
.45165 .34829 L
.45166 .34829 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45166 .34828 L
.45167 .34828 L
.45167 .34828 L
.45167 .34828 L
.45167 .34828 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45167 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34827 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45168 .34826 L
.45169 .34826 L
.45169 .34826 L
Mistroke
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34826 L
.45169 .34825 L
.45169 .34825 L
.45169 .34825 L
.45169 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.4517 .34825 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45171 .34824 L
.45172 .34824 L
.45172 .34824 L
.45172 .34824 L
.45172 .34824 L
Mistroke
.45172 .34824 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45172 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34823 L
.45173 .34822 L
.45173 .34822 L
.45173 .34822 L
.45173 .34822 L
.45173 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45174 .34822 L
.45175 .34822 L
.45175 .34822 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
Mistroke
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45175 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .34821 L
.45176 .3482 L
.45176 .3482 L
.45176 .3482 L
.45176 .3482 L
.45176 .3482 L
.45176 .3482 L
.45176 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45177 .3482 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
Mistroke
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45178 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34819 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.45179 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.4518 .34818 L
.45181 .34818 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
Mistroke
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45181 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34817 L
.45182 .34816 L
.45182 .34816 L
.45182 .34816 L
.45182 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45183 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34816 L
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
Mistroke
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
.45184 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45185 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34815 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45186 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
Mistroke
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45187 .34814 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45188 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34813 L
.45189 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
Mistroke
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.4519 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45191 .34812 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45192 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
Mistroke
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45193 .34811 L
.45194 .34811 L
.45194 .34811 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45194 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45195 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
.45196 .3481 L
Mistroke
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45196 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45197 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34809 L
.45198 .34808 L
.45198 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
Mistroke
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.45199 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.452 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34808 L
.45201 .34807 L
.45201 .34807 L
.45201 .34807 L
.45201 .34807 L
.45201 .34807 L
Mistroke
.45201 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45202 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45203 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
Mistroke
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34807 L
.45204 .34806 L
.45204 .34806 L
.45204 .34806 L
.45204 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45205 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45206 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
Mistroke
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45207 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34806 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45208 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
Mistroke
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.45209 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.4521 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
.45211 .34805 L
Mistroke
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45212 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34805 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45213 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
Mistroke
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45214 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45215 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
Mistroke
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45216 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45217 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
Mistroke
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45218 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.45219 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
Mistroke
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.4522 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45221 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
Mistroke
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45222 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45223 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
Mistroke
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45224 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45225 .34804 L
.45226 .34804 L
.45226 .34804 L
Mistroke
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34804 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45226 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
Mistroke
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45227 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45228 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
Mistroke
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.45229 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34805 L
.4523 .34806 L
Mistroke
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.4523 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
.45231 .34806 L
Mistroke
.45231 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34806 L
.45232 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
Mistroke
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45233 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
Mistroke
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34807 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45234 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
Mistroke
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45235 .34808 L
.45236 .34808 L
.45236 .34808 L
.45236 .34808 L
.45236 .34808 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
Mistroke
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45236 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
.45237 .34809 L
Mistroke
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
Mistroke
.45237 .3481 L
.45237 .3481 L
.45237 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .3481 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
Mistroke
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34811 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45238 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
Mistroke
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34812 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
Mistroke
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34813 L
.45239 .34814 L
.45239 .34814 L
.45239 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
Mistroke
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34814 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
Mistroke
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34815 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
Mistroke
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34816 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.4524 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
Mistroke
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34817 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
Mistroke
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34818 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
Mistroke
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .34819 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
Mistroke
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .3482 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
Mistroke
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34821 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
Mistroke
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.45241 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34822 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
Mistroke
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34823 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
Mistroke
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34824 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
Mistroke
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34825 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
Mistroke
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.4524 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34826 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
Mistroke
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34827 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
Mistroke
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34828 L
.45239 .34829 L
.45239 .34829 L
.45239 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
Mistroke
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .34829 L
.45238 .3483 L
Mistroke
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
.45238 .3483 L
Mistroke
.45238 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .3483 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
Mistroke
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34831 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45237 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
Mistroke
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34832 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
Mistroke
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45236 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34833 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
Mistroke
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
Mistroke
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34834 L
.45235 .34835 L
.45235 .34835 L
.45235 .34835 L
.45235 .34835 L
.45235 .34835 L
.45235 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
Mistroke
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34835 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
.45234 .34836 L
Mistroke
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
Mistroke
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34836 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45233 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
Mistroke
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34837 L
.45232 .34838 L
.45232 .34838 L
Mistroke
.45232 .34838 L
.45232 .34838 L
.45232 .34838 L
.45232 .34838 L
.45232 .34838 L
.45232 .34838 L
.45232 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
Mistroke
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.45231 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34838 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
Mistroke
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
Mistroke
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.4523 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .34839 L
.45229 .3484 L
.45229 .3484 L
Mistroke
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45229 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
Mistroke
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
Mistroke
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45228 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .3484 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
Mistroke
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
.45227 .34841 L
Mistroke
.45227 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
Mistroke
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34841 L
.45226 .34842 L
.45226 .34842 L
.45226 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
Mistroke
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
Mistroke
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45225 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
Mistroke
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
Mistroke
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45224 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
Mistroke
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34842 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
Mistroke
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45223 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
Mistroke
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
Mistroke
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45222 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
Mistroke
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
Mistroke
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.45221 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
.4522 .34843 L
Mistroke
.4522 .34843 L
.4522 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
Mistroke
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
Mistroke
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45219 .34843 L
.45218 .34843 L
Mistroke
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
Mistroke
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
.45218 .34843 L
Mistroke
.45218 .34843 L
.45218 .34843 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
Mistroke
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45218 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
Mistroke
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45217 .34842 L
.45216 .34842 L
.45216 .34842 L
.45216 .34842 L
.45216 .34842 L
.45216 .34842 L
.45216 .34842 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
Mistroke
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .34841 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
Mistroke
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .3484 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
Mistroke
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34839 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
Mistroke
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45216 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34838 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
Mistroke
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34837 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
Mistroke
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
Mistroke
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45217 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
Mistroke
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34836 L
.45218 .34835 L
.45218 .34835 L
Mistroke
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45218 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
Mistroke
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.45219 .34835 L
.4522 .34835 L
.4522 .34835 L
Mistroke
.4522 .34835 L
Mfstroke
.158 1 0 r
.59647 .07527 m
.59676 .0753 L
.59706 .07534 L
.59735 .07538 L
.59764 .07542 L
.59794 .07545 L
.59823 .07549 L
.59853 .07553 L
.59882 .07557 L
.59911 .07561 L
.59941 .07564 L
.5997 .07568 L
.59999 .07572 L
.60028 .07576 L
.60058 .0758 L
.60087 .07584 L
.60116 .07588 L
.60145 .07591 L
.60175 .07595 L
.60204 .07599 L
.60233 .07603 L
.60262 .07607 L
.60291 .07611 L
.6032 .07615 L
.6035 .07619 L
.60379 .07623 L
.60408 .07627 L
.60437 .07631 L
.60466 .07635 L
.60495 .07639 L
.60524 .07643 L
.60553 .07647 L
.60582 .07651 L
.60611 .07655 L
.6064 .07659 L
.60669 .07663 L
.60698 .07667 L
.60727 .07671 L
.60756 .07675 L
.60785 .07679 L
.60814 .07684 L
.60843 .07688 L
.60871 .07692 L
.609 .07696 L
.60929 .077 L
.60958 .07704 L
.60987 .07708 L
.61016 .07713 L
.61044 .07717 L
.61073 .07721 L
Mistroke
.61102 .07725 L
.61131 .07729 L
.61159 .07734 L
.61188 .07738 L
.61217 .07742 L
.61245 .07746 L
.61274 .0775 L
.61303 .07755 L
.61331 .07759 L
.6136 .07763 L
.61389 .07768 L
.61417 .07772 L
.61446 .07776 L
.61474 .07781 L
.61503 .07785 L
.61531 .07789 L
.6156 .07794 L
.61588 .07798 L
.61617 .07802 L
.61645 .07807 L
.61674 .07811 L
.61702 .07815 L
.61731 .0782 L
.61759 .07824 L
.61787 .07829 L
.61816 .07833 L
.61844 .07838 L
.61873 .07842 L
.61901 .07846 L
.61929 .07851 L
.61958 .07855 L
.61986 .0786 L
.62014 .07864 L
.62042 .07869 L
.62071 .07873 L
.62099 .07878 L
.62127 .07882 L
.62155 .07887 L
.62183 .07892 L
.62212 .07896 L
.6224 .07901 L
.62268 .07905 L
.62296 .0791 L
.62324 .07915 L
.62352 .07919 L
.6238 .07924 L
.62408 .07928 L
.62436 .07933 L
.62464 .07938 L
.62492 .07942 L
Mistroke
.6252 .07947 L
.62548 .07952 L
.62576 .07956 L
.62604 .07961 L
.62632 .07966 L
.6266 .07971 L
.62688 .07975 L
.62716 .0798 L
.62744 .07985 L
.62772 .0799 L
.628 .07994 L
.62827 .07999 L
.62855 .08004 L
.62883 .08009 L
.62911 .08013 L
.62939 .08018 L
.62966 .08023 L
.62994 .08028 L
.63022 .08033 L
.6305 .08038 L
.63077 .08043 L
.63105 .08047 L
.63133 .08052 L
.6316 .08057 L
.63188 .08062 L
.63215 .08067 L
.63243 .08072 L
.63271 .08077 L
.63298 .08082 L
.63326 .08087 L
.63353 .08092 L
.63381 .08097 L
.63408 .08102 L
.63436 .08107 L
.63463 .08112 L
.63491 .08117 L
.63518 .08122 L
.63545 .08127 L
.63573 .08132 L
.636 .08137 L
.63628 .08142 L
.63655 .08147 L
.63682 .08152 L
.6371 .08157 L
.63737 .08162 L
.63764 .08168 L
.63791 .08173 L
.63819 .08178 L
.63846 .08183 L
.63873 .08188 L
Mistroke
.639 .08193 L
.63928 .08198 L
.63955 .08204 L
.63982 .08209 L
.64009 .08214 L
.64036 .08219 L
.64063 .08224 L
.6409 .0823 L
.64117 .08235 L
.64144 .0824 L
.64172 .08245 L
.64199 .08251 L
.64226 .08256 L
.64253 .08261 L
.6428 .08267 L
.64306 .08272 L
.64333 .08277 L
.6436 .08283 L
.64387 .08288 L
.64414 .08293 L
.64441 .08299 L
.64468 .08304 L
.64495 .08309 L
.64521 .08315 L
.64548 .0832 L
.64575 .08326 L
.64602 .08331 L
.64629 .08337 L
.64655 .08342 L
.64682 .08348 L
.64709 .08353 L
.64735 .08358 L
.64762 .08364 L
.64789 .08369 L
.64815 .08375 L
.64842 .08381 L
.64869 .08386 L
.64895 .08392 L
.64922 .08397 L
.64948 .08403 L
.64975 .08408 L
.65001 .08414 L
.65028 .08419 L
.65054 .08425 L
.65081 .08431 L
.65107 .08436 L
.65134 .08442 L
.6516 .08448 L
.65186 .08453 L
.65213 .08459 L
Mistroke
.65239 .08465 L
.65266 .0847 L
.65292 .08476 L
.65318 .08482 L
.65344 .08487 L
.65371 .08493 L
.65397 .08499 L
.65423 .08505 L
.65449 .0851 L
.65476 .08516 L
.65502 .08522 L
.65528 .08528 L
.65554 .08534 L
.6558 .08539 L
.65606 .08545 L
.65632 .08551 L
.65658 .08557 L
.65685 .08563 L
.65711 .08569 L
.65737 .08575 L
.65763 .0858 L
.65789 .08586 L
.65815 .08592 L
.6584 .08598 L
.65866 .08604 L
.65892 .0861 L
.65918 .08616 L
.65944 .08622 L
.6597 .08628 L
.65996 .08634 L
.66022 .0864 L
.66047 .08646 L
.66073 .08652 L
.66099 .08658 L
.66125 .08664 L
.6615 .0867 L
.66176 .08676 L
.66202 .08682 L
.66228 .08688 L
.66253 .08694 L
.66279 .08701 L
.66304 .08707 L
.6633 .08713 L
.66356 .08719 L
.66381 .08725 L
.66407 .08731 L
.66432 .08737 L
.66458 .08744 L
.66483 .0875 L
.66509 .08756 L
Mistroke
.66534 .08762 L
.6656 .08768 L
.66585 .08775 L
.6661 .08781 L
.66636 .08787 L
.66661 .08793 L
.66687 .088 L
.66712 .08806 L
.66737 .08812 L
.66762 .08819 L
.66788 .08825 L
.66813 .08831 L
.66838 .08838 L
.66863 .08844 L
.66889 .0885 L
.66914 .08857 L
.66939 .08863 L
.66964 .0887 L
.66989 .08876 L
.67014 .08882 L
.67039 .08889 L
.67064 .08895 L
.6709 .08902 L
.67115 .08908 L
.6714 .08915 L
.67165 .08921 L
.67189 .08928 L
.67214 .08934 L
.67239 .08941 L
.67264 .08947 L
.67289 .08954 L
.67314 .0896 L
.67339 .08967 L
.67364 .08974 L
.67389 .0898 L
.67413 .08987 L
.67438 .08993 L
.67463 .09 L
.67488 .09007 L
.67512 .09013 L
.67537 .0902 L
.67562 .09027 L
.67586 .09033 L
.67611 .0904 L
.67636 .09047 L
.6766 .09053 L
.67685 .0906 L
.67709 .09067 L
.67734 .09074 L
.67758 .0908 L
Mistroke
.67783 .09087 L
.67807 .09094 L
.67832 .09101 L
.67856 .09108 L
.67881 .09114 L
.67905 .09121 L
.67929 .09128 L
.67954 .09135 L
.67978 .09142 L
.68002 .09149 L
.68027 .09155 L
.68051 .09162 L
.68075 .09169 L
.681 .09176 L
.68124 .09183 L
.68148 .0919 L
.68172 .09197 L
.68196 .09204 L
.6822 .09211 L
.68245 .09218 L
.68269 .09225 L
.68293 .09232 L
.68317 .09239 L
.68341 .09246 L
.68365 .09253 L
.68389 .0926 L
.68413 .09267 L
.68437 .09274 L
.68461 .09281 L
.68485 .09289 L
.68509 .09296 L
.68532 .09303 L
.68556 .0931 L
.6858 .09317 L
.68604 .09324 L
.68628 .09331 L
.68651 .09339 L
.68675 .09346 L
.68699 .09353 L
.68723 .0936 L
.68746 .09367 L
.6877 .09375 L
.68794 .09382 L
.68817 .09389 L
.68841 .09397 L
.68864 .09404 L
.68888 .09411 L
.68912 .09418 L
.68935 .09426 L
.68959 .09433 L
Mistroke
.68982 .0944 L
.69006 .09448 L
.69029 .09455 L
.69052 .09463 L
.69076 .0947 L
.69099 .09477 L
.69123 .09485 L
.69146 .09492 L
.69169 .095 L
.69193 .09507 L
.69216 .09515 L
.69239 .09522 L
.69262 .0953 L
.69285 .09537 L
.69309 .09545 L
.69332 .09552 L
.69355 .0956 L
.69378 .09567 L
.69401 .09575 L
.69424 .09582 L
.69447 .0959 L
.6947 .09598 L
.69493 .09605 L
.69516 .09613 L
.69539 .09621 L
.69562 .09628 L
.69585 .09636 L
.69608 .09644 L
.69631 .09651 L
.69654 .09659 L
.69677 .09667 L
.697 .09674 L
.69722 .09682 L
.69745 .0969 L
.69768 .09698 L
.69791 .09705 L
.69813 .09713 L
.69836 .09721 L
.69859 .09729 L
.69881 .09737 L
.69904 .09744 L
.69927 .09752 L
.69949 .0976 L
.69972 .09768 L
.69994 .09776 L
.70017 .09784 L
.70039 .09792 L
.70062 .098 L
.70084 .09808 L
.70107 .09816 L
Mistroke
.70129 .09823 L
.70151 .09831 L
.70174 .09839 L
.70196 .09847 L
.70219 .09855 L
.70241 .09863 L
.70263 .09872 L
.70285 .0988 L
.70308 .09888 L
.7033 .09896 L
.70352 .09904 L
.70374 .09912 L
.70396 .0992 L
.70418 .09928 L
.7044 .09936 L
.70463 .09944 L
.70485 .09953 L
.70507 .09961 L
.70529 .09969 L
.70551 .09977 L
.70573 .09985 L
.70594 .09994 L
.70616 .10002 L
.70638 .1001 L
.7066 .10018 L
.70682 .10027 L
.70704 .10035 L
.70726 .10043 L
.70747 .10051 L
.70769 .1006 L
.70791 .10068 L
.70813 .10076 L
.70834 .10085 L
.70856 .10093 L
.70878 .10102 L
.70899 .1011 L
.70921 .10118 L
.70942 .10127 L
.70964 .10135 L
.70985 .10144 L
.71007 .10152 L
.71028 .10161 L
.7105 .10169 L
.71071 .10178 L
.71093 .10186 L
.71114 .10195 L
.71135 .10203 L
.71157 .10212 L
.71178 .1022 L
.71199 .10229 L
Mistroke
.71221 .10237 L
.71242 .10246 L
.71263 .10255 L
.71284 .10263 L
.71305 .10272 L
.71327 .10281 L
.71348 .10289 L
.71369 .10298 L
.7139 .10307 L
.71411 .10315 L
.71432 .10324 L
.71453 .10333 L
.71474 .10342 L
.71495 .1035 L
.71516 .10359 L
.71537 .10368 L
.71558 .10377 L
.71579 .10385 L
.71599 .10394 L
.7162 .10403 L
.71641 .10412 L
.71662 .10421 L
.71683 .1043 L
.71703 .10439 L
.71724 .10448 L
.71745 .10456 L
.71765 .10465 L
.71786 .10474 L
.71806 .10483 L
.71827 .10492 L
.71848 .10501 L
.71868 .1051 L
.71889 .10519 L
.71909 .10528 L
.7193 .10537 L
.7195 .10546 L
.7197 .10555 L
.71991 .10564 L
.72011 .10574 L
.72031 .10583 L
.72052 .10592 L
.72072 .10601 L
.72092 .1061 L
.72113 .10619 L
.72133 .10628 L
.72153 .10638 L
.72173 .10647 L
.72193 .10656 L
.72213 .10665 L
.72233 .10674 L
Mistroke
.72253 .10684 L
.72274 .10693 L
.72294 .10702 L
.72314 .10711 L
.72333 .10721 L
.72353 .1073 L
.72373 .10739 L
.72393 .10749 L
.72413 .10758 L
.72433 .10767 L
.72453 .10777 L
.72473 .10786 L
.72492 .10796 L
.72512 .10805 L
.72532 .10815 L
.72551 .10824 L
.72571 .10833 L
.72591 .10843 L
.7261 .10852 L
.7263 .10862 L
.72649 .10871 L
.72669 .10881 L
.72688 .10891 L
.72708 .109 L
.72727 .1091 L
.72747 .10919 L
.72766 .10929 L
.72786 .10938 L
.72805 .10948 L
.72824 .10958 L
.72844 .10967 L
.72863 .10977 L
.72882 .10987 L
.72901 .10996 L
.72921 .11006 L
.7294 .11016 L
.72959 .11026 L
.72978 .11035 L
.72997 .11045 L
.73016 .11055 L
.73035 .11065 L
.73054 .11075 L
.73073 .11084 L
.73092 .11094 L
.73111 .11104 L
.7313 .11114 L
.73149 .11124 L
.73168 .11134 L
.73187 .11144 L
.73206 .11154 L
Mistroke
.73224 .11163 L
.73243 .11173 L
.73262 .11183 L
.7328 .11193 L
.73299 .11203 L
.73318 .11213 L
.73336 .11223 L
.73355 .11233 L
.73374 .11243 L
.73392 .11253 L
.73411 .11264 L
.73429 .11274 L
.73448 .11284 L
.73466 .11294 L
.73485 .11304 L
.73503 .11314 L
.73521 .11324 L
.7354 .11334 L
.73558 .11345 L
.73576 .11355 L
.73594 .11365 L
.73613 .11375 L
.73631 .11386 L
.73649 .11396 L
.73667 .11406 L
.73685 .11416 L
.73703 .11427 L
.73722 .11437 L
.7374 .11447 L
.73758 .11458 L
.73776 .11468 L
.73794 .11478 L
.73811 .11489 L
.73829 .11499 L
.73847 .1151 L
.73865 .1152 L
.73883 .1153 L
.73901 .11541 L
.73918 .11551 L
.73936 .11562 L
.73954 .11572 L
.73972 .11583 L
.73989 .11593 L
.74007 .11604 L
.74025 .11615 L
.74042 .11625 L
.7406 .11636 L
.74077 .11646 L
.74095 .11657 L
.74112 .11668 L
Mistroke
.7413 .11678 L
.74147 .11689 L
.74164 .117 L
.74182 .1171 L
.74199 .11721 L
.74216 .11732 L
.74234 .11742 L
.74251 .11753 L
.74268 .11764 L
.74285 .11775 L
.74303 .11785 L
.7432 .11796 L
.74337 .11807 L
.74354 .11818 L
.74371 .11829 L
.74388 .1184 L
.74405 .11851 L
.74422 .11861 L
.74439 .11872 L
.74456 .11883 L
.74473 .11894 L
.74489 .11905 L
.74506 .11916 L
.74523 .11927 L
.7454 .11938 L
.74557 .11949 L
.74573 .1196 L
.7459 .11971 L
.74607 .11982 L
.74623 .11993 L
.7464 .12004 L
.74656 .12015 L
.74673 .12027 L
.7469 .12038 L
.74706 .12049 L
.74722 .1206 L
.74739 .12071 L
.74755 .12082 L
.74772 .12094 L
.74788 .12105 L
.74804 .12116 L
.74821 .12127 L
.74837 .12139 L
.74853 .1215 L
.74869 .12161 L
.74886 .12172 L
.74902 .12184 L
.74918 .12195 L
.74934 .12206 L
.7495 .12218 L
Mistroke
.74966 .12229 L
.74982 .12241 L
.74998 .12252 L
.75014 .12263 L
.7503 .12275 L
.75046 .12286 L
.75061 .12298 L
.75077 .12309 L
.75093 .12321 L
.75109 .12332 L
.75125 .12344 L
.7514 .12355 L
.75156 .12367 L
.75172 .12379 L
.75187 .1239 L
.75203 .12402 L
.75218 .12413 L
.75234 .12425 L
.75249 .12437 L
.75265 .12448 L
.7528 .1246 L
.75296 .12472 L
.75311 .12484 L
.75326 .12495 L
.75342 .12507 L
.75357 .12519 L
.75372 .12531 L
.75388 .12542 L
.75403 .12554 L
.75418 .12566 L
.75433 .12578 L
.75448 .1259 L
.75463 .12602 L
.75478 .12613 L
.75493 .12625 L
.75508 .12637 L
.75523 .12649 L
.75538 .12661 L
.75553 .12673 L
.75568 .12685 L
.75583 .12697 L
.75598 .12709 L
.75613 .12721 L
.75627 .12733 L
.75642 .12745 L
.75657 .12757 L
.75671 .12769 L
.75686 .12781 L
.75701 .12794 L
.75715 .12806 L
Mistroke
.7573 .12818 L
.75744 .1283 L
.75759 .12842 L
.75773 .12854 L
.75788 .12867 L
.75802 .12879 L
.75816 .12891 L
.75831 .12903 L
.75845 .12916 L
.75859 .12928 L
.75873 .1294 L
.75888 .12953 L
.75902 .12965 L
.75916 .12977 L
.7593 .1299 L
.75944 .13002 L
.75958 .13014 L
.75972 .13027 L
.75986 .13039 L
.76 .13052 L
.76014 .13064 L
.76028 .13077 L
.76042 .13089 L
.76056 .13102 L
.76069 .13114 L
.76083 .13127 L
.76097 .13139 L
.76111 .13152 L
.76124 .13164 L
.76138 .13177 L
.76152 .1319 L
.76165 .13202 L
.76179 .13215 L
.76192 .13228 L
.76206 .1324 L
.76219 .13253 L
.76233 .13266 L
.76246 .13278 L
.76259 .13291 L
.76273 .13304 L
.76286 .13317 L
.76299 .13329 L
.76313 .13342 L
.76326 .13355 L
.76339 .13368 L
.76352 .13381 L
.76365 .13394 L
.76378 .13407 L
.76391 .13419 L
.76404 .13432 L
Mistroke
.76417 .13445 L
.7643 .13458 L
.76443 .13471 L
.76456 .13484 L
.76469 .13497 L
.76482 .1351 L
.76495 .13523 L
.76507 .13536 L
.7652 .13549 L
.76533 .13562 L
.76545 .13576 L
.76558 .13589 L
.76571 .13602 L
.76583 .13615 L
.76596 .13628 L
.76608 .13641 L
.76621 .13655 L
.76633 .13668 L
.76646 .13681 L
.76658 .13694 L
.7667 .13707 L
.76683 .13721 L
.76695 .13734 L
.76707 .13747 L
.76719 .13761 L
.76731 .13774 L
.76744 .13787 L
.76756 .13801 L
.76768 .13814 L
.7678 .13827 L
.76792 .13841 L
.76804 .13854 L
.76816 .13868 L
.76828 .13881 L
.7684 .13895 L
.76851 .13908 L
.76863 .13922 L
.76875 .13935 L
.76887 .13949 L
.76898 .13962 L
.7691 .13976 L
.76922 .1399 L
.76933 .14003 L
.76945 .14017 L
.76957 .14031 L
.76968 .14044 L
.7698 .14058 L
.76991 .14072 L
.77002 .14085 L
.77014 .14099 L
Mistroke
.77025 .14113 L
.77037 .14127 L
.77048 .1414 L
.77059 .14154 L
.7707 .14168 L
.77081 .14182 L
.77093 .14196 L
.77104 .14209 L
.77115 .14223 L
.77126 .14237 L
.77137 .14251 L
.77148 .14265 L
.77159 .14279 L
.7717 .14293 L
.77181 .14307 L
.77192 .14321 L
.77202 .14335 L
.77213 .14349 L
.77224 .14363 L
.77235 .14377 L
.77245 .14391 L
.77256 .14405 L
.77267 .14419 L
.77277 .14433 L
.77288 .14448 L
.77298 .14462 L
.77309 .14476 L
.77319 .1449 L
.7733 .14504 L
.7734 .14519 L
.7735 .14533 L
.77361 .14547 L
.77371 .14561 L
.77381 .14576 L
.77391 .1459 L
.77401 .14604 L
.77412 .14619 L
.77422 .14633 L
.77432 .14647 L
.77442 .14662 L
.77452 .14676 L
.77462 .14691 L
.77472 .14705 L
.77482 .14719 L
.77491 .14734 L
.77501 .14748 L
.77511 .14763 L
.77521 .14777 L
.77531 .14792 L
.7754 .14807 L
Mistroke
.7755 .14821 L
.7756 .14836 L
.77569 .1485 L
.77579 .14865 L
.77588 .1488 L
.77598 .14894 L
.77607 .14909 L
.77617 .14924 L
.77626 .14938 L
.77635 .14953 L
.77645 .14968 L
.77654 .14983 L
.77663 .14997 L
.77672 .15012 L
.77682 .15027 L
.77691 .15042 L
.777 .15057 L
.77709 .15072 L
.77718 .15086 L
.77727 .15101 L
.77736 .15116 L
.77745 .15131 L
.77754 .15146 L
.77762 .15161 L
.77771 .15176 L
.7778 .15191 L
.77789 .15206 L
.77798 .15221 L
.77806 .15236 L
.77815 .15251 L
.77823 .15266 L
.77832 .15281 L
.77841 .15296 L
.77849 .15312 L
.77858 .15327 L
.77866 .15342 L
.77874 .15357 L
.77883 .15372 L
.77891 .15387 L
.77899 .15403 L
.77908 .15418 L
.77916 .15433 L
.77924 .15449 L
.77932 .15464 L
.7794 .15479 L
.77948 .15494 L
.77956 .1551 L
.77964 .15525 L
.77972 .15541 L
.7798 .15556 L
Mistroke
.77988 .15571 L
.77996 .15587 L
.78004 .15602 L
.78012 .15618 L
.78019 .15633 L
.78027 .15649 L
.78035 .15664 L
.78042 .1568 L
.7805 .15695 L
.78058 .15711 L
.78065 .15727 L
.78073 .15742 L
.7808 .15758 L
.78088 .15773 L
.78095 .15789 L
.78102 .15805 L
.7811 .1582 L
.78117 .15836 L
.78124 .15852 L
.78131 .15868 L
.78138 .15883 L
.78146 .15899 L
.78153 .15915 L
.7816 .15931 L
.78167 .15947 L
.78174 .15962 L
.78181 .15978 L
.78188 .15994 L
.78195 .1601 L
.78201 .16026 L
.78208 .16042 L
.78215 .16058 L
.78222 .16074 L
.78228 .1609 L
.78235 .16106 L
.78242 .16122 L
.78248 .16138 L
.78255 .16154 L
.78261 .1617 L
.78268 .16186 L
.78274 .16202 L
.78281 .16218 L
.78287 .16234 L
.78293 .16251 L
.783 .16267 L
.78306 .16283 L
.78312 .16299 L
.78318 .16315 L
.78324 .16332 L
.78331 .16348 L
Mistroke
.78337 .16364 L
.78343 .1638 L
.78349 .16397 L
.78355 .16413 L
.78361 .16429 L
.78366 .16446 L
.78372 .16462 L
.78378 .16478 L
.78384 .16495 L
.7839 .16511 L
.78395 .16528 L
.78401 .16544 L
.78407 .16561 L
.78412 .16577 L
.78418 .16594 L
.78423 .1661 L
.78429 .16627 L
.78434 .16643 L
.7844 .1666 L
.78445 .16677 L
.7845 .16693 L
.78455 .1671 L
.78461 .16726 L
.78466 .16743 L
.78471 .1676 L
.78476 .16776 L
.78481 .16793 L
.78486 .1681 L
.78491 .16827 L
.78496 .16843 L
.78501 .1686 L
.78506 .16877 L
.78511 .16894 L
.78516 .16911 L
.78521 .16928 L
.78526 .16944 L
.7853 .16961 L
.78535 .16978 L
.7854 .16995 L
.78544 .17012 L
.78549 .17029 L
.78553 .17046 L
.78558 .17063 L
.78562 .1708 L
.78567 .17097 L
.78571 .17114 L
.78575 .17131 L
.7858 .17148 L
.78584 .17165 L
.78588 .17182 L
Mistroke
.78592 .172 L
.78596 .17217 L
.78601 .17234 L
.78605 .17251 L
.78609 .17268 L
.78613 .17286 L
.78617 .17303 L
.78621 .1732 L
.78624 .17337 L
.78628 .17355 L
.78632 .17372 L
.78636 .17389 L
.7864 .17407 L
.78643 .17424 L
.78647 .17441 L
.78651 .17459 L
.78654 .17476 L
.78658 .17493 L
.78661 .17511 L
.78665 .17528 L
.78668 .17546 L
.78671 .17563 L
.78675 .17581 L
.78678 .17598 L
.78681 .17616 L
.78685 .17633 L
.78688 .17651 L
.78691 .17669 L
.78694 .17686 L
.78697 .17704 L
.787 .17722 L
.78703 .17739 L
.78706 .17757 L
.78709 .17775 L
.78712 .17792 L
.78715 .1781 L
.78718 .17828 L
.7872 .17846 L
.78723 .17863 L
.78726 .17881 L
.78728 .17899 L
.78731 .17917 L
.78734 .17935 L
.78736 .17952 L
.78739 .1797 L
.78741 .17988 L
.78743 .18006 L
.78746 .18024 L
.78748 .18042 L
.7875 .1806 L
Mistroke
.78753 .18078 L
.78755 .18096 L
.78757 .18114 L
.78759 .18132 L
.78761 .1815 L
.78763 .18168 L
.78765 .18186 L
.78767 .18204 L
.78769 .18223 L
.78771 .18241 L
.78773 .18259 L
.78775 .18277 L
.78777 .18295 L
.78778 .18313 L
.7878 .18332 L
.78782 .1835 L
.78783 .18368 L
.78785 .18386 L
.78787 .18405 L
.78788 .18423 L
.7879 .18441 L
.78791 .1846 L
.78792 .18478 L
.78794 .18496 L
.78795 .18515 L
.78796 .18533 L
.78798 .18552 L
.78799 .1857 L
.788 .18589 L
.78801 .18607 L
.78802 .18626 L
.78803 .18644 L
.78804 .18663 L
.78805 .18681 L
.78806 .187 L
.78807 .18718 L
.78808 .18737 L
.78809 .18756 L
.78809 .18774 L
.7881 .18793 L
.78811 .18812 L
.78811 .1883 L
.78812 .18849 L
.78812 .18868 L
.78813 .18886 L
.78813 .18905 L
.78814 .18924 L
.78814 .18943 L
.78815 .18961 L
.78815 .1898 L
Mistroke
.78815 .18999 L
.78816 .19018 L
.78816 .19037 L
.78816 .19056 L
.78816 .19075 L
.78816 .19094 L
.78816 .19112 L
.78816 .19131 L
.78816 .1915 L
.78816 .19169 L
.78816 .19188 L
.78816 .19207 L
.78816 .19226 L
.78815 .19245 L
.78815 .19265 L
.78815 .19284 L
.78814 .19303 L
.78814 .19322 L
.78814 .19341 L
.78813 .1936 L
.78813 .19379 L
.78812 .19399 L
.78811 .19418 L
.78811 .19437 L
.7881 .19456 L
.78809 .19475 L
.78809 .19495 L
.78808 .19514 L
.78807 .19533 L
.78806 .19553 L
.78805 .19572 L
.78804 .19591 L
.78803 .19611 L
.78802 .1963 L
.78801 .19649 L
.788 .19669 L
.78799 .19688 L
.78798 .19708 L
.78796 .19727 L
.78795 .19747 L
.78794 .19766 L
.78792 .19786 L
.78791 .19805 L
.7879 .19825 L
.78788 .19844 L
.78787 .19864 L
.78785 .19884 L
.78783 .19903 L
.78782 .19923 L
.7878 .19942 L
Mistroke
.78778 .19962 L
.78777 .19982 L
.78775 .20001 L
.78773 .20021 L
.78771 .20041 L
.78769 .20061 L
.78767 .2008 L
.78765 .201 L
.78763 .2012 L
.78761 .2014 L
.78759 .2016 L
.78757 .20179 L
.78754 .20199 L
.78752 .20219 L
.7875 .20239 L
.78748 .20259 L
.78745 .20279 L
.78743 .20299 L
.7874 .20319 L
.78738 .20339 L
.78735 .20359 L
.78733 .20379 L
.7873 .20399 L
.78727 .20419 L
.78725 .20439 L
.78722 .20459 L
.78719 .20479 L
.78716 .20499 L
.78714 .20519 L
.78711 .20539 L
.78708 .2056 L
.78705 .2058 L
.78702 .206 L
.78699 .2062 L
.78696 .2064 L
.78692 .20661 L
.78689 .20681 L
.78686 .20701 L
.78683 .20721 L
.78679 .20742 L
.78676 .20762 L
.78673 .20782 L
.78669 .20803 L
.78666 .20823 L
.78662 .20843 L
.78659 .20864 L
.78655 .20884 L
.78651 .20905 L
.78648 .20925 L
.78644 .20945 L
Mistroke
.7864 .20966 L
.78637 .20986 L
.78633 .21007 L
.78629 .21027 L
.78625 .21048 L
.78621 .21068 L
.78617 .21089 L
.78613 .2111 L
.78609 .2113 L
.78605 .21151 L
.78601 .21171 L
.78596 .21192 L
.78592 .21213 L
.78588 .21233 L
.78584 .21254 L
.78579 .21275 L
.78575 .21295 L
.7857 .21316 L
.78566 .21337 L
.78561 .21358 L
.78557 .21378 L
.78552 .21399 L
.78547 .2142 L
.78543 .21441 L
.78538 .21462 L
.78533 .21483 L
.78528 .21503 L
.78524 .21524 L
.78519 .21545 L
.78514 .21566 L
.78509 .21587 L
.78504 .21608 L
.78499 .21629 L
.78494 .2165 L
.78488 .21671 L
.78483 .21692 L
.78478 .21713 L
.78473 .21734 L
.78467 .21755 L
.78462 .21776 L
.78457 .21797 L
.78451 .21818 L
.78446 .21839 L
.7844 .2186 L
.78435 .21882 L
.78429 .21903 L
.78424 .21924 L
.78418 .21945 L
.78412 .21966 L
.78406 .21988 L
Mistroke
.78401 .22009 L
.78395 .2203 L
.78389 .22051 L
.78383 .22073 L
.78377 .22094 L
.78371 .22115 L
.78365 .22136 L
.78359 .22158 L
.78353 .22179 L
.78347 .222 L
.78341 .22222 L
.78334 .22243 L
.78328 .22265 L
.78322 .22286 L
.78315 .22308 L
.78309 .22329 L
.78302 .2235 L
.78296 .22372 L
.78289 .22393 L
.78283 .22415 L
.78276 .22436 L
.7827 .22458 L
.78263 .2248 L
.78256 .22501 L
.78249 .22523 L
.78243 .22544 L
.78236 .22566 L
.78229 .22587 L
.78222 .22609 L
.78215 .22631 L
.78208 .22652 L
.78201 .22674 L
.78194 .22696 L
.78187 .22717 L
.78179 .22739 L
.78172 .22761 L
.78165 .22783 L
.78158 .22804 L
.7815 .22826 L
.78143 .22848 L
.78136 .2287 L
.78128 .22892 L
.78121 .22913 L
.78113 .22935 L
.78105 .22957 L
.78098 .22979 L
.7809 .23001 L
.78083 .23023 L
.78075 .23045 L
.78067 .23067 L
Mistroke
.78059 .23089 L
.78051 .23111 L
.78043 .23133 L
.78035 .23155 L
.78027 .23177 L
.78019 .23199 L
.78011 .23221 L
.78003 .23243 L
.77995 .23265 L
.77987 .23287 L
.77979 .23309 L
.7797 .23331 L
.77962 .23353 L
.77954 .23375 L
.77945 .23397 L
.77937 .23419 L
.77928 .23442 L
.7792 .23464 L
.77911 .23486 L
.77903 .23508 L
.77894 .2353 L
.77885 .23553 L
.77877 .23575 L
.77868 .23597 L
.77859 .23619 L
.7785 .23642 L
.77841 .23664 L
.77833 .23686 L
.77824 .23709 L
.77815 .23731 L
.77806 .23753 L
.77796 .23776 L
.77787 .23798 L
.77778 .2382 L
.77769 .23843 L
.7776 .23865 L
.7775 .23888 L
.77741 .2391 L
.77732 .23932 L
.77722 .23955 L
.77713 .23977 L
.77703 .24 L
.77694 .24022 L
.77684 .24045 L
.77675 .24067 L
.77665 .2409 L
.77655 .24112 L
.77646 .24135 L
.77636 .24158 L
.77626 .2418 L
Mistroke
.77616 .24203 L
.77606 .24225 L
.77597 .24248 L
.77587 .24271 L
.77577 .24293 L
.77567 .24316 L
.77556 .24339 L
.77546 .24361 L
.77536 .24384 L
.77526 .24407 L
.77516 .24429 L
.77505 .24452 L
.77495 .24475 L
.77485 .24498 L
.77474 .2452 L
.77464 .24543 L
.77453 .24566 L
.77443 .24589 L
.77432 .24612 L
.77422 .24634 L
.77411 .24657 L
.774 .2468 L
.7739 .24703 L
.77379 .24726 L
.77368 .24749 L
.77357 .24772 L
.77347 .24794 L
.77336 .24817 L
.77325 .2484 L
.77314 .24863 L
.77303 .24886 L
.77292 .24909 L
.7728 .24932 L
.77269 .24955 L
.77258 .24978 L
.77247 .25001 L
.77236 .25024 L
.77224 .25047 L
.77213 .2507 L
.77202 .25093 L
.7719 .25116 L
.77179 .2514 L
.77167 .25163 L
.77156 .25186 L
.77144 .25209 L
.77132 .25232 L
.77121 .25255 L
.77109 .25278 L
.77097 .25301 L
.77086 .25325 L
Mistroke
.77074 .25348 L
.77062 .25371 L
.7705 .25394 L
.77038 .25417 L
.77026 .25441 L
.77014 .25464 L
.77002 .25487 L
.7699 .2551 L
.76978 .25534 L
.76966 .25557 L
.76953 .2558 L
.76941 .25603 L
.76929 .25627 L
.76916 .2565 L
.76904 .25673 L
.76892 .25697 L
.76879 .2572 L
.76867 .25743 L
.76854 .25767 L
.76842 .2579 L
.76829 .25813 L
.76816 .25837 L
.76804 .2586 L
.76791 .25884 L
.76778 .25907 L
.76766 .25931 L
.76753 .25954 L
.7674 .25977 L
.76727 .26001 L
.76714 .26024 L
.76701 .26048 L
.76688 .26071 L
.76675 .26095 L
.76662 .26118 L
.76649 .26142 L
.76636 .26165 L
.76622 .26189 L
.76609 .26213 L
.76596 .26236 L
.76582 .2626 L
.76569 .26283 L
.76556 .26307 L
.76542 .26331 L
.76529 .26354 L
.76515 .26378 L
.76502 .26401 L
.76488 .26425 L
.76474 .26449 L
.76461 .26472 L
.76447 .26496 L
Mistroke
.76433 .2652 L
.7642 .26543 L
.76406 .26567 L
.76392 .26591 L
.76378 .26614 L
.76364 .26638 L
.7635 .26662 L
.76336 .26686 L
.76322 .26709 L
.76308 .26733 L
.76294 .26757 L
.7628 .26781 L
.76265 .26804 L
.76251 .26828 L
.76237 .26852 L
.76223 .26876 L
.76208 .269 L
.76194 .26923 L
.76179 .26947 L
.76165 .26971 L
.76151 .26995 L
.76136 .27019 L
.76121 .27043 L
.76107 .27067 L
.76092 .2709 L
.76077 .27114 L
.76063 .27138 L
.76048 .27162 L
.76033 .27186 L
.76018 .2721 L
.76003 .27234 L
.75989 .27258 L
.75974 .27282 L
.75959 .27306 L
.75944 .2733 L
.75929 .27354 L
.75913 .27378 L
.75898 .27402 L
.75883 .27426 L
.75868 .2745 L
.75853 .27474 L
.75837 .27498 L
.75822 .27522 L
.75807 .27546 L
.75791 .2757 L
.75776 .27594 L
.75761 .27618 L
.75745 .27642 L
.7573 .27666 L
.75714 .2769 L
Mistroke
.75698 .27714 L
.75683 .27738 L
.75667 .27762 L
.75651 .27786 L
.75636 .2781 L
.7562 .27835 L
.75604 .27859 L
.75588 .27883 L
.75572 .27907 L
.75556 .27931 L
.7554 .27955 L
.75524 .27979 L
.75508 .28003 L
.75492 .28028 L
.75476 .28052 L
.7546 .28076 L
.75444 .281 L
.75428 .28124 L
.75411 .28149 L
.75395 .28173 L
.75379 .28197 L
.75362 .28221 L
.75346 .28245 L
.7533 .2827 L
.75313 .28294 L
.75297 .28318 L
.7528 .28342 L
.75263 .28367 L
.75247 .28391 L
.7523 .28415 L
.75214 .28439 L
.75197 .28464 L
.7518 .28488 L
.75163 .28512 L
.75146 .28536 L
.7513 .28561 L
.75113 .28585 L
.75096 .28609 L
.75079 .28634 L
.75062 .28658 L
.75045 .28682 L
.75028 .28707 L
.75011 .28731 L
.74994 .28755 L
.74976 .2878 L
.74959 .28804 L
.74942 .28828 L
.74925 .28853 L
.74907 .28877 L
.7489 .28901 L
Mistroke
.74873 .28926 L
.74855 .2895 L
.74838 .28975 L
.7482 .28999 L
.74803 .29023 L
.74785 .29048 L
.74768 .29072 L
.7475 .29097 L
.74732 .29121 L
.74715 .29145 L
.74697 .2917 L
.74679 .29194 L
.74662 .29219 L
.74644 .29243 L
.74626 .29267 L
.74608 .29292 L
.7459 .29316 L
.74572 .29341 L
.74554 .29365 L
.74536 .2939 L
.74518 .29414 L
.745 .29439 L
.74482 .29463 L
.74464 .29488 L
.74445 .29512 L
.74427 .29536 L
.74409 .29561 L
.74391 .29585 L
.74372 .2961 L
.74354 .29634 L
.74336 .29659 L
.74317 .29683 L
.74299 .29708 L
.7428 .29732 L
.74262 .29757 L
.74243 .29781 L
.74225 .29806 L
.74206 .2983 L
.74187 .29855 L
.74169 .29879 L
.7415 .29904 L
.74131 .29928 L
.74112 .29953 L
.74094 .29978 L
.74075 .30002 L
.74056 .30027 L
.74037 .30051 L
.74018 .30076 L
.73999 .301 L
.7398 .30125 L
Mistroke
.73961 .30149 L
.73942 .30174 L
.73923 .30198 L
.73904 .30223 L
.73885 .30248 L
.73865 .30272 L
.73846 .30297 L
.73827 .30321 L
.73808 .30346 L
.73788 .3037 L
.73769 .30395 L
.73749 .30419 L
.7373 .30444 L
.73711 .30469 L
.73691 .30493 L
.73672 .30518 L
.73652 .30542 L
.73632 .30567 L
.73613 .30591 L
.73593 .30616 L
.73574 .30641 L
.73554 .30665 L
.73534 .3069 L
.73514 .30714 L
.73494 .30739 L
.73475 .30764 L
.73455 .30788 L
.73435 .30813 L
.73415 .30837 L
.73395 .30862 L
.73375 .30887 L
.73355 .30911 L
.73335 .30936 L
.73315 .3096 L
.73295 .30985 L
.73275 .3101 L
.73255 .31034 L
.73234 .31059 L
.73214 .31083 L
.73194 .31108 L
.73174 .31133 L
.73153 .31157 L
.73133 .31182 L
.73112 .31206 L
.73092 .31231 L
.73072 .31256 L
.73051 .3128 L
.73031 .31305 L
.7301 .31329 L
.7299 .31354 L
Mistroke
.72969 .31379 L
.72948 .31403 L
.72928 .31428 L
.72907 .31452 L
.72886 .31477 L
.72866 .31501 L
.72845 .31526 L
.72824 .31551 L
.72803 .31575 L
.72782 .316 L
.72761 .31624 L
.72741 .31649 L
.7272 .31674 L
.72699 .31698 L
.72678 .31723 L
.72657 .31747 L
.72636 .31772 L
.72615 .31797 L
.72593 .31821 L
.72572 .31846 L
.72551 .3187 L
.7253 .31895 L
.72509 .3192 L
.72487 .31944 L
.72466 .31969 L
.72445 .31993 L
.72423 .32018 L
.72402 .32042 L
.72381 .32067 L
.72359 .32092 L
.72338 .32116 L
.72316 .32141 L
.72295 .32165 L
.72273 .3219 L
.72252 .32214 L
.7223 .32239 L
.72209 .32263 L
.72187 .32288 L
.72165 .32313 L
.72143 .32337 L
.72122 .32362 L
.721 .32386 L
.72078 .32411 L
.72056 .32435 L
.72035 .3246 L
.72013 .32484 L
.71991 .32509 L
.71969 .32533 L
.71947 .32558 L
.71925 .32582 L
Mistroke
.71903 .32607 L
.71881 .32631 L
.71859 .32656 L
.71837 .3268 L
.71815 .32705 L
.71793 .32729 L
.7177 .32754 L
.71748 .32778 L
.71726 .32803 L
.71704 .32827 L
.71682 .32852 L
.71659 .32876 L
.71637 .32901 L
.71615 .32925 L
.71592 .3295 L
.7157 .32974 L
.71547 .32999 L
.71525 .33023 L
.71502 .33048 L
.7148 .33072 L
.71457 .33097 L
.71435 .33121 L
.71412 .33145 L
.7139 .3317 L
.71367 .33194 L
.71344 .33219 L
.71322 .33243 L
.71299 .33268 L
.71276 .33292 L
.71254 .33316 L
.71231 .33341 L
.71208 .33365 L
.71185 .3339 L
.71162 .33414 L
.71139 .33438 L
.71116 .33463 L
.71094 .33487 L
.71071 .33512 L
.71048 .33536 L
.71025 .3356 L
.71002 .33585 L
.70979 .33609 L
.70955 .33633 L
.70932 .33658 L
.70909 .33682 L
.70886 .33706 L
.70863 .33731 L
.7084 .33755 L
.70817 .33779 L
.70793 .33804 L
Mistroke
.7077 .33828 L
.70747 .33852 L
.70723 .33876 L
.707 .33901 L
.70677 .33925 L
.70653 .33949 L
.7063 .33973 L
.70607 .33998 L
.70583 .34022 L
.7056 .34046 L
.70536 .3407 L
.70513 .34095 L
.70489 .34119 L
.70465 .34143 L
.70442 .34167 L
.70418 .34192 L
.70395 .34216 L
.70371 .3424 L
.70347 .34264 L
.70324 .34288 L
.703 .34313 L
.70276 .34337 L
.70252 .34361 L
.70228 .34385 L
.70205 .34409 L
.70181 .34433 L
.70157 .34457 L
.70133 .34482 L
.70109 .34506 L
.70085 .3453 L
.70061 .34554 L
.70037 .34578 L
.70013 .34602 L
.69989 .34626 L
.69965 .3465 L
.69941 .34674 L
.69917 .34698 L
.69893 .34722 L
.69869 .34746 L
.69845 .3477 L
.69821 .34794 L
.69796 .34818 L
.69772 .34842 L
.69748 .34866 L
.69724 .3489 L
.69699 .34914 L
.69675 .34938 L
.69651 .34962 L
.69627 .34986 L
.69602 .3501 L
Mistroke
.69578 .35034 L
.69553 .35058 L
.69529 .35082 L
.69505 .35106 L
.6948 .3513 L
.69456 .35154 L
.69431 .35178 L
.69407 .35202 L
.69382 .35225 L
.69358 .35249 L
.69333 .35273 L
.69308 .35297 L
.69284 .35321 L
.69259 .35345 L
.69235 .35368 L
.6921 .35392 L
.69185 .35416 L
.6916 .3544 L
.69136 .35464 L
.69111 .35487 L
.69086 .35511 L
.69061 .35535 L
.69037 .35559 L
.69012 .35582 L
.68987 .35606 L
.68962 .3563 L
.68937 .35654 L
.68912 .35677 L
.68887 .35701 L
.68862 .35725 L
.68837 .35748 L
.68812 .35772 L
.68787 .35795 L
.68762 .35819 L
.68737 .35843 L
.68712 .35866 L
.68687 .3589 L
.68662 .35914 L
.68637 .35937 L
.68612 .35961 L
.68587 .35984 L
.68562 .36008 L
.68537 .36031 L
.68511 .36055 L
.68486 .36078 L
.68461 .36102 L
.68436 .36125 L
.6841 .36149 L
.68385 .36172 L
.6836 .36196 L
Mistroke
.68335 .36219 L
.68309 .36243 L
.68284 .36266 L
.68259 .36289 L
.68233 .36313 L
.68208 .36336 L
.68182 .3636 L
.68157 .36383 L
.68131 .36406 L
.68106 .3643 L
.68081 .36453 L
.68055 .36476 L
.6803 .365 L
.68004 .36523 L
.67978 .36546 L
.67953 .36569 L
.67927 .36593 L
.67902 .36616 L
.67876 .36639 L
.67851 .36662 L
.67825 .36685 L
.67799 .36709 L
.67774 .36732 L
.67748 .36755 L
.67722 .36778 L
.67696 .36801 L
.67671 .36824 L
.67645 .36848 L
.67619 .36871 L
.67593 .36894 L
.67568 .36917 L
.67542 .3694 L
.67516 .36963 L
.6749 .36986 L
.67464 .37009 L
.67438 .37032 L
.67413 .37055 L
.67387 .37078 L
.67361 .37101 L
.67335 .37124 L
.67309 .37147 L
.67283 .3717 L
.67257 .37193 L
.67231 .37216 L
.67205 .37238 L
.67179 .37261 L
.67153 .37284 L
.67127 .37307 L
.67101 .3733 L
.67075 .37353 L
Mistroke
.67049 .37376 L
.67023 .37398 L
.66997 .37421 L
.6697 .37444 L
.66944 .37467 L
.66918 .37489 L
.66892 .37512 L
.66866 .37535 L
.6684 .37557 L
.66814 .3758 L
.66787 .37603 L
.66761 .37625 L
.66735 .37648 L
.66709 .37671 L
.66682 .37693 L
.66656 .37716 L
.6663 .37738 L
.66604 .37761 L
.66577 .37784 L
.66551 .37806 L
.66525 .37829 L
.66498 .37851 L
.66472 .37874 L
.66445 .37896 L
.66419 .37918 L
.66393 .37941 L
.66366 .37963 L
.6634 .37986 L
.66313 .38008 L
.66287 .3803 L
.66261 .38053 L
.66234 .38075 L
.66208 .38098 L
.66181 .3812 L
.66155 .38142 L
.66128 .38164 L
.66102 .38187 L
.66075 .38209 L
.66049 .38231 L
.66022 .38253 L
.65995 .38276 L
.65969 .38298 L
.65942 .3832 L
.65916 .38342 L
.65889 .38364 L
.65863 .38386 L
.65836 .38408 L
.65809 .3843 L
.65783 .38453 L
.65756 .38475 L
Mistroke
.65729 .38497 L
.65703 .38519 L
.65676 .38541 L
.65649 .38563 L
.65623 .38585 L
.65596 .38607 L
.65569 .38628 L
.65542 .3865 L
.65516 .38672 L
.65489 .38694 L
.65462 .38716 L
.65435 .38738 L
.65409 .3876 L
.65382 .38782 L
.65355 .38803 L
.65328 .38825 L
.65301 .38847 L
.65275 .38869 L
.65248 .3889 L
.65221 .38912 L
.65194 .38934 L
.65167 .38955 L
.6514 .38977 L
.65113 .38999 L
.65087 .3902 L
.6506 .39042 L
.65033 .39063 L
.65006 .39085 L
.64979 .39107 L
.64952 .39128 L
.64925 .3915 L
.64898 .39171 L
.64871 .39193 L
.64844 .39214 L
.64817 .39235 L
.6479 .39257 L
.64763 .39278 L
.64736 .393 L
.64709 .39321 L
.64682 .39342 L
.64655 .39364 L
.64628 .39385 L
.64601 .39406 L
.64574 .39428 L
.64547 .39449 L
.6452 .3947 L
.64493 .39491 L
.64466 .39512 L
.64439 .39534 L
.64412 .39555 L
Mistroke
.64385 .39576 L
.64358 .39597 L
.64331 .39618 L
.64304 .39639 L
.64277 .3966 L
.6425 .39681 L
.64222 .39702 L
.64195 .39723 L
.64168 .39744 L
.64141 .39765 L
.64114 .39786 L
.64087 .39807 L
.6406 .39828 L
.64033 .39849 L
.64005 .3987 L
.63978 .39891 L
.63951 .39911 L
.63924 .39932 L
.63897 .39953 L
.6387 .39974 L
.63842 .39995 L
.63815 .40015 L
.63788 .40036 L
.63761 .40057 L
.63734 .40077 L
.63706 .40098 L
.63679 .40119 L
.63652 .40139 L
.63625 .4016 L
.63597 .4018 L
.6357 .40201 L
.63543 .40221 L
.63516 .40242 L
.63489 .40262 L
.63461 .40283 L
.63434 .40303 L
.63407 .40324 L
.6338 .40344 L
.63352 .40365 L
.63325 .40385 L
.63298 .40405 L
.6327 .40426 L
.63243 .40446 L
.63216 .40466 L
.63189 .40486 L
.63161 .40507 L
.63134 .40527 L
.63107 .40547 L
.63079 .40567 L
.63052 .40587 L
Mistroke
.63025 .40607 L
.62998 .40627 L
.6297 .40648 L
.62943 .40668 L
.62916 .40688 L
.62888 .40708 L
.62861 .40728 L
.62834 .40748 L
.62806 .40768 L
.62779 .40788 L
.62752 .40807 L
.62724 .40827 L
.62697 .40847 L
.6267 .40867 L
.62642 .40887 L
.62615 .40907 L
.62588 .40926 L
.6256 .40946 L
.62533 .40966 L
.62506 .40986 L
.62478 .41005 L
.62451 .41025 L
.62424 .41045 L
.62396 .41064 L
.62369 .41084 L
.62341 .41103 L
.62314 .41123 L
.62287 .41142 L
.62259 .41162 L
.62232 .41181 L
.62205 .41201 L
.62177 .4122 L
.6215 .4124 L
.62123 .41259 L
.62095 .41279 L
.62068 .41298 L
.6204 .41317 L
.62013 .41337 L
.61986 .41356 L
.61958 .41375 L
.61931 .41394 L
.61904 .41414 L
.61876 .41433 L
.61849 .41452 L
.61822 .41471 L
.61794 .4149 L
.61767 .41509 L
.61739 .41528 L
.61712 .41547 L
.61685 .41566 L
Mistroke
.61657 .41585 L
.6163 .41604 L
.61603 .41623 L
.61575 .41642 L
.61548 .41661 L
.61521 .4168 L
.61493 .41699 L
.61466 .41718 L
.61438 .41737 L
.61411 .41755 L
.61384 .41774 L
.61356 .41793 L
.61329 .41812 L
.61302 .4183 L
.61274 .41849 L
.61247 .41868 L
.6122 .41886 L
.61192 .41905 L
.61165 .41923 L
.61138 .41942 L
.6111 .4196 L
.61083 .41979 L
.61056 .41997 L
.61028 .42016 L
.61001 .42034 L
.60974 .42053 L
.60946 .42071 L
.60919 .4209 L
.60892 .42108 L
.60864 .42126 L
.60837 .42144 L
.6081 .42163 L
.60782 .42181 L
.60755 .42199 L
.60728 .42217 L
.607 .42236 L
.60673 .42254 L
.60646 .42272 L
.60618 .4229 L
.60591 .42308 L
.60564 .42326 L
.60537 .42344 L
.60509 .42362 L
.60482 .4238 L
.60455 .42398 L
.60427 .42416 L
.604 .42434 L
.60373 .42452 L
.60346 .42469 L
.60318 .42487 L
Mistroke
.60291 .42505 L
.60264 .42523 L
.60237 .42541 L
.60209 .42558 L
.60182 .42576 L
.60155 .42594 L
.60128 .42611 L
.601 .42629 L
.60073 .42646 L
.60046 .42664 L
.60019 .42682 L
.59991 .42699 L
.59964 .42717 L
.59937 .42734 L
.5991 .42751 L
.59883 .42769 L
.59855 .42786 L
.59828 .42804 L
.59801 .42821 L
.59774 .42838 L
.59747 .42856 L
.59719 .42873 L
.59692 .4289 L
.59665 .42907 L
.59638 .42924 L
.59611 .42942 L
.59584 .42959 L
.59557 .42976 L
.59529 .42993 L
.59502 .4301 L
.59475 .43027 L
.59448 .43044 L
.59421 .43061 L
.59394 .43078 L
.59367 .43095 L
.5934 .43112 L
.59313 .43129 L
.59285 .43145 L
.59258 .43162 L
.59231 .43179 L
.59204 .43196 L
.59177 .43213 L
.5915 .43229 L
.59123 .43246 L
.59096 .43263 L
.59069 .43279 L
.59042 .43296 L
.59015 .43312 L
.58988 .43329 L
.58961 .43345 L
Mistroke
.58934 .43362 L
.58907 .43378 L
.5888 .43395 L
.58853 .43411 L
.58826 .43428 L
.58799 .43444 L
.58772 .4346 L
.58745 .43477 L
.58718 .43493 L
.58691 .43509 L
.58664 .43526 L
.58637 .43542 L
.5861 .43558 L
.58583 .43574 L
.58557 .4359 L
.5853 .43606 L
.58503 .43622 L
.58476 .43638 L
.58449 .43654 L
.58422 .4367 L
.58395 .43686 L
.58368 .43702 L
.58342 .43718 L
.58315 .43734 L
.58288 .4375 L
.58261 .43766 L
.58234 .43782 L
.58207 .43797 L
.58181 .43813 L
.58154 .43829 L
.58127 .43845 L
.581 .4386 L
.58074 .43876 L
.58047 .43892 L
.5802 .43907 L
.57993 .43923 L
.57967 .43938 L
.5794 .43954 L
.57913 .43969 L
.57886 .43985 L
.5786 .44 L
.57833 .44015 L
.57806 .44031 L
.5778 .44046 L
.57753 .44061 L
.57726 .44077 L
.577 .44092 L
.57673 .44107 L
.57646 .44122 L
.5762 .44138 L
Mistroke
.57593 .44153 L
.57567 .44168 L
.5754 .44183 L
.57514 .44198 L
.57487 .44213 L
.5746 .44228 L
.57434 .44243 L
.57407 .44258 L
.57381 .44273 L
.57354 .44288 L
.57328 .44303 L
.57301 .44318 L
.57275 .44332 L
.57248 .44347 L
.57222 .44362 L
.57195 .44377 L
.57169 .44391 L
.57142 .44406 L
.57116 .44421 L
.5709 .44435 L
.57063 .4445 L
.57037 .44465 L
.5701 .44479 L
.56984 .44494 L
.56958 .44508 L
.56931 .44523 L
.56905 .44537 L
.56879 .44551 L
.56852 .44566 L
.56826 .4458 L
.568 .44594 L
.56773 .44609 L
.56747 .44623 L
.56721 .44637 L
.56695 .44651 L
.56668 .44666 L
.56642 .4468 L
.56616 .44694 L
.5659 .44708 L
.56564 .44722 L
.56537 .44736 L
.56511 .4475 L
.56485 .44764 L
.56459 .44778 L
.56433 .44792 L
.56407 .44806 L
.5638 .4482 L
.56354 .44833 L
.56328 .44847 L
.56302 .44861 L
Mistroke
.56276 .44875 L
.5625 .44888 L
.56224 .44902 L
.56198 .44916 L
.56172 .44929 L
.56146 .44943 L
.5612 .44957 L
.56094 .4497 L
.56068 .44984 L
.56042 .44997 L
.56016 .45011 L
.5599 .45024 L
.55964 .45038 L
.55938 .45051 L
.55912 .45064 L
.55886 .45078 L
.55861 .45091 L
.55835 .45104 L
.55809 .45117 L
.55783 .45131 L
.55757 .45144 L
.55731 .45157 L
.55706 .4517 L
.5568 .45183 L
.55654 .45196 L
.55628 .45209 L
.55603 .45222 L
.55577 .45235 L
.55551 .45248 L
.55525 .45261 L
.555 .45274 L
.55474 .45287 L
.55448 .453 L
.55423 .45313 L
.55397 .45325 L
.55371 .45338 L
.55346 .45351 L
.5532 .45363 L
.55295 .45376 L
.55269 .45389 L
.55243 .45401 L
.55218 .45414 L
.55192 .45427 L
.55167 .45439 L
.55141 .45452 L
.55116 .45464 L
.5509 .45476 L
.55065 .45489 L
.55039 .45501 L
.55014 .45514 L
Mistroke
.54989 .45526 L
.54963 .45538 L
.54938 .4555 L
.54912 .45563 L
.54887 .45575 L
.54862 .45587 L
.54836 .45599 L
.54811 .45611 L
.54786 .45623 L
.5476 .45635 L
.54735 .45647 L
.5471 .4566 L
.54685 .45671 L
.54659 .45683 L
.54634 .45695 L
.54609 .45707 L
.54584 .45719 L
.54559 .45731 L
.54533 .45743 L
.54508 .45754 L
.54483 .45766 L
.54458 .45778 L
.54433 .4579 L
.54408 .45801 L
.54383 .45813 L
.54358 .45825 L
.54333 .45836 L
.54308 .45848 L
.54283 .45859 L
.54258 .45871 L
.54233 .45882 L
.54208 .45893 L
.54183 .45905 L
.54158 .45916 L
.54133 .45928 L
.54108 .45939 L
.54083 .4595 L
.54058 .45961 L
.54033 .45973 L
.54009 .45984 L
.53984 .45995 L
.53959 .46006 L
.53934 .46017 L
.53909 .46028 L
.53885 .46039 L
.5386 .4605 L
.53835 .46061 L
.5381 .46072 L
.53786 .46083 L
.53761 .46094 L
Mistroke
.53736 .46105 L
.53712 .46116 L
.53687 .46127 L
.53662 .46137 L
.53638 .46148 L
.53613 .46159 L
.53589 .4617 L
.53564 .4618 L
.53539 .46191 L
.53515 .46202 L
.5349 .46212 L
.53466 .46223 L
.53441 .46233 L
.53417 .46244 L
.53393 .46254 L
.53368 .46265 L
.53344 .46275 L
.53319 .46285 L
.53295 .46296 L
.53271 .46306 L
.53246 .46316 L
.53222 .46327 L
.53198 .46337 L
.53173 .46347 L
.53149 .46357 L
.53125 .46367 L
.53101 .46378 L
.53076 .46388 L
.53052 .46398 L
.53028 .46408 L
.53004 .46418 L
.5298 .46428 L
.52955 .46438 L
.52931 .46448 L
.52907 .46458 L
.52883 .46467 L
.52859 .46477 L
.52835 .46487 L
.52811 .46497 L
.52787 .46507 L
.52763 .46516 L
.52739 .46526 L
.52715 .46536 L
.52691 .46545 L
.52667 .46555 L
.52643 .46564 L
.52619 .46574 L
.52595 .46583 L
.52572 .46593 L
.52548 .46602 L
Mistroke
.52524 .46612 L
.525 .46621 L
.52476 .46631 L
.52453 .4664 L
.52429 .46649 L
.52405 .46659 L
.52381 .46668 L
.52358 .46677 L
.52334 .46686 L
.5231 .46695 L
.52287 .46705 L
.52263 .46714 L
.52239 .46723 L
.52216 .46732 L
.52192 .46741 L
.52169 .4675 L
.52145 .46759 L
.52122 .46768 L
.52098 .46777 L
.52075 .46785 L
.52051 .46794 L
.52028 .46803 L
.52004 .46812 L
.51981 .46821 L
.51957 .46829 L
.51934 .46838 L
.51911 .46847 L
.51887 .46855 L
.51864 .46864 L
.51841 .46873 L
.51817 .46881 L
.51794 .4689 L
.51771 .46898 L
.51748 .46907 L
.51724 .46915 L
.51701 .46924 L
.51678 .46932 L
.51655 .4694 L
.51632 .46949 L
.51609 .46957 L
.51586 .46965 L
.51562 .46974 L
.51539 .46982 L
.51516 .4699 L
.51493 .46998 L
.5147 .47006 L
.51447 .47014 L
.51424 .47022 L
.51401 .47031 L
.51379 .47039 L
Mistroke
.51356 .47047 L
.51333 .47055 L
.5131 .47062 L
.51287 .4707 L
.51264 .47078 L
.51241 .47086 L
.51219 .47094 L
.51196 .47102 L
.51173 .47109 L
.5115 .47117 L
.51128 .47125 L
.51105 .47133 L
.51082 .4714 L
.51059 .47148 L
.51037 .47155 L
.51014 .47163 L
.50992 .47171 L
.50969 .47178 L
.50946 .47186 L
.50924 .47193 L
.50901 .472 L
.50879 .47208 L
.50856 .47215 L
.50834 .47223 L
.50811 .4723 L
.50789 .47237 L
.50767 .47244 L
.50744 .47252 L
.50722 .47259 L
.507 .47266 L
.50677 .47273 L
.50655 .4728 L
.50633 .47287 L
.5061 .47294 L
.50588 .47301 L
.50566 .47308 L
.50544 .47315 L
.50521 .47322 L
.50499 .47329 L
.50477 .47336 L
.50455 .47343 L
.50433 .4735 L
.50411 .47357 L
.50389 .47363 L
.50367 .4737 L
.50345 .47377 L
.50323 .47384 L
.50301 .4739 L
.50279 .47397 L
.50257 .47404 L
Mistroke
.50235 .4741 L
.50213 .47417 L
.50191 .47423 L
.50169 .4743 L
.50147 .47436 L
.50125 .47443 L
.50104 .47449 L
.50082 .47455 L
.5006 .47462 L
.50038 .47468 L
.50016 .47475 L
.49995 .47481 L
.49973 .47487 L
.49951 .47493 L
.4993 .47499 L
.49908 .47506 L
.49886 .47512 L
.49865 .47518 L
.49843 .47524 L
.49822 .4753 L
.498 .47536 L
.49779 .47542 L
.49757 .47548 L
.49736 .47554 L
.49714 .4756 L
.49693 .47566 L
.49671 .47572 L
.4965 .47578 L
.49629 .47583 L
.49607 .47589 L
.49586 .47595 L
.49565 .47601 L
.49543 .47606 L
.49522 .47612 L
.49501 .47618 L
.4948 .47623 L
.49459 .47629 L
.49437 .47634 L
.49416 .4764 L
.49395 .47645 L
.49374 .47651 L
.49353 .47656 L
.49332 .47662 L
.49311 .47667 L
.4929 .47673 L
.49269 .47678 L
.49248 .47683 L
.49227 .47689 L
.49206 .47694 L
.49185 .47699 L
Mistroke
.49164 .47704 L
.49143 .4771 L
.49122 .47715 L
.49101 .4772 L
.4908 .47725 L
.4906 .4773 L
.49039 .47735 L
.49018 .4774 L
.48997 .47745 L
.48977 .4775 L
.48956 .47755 L
.48935 .4776 L
.48915 .47765 L
.48894 .4777 L
.48873 .47775 L
.48853 .47779 L
.48832 .47784 L
.48812 .47789 L
.48791 .47794 L
.48771 .47798 L
.4875 .47803 L
.4873 .47808 L
.48709 .47812 L
.48689 .47817 L
.48668 .47821 L
.48648 .47826 L
.48628 .47831 L
.48607 .47835 L
.48587 .47839 L
.48567 .47844 L
.48546 .47848 L
.48526 .47853 L
.48506 .47857 L
.48486 .47861 L
.48465 .47866 L
.48445 .4787 L
.48425 .47874 L
.48405 .47878 L
.48385 .47883 L
.48365 .47887 L
.48345 .47891 L
.48325 .47895 L
.48305 .47899 L
.48285 .47903 L
.48265 .47907 L
.48245 .47911 L
.48225 .47915 L
.48205 .47919 L
.48185 .47923 L
.48165 .47927 L
Mistroke
.48145 .47931 L
.48125 .47935 L
.48106 .47939 L
.48086 .47943 L
.48066 .47946 L
.48046 .4795 L
.48027 .47954 L
.48007 .47958 L
.47987 .47961 L
.47967 .47965 L
.47948 .47969 L
.47928 .47972 L
.47909 .47976 L
.47889 .47979 L
.4787 .47983 L
.4785 .47986 L
.4783 .4799 L
.47811 .47993 L
.47792 .47997 L
.47772 .48 L
.47753 .48004 L
.47733 .48007 L
.47714 .4801 L
.47695 .48013 L
.47675 .48017 L
.47656 .4802 L
.47637 .48023 L
.47617 .48026 L
.47598 .4803 L
.47579 .48033 L
.4756 .48036 L
.4754 .48039 L
.47521 .48042 L
.47502 .48045 L
.47483 .48048 L
.47464 .48051 L
.47445 .48054 L
.47426 .48057 L
.47407 .4806 L
.47388 .48063 L
.47369 .48066 L
.4735 .48069 L
.47331 .48071 L
.47312 .48074 L
.47293 .48077 L
.47274 .4808 L
.47255 .48082 L
.47236 .48085 L
.47218 .48088 L
.47199 .4809 L
Mistroke
.4718 .48093 L
.47161 .48096 L
.47143 .48098 L
.47124 .48101 L
.47105 .48103 L
.47087 .48106 L
.47068 .48108 L
.47049 .48111 L
.47031 .48113 L
.47012 .48116 L
.46994 .48118 L
.46975 .4812 L
.46956 .48123 L
.46938 .48125 L
.4692 .48127 L
.46901 .48129 L
.46883 .48132 L
.46864 .48134 L
.46846 .48136 L
.46828 .48138 L
.46809 .4814 L
.46791 .48142 L
.46773 .48145 L
.46754 .48147 L
.46736 .48149 L
.46718 .48151 L
.467 .48153 L
.46681 .48155 L
.46663 .48157 L
.46645 .48158 L
.46627 .4816 L
.46609 .48162 L
.46591 .48164 L
.46573 .48166 L
.46555 .48168 L
.46537 .48169 L
.46519 .48171 L
.46501 .48173 L
.46483 .48175 L
.46465 .48176 L
.46447 .48178 L
.46429 .4818 L
.46411 .48181 L
.46394 .48183 L
.46376 .48184 L
.46358 .48186 L
.4634 .48187 L
.46322 .48189 L
.46305 .4819 L
.46287 .48192 L
Mistroke
.46269 .48193 L
.46252 .48195 L
.46234 .48196 L
.46216 .48197 L
.46199 .48199 L
.46181 .482 L
.46164 .48201 L
.46146 .48202 L
.46129 .48204 L
.46111 .48205 L
.46094 .48206 L
.46076 .48207 L
.46059 .48208 L
.46042 .4821 L
.46024 .48211 L
.46007 .48212 L
.45989 .48213 L
.45972 .48214 L
.45955 .48215 L
.45938 .48216 L
.4592 .48217 L
.45903 .48218 L
.45886 .48219 L
.45869 .48219 L
.45852 .4822 L
.45835 .48221 L
.45817 .48222 L
.458 .48223 L
.45783 .48223 L
.45766 .48224 L
.45749 .48225 L
.45732 .48226 L
.45715 .48226 L
.45698 .48227 L
.45681 .48228 L
.45664 .48228 L
.45648 .48229 L
.45631 .48229 L
.45614 .4823 L
.45597 .4823 L
.4558 .48231 L
.45563 .48231 L
.45547 .48232 L
.4553 .48232 L
.45513 .48233 L
.45497 .48233 L
.4548 .48234 L
.45463 .48234 L
.45447 .48234 L
.4543 .48234 L
Mistroke
.45413 .48235 L
.45397 .48235 L
.4538 .48235 L
.45364 .48235 L
.45347 .48236 L
.45331 .48236 L
.45314 .48236 L
.45298 .48236 L
.45282 .48236 L
.45265 .48236 L
.45249 .48236 L
.45232 .48236 L
.45216 .48236 L
.452 .48236 L
.45184 .48236 L
.45167 .48236 L
.45151 .48236 L
.45135 .48236 L
.45119 .48236 L
.45103 .48236 L
.45086 .48236 L
.4507 .48236 L
.45054 .48235 L
.45038 .48235 L
.45022 .48235 L
.45006 .48235 L
.4499 .48234 L
.44974 .48234 L
.44958 .48234 L
.44942 .48233 L
.44926 .48233 L
.4491 .48233 L
.44894 .48232 L
.44878 .48232 L
.44863 .48231 L
.44847 .48231 L
.44831 .4823 L
.44815 .4823 L
.448 .48229 L
.44784 .48229 L
.44768 .48228 L
.44752 .48228 L
.44737 .48227 L
.44721 .48226 L
.44705 .48226 L
.4469 .48225 L
.44674 .48224 L
.44659 .48224 L
.44643 .48223 L
.44628 .48222 L
Mistroke
.44612 .48221 L
.44597 .4822 L
.44581 .4822 L
.44566 .48219 L
.4455 .48218 L
.44535 .48217 L
.4452 .48216 L
.44504 .48215 L
.44489 .48214 L
.44474 .48213 L
.44458 .48212 L
.44443 .48211 L
.44428 .4821 L
.44413 .48209 L
.44398 .48208 L
.44382 .48207 L
.44367 .48206 L
.44352 .48205 L
.44337 .48204 L
.44322 .48202 L
.44307 .48201 L
.44292 .482 L
.44277 .48199 L
.44262 .48197 L
.44247 .48196 L
.44232 .48195 L
.44217 .48194 L
.44202 .48192 L
.44187 .48191 L
.44172 .4819 L
.44158 .48188 L
.44143 .48187 L
.44128 .48185 L
.44113 .48184 L
.44098 .48182 L
.44084 .48181 L
.44069 .48179 L
.44054 .48178 L
.4404 .48176 L
.44025 .48175 L
.4401 .48173 L
.43996 .48172 L
.43981 .4817 L
.43967 .48168 L
.43952 .48167 L
.43938 .48165 L
.43923 .48163 L
.43909 .48162 L
.43894 .4816 L
.4388 .48158 L
Mistroke
.43865 .48156 L
.43851 .48154 L
.43837 .48153 L
.43822 .48151 L
.43808 .48149 L
.43794 .48147 L
.43779 .48145 L
.43765 .48143 L
.43751 .48141 L
.43737 .48139 L
.43722 .48137 L
.43708 .48135 L
.43694 .48133 L
.4368 .48131 L
.43666 .48129 L
.43652 .48127 L
.43638 .48125 L
.43624 .48123 L
.4361 .48121 L
.43596 .48119 L
.43582 .48117 L
.43568 .48115 L
.43554 .48112 L
.4354 .4811 L
.43526 .48108 L
.43512 .48106 L
.43498 .48103 L
.43484 .48101 L
.4347 .48099 L
.43457 .48096 L
.43443 .48094 L
.43429 .48092 L
.43415 .48089 L
.43402 .48087 L
.43388 .48085 L
.43374 .48082 L
.43361 .4808 L
.43347 .48077 L
.43333 .48075 L
.4332 .48072 L
.43306 .4807 L
.43293 .48067 L
.43279 .48065 L
.43266 .48062 L
.43252 .4806 L
.43239 .48057 L
.43225 .48054 L
.43212 .48052 L
.43199 .48049 L
.43185 .48046 L
Mistroke
.43172 .48044 L
.43159 .48041 L
.43145 .48038 L
.43132 .48035 L
.43119 .48033 L
.43105 .4803 L
.43092 .48027 L
.43079 .48024 L
.43066 .48021 L
.43053 .48019 L
.43039 .48016 L
.43026 .48013 L
.43013 .4801 L
.43 .48007 L
.42987 .48004 L
.42974 .48001 L
.42961 .47998 L
.42948 .47995 L
.42935 .47992 L
.42922 .47989 L
.42909 .47986 L
.42896 .47983 L
.42883 .4798 L
.42871 .47977 L
.42858 .47974 L
.42845 .47971 L
.42832 .47967 L
.42819 .47964 L
.42807 .47961 L
.42794 .47958 L
.42781 .47955 L
.42768 .47952 L
.42756 .47948 L
.42743 .47945 L
.4273 .47942 L
.42718 .47938 L
.42705 .47935 L
.42693 .47932 L
.4268 .47928 L
.42667 .47925 L
.42655 .47922 L
.42642 .47918 L
.4263 .47915 L
.42617 .47912 L
.42605 .47908 L
.42593 .47905 L
.4258 .47901 L
.42568 .47898 L
.42555 .47894 L
.42543 .47891 L
Mistroke
.42531 .47887 L
.42519 .47884 L
.42506 .4788 L
.42494 .47876 L
.42482 .47873 L
.4247 .47869 L
.42457 .47866 L
.42445 .47862 L
.42433 .47858 L
.42421 .47855 L
.42409 .47851 L
.42397 .47847 L
.42385 .47843 L
.42373 .4784 L
.42361 .47836 L
.42349 .47832 L
.42337 .47828 L
.42325 .47825 L
.42313 .47821 L
.42301 .47817 L
.42289 .47813 L
.42277 .47809 L
.42265 .47805 L
.42253 .47801 L
.42241 .47798 L
.4223 .47794 L
.42218 .4779 L
.42206 .47786 L
.42194 .47782 L
.42183 .47778 L
.42171 .47774 L
.42159 .4777 L
.42148 .47766 L
.42136 .47762 L
.42124 .47758 L
.42113 .47754 L
.42101 .47749 L
.4209 .47745 L
.42078 .47741 L
.42066 .47737 L
.42055 .47733 L
.42043 .47729 L
.42032 .47725 L
.42021 .4772 L
.42009 .47716 L
.41998 .47712 L
.41986 .47708 L
.41975 .47703 L
.41964 .47699 L
.41952 .47695 L
Mistroke
.41941 .47691 L
.4193 .47686 L
.41918 .47682 L
.41907 .47678 L
.41896 .47673 L
.41885 .47669 L
.41874 .47665 L
.41862 .4766 L
.41851 .47656 L
.4184 .47651 L
.41829 .47647 L
.41818 .47642 L
.41807 .47638 L
.41796 .47633 L
.41785 .47629 L
.41774 .47624 L
.41763 .4762 L
.41752 .47615 L
.41741 .47611 L
.4173 .47606 L
.41719 .47602 L
.41708 .47597 L
.41697 .47592 L
.41686 .47588 L
.41676 .47583 L
.41665 .47579 L
.41654 .47574 L
.41643 .47569 L
.41632 .47565 L
.41622 .4756 L
.41611 .47555 L
.416 .4755 L
.4159 .47546 L
.41579 .47541 L
.41568 .47536 L
.41558 .47531 L
.41547 .47526 L
.41537 .47522 L
.41526 .47517 L
.41515 .47512 L
.41505 .47507 L
.41494 .47502 L
.41484 .47497 L
.41473 .47492 L
.41463 .47488 L
.41453 .47483 L
.41442 .47478 L
.41432 .47473 L
.41421 .47468 L
.41411 .47463 L
Mistroke
.41401 .47458 L
.4139 .47453 L
.4138 .47448 L
.4137 .47443 L
.4136 .47438 L
.41349 .47433 L
.41339 .47428 L
.41329 .47423 L
.41319 .47418 L
.41309 .47412 L
.41299 .47407 L
.41288 .47402 L
.41278 .47397 L
.41268 .47392 L
.41258 .47387 L
.41248 .47382 L
.41238 .47376 L
.41228 .47371 L
.41218 .47366 L
.41208 .47361 L
.41198 .47355 L
.41188 .4735 L
.41178 .47345 L
.41168 .4734 L
.41159 .47334 L
.41149 .47329 L
.41139 .47324 L
.41129 .47318 L
.41119 .47313 L
.4111 .47308 L
.411 .47302 L
.4109 .47297 L
.4108 .47292 L
.41071 .47286 L
.41061 .47281 L
.41051 .47275 L
.41042 .4727 L
.41032 .47264 L
.41022 .47259 L
.41013 .47254 L
.41003 .47248 L
.40994 .47243 L
.40984 .47237 L
.40975 .47232 L
.40965 .47226 L
.40956 .4722 L
.40946 .47215 L
.40937 .47209 L
.40927 .47204 L
.40918 .47198 L
Mistroke
.40909 .47193 L
.40899 .47187 L
.4089 .47181 L
.4088 .47176 L
.40871 .4717 L
.40862 .47164 L
.40853 .47159 L
.40843 .47153 L
.40834 .47147 L
.40825 .47142 L
.40816 .47136 L
.40806 .4713 L
.40797 .47124 L
.40788 .47119 L
.40779 .47113 L
.4077 .47107 L
.40761 .47101 L
.40752 .47096 L
.40743 .4709 L
.40734 .47084 L
.40725 .47078 L
.40716 .47072 L
.40707 .47066 L
.40698 .47061 L
.40689 .47055 L
.4068 .47049 L
.40671 .47043 L
.40662 .47037 L
.40653 .47031 L
.40644 .47025 L
.40635 .47019 L
.40627 .47013 L
.40618 .47007 L
.40609 .47001 L
.406 .46995 L
.40592 .46989 L
.40583 .46983 L
.40574 .46977 L
.40565 .46971 L
.40557 .46965 L
.40548 .46959 L
.40539 .46953 L
.40531 .46947 L
.40522 .46941 L
.40514 .46935 L
.40505 .46929 L
.40497 .46923 L
.40488 .46917 L
.4048 .46911 L
.40471 .46904 L
Mistroke
.40463 .46898 L
.40454 .46892 L
.40446 .46886 L
.40437 .4688 L
.40429 .46874 L
.4042 .46867 L
.40412 .46861 L
.40404 .46855 L
.40395 .46849 L
.40387 .46842 L
.40379 .46836 L
.4037 .4683 L
.40362 .46824 L
.40354 .46817 L
.40346 .46811 L
.40338 .46805 L
.40329 .46799 L
.40321 .46792 L
.40313 .46786 L
.40305 .4678 L
.40297 .46773 L
.40289 .46767 L
.40281 .4676 L
.40272 .46754 L
.40264 .46748 L
.40256 .46741 L
.40248 .46735 L
.4024 .46728 L
.40232 .46722 L
.40224 .46716 L
.40216 .46709 L
.40208 .46703 L
.40201 .46696 L
.40193 .4669 L
.40185 .46683 L
.40177 .46677 L
.40169 .4667 L
.40161 .46664 L
.40153 .46657 L
.40146 .46651 L
.40138 .46644 L
.4013 .46638 L
.40122 .46631 L
.40115 .46625 L
.40107 .46618 L
.40099 .46611 L
.40092 .46605 L
.40084 .46598 L
.40076 .46592 L
.40069 .46585 L
Mistroke
.40061 .46578 L
.40053 .46572 L
.40046 .46565 L
.40038 .46558 L
.40031 .46552 L
.40023 .46545 L
.40016 .46538 L
.40008 .46532 L
.40001 .46525 L
.39993 .46518 L
.39986 .46512 L
.39978 .46505 L
.39971 .46498 L
.39964 .46491 L
.39956 .46485 L
.39949 .46478 L
.39942 .46471 L
.39934 .46464 L
.39927 .46458 L
.3992 .46451 L
.39912 .46444 L
.39905 .46437 L
.39898 .4643 L
.39891 .46424 L
.39884 .46417 L
.39876 .4641 L
.39869 .46403 L
.39862 .46396 L
.39855 .46389 L
.39848 .46383 L
.39841 .46376 L
.39834 .46369 L
.39826 .46362 L
.39819 .46355 L
.39812 .46348 L
.39805 .46341 L
.39798 .46334 L
.39791 .46327 L
.39784 .4632 L
.39777 .46313 L
.39771 .46306 L
.39764 .46299 L
.39757 .46292 L
.3975 .46285 L
.39743 .46278 L
.39736 .46271 L
.39729 .46264 L
.39722 .46257 L
.39716 .4625 L
.39709 .46243 L
Mistroke
.39702 .46236 L
.39695 .46229 L
.39689 .46222 L
.39682 .46215 L
.39675 .46208 L
.39668 .46201 L
.39662 .46194 L
.39655 .46187 L
.39648 .4618 L
.39642 .46173 L
.39635 .46166 L
.39629 .46158 L
.39622 .46151 L
.39615 .46144 L
.39609 .46137 L
.39602 .4613 L
.39596 .46123 L
.39589 .46116 L
.39583 .46108 L
.39576 .46101 L
.3957 .46094 L
.39564 .46087 L
.39557 .4608 L
.39551 .46072 L
.39544 .46065 L
.39538 .46058 L
.39532 .46051 L
.39525 .46044 L
.39519 .46036 L
.39513 .46029 L
.39506 .46022 L
.395 .46015 L
.39494 .46007 L
.39488 .46 L
.39481 .45993 L
.39475 .45985 L
.39469 .45978 L
.39463 .45971 L
.39457 .45963 L
.3945 .45956 L
.39444 .45949 L
.39438 .45941 L
.39432 .45934 L
.39426 .45927 L
.3942 .45919 L
.39414 .45912 L
.39408 .45905 L
.39402 .45897 L
.39396 .4589 L
.3939 .45883 L
Mistroke
.39384 .45875 L
.39378 .45868 L
.39372 .4586 L
.39366 .45853 L
.3936 .45846 L
.39354 .45838 L
.39348 .45831 L
.39342 .45823 L
.39336 .45816 L
.39331 .45808 L
.39325 .45801 L
.39319 .45793 L
.39313 .45786 L
.39307 .45779 L
.39302 .45771 L
.39296 .45764 L
.3929 .45756 L
.39284 .45749 L
.39279 .45741 L
.39273 .45734 L
.39267 .45726 L
.39262 .45719 L
.39256 .45711 L
.3925 .45703 L
.39245 .45696 L
.39239 .45688 L
.39234 .45681 L
.39228 .45673 L
.39223 .45666 L
.39217 .45658 L
.39211 .45651 L
.39206 .45643 L
.392 .45635 L
.39195 .45628 L
.3919 .4562 L
.39184 .45613 L
.39179 .45605 L
.39173 .45597 L
.39168 .4559 L
.39162 .45582 L
.39157 .45575 L
.39152 .45567 L
.39146 .45559 L
.39141 .45552 L
.39136 .45544 L
.3913 .45536 L
.39125 .45529 L
.3912 .45521 L
.39115 .45513 L
.39109 .45506 L
Mistroke
.39104 .45498 L
.39099 .4549 L
.39094 .45483 L
.39089 .45475 L
.39083 .45467 L
.39078 .45459 L
.39073 .45452 L
.39068 .45444 L
.39063 .45436 L
.39058 .45429 L
.39053 .45421 L
.39048 .45413 L
.39043 .45405 L
.39038 .45398 L
.39033 .4539 L
.39028 .45382 L
.39023 .45374 L
.39018 .45366 L
.39013 .45359 L
.39008 .45351 L
.39003 .45343 L
.38998 .45335 L
.38993 .45328 L
.38988 .4532 L
.38983 .45312 L
.38978 .45304 L
.38973 .45296 L
.38969 .45288 L
.38964 .45281 L
.38959 .45273 L
.38954 .45265 L
.38949 .45257 L
.38945 .45249 L
.3894 .45241 L
.38935 .45234 L
.38931 .45226 L
.38926 .45218 L
.38921 .4521 L
.38916 .45202 L
.38912 .45194 L
.38907 .45186 L
.38903 .45178 L
.38898 .45171 L
.38893 .45163 L
.38889 .45155 L
.38884 .45147 L
.3888 .45139 L
.38875 .45131 L
.3887 .45123 L
.38866 .45115 L
Mistroke
.38861 .45107 L
.38857 .45099 L
.38852 .45091 L
.38848 .45084 L
.38844 .45076 L
.38839 .45068 L
.38835 .4506 L
.3883 .45052 L
.38826 .45044 L
.38822 .45036 L
.38817 .45028 L
.38813 .4502 L
.38808 .45012 L
.38804 .45004 L
.388 .44996 L
.38796 .44988 L
.38791 .4498 L
.38787 .44972 L
.38783 .44964 L
.38778 .44956 L
.38774 .44948 L
.3877 .4494 L
.38766 .44932 L
.38762 .44924 L
.38757 .44916 L
.38753 .44908 L
.38749 .449 L
.38745 .44892 L
.38741 .44884 L
.38737 .44876 L
.38733 .44868 L
.38729 .4486 L
.38725 .44852 L
.38721 .44843 L
.38716 .44835 L
.38712 .44827 L
.38708 .44819 L
.38704 .44811 L
.387 .44803 L
.38697 .44795 L
.38693 .44787 L
.38689 .44779 L
.38685 .44771 L
.38681 .44763 L
.38677 .44755 L
.38673 .44746 L
.38669 .44738 L
.38665 .4473 L
.38661 .44722 L
.38658 .44714 L
Mistroke
.38654 .44706 L
.3865 .44698 L
.38646 .4469 L
.38642 .44682 L
.38639 .44673 L
.38635 .44665 L
.38631 .44657 L
.38627 .44649 L
.38624 .44641 L
.3862 .44633 L
.38616 .44625 L
.38612 .44616 L
.38609 .44608 L
.38605 .446 L
.38602 .44592 L
.38598 .44584 L
.38594 .44576 L
.38591 .44567 L
.38587 .44559 L
.38584 .44551 L
.3858 .44543 L
.38576 .44535 L
.38573 .44527 L
.38569 .44518 L
.38566 .4451 L
.38562 .44502 L
.38559 .44494 L
.38555 .44486 L
.38552 .44477 L
.38548 .44469 L
.38545 .44461 L
.38542 .44453 L
.38538 .44445 L
.38535 .44436 L
.38531 .44428 L
.38528 .4442 L
.38525 .44412 L
.38521 .44403 L
.38518 .44395 L
.38515 .44387 L
.38511 .44379 L
.38508 .4437 L
.38505 .44362 L
.38502 .44354 L
.38498 .44346 L
.38495 .44337 L
.38492 .44329 L
.38489 .44321 L
.38485 .44313 L
.38482 .44304 L
Mistroke
.38479 .44296 L
.38476 .44288 L
.38473 .4428 L
.3847 .44271 L
.38466 .44263 L
.38463 .44255 L
.3846 .44247 L
.38457 .44238 L
.38454 .4423 L
.38451 .44222 L
.38448 .44213 L
.38445 .44205 L
.38442 .44197 L
.38439 .44189 L
.38436 .4418 L
.38433 .44172 L
.3843 .44164 L
.38427 .44155 L
.38424 .44147 L
.38421 .44139 L
.38418 .4413 L
.38415 .44122 L
.38412 .44114 L
.38409 .44106 L
.38406 .44097 L
.38404 .44089 L
.38401 .44081 L
.38398 .44072 L
.38395 .44064 L
.38392 .44056 L
.38389 .44047 L
.38387 .44039 L
.38384 .44031 L
.38381 .44022 L
.38378 .44014 L
.38375 .44006 L
.38373 .43997 L
.3837 .43989 L
.38367 .43981 L
.38365 .43972 L
.38362 .43964 L
.38359 .43956 L
.38357 .43947 L
.38354 .43939 L
.38351 .43931 L
.38349 .43922 L
.38346 .43914 L
.38343 .43905 L
.38341 .43897 L
.38338 .43889 L
Mistroke
.38336 .4388 L
.38333 .43872 L
.3833 .43864 L
.38328 .43855 L
.38325 .43847 L
.38323 .43839 L
.3832 .4383 L
.38318 .43822 L
.38315 .43813 L
.38313 .43805 L
.38311 .43797 L
.38308 .43788 L
.38306 .4378 L
.38303 .43772 L
.38301 .43763 L
.38298 .43755 L
.38296 .43746 L
.38294 .43738 L
.38291 .4373 L
.38289 .43721 L
.38287 .43713 L
.38284 .43704 L
.38282 .43696 L
.3828 .43688 L
.38277 .43679 L
.38275 .43671 L
.38273 .43662 L
.38271 .43654 L
.38268 .43646 L
.38266 .43637 L
.38264 .43629 L
.38262 .4362 L
.38259 .43612 L
.38257 .43604 L
.38255 .43595 L
.38253 .43587 L
.38251 .43578 L
.38249 .4357 L
.38246 .43562 L
.38244 .43553 L
.38242 .43545 L
.3824 .43536 L
.38238 .43528 L
.38236 .43519 L
.38234 .43511 L
.38232 .43503 L
.3823 .43494 L
.38228 .43486 L
.38226 .43477 L
.38224 .43469 L
Mistroke
.38222 .4346 L
.3822 .43452 L
.38218 .43444 L
.38216 .43435 L
.38214 .43427 L
.38212 .43418 L
.3821 .4341 L
.38208 .43401 L
.38206 .43393 L
.38204 .43385 L
.38202 .43376 L
.382 .43368 L
.38199 .43359 L
.38197 .43351 L
.38195 .43342 L
.38193 .43334 L
.38191 .43326 L
.38189 .43317 L
.38188 .43309 L
.38186 .433 L
.38184 .43292 L
.38182 .43283 L
.38181 .43275 L
.38179 .43266 L
.38177 .43258 L
.38175 .4325 L
.38174 .43241 L
.38172 .43233 L
.3817 .43224 L
.38169 .43216 L
.38167 .43207 L
.38165 .43199 L
.38164 .43191 L
.38162 .43182 L
.3816 .43174 L
.38159 .43165 L
.38157 .43157 L
.38155 .43148 L
.38154 .4314 L
.38152 .43131 L
.38151 .43123 L
.38149 .43114 L
.38148 .43106 L
.38146 .43098 L
.38145 .43089 L
.38143 .43081 L
.38142 .43072 L
.3814 .43064 L
.38139 .43055 L
.38137 .43047 L
Mistroke
.38136 .43038 L
.38134 .4303 L
.38133 .43022 L
.38131 .43013 L
.3813 .43005 L
.38128 .42996 L
.38127 .42988 L
.38126 .42979 L
.38124 .42971 L
.38123 .42962 L
.38122 .42954 L
.3812 .42945 L
.38119 .42937 L
.38118 .42929 L
.38116 .4292 L
.38115 .42912 L
.38114 .42903 L
.38112 .42895 L
.38111 .42886 L
.3811 .42878 L
.38109 .42869 L
.38107 .42861 L
.38106 .42853 L
.38105 .42844 L
.38104 .42836 L
.38102 .42827 L
.38101 .42819 L
.381 .4281 L
.38099 .42802 L
.38098 .42793 L
.38097 .42785 L
.38095 .42776 L
.38094 .42768 L
.38093 .4276 L
.38092 .42751 L
.38091 .42743 L
.3809 .42734 L
.38089 .42726 L
.38088 .42717 L
.38087 .42709 L
.38086 .427 L
.38085 .42692 L
.38084 .42684 L
.38083 .42675 L
.38082 .42667 L
.38081 .42658 L
.3808 .4265 L
.38079 .42641 L
.38078 .42633 L
.38077 .42624 L
Mistroke
.38076 .42616 L
.38075 .42608 L
.38074 .42599 L
.38073 .42591 L
.38072 .42582 L
.38071 .42574 L
.3807 .42565 L
.38069 .42557 L
.38068 .42548 L
.38068 .4254 L
.38067 .42532 L
.38066 .42523 L
.38065 .42515 L
.38064 .42506 L
.38063 .42498 L
.38063 .42489 L
.38062 .42481 L
.38061 .42472 L
.3806 .42464 L
.38059 .42456 L
.38059 .42447 L
.38058 .42439 L
.38057 .4243 L
.38056 .42422 L
.38056 .42413 L
.38055 .42405 L
.38054 .42397 L
.38054 .42388 L
.38053 .4238 L
.38052 .42371 L
.38052 .42363 L
.38051 .42354 L
.3805 .42346 L
.3805 .42338 L
.38049 .42329 L
.38048 .42321 L
.38048 .42312 L
.38047 .42304 L
.38047 .42296 L
.38046 .42287 L
.38045 .42279 L
.38045 .4227 L
.38044 .42262 L
.38044 .42253 L
.38043 .42245 L
.38043 .42237 L
.38042 .42228 L
.38042 .4222 L
.38041 .42211 L
.38041 .42203 L
Mistroke
.3804 .42195 L
.3804 .42186 L
.38039 .42178 L
.38039 .42169 L
.38038 .42161 L
.38038 .42153 L
.38038 .42144 L
.38037 .42136 L
.38037 .42127 L
.38036 .42119 L
.38036 .42111 L
.38036 .42102 L
.38035 .42094 L
.38035 .42085 L
.38034 .42077 L
.38034 .42069 L
.38034 .4206 L
.38033 .42052 L
.38033 .42043 L
.38033 .42035 L
.38033 .42027 L
.38032 .42018 L
.38032 .4201 L
.38032 .42002 L
.38031 .41993 L
.38031 .41985 L
.38031 .41976 L
.38031 .41968 L
.38031 .4196 L
.3803 .41951 L
.3803 .41943 L
.3803 .41935 L
.3803 .41926 L
.3803 .41918 L
.38029 .41909 L
.38029 .41901 L
.38029 .41893 L
.38029 .41884 L
.38029 .41876 L
.38029 .41868 L
.38028 .41859 L
.38028 .41851 L
.38028 .41843 L
.38028 .41834 L
.38028 .41826 L
.38028 .41818 L
.38028 .41809 L
.38028 .41801 L
.38028 .41793 L
.38028 .41784 L
Mistroke
.38028 .41776 L
.38028 .41767 L
.38028 .41759 L
.38028 .41751 L
.38028 .41742 L
.38028 .41734 L
.38028 .41726 L
.38028 .41717 L
.38028 .41709 L
.38028 .41701 L
.38028 .41692 L
.38028 .41684 L
.38028 .41676 L
.38028 .41668 L
.38028 .41659 L
.38028 .41651 L
.38028 .41643 L
.38029 .41634 L
.38029 .41626 L
.38029 .41618 L
.38029 .41609 L
.38029 .41601 L
.38029 .41593 L
.38029 .41584 L
.3803 .41576 L
.3803 .41568 L
.3803 .41559 L
.3803 .41551 L
.3803 .41543 L
.3803 .41535 L
.38031 .41526 L
.38031 .41518 L
.38031 .4151 L
.38031 .41501 L
.38032 .41493 L
.38032 .41485 L
.38032 .41477 L
.38032 .41468 L
.38033 .4146 L
.38033 .41452 L
.38033 .41443 L
.38034 .41435 L
.38034 .41427 L
.38034 .41419 L
.38035 .4141 L
.38035 .41402 L
.38035 .41394 L
.38036 .41386 L
.38036 .41377 L
.38036 .41369 L
Mistroke
.38037 .41361 L
.38037 .41353 L
.38038 .41344 L
.38038 .41336 L
.38038 .41328 L
.38039 .4132 L
.38039 .41311 L
.3804 .41303 L
.3804 .41295 L
.38041 .41287 L
.38041 .41278 L
.38042 .4127 L
.38042 .41262 L
.38043 .41254 L
.38043 .41246 L
.38044 .41237 L
.38044 .41229 L
.38045 .41221 L
.38045 .41213 L
.38046 .41204 L
.38046 .41196 L
.38047 .41188 L
.38047 .4118 L
.38048 .41172 L
.38048 .41163 L
.38049 .41155 L
.3805 .41147 L
.3805 .41139 L
.38051 .41131 L
.38051 .41122 L
.38052 .41114 L
.38053 .41106 L
.38053 .41098 L
.38054 .4109 L
.38055 .41081 L
.38055 .41073 L
.38056 .41065 L
.38057 .41057 L
.38057 .41049 L
.38058 .41041 L
.38059 .41032 L
.38059 .41024 L
.3806 .41016 L
.38061 .41008 L
.38061 .41 L
.38062 .40992 L
.38063 .40983 L
.38064 .40975 L
.38064 .40967 L
.38065 .40959 L
Mistroke
.38066 .40951 L
.38067 .40943 L
.38067 .40935 L
.38068 .40926 L
.38069 .40918 L
.3807 .4091 L
.38071 .40902 L
.38072 .40894 L
.38072 .40886 L
.38073 .40878 L
.38074 .4087 L
.38075 .40861 L
.38076 .40853 L
.38077 .40845 L
.38077 .40837 L
.38078 .40829 L
.38079 .40821 L
.3808 .40813 L
.38081 .40805 L
.38082 .40797 L
.38083 .40789 L
.38084 .4078 L
.38085 .40772 L
.38086 .40764 L
.38087 .40756 L
.38088 .40748 L
.38089 .4074 L
.3809 .40732 L
.3809 .40724 L
.38091 .40716 L
.38092 .40708 L
.38093 .407 L
.38094 .40692 L
.38095 .40684 L
.38096 .40675 L
.38098 .40667 L
.38099 .40659 L
.381 .40651 L
.38101 .40643 L
.38102 .40635 L
.38103 .40627 L
.38104 .40619 L
.38105 .40611 L
.38106 .40603 L
.38107 .40595 L
.38108 .40587 L
.38109 .40579 L
.3811 .40571 L
.38111 .40563 L
.38113 .40555 L
Mistroke
.38114 .40547 L
.38115 .40539 L
.38116 .40531 L
.38117 .40523 L
.38118 .40515 L
.3812 .40507 L
.38121 .40499 L
.38122 .40491 L
.38123 .40483 L
.38124 .40475 L
.38125 .40467 L
.38127 .40459 L
.38128 .40451 L
.38129 .40443 L
.3813 .40435 L
.38132 .40427 L
.38133 .40419 L
.38134 .40411 L
.38135 .40403 L
.38137 .40395 L
.38138 .40387 L
.38139 .40379 L
.3814 .40371 L
.38142 .40363 L
.38143 .40355 L
.38144 .40347 L
.38146 .4034 L
.38147 .40332 L
.38148 .40324 L
.3815 .40316 L
.38151 .40308 L
.38152 .403 L
.38154 .40292 L
.38155 .40284 L
.38156 .40276 L
.38158 .40268 L
.38159 .4026 L
.3816 .40252 L
.38162 .40244 L
.38163 .40237 L
.38165 .40229 L
.38166 .40221 L
.38167 .40213 L
.38169 .40205 L
.3817 .40197 L
.38172 .40189 L
.38173 .40181 L
.38175 .40173 L
.38176 .40166 L
.38177 .40158 L
Mistroke
.38179 .4015 L
.3818 .40142 L
.38182 .40134 L
.38183 .40126 L
.38185 .40118 L
.38186 .40111 L
.38188 .40103 L
.38189 .40095 L
.38191 .40087 L
.38192 .40079 L
.38194 .40071 L
.38195 .40064 L
.38197 .40056 L
.38199 .40048 L
.382 .4004 L
.38202 .40032 L
.38203 .40024 L
.38205 .40017 L
.38206 .40009 L
.38208 .40001 L
.3821 .39993 L
.38211 .39985 L
.38213 .39978 L
.38214 .3997 L
.38216 .39962 L
.38218 .39954 L
.38219 .39946 L
.38221 .39939 L
.38223 .39931 L
.38224 .39923 L
.38226 .39915 L
.38228 .39908 L
.38229 .399 L
.38231 .39892 L
.38233 .39884 L
.38234 .39876 L
.38236 .39869 L
.38238 .39861 L
.38239 .39853 L
.38241 .39845 L
.38243 .39838 L
.38244 .3983 L
.38246 .39822 L
.38248 .39815 L
.3825 .39807 L
.38251 .39799 L
.38253 .39791 L
.38255 .39784 L
.38257 .39776 L
.38258 .39768 L
Mistroke
.3826 .39761 L
.38262 .39753 L
.38264 .39745 L
.38266 .39737 L
.38267 .3973 L
.38269 .39722 L
.38271 .39714 L
.38273 .39707 L
.38275 .39699 L
.38277 .39691 L
.38278 .39684 L
.3828 .39676 L
.38282 .39668 L
.38284 .39661 L
.38286 .39653 L
.38288 .39645 L
.3829 .39638 L
.38291 .3963 L
.38293 .39622 L
.38295 .39615 L
.38297 .39607 L
.38299 .396 L
.38301 .39592 L
.38303 .39584 L
.38305 .39577 L
.38307 .39569 L
.38309 .39561 L
.3831 .39554 L
.38312 .39546 L
.38314 .39539 L
.38316 .39531 L
.38318 .39523 L
.3832 .39516 L
.38322 .39508 L
.38324 .39501 L
.38326 .39493 L
.38328 .39485 L
.3833 .39478 L
.38332 .3947 L
.38334 .39463 L
.38336 .39455 L
.38338 .39448 L
.3834 .3944 L
.38342 .39432 L
.38344 .39425 L
.38346 .39417 L
.38348 .3941 L
.3835 .39402 L
.38352 .39395 L
.38354 .39387 L
Mistroke
.38357 .3938 L
.38359 .39372 L
.38361 .39365 L
.38363 .39357 L
.38365 .3935 L
.38367 .39342 L
.38369 .39335 L
.38371 .39327 L
.38373 .3932 L
.38375 .39312 L
.38377 .39305 L
.3838 .39297 L
.38382 .3929 L
.38384 .39282 L
.38386 .39275 L
.38388 .39267 L
.3839 .3926 L
.38392 .39252 L
.38395 .39245 L
.38397 .39237 L
.38399 .3923 L
.38401 .39222 L
.38403 .39215 L
.38405 .39207 L
.38408 .392 L
.3841 .39193 L
.38412 .39185 L
.38414 .39178 L
.38417 .3917 L
.38419 .39163 L
.38421 .39155 L
.38423 .39148 L
.38425 .39141 L
.38428 .39133 L
.3843 .39126 L
.38432 .39118 L
.38434 .39111 L
.38437 .39104 L
.38439 .39096 L
.38441 .39089 L
.38443 .39081 L
.38446 .39074 L
.38448 .39067 L
.3845 .39059 L
.38453 .39052 L
.38455 .39045 L
.38457 .39037 L
.3846 .3903 L
.38462 .39023 L
.38464 .39015 L
Mistroke
.38467 .39008 L
.38469 .39 L
.38471 .38993 L
.38474 .38986 L
.38476 .38978 L
.38478 .38971 L
.38481 .38964 L
.38483 .38957 L
.38485 .38949 L
.38488 .38942 L
.3849 .38935 L
.38492 .38927 L
.38495 .3892 L
.38497 .38913 L
.385 .38905 L
.38502 .38898 L
.38504 .38891 L
.38507 .38884 L
.38509 .38876 L
.38512 .38869 L
.38514 .38862 L
.38517 .38854 L
.38519 .38847 L
.38521 .3884 L
.38524 .38833 L
.38526 .38825 L
.38529 .38818 L
.38531 .38811 L
.38534 .38804 L
.38536 .38797 L
.38539 .38789 L
.38541 .38782 L
.38544 .38775 L
.38546 .38768 L
.38549 .3876 L
.38551 .38753 L
.38554 .38746 L
.38556 .38739 L
.38559 .38732 L
.38561 .38724 L
.38564 .38717 L
.38566 .3871 L
.38569 .38703 L
.38571 .38696 L
.38574 .38689 L
.38576 .38681 L
.38579 .38674 L
.38582 .38667 L
.38584 .3866 L
.38587 .38653 L
Mistroke
.38589 .38646 L
.38592 .38638 L
.38594 .38631 L
.38597 .38624 L
.386 .38617 L
.38602 .3861 L
.38605 .38603 L
.38607 .38596 L
.3861 .38589 L
.38613 .38581 L
.38615 .38574 L
.38618 .38567 L
.3862 .3856 L
.38623 .38553 L
.38626 .38546 L
.38628 .38539 L
.38631 .38532 L
.38634 .38525 L
.38636 .38518 L
.38639 .38511 L
.38642 .38503 L
.38644 .38496 L
.38647 .38489 L
.3865 .38482 L
.38652 .38475 L
.38655 .38468 L
.38658 .38461 L
.3866 .38454 L
.38663 .38447 L
.38666 .3844 L
.38668 .38433 L
.38671 .38426 L
.38674 .38419 L
.38677 .38412 L
.38679 .38405 L
.38682 .38398 L
.38685 .38391 L
.38688 .38384 L
.3869 .38377 L
.38693 .3837 L
.38696 .38363 L
.38699 .38356 L
.38701 .38349 L
.38704 .38342 L
.38707 .38335 L
.3871 .38328 L
.38712 .38321 L
.38715 .38314 L
.38718 .38307 L
.38721 .383 L
Mistroke
.38724 .38293 L
.38726 .38286 L
.38729 .38279 L
.38732 .38273 L
.38735 .38266 L
.38738 .38259 L
.3874 .38252 L
.38743 .38245 L
.38746 .38238 L
.38749 .38231 L
.38752 .38224 L
.38755 .38217 L
.38757 .3821 L
.3876 .38203 L
.38763 .38197 L
.38766 .3819 L
.38769 .38183 L
.38772 .38176 L
.38775 .38169 L
.38777 .38162 L
.3878 .38155 L
.38783 .38148 L
.38786 .38142 L
.38789 .38135 L
.38792 .38128 L
.38795 .38121 L
.38798 .38114 L
.38801 .38107 L
.38803 .38101 L
.38806 .38094 L
.38809 .38087 L
.38812 .3808 L
.38815 .38073 L
.38818 .38067 L
.38821 .3806 L
.38824 .38053 L
.38827 .38046 L
.3883 .38039 L
.38833 .38033 L
.38836 .38026 L
.38839 .38019 L
.38842 .38012 L
.38845 .38006 L
.38848 .37999 L
.38851 .37992 L
.38854 .37985 L
.38856 .37978 L
.38859 .37972 L
.38862 .37965 L
.38865 .37958 L
Mistroke
.38868 .37952 L
.38871 .37945 L
.38874 .37938 L
.38877 .37931 L
.3888 .37925 L
.38883 .37918 L
.38886 .37911 L
.3889 .37905 L
.38893 .37898 L
.38896 .37891 L
.38899 .37884 L
.38902 .37878 L
.38905 .37871 L
.38908 .37864 L
.38911 .37858 L
.38914 .37851 L
.38917 .37844 L
.3892 .37838 L
.38923 .37831 L
.38926 .37824 L
.38929 .37818 L
.38932 .37811 L
.38935 .37805 L
.38938 .37798 L
.38941 .37791 L
.38945 .37785 L
.38948 .37778 L
.38951 .37771 L
.38954 .37765 L
.38957 .37758 L
.3896 .37752 L
.38963 .37745 L
.38966 .37738 L
.38969 .37732 L
.38973 .37725 L
.38976 .37719 L
.38979 .37712 L
.38982 .37705 L
.38985 .37699 L
.38988 .37692 L
.38991 .37686 L
.38994 .37679 L
.38998 .37673 L
.39001 .37666 L
.39004 .3766 L
.39007 .37653 L
.3901 .37647 L
.39013 .3764 L
.39017 .37633 L
.3902 .37627 L
Mistroke
.39023 .3762 L
.39026 .37614 L
.39029 .37607 L
.39033 .37601 L
.39036 .37594 L
.39039 .37588 L
.39042 .37581 L
.39045 .37575 L
.39049 .37569 L
.39052 .37562 L
.39055 .37556 L
.39058 .37549 L
.39061 .37543 L
.39065 .37536 L
.39068 .3753 L
.39071 .37523 L
.39074 .37517 L
.39078 .3751 L
.39081 .37504 L
.39084 .37498 L
.39087 .37491 L
.39091 .37485 L
.39094 .37478 L
.39097 .37472 L
.391 .37465 L
.39104 .37459 L
.39107 .37453 L
.3911 .37446 L
.39113 .3744 L
.39117 .37433 L
.3912 .37427 L
.39123 .37421 L
.39127 .37414 L
.3913 .37408 L
.39133 .37402 L
.39136 .37395 L
.3914 .37389 L
.39143 .37383 L
.39146 .37376 L
.3915 .3737 L
.39153 .37364 L
.39156 .37357 L
.3916 .37351 L
.39163 .37345 L
.39166 .37338 L
.3917 .37332 L
.39173 .37326 L
.39176 .37319 L
.3918 .37313 L
.39183 .37307 L
Mistroke
.39186 .373 L
.3919 .37294 L
.39193 .37288 L
.39196 .37282 L
.392 .37275 L
.39203 .37269 L
.39206 .37263 L
.3921 .37256 L
.39213 .3725 L
.39216 .37244 L
.3922 .37238 L
.39223 .37231 L
.39227 .37225 L
.3923 .37219 L
.39233 .37213 L
.39237 .37207 L
.3924 .372 L
.39244 .37194 L
.39247 .37188 L
.3925 .37182 L
.39254 .37175 L
.39257 .37169 L
.39261 .37163 L
.39264 .37157 L
.39267 .37151 L
.39271 .37145 L
.39274 .37138 L
.39278 .37132 L
.39281 .37126 L
.39285 .3712 L
.39288 .37114 L
.39291 .37108 L
.39295 .37101 L
.39298 .37095 L
.39302 .37089 L
.39305 .37083 L
.39309 .37077 L
.39312 .37071 L
.39316 .37065 L
.39319 .37059 L
.39323 .37052 L
.39326 .37046 L
.39329 .3704 L
.39333 .37034 L
.39336 .37028 L
.3934 .37022 L
.39343 .37016 L
.39347 .3701 L
.3935 .37004 L
.39354 .36998 L
Mistroke
.39357 .36992 L
.39361 .36985 L
.39364 .36979 L
.39368 .36973 L
.39371 .36967 L
.39375 .36961 L
.39378 .36955 L
.39382 .36949 L
.39385 .36943 L
.39389 .36937 L
.39392 .36931 L
.39396 .36925 L
.39399 .36919 L
.39403 .36913 L
.39407 .36907 L
.3941 .36901 L
.39414 .36895 L
.39417 .36889 L
.39421 .36883 L
.39424 .36877 L
.39428 .36871 L
.39431 .36865 L
.39435 .36859 L
.39438 .36853 L
.39442 .36847 L
.39446 .36841 L
.39449 .36835 L
.39453 .36829 L
.39456 .36824 L
.3946 .36818 L
.39463 .36812 L
.39467 .36806 L
.39471 .368 L
.39474 .36794 L
.39478 .36788 L
.39481 .36782 L
.39485 .36776 L
.39488 .3677 L
.39492 .36764 L
.39496 .36758 L
.39499 .36753 L
.39503 .36747 L
.39506 .36741 L
.3951 .36735 L
.39514 .36729 L
.39517 .36723 L
.39521 .36717 L
.39525 .36712 L
.39528 .36706 L
.39532 .367 L
Mistroke
.39535 .36694 L
.39539 .36688 L
.39543 .36682 L
.39546 .36677 L
.3955 .36671 L
.39554 .36665 L
.39557 .36659 L
.39561 .36653 L
.39564 .36647 L
.39568 .36642 L
.39572 .36636 L
.39575 .3663 L
.39579 .36624 L
.39583 .36619 L
.39586 .36613 L
.3959 .36607 L
.39594 .36601 L
.39597 .36595 L
.39601 .3659 L
.39605 .36584 L
.39608 .36578 L
.39612 .36572 L
.39616 .36567 L
.39619 .36561 L
.39623 .36555 L
.39627 .3655 L
.3963 .36544 L
.39634 .36538 L
.39638 .36532 L
.39642 .36527 L
.39645 .36521 L
.39649 .36515 L
.39653 .3651 L
.39656 .36504 L
.3966 .36498 L
.39664 .36493 L
.39667 .36487 L
.39671 .36481 L
.39675 .36476 L
.39679 .3647 L
.39682 .36464 L
.39686 .36459 L
.3969 .36453 L
.39693 .36447 L
.39697 .36442 L
.39701 .36436 L
.39705 .3643 L
.39708 .36425 L
.39712 .36419 L
.39716 .36414 L
Mistroke
.3972 .36408 L
.39723 .36402 L
.39727 .36397 L
.39731 .36391 L
.39735 .36386 L
.39738 .3638 L
.39742 .36374 L
.39746 .36369 L
.3975 .36363 L
.39753 .36358 L
.39757 .36352 L
.39761 .36347 L
.39765 .36341 L
.39768 .36336 L
.39772 .3633 L
.39776 .36324 L
.3978 .36319 L
.39784 .36313 L
.39787 .36308 L
.39791 .36302 L
.39795 .36297 L
.39799 .36291 L
.39802 .36286 L
.39806 .3628 L
.3981 .36275 L
.39814 .36269 L
.39818 .36264 L
.39821 .36258 L
.39825 .36253 L
.39829 .36247 L
.39833 .36242 L
.39837 .36236 L
.3984 .36231 L
.39844 .36226 L
.39848 .3622 L
.39852 .36215 L
.39856 .36209 L
.39859 .36204 L
.39863 .36198 L
.39867 .36193 L
.39871 .36187 L
.39875 .36182 L
.39879 .36177 L
.39882 .36171 L
.39886 .36166 L
.3989 .3616 L
.39894 .36155 L
.39898 .3615 L
.39902 .36144 L
.39905 .36139 L
Mistroke
.39909 .36134 L
.39913 .36128 L
.39917 .36123 L
.39921 .36117 L
.39925 .36112 L
.39928 .36107 L
.39932 .36101 L
.39936 .36096 L
.3994 .36091 L
.39944 .36085 L
.39948 .3608 L
.39952 .36075 L
.39955 .36069 L
.39959 .36064 L
.39963 .36059 L
.39967 .36053 L
.39971 .36048 L
.39975 .36043 L
.39979 .36038 L
.39983 .36032 L
.39986 .36027 L
.3999 .36022 L
.39994 .36016 L
.39998 .36011 L
.40002 .36006 L
.40006 .36001 L
.4001 .35995 L
.40014 .3599 L
.40018 .35985 L
.40021 .3598 L
.40025 .35974 L
.40029 .35969 L
.40033 .35964 L
.40037 .35959 L
.40041 .35953 L
.40045 .35948 L
.40049 .35943 L
.40053 .35938 L
.40057 .35933 L
.4006 .35927 L
.40064 .35922 L
.40068 .35917 L
.40072 .35912 L
.40076 .35907 L
.4008 .35902 L
.40084 .35896 L
.40088 .35891 L
.40092 .35886 L
.40096 .35881 L
.401 .35876 L
Mistroke
.40104 .35871 L
.40107 .35865 L
.40111 .3586 L
.40115 .35855 L
.40119 .3585 L
.40123 .35845 L
.40127 .3584 L
.40131 .35835 L
.40135 .3583 L
.40139 .35825 L
.40143 .35819 L
.40147 .35814 L
.40151 .35809 L
.40155 .35804 L
.40159 .35799 L
.40163 .35794 L
.40167 .35789 L
.40171 .35784 L
.40174 .35779 L
.40178 .35774 L
.40182 .35769 L
.40186 .35764 L
.4019 .35759 L
.40194 .35754 L
.40198 .35749 L
.40202 .35744 L
.40206 .35739 L
.4021 .35733 L
.40214 .35728 L
.40218 .35723 L
.40222 .35718 L
.40226 .35713 L
.4023 .35708 L
.40234 .35703 L
.40238 .35698 L
.40242 .35694 L
.40246 .35689 L
.4025 .35684 L
.40254 .35679 L
.40258 .35674 L
.40262 .35669 L
.40266 .35664 L
.4027 .35659 L
.40274 .35654 L
.40278 .35649 L
.40282 .35644 L
.40286 .35639 L
.4029 .35634 L
.40294 .35629 L
.40298 .35624 L
Mistroke
.40302 .35619 L
.40306 .35614 L
.4031 .3561 L
.40314 .35605 L
.40318 .356 L
.40322 .35595 L
.40326 .3559 L
.4033 .35585 L
.40334 .3558 L
.40338 .35575 L
.40342 .3557 L
.40346 .35566 L
.4035 .35561 L
.40354 .35556 L
.40358 .35551 L
.40362 .35546 L
.40366 .35541 L
.4037 .35537 L
.40374 .35532 L
.40378 .35527 L
.40382 .35522 L
.40386 .35517 L
.4039 .35512 L
.40394 .35508 L
.40398 .35503 L
.40402 .35498 L
.40406 .35493 L
.4041 .35488 L
.40414 .35484 L
.40418 .35479 L
.40422 .35474 L
.40426 .35469 L
.4043 .35465 L
.40434 .3546 L
.40438 .35455 L
.40443 .3545 L
.40447 .35446 L
.40451 .35441 L
.40455 .35436 L
.40459 .35431 L
.40463 .35427 L
.40467 .35422 L
.40471 .35417 L
.40475 .35412 L
.40479 .35408 L
.40483 .35403 L
.40487 .35398 L
.40491 .35394 L
.40495 .35389 L
.40499 .35384 L
Mistroke
.40503 .3538 L
.40507 .35375 L
.40511 .3537 L
.40515 .35366 L
.4052 .35361 L
.40524 .35356 L
.40528 .35352 L
.40532 .35347 L
.40536 .35342 L
.4054 .35338 L
.40544 .35333 L
.40548 .35328 L
.40552 .35324 L
.40556 .35319 L
.4056 .35315 L
.40564 .3531 L
.40568 .35305 L
.40572 .35301 L
.40577 .35296 L
.40581 .35292 L
.40585 .35287 L
.40589 .35282 L
.40593 .35278 L
.40597 .35273 L
.40601 .35269 L
.40605 .35264 L
.40609 .35259 L
.40613 .35255 L
.40617 .3525 L
.40621 .35246 L
.40626 .35241 L
.4063 .35237 L
.40634 .35232 L
.40638 .35228 L
.40642 .35223 L
.40646 .35219 L
.4065 .35214 L
.40654 .3521 L
.40658 .35205 L
.40662 .35201 L
.40666 .35196 L
.40671 .35192 L
.40675 .35187 L
.40679 .35183 L
.40683 .35178 L
.40687 .35174 L
.40691 .35169 L
.40695 .35165 L
.40699 .3516 L
.40703 .35156 L
Mistroke
.40707 .35151 L
.40712 .35147 L
.40716 .35142 L
.4072 .35138 L
.40724 .35134 L
.40728 .35129 L
.40732 .35125 L
.40736 .3512 L
.4074 .35116 L
.40744 .35111 L
.40749 .35107 L
.40753 .35103 L
.40757 .35098 L
.40761 .35094 L
.40765 .3509 L
.40769 .35085 L
.40773 .35081 L
.40777 .35076 L
.40781 .35072 L
.40786 .35068 L
.4079 .35063 L
.40794 .35059 L
.40798 .35055 L
.40802 .3505 L
.40806 .35046 L
.4081 .35042 L
.40814 .35037 L
.40819 .35033 L
.40823 .35029 L
.40827 .35024 L
.40831 .3502 L
.40835 .35016 L
.40839 .35011 L
.40843 .35007 L
.40847 .35003 L
.40852 .34998 L
.40856 .34994 L
.4086 .3499 L
.40864 .34986 L
.40868 .34981 L
.40872 .34977 L
.40876 .34973 L
.4088 .34968 L
.40885 .34964 L
.40889 .3496 L
.40893 .34956 L
.40897 .34951 L
.40901 .34947 L
.40905 .34943 L
.40909 .34939 L
Mistroke
.40914 .34935 L
.40918 .3493 L
.40922 .34926 L
.40926 .34922 L
.4093 .34918 L
.40934 .34914 L
.40938 .34909 L
.40943 .34905 L
.40947 .34901 L
.40951 .34897 L
.40955 .34893 L
.40959 .34888 L
.40963 .34884 L
.40967 .3488 L
.40972 .34876 L
.40976 .34872 L
.4098 .34868 L
.40984 .34863 L
.40988 .34859 L
.40992 .34855 L
.40996 .34851 L
.41001 .34847 L
.41005 .34843 L
.41009 .34839 L
.41013 .34835 L
.41017 .3483 L
.41021 .34826 L
.41026 .34822 L
.4103 .34818 L
.41034 .34814 L
.41038 .3481 L
.41042 .34806 L
.41046 .34802 L
.4105 .34798 L
.41055 .34794 L
.41059 .3479 L
.41063 .34785 L
.41067 .34781 L
.41071 .34777 L
.41075 .34773 L
.4108 .34769 L
.41084 .34765 L
.41088 .34761 L
.41092 .34757 L
.41096 .34753 L
.411 .34749 L
.41104 .34745 L
.41109 .34741 L
.41113 .34737 L
.41117 .34733 L
Mistroke
.41121 .34729 L
.41125 .34725 L
.41129 .34721 L
.41134 .34717 L
.41138 .34713 L
.41142 .34709 L
.41146 .34705 L
.4115 .34701 L
.41154 .34697 L
.41159 .34693 L
.41163 .34689 L
.41167 .34685 L
.41171 .34681 L
.41175 .34678 L
.41179 .34674 L
.41184 .3467 L
.41188 .34666 L
.41192 .34662 L
.41196 .34658 L
.412 .34654 L
.41204 .3465 L
.41209 .34646 L
.41213 .34642 L
.41217 .34638 L
.41221 .34634 L
.41225 .34631 L
.41229 .34627 L
.41234 .34623 L
.41238 .34619 L
.41242 .34615 L
.41246 .34611 L
.4125 .34607 L
.41254 .34603 L
.41259 .346 L
.41263 .34596 L
.41267 .34592 L
.41271 .34588 L
.41275 .34584 L
.41279 .3458 L
.41284 .34577 L
.41288 .34573 L
.41292 .34569 L
.41296 .34565 L
.413 .34561 L
.41304 .34558 L
.41309 .34554 L
.41313 .3455 L
.41317 .34546 L
.41321 .34542 L
.41325 .34539 L
Mistroke
.4133 .34535 L
.41334 .34531 L
.41338 .34527 L
.41342 .34524 L
.41346 .3452 L
.4135 .34516 L
.41355 .34512 L
.41359 .34509 L
.41363 .34505 L
.41367 .34501 L
.41371 .34497 L
.41375 .34494 L
.4138 .3449 L
.41384 .34486 L
.41388 .34482 L
.41392 .34479 L
.41396 .34475 L
.414 .34471 L
.41405 .34468 L
.41409 .34464 L
.41413 .3446 L
.41417 .34457 L
.41421 .34453 L
.41426 .34449 L
.4143 .34446 L
.41434 .34442 L
.41438 .34438 L
.41442 .34435 L
.41446 .34431 L
.41451 .34427 L
.41455 .34424 L
.41459 .3442 L
.41463 .34416 L
.41467 .34413 L
.41471 .34409 L
.41476 .34405 L
.4148 .34402 L
.41484 .34398 L
.41488 .34395 L
.41492 .34391 L
.41496 .34387 L
.41501 .34384 L
.41505 .3438 L
.41509 .34377 L
.41513 .34373 L
.41517 .3437 L
.41522 .34366 L
.41526 .34362 L
.4153 .34359 L
.41534 .34355 L
Mistroke
.41538 .34352 L
.41542 .34348 L
.41547 .34345 L
.41551 .34341 L
.41555 .34337 L
.41559 .34334 L
.41563 .3433 L
.41567 .34327 L
.41572 .34323 L
.41576 .3432 L
.4158 .34316 L
.41584 .34313 L
.41588 .34309 L
.41592 .34306 L
.41597 .34302 L
.41601 .34299 L
.41605 .34295 L
.41609 .34292 L
.41613 .34288 L
.41618 .34285 L
.41622 .34281 L
.41626 .34278 L
.4163 .34275 L
.41634 .34271 L
.41638 .34268 L
.41643 .34264 L
.41647 .34261 L
.41651 .34257 L
.41655 .34254 L
.41659 .3425 L
.41663 .34247 L
.41668 .34244 L
.41672 .3424 L
.41676 .34237 L
.4168 .34233 L
.41684 .3423 L
.41688 .34227 L
.41693 .34223 L
.41697 .3422 L
.41701 .34216 L
.41705 .34213 L
.41709 .3421 L
.41713 .34206 L
.41718 .34203 L
.41722 .342 L
.41726 .34196 L
.4173 .34193 L
.41734 .34189 L
.41738 .34186 L
.41743 .34183 L
Mistroke
.41747 .34179 L
.41751 .34176 L
.41755 .34173 L
.41759 .34169 L
.41763 .34166 L
.41768 .34163 L
.41772 .34159 L
.41776 .34156 L
.4178 .34153 L
.41784 .3415 L
.41788 .34146 L
.41793 .34143 L
.41797 .3414 L
.41801 .34136 L
.41805 .34133 L
.41809 .3413 L
.41813 .34127 L
.41817 .34123 L
.41822 .3412 L
.41826 .34117 L
.4183 .34114 L
.41834 .3411 L
.41838 .34107 L
.41842 .34104 L
.41847 .34101 L
.41851 .34097 L
.41855 .34094 L
.41859 .34091 L
.41863 .34088 L
.41867 .34084 L
.41872 .34081 L
.41876 .34078 L
.4188 .34075 L
.41884 .34072 L
.41888 .34068 L
.41892 .34065 L
.41896 .34062 L
.41901 .34059 L
.41905 .34056 L
.41909 .34053 L
.41913 .34049 L
.41917 .34046 L
.41921 .34043 L
.41925 .3404 L
.4193 .34037 L
.41934 .34034 L
.41938 .3403 L
.41942 .34027 L
.41946 .34024 L
.4195 .34021 L
Mistroke
.41955 .34018 L
.41959 .34015 L
.41963 .34012 L
.41967 .34009 L
.41971 .34005 L
.41975 .34002 L
.41979 .33999 L
.41984 .33996 L
.41988 .33993 L
.41992 .3399 L
.41996 .33987 L
.42 .33984 L
.42004 .33981 L
.42008 .33978 L
.42013 .33975 L
.42017 .33972 L
.42021 .33969 L
.42025 .33965 L
.42029 .33962 L
.42033 .33959 L
.42037 .33956 L
.42041 .33953 L
.42046 .3395 L
.4205 .33947 L
.42054 .33944 L
.42058 .33941 L
.42062 .33938 L
.42066 .33935 L
.4207 .33932 L
.42075 .33929 L
.42079 .33926 L
.42083 .33923 L
.42087 .3392 L
.42091 .33917 L
.42095 .33914 L
.42099 .33911 L
.42103 .33908 L
.42108 .33905 L
.42112 .33902 L
.42116 .33899 L
.4212 .33896 L
.42124 .33893 L
.42128 .3389 L
.42132 .33888 L
.42136 .33885 L
.42141 .33882 L
.42145 .33879 L
.42149 .33876 L
.42153 .33873 L
.42157 .3387 L
Mistroke
.42161 .33867 L
.42165 .33864 L
.42169 .33861 L
.42174 .33858 L
.42178 .33855 L
.42182 .33853 L
.42186 .3385 L
.4219 .33847 L
.42194 .33844 L
.42198 .33841 L
.42202 .33838 L
.42206 .33835 L
.42211 .33832 L
.42215 .3383 L
.42219 .33827 L
.42223 .33824 L
.42227 .33821 L
.42231 .33818 L
.42235 .33815 L
.42239 .33812 L
.42243 .3381 L
.42247 .33807 L
.42252 .33804 L
.42256 .33801 L
.4226 .33798 L
.42264 .33795 L
.42268 .33793 L
.42272 .3379 L
.42276 .33787 L
.4228 .33784 L
.42284 .33781 L
.42288 .33779 L
.42293 .33776 L
.42297 .33773 L
.42301 .3377 L
.42305 .33768 L
.42309 .33765 L
.42313 .33762 L
.42317 .33759 L
.42321 .33757 L
.42325 .33754 L
.42329 .33751 L
.42333 .33748 L
.42338 .33746 L
.42342 .33743 L
.42346 .3374 L
.4235 .33737 L
.42354 .33735 L
.42358 .33732 L
.42362 .33729 L
Mistroke
.42366 .33727 L
.4237 .33724 L
.42374 .33721 L
.42378 .33718 L
.42382 .33716 L
.42387 .33713 L
.42391 .3371 L
.42395 .33708 L
.42399 .33705 L
.42403 .33702 L
.42407 .337 L
.42411 .33697 L
.42415 .33694 L
.42419 .33692 L
.42423 .33689 L
.42427 .33686 L
.42431 .33684 L
.42435 .33681 L
.42439 .33678 L
.42444 .33676 L
.42448 .33673 L
.42452 .33671 L
.42456 .33668 L
.4246 .33665 L
.42464 .33663 L
.42468 .3366 L
.42472 .33657 L
.42476 .33655 L
.4248 .33652 L
.42484 .3365 L
.42488 .33647 L
.42492 .33645 L
.42496 .33642 L
.425 .33639 L
.42504 .33637 L
.42508 .33634 L
.42513 .33632 L
.42517 .33629 L
.42521 .33627 L
.42525 .33624 L
.42529 .33621 L
.42533 .33619 L
.42537 .33616 L
.42541 .33614 L
.42545 .33611 L
.42549 .33609 L
.42553 .33606 L
.42557 .33604 L
.42561 .33601 L
.42565 .33599 L
Mistroke
.42569 .33596 L
.42573 .33594 L
.42577 .33591 L
.42581 .33589 L
.42585 .33586 L
.42589 .33584 L
.42593 .33581 L
.42597 .33579 L
.42601 .33576 L
.42605 .33574 L
.42609 .33571 L
.42613 .33569 L
.42618 .33566 L
.42622 .33564 L
.42626 .33561 L
.4263 .33559 L
.42634 .33557 L
.42638 .33554 L
.42642 .33552 L
.42646 .33549 L
.4265 .33547 L
.42654 .33544 L
.42658 .33542 L
.42662 .3354 L
.42666 .33537 L
.4267 .33535 L
.42674 .33532 L
.42678 .3353 L
.42682 .33528 L
.42686 .33525 L
.4269 .33523 L
.42694 .3352 L
.42698 .33518 L
.42702 .33516 L
.42706 .33513 L
.4271 .33511 L
.42714 .33509 L
.42718 .33506 L
.42722 .33504 L
.42726 .33501 L
.4273 .33499 L
.42734 .33497 L
.42738 .33494 L
.42742 .33492 L
.42746 .3349 L
.4275 .33487 L
.42754 .33485 L
.42758 .33483 L
.42762 .3348 L
.42766 .33478 L
Mistroke
.4277 .33476 L
.42774 .33473 L
.42778 .33471 L
.42782 .33469 L
.42786 .33467 L
.4279 .33464 L
.42794 .33462 L
.42798 .3346 L
.42802 .33457 L
.42806 .33455 L
.42809 .33453 L
.42813 .33451 L
.42817 .33448 L
.42821 .33446 L
.42825 .33444 L
.42829 .33442 L
.42833 .33439 L
.42837 .33437 L
.42841 .33435 L
.42845 .33433 L
.42849 .3343 L
.42853 .33428 L
.42857 .33426 L
.42861 .33424 L
.42865 .33421 L
.42869 .33419 L
.42873 .33417 L
.42877 .33415 L
.42881 .33413 L
.42885 .3341 L
.42889 .33408 L
.42893 .33406 L
.42897 .33404 L
.42901 .33402 L
.42904 .334 L
.42908 .33397 L
.42912 .33395 L
.42916 .33393 L
.4292 .33391 L
.42924 .33389 L
.42928 .33387 L
.42932 .33384 L
.42936 .33382 L
.4294 .3338 L
.42944 .33378 L
.42948 .33376 L
.42952 .33374 L
.42956 .33372 L
.4296 .33369 L
.42964 .33367 L
Mistroke
.42967 .33365 L
.42971 .33363 L
.42975 .33361 L
.42979 .33359 L
.42983 .33357 L
.42987 .33355 L
.42991 .33353 L
.42995 .3335 L
.42999 .33348 L
.43003 .33346 L
.43007 .33344 L
.43011 .33342 L
.43014 .3334 L
.43018 .33338 L
.43022 .33336 L
.43026 .33334 L
.4303 .33332 L
.43034 .3333 L
.43038 .33328 L
.43042 .33326 L
.43046 .33324 L
.4305 .33322 L
.43053 .3332 L
.43057 .33317 L
.43061 .33315 L
.43065 .33313 L
.43069 .33311 L
.43073 .33309 L
.43077 .33307 L
.43081 .33305 L
.43085 .33303 L
.43088 .33301 L
.43092 .33299 L
.43096 .33297 L
.431 .33295 L
.43104 .33293 L
.43108 .33291 L
.43112 .33289 L
.43116 .33287 L
.43119 .33286 L
.43123 .33284 L
.43127 .33282 L
.43131 .3328 L
.43135 .33278 L
.43139 .33276 L
.43143 .33274 L
.43147 .33272 L
.4315 .3327 L
.43154 .33268 L
.43158 .33266 L
Mistroke
.43162 .33264 L
.43166 .33262 L
.4317 .3326 L
.43174 .33258 L
.43177 .33256 L
.43181 .33254 L
.43185 .33253 L
.43189 .33251 L
.43193 .33249 L
.43197 .33247 L
.43201 .33245 L
.43204 .33243 L
.43208 .33241 L
.43212 .33239 L
.43216 .33237 L
.4322 .33236 L
.43224 .33234 L
.43227 .33232 L
.43231 .3323 L
.43235 .33228 L
.43239 .33226 L
.43243 .33224 L
.43247 .33223 L
.4325 .33221 L
.43254 .33219 L
.43258 .33217 L
.43262 .33215 L
.43266 .33213 L
.43269 .33212 L
.43273 .3321 L
.43277 .33208 L
.43281 .33206 L
.43285 .33204 L
.43289 .33202 L
.43292 .33201 L
.43296 .33199 L
.433 .33197 L
.43304 .33195 L
.43308 .33193 L
.43311 .33192 L
.43315 .3319 L
.43319 .33188 L
.43323 .33186 L
.43327 .33185 L
.4333 .33183 L
.43334 .33181 L
.43338 .33179 L
.43342 .33178 L
.43345 .33176 L
.43349 .33174 L
Mistroke
.43353 .33172 L
.43357 .33171 L
.43361 .33169 L
.43364 .33167 L
.43368 .33165 L
.43372 .33164 L
.43376 .33162 L
.4338 .3316 L
.43383 .33158 L
.43387 .33157 L
.43391 .33155 L
.43395 .33153 L
.43398 .33152 L
.43402 .3315 L
.43406 .33148 L
.4341 .33147 L
.43413 .33145 L
.43417 .33143 L
.43421 .33141 L
.43425 .3314 L
.43428 .33138 L
.43432 .33136 L
.43436 .33135 L
.4344 .33133 L
.43443 .33131 L
.43447 .3313 L
.43451 .33128 L
.43455 .33126 L
.43458 .33125 L
.43462 .33123 L
.43466 .33122 L
.4347 .3312 L
.43473 .33118 L
.43477 .33117 L
.43481 .33115 L
.43485 .33113 L
.43488 .33112 L
.43492 .3311 L
.43496 .33109 L
.43499 .33107 L
.43503 .33105 L
.43507 .33104 L
.43511 .33102 L
.43514 .33101 L
.43518 .33099 L
.43522 .33097 L
.43525 .33096 L
.43529 .33094 L
.43533 .33093 L
.43537 .33091 L
Mistroke
.4354 .3309 L
.43544 .33088 L
.43548 .33086 L
.43551 .33085 L
.43555 .33083 L
.43559 .33082 L
.43563 .3308 L
.43566 .33079 L
.4357 .33077 L
.43574 .33076 L
.43577 .33074 L
.43581 .33072 L
.43585 .33071 L
.43588 .33069 L
.43592 .33068 L
.43596 .33066 L
.43599 .33065 L
.43603 .33063 L
.43607 .33062 L
.4361 .3306 L
.43614 .33059 L
.43618 .33057 L
.43621 .33056 L
.43625 .33054 L
.43629 .33053 L
.43632 .33051 L
.43636 .3305 L
.4364 .33048 L
.43643 .33047 L
.43647 .33046 L
.43651 .33044 L
.43654 .33043 L
.43658 .33041 L
.43662 .3304 L
.43665 .33038 L
.43669 .33037 L
.43673 .33035 L
.43676 .33034 L
.4368 .33033 L
.43684 .33031 L
.43687 .3303 L
.43691 .33028 L
.43694 .33027 L
.43698 .33025 L
.43702 .33024 L
.43705 .33023 L
.43709 .33021 L
.43713 .3302 L
.43716 .33018 L
.4372 .33017 L
Mistroke
.43723 .33016 L
.43727 .33014 L
.43731 .33013 L
.43734 .33011 L
.43738 .3301 L
.43742 .33009 L
.43745 .33007 L
.43749 .33006 L
.43752 .33005 L
.43756 .33003 L
.4376 .33002 L
.43763 .33 L
.43767 .32999 L
.4377 .32998 L
.43774 .32996 L
.43778 .32995 L
.43781 .32994 L
.43785 .32992 L
.43788 .32991 L
.43792 .3299 L
.43795 .32988 L
.43799 .32987 L
.43803 .32986 L
.43806 .32984 L
.4381 .32983 L
.43813 .32982 L
.43817 .3298 L
.43821 .32979 L
.43824 .32978 L
.43828 .32977 L
.43831 .32975 L
.43835 .32974 L
.43838 .32973 L
.43842 .32971 L
.43845 .3297 L
.43849 .32969 L
.43853 .32968 L
.43856 .32966 L
.4386 .32965 L
.43863 .32964 L
.43867 .32963 L
.4387 .32961 L
.43874 .3296 L
.43877 .32959 L
.43881 .32958 L
.43885 .32956 L
.43888 .32955 L
.43892 .32954 L
.43895 .32953 L
.43899 .32951 L
Mistroke
.43902 .3295 L
.43906 .32949 L
.43909 .32948 L
.43913 .32946 L
.43916 .32945 L
.4392 .32944 L
.43923 .32943 L
.43927 .32942 L
.4393 .3294 L
.43934 .32939 L
.43937 .32938 L
.43941 .32937 L
.43944 .32936 L
.43948 .32935 L
.43951 .32933 L
.43955 .32932 L
.43958 .32931 L
.43962 .3293 L
.43965 .32929 L
.43969 .32927 L
.43972 .32926 L
.43976 .32925 L
.43979 .32924 L
.43983 .32923 L
.43986 .32922 L
.4399 .32921 L
.43993 .32919 L
.43997 .32918 L
.44 .32917 L
.44004 .32916 L
.44007 .32915 L
.44011 .32914 L
.44014 .32913 L
.44018 .32912 L
.44021 .3291 L
.44025 .32909 L
.44028 .32908 L
.44032 .32907 L
.44035 .32906 L
.44038 .32905 L
.44042 .32904 L
.44045 .32903 L
.44049 .32902 L
.44052 .32901 L
.44056 .32899 L
.44059 .32898 L
.44063 .32897 L
.44066 .32896 L
.44069 .32895 L
.44073 .32894 L
Mistroke
.44076 .32893 L
.4408 .32892 L
.44083 .32891 L
.44087 .3289 L
.4409 .32889 L
.44093 .32888 L
.44097 .32887 L
.441 .32886 L
.44104 .32885 L
.44107 .32884 L
.44111 .32883 L
.44114 .32882 L
.44117 .32881 L
.44121 .3288 L
.44124 .32878 L
.44128 .32877 L
.44131 .32876 L
.44134 .32875 L
.44138 .32874 L
.44141 .32873 L
.44145 .32872 L
.44148 .32871 L
.44151 .3287 L
.44155 .32869 L
.44158 .32868 L
.44162 .32868 L
.44165 .32867 L
.44168 .32866 L
.44172 .32865 L
.44175 .32864 L
.44178 .32863 L
.44182 .32862 L
.44185 .32861 L
.44189 .3286 L
.44192 .32859 L
.44195 .32858 L
.44199 .32857 L
.44202 .32856 L
.44205 .32855 L
.44209 .32854 L
.44212 .32853 L
.44215 .32852 L
.44219 .32851 L
.44222 .3285 L
.44226 .32849 L
.44229 .32849 L
.44232 .32848 L
.44236 .32847 L
.44239 .32846 L
.44242 .32845 L
Mistroke
.44246 .32844 L
.44249 .32843 L
.44252 .32842 L
.44256 .32841 L
.44259 .3284 L
.44262 .32839 L
.44266 .32839 L
.44269 .32838 L
.44272 .32837 L
.44275 .32836 L
.44279 .32835 L
.44282 .32834 L
.44285 .32833 L
.44289 .32832 L
.44292 .32832 L
.44295 .32831 L
.44299 .3283 L
.44302 .32829 L
.44305 .32828 L
.44309 .32827 L
.44312 .32827 L
.44315 .32826 L
.44318 .32825 L
.44322 .32824 L
.44325 .32823 L
.44328 .32822 L
.44332 .32822 L
.44335 .32821 L
.44338 .3282 L
.44341 .32819 L
.44345 .32818 L
.44348 .32817 L
.44351 .32817 L
.44354 .32816 L
.44358 .32815 L
.44361 .32814 L
.44364 .32813 L
.44368 .32813 L
.44371 .32812 L
.44374 .32811 L
.44377 .3281 L
.44381 .3281 L
.44384 .32809 L
.44387 .32808 L
.4439 .32807 L
.44394 .32806 L
.44397 .32806 L
.444 .32805 L
.44403 .32804 L
.44406 .32803 L
Mistroke
.4441 .32803 L
.44413 .32802 L
.44416 .32801 L
.44419 .328 L
.44423 .328 L
.44426 .32799 L
.44429 .32798 L
.44432 .32797 L
.44435 .32797 L
.44439 .32796 L
.44442 .32795 L
.44445 .32795 L
.44448 .32794 L
.44452 .32793 L
.44455 .32792 L
.44458 .32792 L
.44461 .32791 L
.44464 .3279 L
.44468 .3279 L
.44471 .32789 L
.44474 .32788 L
.44477 .32788 L
.4448 .32787 L
.44483 .32786 L
.44487 .32786 L
.4449 .32785 L
.44493 .32784 L
.44496 .32783 L
.44499 .32783 L
.44502 .32782 L
.44506 .32781 L
.44509 .32781 L
.44512 .3278 L
.44515 .3278 L
.44518 .32779 L
.44521 .32778 L
.44525 .32778 L
.44528 .32777 L
.44531 .32776 L
.44534 .32776 L
.44537 .32775 L
.4454 .32774 L
.44543 .32774 L
.44547 .32773 L
.4455 .32773 L
.44553 .32772 L
.44556 .32771 L
.44559 .32771 L
.44562 .3277 L
.44565 .32769 L
Mistroke
.44569 .32769 L
.44572 .32768 L
.44575 .32768 L
.44578 .32767 L
.44581 .32766 L
.44584 .32766 L
.44587 .32765 L
.4459 .32765 L
.44593 .32764 L
.44597 .32764 L
.446 .32763 L
.44603 .32762 L
.44606 .32762 L
.44609 .32761 L
.44612 .32761 L
.44615 .3276 L
.44618 .3276 L
.44621 .32759 L
.44624 .32758 L
.44627 .32758 L
.44631 .32757 L
.44634 .32757 L
.44637 .32756 L
.4464 .32756 L
.44643 .32755 L
.44646 .32755 L
.44649 .32754 L
.44652 .32754 L
.44655 .32753 L
.44658 .32753 L
.44661 .32752 L
.44664 .32752 L
.44667 .32751 L
.4467 .32751 L
.44673 .3275 L
.44677 .3275 L
.4468 .32749 L
.44683 .32749 L
.44686 .32748 L
.44689 .32748 L
.44692 .32747 L
.44695 .32747 L
.44698 .32746 L
.44701 .32746 L
.44704 .32745 L
.44707 .32745 L
.4471 .32744 L
.44713 .32744 L
.44716 .32743 L
.44719 .32743 L
Mistroke
.44722 .32742 L
.44725 .32742 L
.44728 .32741 L
.44731 .32741 L
.44734 .3274 L
.44737 .3274 L
.4474 .3274 L
.44743 .32739 L
.44746 .32739 L
.44749 .32738 L
.44752 .32738 L
.44755 .32737 L
.44758 .32737 L
.44761 .32737 L
.44764 .32736 L
.44767 .32736 L
.4477 .32735 L
.44773 .32735 L
.44776 .32734 L
.44779 .32734 L
.44782 .32734 L
.44785 .32733 L
.44788 .32733 L
.44791 .32732 L
.44794 .32732 L
.44797 .32732 L
.448 .32731 L
.44802 .32731 L
.44805 .3273 L
.44808 .3273 L
.44811 .3273 L
.44814 .32729 L
.44817 .32729 L
.4482 .32729 L
.44823 .32728 L
.44826 .32728 L
.44829 .32727 L
.44832 .32727 L
.44835 .32727 L
.44838 .32726 L
.44841 .32726 L
.44844 .32726 L
.44846 .32725 L
.44849 .32725 L
.44852 .32725 L
.44855 .32724 L
.44858 .32724 L
.44861 .32724 L
.44864 .32723 L
.44867 .32723 L
Mistroke
.4487 .32723 L
.44873 .32722 L
.44876 .32722 L
.44878 .32722 L
.44881 .32721 L
.44884 .32721 L
.44887 .32721 L
.4489 .3272 L
.44893 .3272 L
.44896 .3272 L
.44899 .3272 L
.44901 .32719 L
.44904 .32719 L
.44907 .32719 L
.4491 .32718 L
.44913 .32718 L
.44916 .32718 L
.44919 .32718 L
.44922 .32717 L
.44924 .32717 L
.44927 .32717 L
.4493 .32716 L
.44933 .32716 L
.44936 .32716 L
.44939 .32716 L
.44941 .32715 L
.44944 .32715 L
.44947 .32715 L
.4495 .32715 L
.44953 .32714 L
.44956 .32714 L
.44958 .32714 L
.44961 .32714 L
.44964 .32713 L
.44967 .32713 L
.4497 .32713 L
.44973 .32713 L
.44975 .32712 L
.44978 .32712 L
.44981 .32712 L
.44984 .32712 L
.44987 .32712 L
.44989 .32711 L
.44992 .32711 L
.44995 .32711 L
.44998 .32711 L
.45001 .32711 L
.45003 .3271 L
.45006 .3271 L
.45009 .3271 L
Mistroke
.45012 .3271 L
.45015 .3271 L
.45017 .32709 L
.4502 .32709 L
.45023 .32709 L
.45026 .32709 L
.45028 .32709 L
.45031 .32708 L
.45034 .32708 L
.45037 .32708 L
.45039 .32708 L
.45042 .32708 L
.45045 .32708 L
.45048 .32707 L
.4505 .32707 L
.45053 .32707 L
.45056 .32707 L
.45059 .32707 L
.45061 .32707 L
.45064 .32707 L
.45067 .32706 L
.4507 .32706 L
.45072 .32706 L
.45075 .32706 L
.45078 .32706 L
.45081 .32706 L
.45083 .32706 L
.45086 .32705 L
.45089 .32705 L
.45091 .32705 L
.45094 .32705 L
.45097 .32705 L
.451 .32705 L
.45102 .32705 L
.45105 .32705 L
.45108 .32705 L
.4511 .32704 L
.45113 .32704 L
.45116 .32704 L
.45118 .32704 L
.45121 .32704 L
.45124 .32704 L
.45126 .32704 L
.45129 .32704 L
.45132 .32704 L
.45135 .32704 L
.45137 .32704 L
.4514 .32703 L
.45143 .32703 L
.45145 .32703 L
Mistroke
.45148 .32703 L
.45151 .32703 L
.45153 .32703 L
.45156 .32703 L
.45159 .32703 L
.45161 .32703 L
.45164 .32703 L
.45166 .32703 L
.45169 .32703 L
.45172 .32703 L
.45174 .32703 L
.45177 .32703 L
.4518 .32703 L
.45182 .32703 L
.45185 .32703 L
.45188 .32703 L
.4519 .32702 L
.45193 .32702 L
.45195 .32702 L
.45198 .32702 L
.45201 .32702 L
.45203 .32702 L
.45206 .32702 L
.45209 .32702 L
.45211 .32702 L
.45214 .32702 L
.45216 .32702 L
.45219 .32702 L
.45222 .32702 L
.45224 .32702 L
.45227 .32702 L
.45229 .32702 L
.45232 .32702 L
.45234 .32702 L
.45237 .32702 L
.4524 .32702 L
.45242 .32702 L
.45245 .32702 L
.45247 .32702 L
.4525 .32702 L
.45252 .32702 L
.45255 .32703 L
.45258 .32703 L
.4526 .32703 L
.45263 .32703 L
.45265 .32703 L
.45268 .32703 L
.4527 .32703 L
.45273 .32703 L
.45275 .32703 L
Mistroke
.45278 .32703 L
.45281 .32703 L
.45283 .32703 L
.45286 .32703 L
.45288 .32703 L
.45291 .32703 L
.45293 .32703 L
.45296 .32703 L
.45298 .32703 L
.45301 .32703 L
.45303 .32704 L
.45306 .32704 L
.45308 .32704 L
.45311 .32704 L
.45313 .32704 L
.45316 .32704 L
.45318 .32704 L
.45321 .32704 L
.45323 .32704 L
.45326 .32704 L
.45328 .32704 L
.45331 .32705 L
.45333 .32705 L
.45336 .32705 L
.45338 .32705 L
.45341 .32705 L
.45343 .32705 L
.45346 .32705 L
.45348 .32705 L
.45351 .32705 L
.45353 .32706 L
.45356 .32706 L
.45358 .32706 L
.45361 .32706 L
.45363 .32706 L
.45366 .32706 L
.45368 .32706 L
.4537 .32706 L
.45373 .32707 L
.45375 .32707 L
.45378 .32707 L
.4538 .32707 L
.45383 .32707 L
.45385 .32707 L
.45388 .32707 L
.4539 .32708 L
.45392 .32708 L
.45395 .32708 L
.45397 .32708 L
.454 .32708 L
Mistroke
.45402 .32708 L
.45405 .32709 L
.45407 .32709 L
.45409 .32709 L
.45412 .32709 L
.45414 .32709 L
.45417 .32709 L
.45419 .3271 L
.45421 .3271 L
.45424 .3271 L
.45426 .3271 L
.45429 .3271 L
.45431 .32711 L
.45433 .32711 L
.45436 .32711 L
.45438 .32711 L
.45441 .32711 L
.45443 .32712 L
.45445 .32712 L
.45448 .32712 L
.4545 .32712 L
.45452 .32712 L
.45455 .32713 L
.45457 .32713 L
.4546 .32713 L
.45462 .32713 L
.45464 .32713 L
.45467 .32714 L
.45469 .32714 L
.45471 .32714 L
.45474 .32714 L
.45476 .32715 L
.45478 .32715 L
.45481 .32715 L
.45483 .32715 L
.45485 .32716 L
.45488 .32716 L
.4549 .32716 L
.45492 .32716 L
.45495 .32717 L
.45497 .32717 L
.45499 .32717 L
.45502 .32717 L
.45504 .32718 L
.45506 .32718 L
.45509 .32718 L
.45511 .32718 L
.45513 .32719 L
.45515 .32719 L
.45518 .32719 L
Mistroke
.4552 .32719 L
.45522 .3272 L
.45525 .3272 L
.45527 .3272 L
.45529 .32721 L
.45532 .32721 L
.45534 .32721 L
.45536 .32721 L
.45538 .32722 L
.45541 .32722 L
.45543 .32722 L
.45545 .32723 L
.45547 .32723 L
.4555 .32723 L
.45552 .32724 L
.45554 .32724 L
.45557 .32724 L
.45559 .32724 L
.45561 .32725 L
.45563 .32725 L
.45566 .32725 L
.45568 .32726 L
.4557 .32726 L
.45572 .32726 L
.45575 .32727 L
.45577 .32727 L
.45579 .32727 L
.45581 .32728 L
.45583 .32728 L
.45586 .32728 L
.45588 .32729 L
.4559 .32729 L
.45592 .32729 L
.45595 .3273 L
.45597 .3273 L
.45599 .3273 L
.45601 .32731 L
.45603 .32731 L
.45606 .32731 L
.45608 .32732 L
.4561 .32732 L
.45612 .32733 L
.45614 .32733 L
.45617 .32733 L
.45619 .32734 L
.45621 .32734 L
.45623 .32734 L
.45625 .32735 L
.45628 .32735 L
.4563 .32735 L
Mistroke
.45632 .32736 L
.45634 .32736 L
.45636 .32737 L
.45638 .32737 L
.45641 .32737 L
.45643 .32738 L
.45645 .32738 L
.45647 .32739 L
.45649 .32739 L
.45651 .32739 L
.45653 .3274 L
.45656 .3274 L
.45658 .32741 L
.4566 .32741 L
.45662 .32741 L
.45664 .32742 L
.45666 .32742 L
.45668 .32743 L
.45671 .32743 L
.45673 .32743 L
.45675 .32744 L
.45677 .32744 L
.45679 .32745 L
.45681 .32745 L
.45683 .32746 L
.45685 .32746 L
.45688 .32746 L
.4569 .32747 L
.45692 .32747 L
.45694 .32748 L
.45696 .32748 L
.45698 .32749 L
.457 .32749 L
.45702 .32749 L
.45704 .3275 L
.45706 .3275 L
.45708 .32751 L
.45711 .32751 L
.45713 .32752 L
.45715 .32752 L
.45717 .32753 L
.45719 .32753 L
.45721 .32753 L
.45723 .32754 L
.45725 .32754 L
.45727 .32755 L
.45729 .32755 L
.45731 .32756 L
.45733 .32756 L
.45735 .32757 L
Mistroke
.45737 .32757 L
.45739 .32758 L
.45742 .32758 L
.45744 .32759 L
.45746 .32759 L
.45748 .3276 L
.4575 .3276 L
.45752 .32761 L
.45754 .32761 L
.45756 .32762 L
.45758 .32762 L
.4576 .32763 L
.45762 .32763 L
.45764 .32764 L
.45766 .32764 L
.45768 .32765 L
.4577 .32765 L
.45772 .32766 L
.45774 .32766 L
.45776 .32767 L
.45778 .32767 L
.4578 .32768 L
.45782 .32768 L
.45784 .32769 L
.45786 .32769 L
.45788 .3277 L
.4579 .3277 L
.45792 .32771 L
.45794 .32771 L
.45796 .32772 L
.45798 .32772 L
.458 .32773 L
.45802 .32773 L
.45804 .32774 L
.45806 .32775 L
.45808 .32775 L
.4581 .32776 L
.45812 .32776 L
.45813 .32777 L
.45815 .32777 L
.45817 .32778 L
.45819 .32778 L
.45821 .32779 L
.45823 .32779 L
.45825 .3278 L
.45827 .32781 L
.45829 .32781 L
.45831 .32782 L
.45833 .32782 L
.45835 .32783 L
Mistroke
.45837 .32783 L
.45839 .32784 L
.45841 .32785 L
.45842 .32785 L
.45844 .32786 L
.45846 .32786 L
.45848 .32787 L
.4585 .32787 L
.45852 .32788 L
.45854 .32789 L
.45856 .32789 L
.45858 .3279 L
.4586 .3279 L
.45862 .32791 L
.45863 .32792 L
.45865 .32792 L
.45867 .32793 L
.45869 .32793 L
.45871 .32794 L
.45873 .32795 L
.45875 .32795 L
.45877 .32796 L
.45878 .32796 L
.4588 .32797 L
.45882 .32798 L
.45884 .32798 L
.45886 .32799 L
.45888 .32799 L
.4589 .328 L
.45891 .32801 L
.45893 .32801 L
.45895 .32802 L
.45897 .32802 L
.45899 .32803 L
.45901 .32804 L
.45903 .32804 L
.45904 .32805 L
.45906 .32806 L
.45908 .32806 L
.4591 .32807 L
.45912 .32808 L
.45914 .32808 L
.45915 .32809 L
.45917 .32809 L
.45919 .3281 L
.45921 .32811 L
.45923 .32811 L
.45924 .32812 L
.45926 .32813 L
.45928 .32813 L
Mistroke
.4593 .32814 L
.45932 .32815 L
.45933 .32815 L
.45935 .32816 L
.45937 .32817 L
.45939 .32817 L
.45941 .32818 L
.45942 .32819 L
.45944 .32819 L
.45946 .3282 L
.45948 .32821 L
.45949 .32821 L
.45951 .32822 L
.45953 .32823 L
.45955 .32823 L
.45957 .32824 L
.45958 .32825 L
.4596 .32825 L
.45962 .32826 L
.45964 .32827 L
.45965 .32827 L
.45967 .32828 L
.45969 .32829 L
.45971 .3283 L
.45972 .3283 L
.45974 .32831 L
.45976 .32832 L
.45977 .32832 L
.45979 .32833 L
.45981 .32834 L
.45983 .32834 L
.45984 .32835 L
.45986 .32836 L
.45988 .32837 L
.4599 .32837 L
.45991 .32838 L
.45993 .32839 L
.45995 .32839 L
.45996 .3284 L
.45998 .32841 L
.46 .32842 L
.46002 .32842 L
.46003 .32843 L
.46005 .32844 L
.46007 .32844 L
.46008 .32845 L
.4601 .32846 L
.46012 .32847 L
.46013 .32847 L
.46015 .32848 L
Mistroke
.46017 .32849 L
.46018 .3285 L
.4602 .3285 L
.46022 .32851 L
.46023 .32852 L
.46025 .32853 L
.46027 .32853 L
.46028 .32854 L
.4603 .32855 L
.46032 .32855 L
.46033 .32856 L
.46035 .32857 L
.46037 .32858 L
.46038 .32859 L
.4604 .32859 L
.46042 .3286 L
.46043 .32861 L
.46045 .32862 L
.46046 .32862 L
.46048 .32863 L
.4605 .32864 L
.46051 .32865 L
.46053 .32865 L
.46055 .32866 L
.46056 .32867 L
.46058 .32868 L
.46059 .32868 L
.46061 .32869 L
.46063 .3287 L
.46064 .32871 L
.46066 .32872 L
.46067 .32872 L
.46069 .32873 L
.46071 .32874 L
.46072 .32875 L
.46074 .32876 L
.46075 .32876 L
.46077 .32877 L
.46079 .32878 L
.4608 .32879 L
.46082 .32879 L
.46083 .3288 L
.46085 .32881 L
.46086 .32882 L
.46088 .32883 L
.4609 .32883 L
.46091 .32884 L
.46093 .32885 L
.46094 .32886 L
.46096 .32887 L
Mistroke
.46097 .32888 L
.46099 .32888 L
.461 .32889 L
.46102 .3289 L
.46104 .32891 L
.46105 .32892 L
.46107 .32892 L
.46108 .32893 L
.4611 .32894 L
.46111 .32895 L
.46113 .32896 L
.46114 .32897 L
.46116 .32897 L
.46117 .32898 L
.46119 .32899 L
.4612 .329 L
.46122 .32901 L
.46123 .32902 L
.46125 .32902 L
.46126 .32903 L
.46128 .32904 L
.46129 .32905 L
.46131 .32906 L
.46132 .32907 L
.46134 .32907 L
.46135 .32908 L
.46137 .32909 L
.46138 .3291 L
.4614 .32911 L
.46141 .32912 L
.46143 .32913 L
.46144 .32913 L
.46146 .32914 L
.46147 .32915 L
.46149 .32916 L
.4615 .32917 L
.46152 .32918 L
.46153 .32919 L
.46155 .32919 L
.46156 .3292 L
.46157 .32921 L
.46159 .32922 L
.4616 .32923 L
.46162 .32924 L
.46163 .32925 L
.46165 .32925 L
.46166 .32926 L
.46168 .32927 L
.46169 .32928 L
.4617 .32929 L
Mistroke
.46172 .3293 L
.46173 .32931 L
.46175 .32932 L
.46176 .32933 L
.46178 .32933 L
.46179 .32934 L
.4618 .32935 L
.46182 .32936 L
.46183 .32937 L
.46185 .32938 L
.46186 .32939 L
.46187 .3294 L
.46189 .32941 L
.4619 .32941 L
.46192 .32942 L
.46193 .32943 L
.46194 .32944 L
.46196 .32945 L
.46197 .32946 L
.46199 .32947 L
.462 .32948 L
.46201 .32949 L
.46203 .3295 L
.46204 .32951 L
.46206 .32951 L
.46207 .32952 L
.46208 .32953 L
.4621 .32954 L
.46211 .32955 L
.46212 .32956 L
.46214 .32957 L
.46215 .32958 L
.46216 .32959 L
.46218 .3296 L
.46219 .32961 L
.4622 .32962 L
.46222 .32962 L
.46223 .32963 L
.46224 .32964 L
.46226 .32965 L
.46227 .32966 L
.46228 .32967 L
.4623 .32968 L
.46231 .32969 L
.46232 .3297 L
.46234 .32971 L
.46235 .32972 L
.46236 .32973 L
.46238 .32974 L
.46239 .32975 L
Mistroke
.4624 .32976 L
.46242 .32977 L
.46243 .32978 L
.46244 .32978 L
.46246 .32979 L
.46247 .3298 L
.46248 .32981 L
.46249 .32982 L
.46251 .32983 L
.46252 .32984 L
.46253 .32985 L
.46255 .32986 L
.46256 .32987 L
.46257 .32988 L
.46258 .32989 L
.4626 .3299 L
.46261 .32991 L
.46262 .32992 L
.46264 .32993 L
.46265 .32994 L
.46266 .32995 L
.46267 .32996 L
.46269 .32997 L
.4627 .32998 L
.46271 .32999 L
.46272 .33 L
.46274 .33001 L
.46275 .33002 L
.46276 .33003 L
.46277 .33004 L
.46279 .33005 L
.4628 .33006 L
.46281 .33007 L
.46282 .33008 L
.46283 .33009 L
.46285 .3301 L
.46286 .3301 L
.46287 .33011 L
.46288 .33012 L
.4629 .33013 L
.46291 .33014 L
.46292 .33015 L
.46293 .33016 L
.46294 .33017 L
.46296 .33018 L
.46297 .33019 L
.46298 .3302 L
.46299 .33021 L
.463 .33022 L
.46302 .33023 L
Mistroke
.46303 .33024 L
.46304 .33025 L
.46305 .33026 L
.46306 .33027 L
.46308 .33028 L
.46309 .3303 L
.4631 .33031 L
.46311 .33032 L
.46312 .33033 L
.46313 .33034 L
.46315 .33035 L
.46316 .33036 L
.46317 .33037 L
.46318 .33038 L
.46319 .33039 L
.4632 .3304 L
.46322 .33041 L
.46323 .33042 L
.46324 .33043 L
.46325 .33044 L
.46326 .33045 L
.46327 .33046 L
.46328 .33047 L
.4633 .33048 L
.46331 .33049 L
.46332 .3305 L
.46333 .33051 L
.46334 .33052 L
.46335 .33053 L
.46336 .33054 L
.46337 .33055 L
.46339 .33056 L
.4634 .33057 L
.46341 .33058 L
.46342 .33059 L
.46343 .3306 L
.46344 .33061 L
.46345 .33062 L
.46346 .33063 L
.46347 .33065 L
.46349 .33066 L
.4635 .33067 L
.46351 .33068 L
.46352 .33069 L
.46353 .3307 L
.46354 .33071 L
.46355 .33072 L
.46356 .33073 L
.46357 .33074 L
.46358 .33075 L
Mistroke
.46359 .33076 L
.4636 .33077 L
.46361 .33078 L
.46363 .33079 L
.46364 .3308 L
.46365 .33081 L
.46366 .33083 L
.46367 .33084 L
.46368 .33085 L
.46369 .33086 L
.4637 .33087 L
.46371 .33088 L
.46372 .33089 L
.46373 .3309 L
.46374 .33091 L
.46375 .33092 L
.46376 .33093 L
.46377 .33094 L
.46378 .33095 L
.46379 .33096 L
.4638 .33098 L
.46381 .33099 L
.46382 .331 L
.46383 .33101 L
.46384 .33102 L
.46385 .33103 L
.46386 .33104 L
.46387 .33105 L
.46388 .33106 L
.46389 .33107 L
.4639 .33108 L
.46391 .33109 L
.46392 .33111 L
.46393 .33112 L
.46394 .33113 L
.46395 .33114 L
.46396 .33115 L
.46397 .33116 L
.46398 .33117 L
.46399 .33118 L
.464 .33119 L
.46401 .3312 L
.46402 .33122 L
.46403 .33123 L
.46404 .33124 L
.46405 .33125 L
.46406 .33126 L
.46407 .33127 L
.46408 .33128 L
.46409 .33129 L
Mistroke
.4641 .3313 L
.46411 .33132 L
.46412 .33133 L
.46413 .33134 L
.46414 .33135 L
.46415 .33136 L
.46416 .33137 L
.46417 .33138 L
.46418 .33139 L
.46419 .3314 L
.4642 .33142 L
.4642 .33143 L
.46421 .33144 L
.46422 .33145 L
.46423 .33146 L
.46424 .33147 L
.46425 .33148 L
.46426 .33149 L
.46427 .33151 L
.46428 .33152 L
.46429 .33153 L
.4643 .33154 L
.46431 .33155 L
.46431 .33156 L
.46432 .33157 L
.46433 .33158 L
.46434 .3316 L
.46435 .33161 L
.46436 .33162 L
.46437 .33163 L
.46438 .33164 L
.46439 .33165 L
.4644 .33166 L
.4644 .33167 L
.46441 .33169 L
.46442 .3317 L
.46443 .33171 L
.46444 .33172 L
.46445 .33173 L
.46446 .33174 L
.46446 .33175 L
.46447 .33177 L
.46448 .33178 L
.46449 .33179 L
.4645 .3318 L
.46451 .33181 L
.46452 .33182 L
.46453 .33184 L
.46453 .33185 L
.46454 .33186 L
Mistroke
.46455 .33187 L
.46456 .33188 L
.46457 .33189 L
.46458 .3319 L
.46458 .33192 L
.46459 .33193 L
.4646 .33194 L
.46461 .33195 L
.46462 .33196 L
.46463 .33197 L
.46463 .33199 L
.46464 .332 L
.46465 .33201 L
.46466 .33202 L
.46467 .33203 L
.46467 .33204 L
.46468 .33206 L
.46469 .33207 L
.4647 .33208 L
.46471 .33209 L
.46471 .3321 L
.46472 .33211 L
.46473 .33213 L
.46474 .33214 L
.46475 .33215 L
.46475 .33216 L
.46476 .33217 L
.46477 .33218 L
.46478 .3322 L
.46479 .33221 L
.46479 .33222 L
.4648 .33223 L
.46481 .33224 L
.46482 .33225 L
.46482 .33227 L
.46483 .33228 L
.46484 .33229 L
.46485 .3323 L
.46485 .33231 L
.46486 .33233 L
.46487 .33234 L
.46488 .33235 L
.46489 .33236 L
.46489 .33237 L
.4649 .33238 L
.46491 .3324 L
.46492 .33241 L
.46492 .33242 L
.46493 .33243 L
.46494 .33244 L
Mistroke
.46494 .33246 L
.46495 .33247 L
.46496 .33248 L
.46497 .33249 L
.46497 .3325 L
.46498 .33252 L
.46499 .33253 L
.465 .33254 L
.465 .33255 L
.46501 .33256 L
.46502 .33258 L
.46502 .33259 L
.46503 .3326 L
.46504 .33261 L
.46505 .33262 L
.46505 .33264 L
.46506 .33265 L
.46507 .33266 L
.46507 .33267 L
.46508 .33268 L
.46509 .3327 L
.46509 .33271 L
.4651 .33272 L
.46511 .33273 L
.46511 .33274 L
.46512 .33276 L
.46513 .33277 L
.46513 .33278 L
.46514 .33279 L
.46515 .3328 L
.46515 .33282 L
.46516 .33283 L
.46517 .33284 L
.46517 .33285 L
.46518 .33287 L
.46519 .33288 L
.46519 .33289 L
.4652 .3329 L
.46521 .33291 L
.46521 .33293 L
.46522 .33294 L
.46523 .33295 L
.46523 .33296 L
.46524 .33298 L
.46525 .33299 L
.46525 .333 L
.46526 .33301 L
.46527 .33302 L
.46527 .33304 L
.46528 .33305 L
Mistroke
.46528 .33306 L
.46529 .33307 L
.4653 .33309 L
.4653 .3331 L
.46531 .33311 L
.46531 .33312 L
.46532 .33313 L
.46533 .33315 L
.46533 .33316 L
.46534 .33317 L
.46535 .33318 L
.46535 .3332 L
.46536 .33321 L
.46536 .33322 L
.46537 .33323 L
.46538 .33325 L
.46538 .33326 L
.46539 .33327 L
.46539 .33328 L
.4654 .33329 L
.4654 .33331 L
.46541 .33332 L
.46542 .33333 L
.46542 .33334 L
.46543 .33336 L
.46543 .33337 L
.46544 .33338 L
.46545 .33339 L
.46545 .33341 L
.46546 .33342 L
.46546 .33343 L
.46547 .33344 L
.46547 .33346 L
.46548 .33347 L
.46548 .33348 L
.46549 .33349 L
.4655 .33351 L
.4655 .33352 L
.46551 .33353 L
.46551 .33354 L
.46552 .33356 L
.46552 .33357 L
.46553 .33358 L
.46553 .33359 L
.46554 .33361 L
.46554 .33362 L
.46555 .33363 L
.46555 .33364 L
.46556 .33366 L
.46557 .33367 L
Mistroke
.46557 .33368 L
.46558 .33369 L
.46558 .33371 L
.46559 .33372 L
.46559 .33373 L
.4656 .33374 L
.4656 .33376 L
.46561 .33377 L
.46561 .33378 L
.46562 .33379 L
.46562 .33381 L
.46563 .33382 L
.46563 .33383 L
.46564 .33384 L
.46564 .33386 L
.46565 .33387 L
.46565 .33388 L
.46566 .3339 L
.46566 .33391 L
.46567 .33392 L
.46567 .33393 L
.46568 .33395 L
.46568 .33396 L
.46568 .33397 L
.46569 .33398 L
.46569 .334 L
.4657 .33401 L
.4657 .33402 L
.46571 .33403 L
.46571 .33405 L
.46572 .33406 L
.46572 .33407 L
.46573 .33409 L
.46573 .3341 L
.46574 .33411 L
.46574 .33412 L
.46574 .33414 L
.46575 .33415 L
.46575 .33416 L
.46576 .33417 L
.46576 .33419 L
.46577 .3342 L
.46577 .33421 L
.46578 .33423 L
.46578 .33424 L
.46578 .33425 L
.46579 .33426 L
.46579 .33428 L
.4658 .33429 L
.4658 .3343 L
Mistroke
.46581 .33431 L
.46581 .33433 L
.46581 .33434 L
.46582 .33435 L
.46582 .33437 L
.46583 .33438 L
.46583 .33439 L
.46583 .3344 L
.46584 .33442 L
.46584 .33443 L
.46585 .33444 L
.46585 .33446 L
.46585 .33447 L
.46586 .33448 L
.46586 .33449 L
.46587 .33451 L
.46587 .33452 L
.46587 .33453 L
.46588 .33455 L
.46588 .33456 L
.46588 .33457 L
.46589 .33458 L
.46589 .3346 L
.4659 .33461 L
.4659 .33462 L
.4659 .33464 L
.46591 .33465 L
.46591 .33466 L
.46591 .33467 L
.46592 .33469 L
.46592 .3347 L
.46593 .33471 L
.46593 .33473 L
.46593 .33474 L
.46594 .33475 L
.46594 .33477 L
.46594 .33478 L
.46595 .33479 L
.46595 .3348 L
.46595 .33482 L
.46596 .33483 L
.46596 .33484 L
.46596 .33486 L
.46597 .33487 L
.46597 .33488 L
.46597 .33489 L
.46598 .33491 L
.46598 .33492 L
.46598 .33493 L
.46599 .33495 L
Mistroke
.46599 .33496 L
.46599 .33497 L
.466 .33499 L
.466 .335 L
.466 .33501 L
.46601 .33502 L
.46601 .33504 L
.46601 .33505 L
.46601 .33506 L
.46602 .33508 L
.46602 .33509 L
.46602 .3351 L
.46603 .33512 L
.46603 .33513 L
.46603 .33514 L
.46604 .33515 L
.46604 .33517 L
.46604 .33518 L
.46604 .33519 L
.46605 .33521 L
.46605 .33522 L
.46605 .33523 L
.46606 .33525 L
.46606 .33526 L
.46606 .33527 L
.46606 .33529 L
.46607 .3353 L
.46607 .33531 L
.46607 .33532 L
.46607 .33534 L
.46608 .33535 L
.46608 .33536 L
.46608 .33538 L
.46609 .33539 L
.46609 .3354 L
.46609 .33542 L
.46609 .33543 L
.4661 .33544 L
.4661 .33546 L
.4661 .33547 L
.4661 .33548 L
.46611 .33549 L
.46611 .33551 L
.46611 .33552 L
.46611 .33553 L
.46611 .33555 L
.46612 .33556 L
.46612 .33557 L
.46612 .33559 L
.46612 .3356 L
Mistroke
.46613 .33561 L
.46613 .33563 L
.46613 .33564 L
.46613 .33565 L
.46614 .33567 L
.46614 .33568 L
.46614 .33569 L
.46614 .3357 L
.46614 .33572 L
.46615 .33573 L
.46615 .33574 L
.46615 .33576 L
.46615 .33577 L
.46615 .33578 L
.46616 .3358 L
.46616 .33581 L
.46616 .33582 L
.46616 .33584 L
.46616 .33585 L
.46617 .33586 L
.46617 .33588 L
.46617 .33589 L
.46617 .3359 L
.46617 .33592 L
.46618 .33593 L
.46618 .33594 L
.46618 .33596 L
.46618 .33597 L
.46618 .33598 L
.46618 .336 L
.46619 .33601 L
.46619 .33602 L
.46619 .33603 L
.46619 .33605 L
.46619 .33606 L
.46619 .33607 L
.4662 .33609 L
.4662 .3361 L
.4662 .33611 L
.4662 .33613 L
.4662 .33614 L
.4662 .33615 L
.4662 .33617 L
.46621 .33618 L
.46621 .33619 L
.46621 .33621 L
.46621 .33622 L
.46621 .33623 L
.46621 .33625 L
.46621 .33626 L
Mistroke
.46622 .33627 L
.46622 .33629 L
.46622 .3363 L
.46622 .33631 L
.46622 .33633 L
.46622 .33634 L
.46622 .33635 L
.46622 .33637 L
.46623 .33638 L
.46623 .33639 L
.46623 .33641 L
.46623 .33642 L
.46623 .33643 L
.46623 .33645 L
.46623 .33646 L
.46623 .33647 L
.46624 .33649 L
.46624 .3365 L
.46624 .33651 L
.46624 .33652 L
.46624 .33654 L
.46624 .33655 L
.46624 .33656 L
.46624 .33658 L
.46624 .33659 L
.46624 .3366 L
.46624 .33662 L
.46625 .33663 L
.46625 .33664 L
.46625 .33666 L
.46625 .33667 L
.46625 .33668 L
.46625 .3367 L
.46625 .33671 L
.46625 .33672 L
.46625 .33674 L
.46625 .33675 L
.46625 .33676 L
.46625 .33678 L
.46625 .33679 L
.46626 .3368 L
.46626 .33682 L
.46626 .33683 L
.46626 .33684 L
.46626 .33686 L
.46626 .33687 L
.46626 .33688 L
.46626 .3369 L
.46626 .33691 L
.46626 .33692 L
Mistroke
.46626 .33694 L
.46626 .33695 L
.46626 .33696 L
.46626 .33698 L
.46626 .33699 L
.46626 .337 L
.46626 .33702 L
.46626 .33703 L
.46626 .33704 L
.46626 .33706 L
.46626 .33707 L
.46627 .33708 L
.46627 .3371 L
.46627 .33711 L
.46627 .33712 L
.46627 .33714 L
.46627 .33715 L
.46627 .33716 L
.46627 .33718 L
.46627 .33719 L
.46627 .3372 L
.46627 .33722 L
.46627 .33723 L
.46627 .33724 L
.46627 .33726 L
.46627 .33727 L
.46627 .33728 L
.46627 .3373 L
.46627 .33731 L
.46627 .33732 L
.46627 .33734 L
.46627 .33735 L
.46627 .33736 L
.46627 .33738 L
.46627 .33739 L
.46627 .3374 L
.46627 .33742 L
.46627 .33743 L
.46627 .33744 L
.46627 .33746 L
.46627 .33747 L
.46627 .33748 L
.46627 .3375 L
.46627 .33751 L
.46627 .33752 L
.46626 .33754 L
.46626 .33755 L
.46626 .33756 L
.46626 .33758 L
.46626 .33759 L
Mistroke
.46626 .3376 L
.46626 .33762 L
.46626 .33763 L
.46626 .33764 L
.46626 .33766 L
.46626 .33767 L
.46626 .33768 L
.46626 .3377 L
.46626 .33771 L
.46626 .33772 L
.46626 .33774 L
.46626 .33775 L
.46626 .33776 L
.46626 .33778 L
.46626 .33779 L
.46626 .3378 L
.46626 .33782 L
.46625 .33783 L
.46625 .33784 L
.46625 .33786 L
.46625 .33787 L
.46625 .33788 L
.46625 .3379 L
.46625 .33791 L
.46625 .33792 L
.46625 .33794 L
.46625 .33795 L
.46625 .33796 L
.46625 .33798 L
.46625 .33799 L
.46624 .338 L
.46624 .33802 L
.46624 .33803 L
.46624 .33804 L
.46624 .33806 L
.46624 .33807 L
.46624 .33808 L
.46624 .3381 L
.46624 .33811 L
.46624 .33812 L
.46624 .33814 L
.46623 .33815 L
.46623 .33816 L
.46623 .33818 L
.46623 .33819 L
.46623 .3382 L
.46623 .33822 L
.46623 .33823 L
.46623 .33824 L
.46623 .33826 L
Mistroke
.46622 .33827 L
.46622 .33828 L
.46622 .3383 L
.46622 .33831 L
.46622 .33832 L
.46622 .33834 L
.46622 .33835 L
.46622 .33836 L
.46621 .33838 L
.46621 .33839 L
.46621 .3384 L
.46621 .33842 L
.46621 .33843 L
.46621 .33844 L
.46621 .33846 L
.46621 .33847 L
.4662 .33848 L
.4662 .3385 L
.4662 .33851 L
.4662 .33852 L
.4662 .33854 L
.4662 .33855 L
.4662 .33856 L
.46619 .33858 L
.46619 .33859 L
.46619 .3386 L
.46619 .33862 L
.46619 .33863 L
.46619 .33864 L
.46618 .33866 L
.46618 .33867 L
.46618 .33868 L
.46618 .3387 L
.46618 .33871 L
.46618 .33872 L
.46617 .33874 L
.46617 .33875 L
.46617 .33876 L
.46617 .33878 L
.46617 .33879 L
.46617 .3388 L
.46616 .33882 L
.46616 .33883 L
.46616 .33884 L
.46616 .33886 L
.46616 .33887 L
.46615 .33888 L
.46615 .3389 L
.46615 .33891 L
.46615 .33892 L
Mistroke
.46615 .33894 L
.46614 .33895 L
.46614 .33896 L
.46614 .33898 L
.46614 .33899 L
.46614 .339 L
.46613 .33902 L
.46613 .33903 L
.46613 .33904 L
.46613 .33906 L
.46613 .33907 L
.46612 .33908 L
.46612 .3391 L
.46612 .33911 L
.46612 .33912 L
.46612 .33914 L
.46611 .33915 L
.46611 .33916 L
.46611 .33918 L
.46611 .33919 L
.46611 .3392 L
.4661 .33922 L
.4661 .33923 L
.4661 .33924 L
.4661 .33926 L
.46609 .33927 L
.46609 .33928 L
.46609 .3393 L
.46609 .33931 L
.46608 .33932 L
.46608 .33933 L
.46608 .33935 L
.46608 .33936 L
.46608 .33937 L
.46607 .33939 L
.46607 .3394 L
.46607 .33941 L
.46607 .33943 L
.46606 .33944 L
.46606 .33945 L
.46606 .33947 L
.46606 .33948 L
.46605 .33949 L
.46605 .33951 L
.46605 .33952 L
.46605 .33953 L
.46604 .33955 L
.46604 .33956 L
.46604 .33957 L
.46603 .33959 L
Mistroke
.46603 .3396 L
.46603 .33961 L
.46603 .33963 L
.46602 .33964 L
.46602 .33965 L
.46602 .33967 L
.46602 .33968 L
.46601 .33969 L
.46601 .3397 L
.46601 .33972 L
.466 .33973 L
.466 .33974 L
.466 .33976 L
.466 .33977 L
.46599 .33978 L
.46599 .3398 L
.46599 .33981 L
.46598 .33982 L
.46598 .33984 L
.46598 .33985 L
.46598 .33986 L
.46597 .33988 L
.46597 .33989 L
.46597 .3399 L
.46596 .33992 L
.46596 .33993 L
.46596 .33994 L
.46596 .33995 L
.46595 .33997 L
.46595 .33998 L
.46595 .33999 L
.46594 .34001 L
.46594 .34002 L
.46594 .34003 L
.46593 .34005 L
.46593 .34006 L
.46593 .34007 L
.46592 .34009 L
.46592 .3401 L
.46592 .34011 L
.46591 .34013 L
.46591 .34014 L
.46591 .34015 L
.46591 .34016 L
.4659 .34018 L
.4659 .34019 L
.4659 .3402 L
.46589 .34022 L
.46589 .34023 L
.46589 .34024 L
Mistroke
.46588 .34026 L
.46588 .34027 L
.46588 .34028 L
.46587 .3403 L
.46587 .34031 L
.46587 .34032 L
.46586 .34033 L
.46586 .34035 L
.46586 .34036 L
.46585 .34037 L
.46585 .34039 L
.46584 .3404 L
.46584 .34041 L
.46584 .34043 L
.46583 .34044 L
.46583 .34045 L
.46583 .34047 L
.46582 .34048 L
.46582 .34049 L
.46582 .3405 L
.46581 .34052 L
.46581 .34053 L
.46581 .34054 L
.4658 .34056 L
.4658 .34057 L
.46579 .34058 L
.46579 .3406 L
.46579 .34061 L
.46578 .34062 L
.46578 .34063 L
.46578 .34065 L
.46577 .34066 L
.46577 .34067 L
.46577 .34069 L
.46576 .3407 L
.46576 .34071 L
.46575 .34073 L
.46575 .34074 L
.46575 .34075 L
.46574 .34076 L
.46574 .34078 L
.46573 .34079 L
.46573 .3408 L
.46573 .34082 L
.46572 .34083 L
.46572 .34084 L
.46572 .34086 L
.46571 .34087 L
.46571 .34088 L
.4657 .34089 L
Mistroke
.4657 .34091 L
.4657 .34092 L
.46569 .34093 L
.46569 .34095 L
.46568 .34096 L
.46568 .34097 L
.46568 .34098 L
.46567 .341 L
.46567 .34101 L
.46566 .34102 L
.46566 .34104 L
.46566 .34105 L
.46565 .34106 L
.46565 .34107 L
.46564 .34109 L
.46564 .3411 L
.46563 .34111 L
.46563 .34113 L
.46563 .34114 L
.46562 .34115 L
.46562 .34116 L
.46561 .34118 L
.46561 .34119 L
.46561 .3412 L
.4656 .34122 L
.4656 .34123 L
.46559 .34124 L
.46559 .34125 L
.46558 .34127 L
.46558 .34128 L
.46557 .34129 L
.46557 .34131 L
.46557 .34132 L
.46556 .34133 L
.46556 .34134 L
.46555 .34136 L
.46555 .34137 L
.46554 .34138 L
.46554 .3414 L
.46554 .34141 L
.46553 .34142 L
.46553 .34143 L
.46552 .34145 L
.46552 .34146 L
.46551 .34147 L
.46551 .34149 L
.4655 .3415 L
.4655 .34151 L
.4655 .34152 L
.46549 .34154 L
Mistroke
.46549 .34155 L
.46548 .34156 L
.46548 .34157 L
.46547 .34159 L
.46547 .3416 L
.46546 .34161 L
.46546 .34163 L
.46545 .34164 L
.46545 .34165 L
.46544 .34166 L
.46544 .34168 L
.46544 .34169 L
.46543 .3417 L
.46543 .34171 L
.46542 .34173 L
.46542 .34174 L
.46541 .34175 L
.46541 .34176 L
.4654 .34178 L
.4654 .34179 L
.46539 .3418 L
.46539 .34182 L
.46538 .34183 L
.46538 .34184 L
.46537 .34185 L
.46537 .34187 L
.46536 .34188 L
.46536 .34189 L
.46535 .3419 L
.46535 .34192 L
.46534 .34193 L
.46534 .34194 L
.46533 .34195 L
.46533 .34197 L
.46532 .34198 L
.46532 .34199 L
.46531 .34201 L
.46531 .34202 L
.4653 .34203 L
.4653 .34204 L
.46529 .34206 L
.46529 .34207 L
.46528 .34208 L
.46528 .34209 L
.46527 .34211 L
.46527 .34212 L
.46526 .34213 L
.46526 .34214 L
.46525 .34216 L
.46525 .34217 L
Mistroke
.46524 .34218 L
.46524 .34219 L
.46523 .34221 L
.46523 .34222 L
.46522 .34223 L
.46522 .34224 L
.46521 .34226 L
.46521 .34227 L
.4652 .34228 L
.4652 .34229 L
.46519 .34231 L
.46519 .34232 L
.46518 .34233 L
.46518 .34234 L
.46517 .34236 L
.46517 .34237 L
.46516 .34238 L
.46515 .34239 L
.46515 .34241 L
.46514 .34242 L
.46514 .34243 L
.46513 .34244 L
.46513 .34246 L
.46512 .34247 L
.46512 .34248 L
.46511 .34249 L
.46511 .34251 L
.4651 .34252 L
.4651 .34253 L
.46509 .34254 L
.46508 .34256 L
.46508 .34257 L
.46507 .34258 L
.46507 .34259 L
.46506 .3426 L
.46506 .34262 L
.46505 .34263 L
.46505 .34264 L
.46504 .34265 L
.46504 .34267 L
.46503 .34268 L
.46502 .34269 L
.46502 .3427 L
.46501 .34272 L
.46501 .34273 L
.465 .34274 L
.465 .34275 L
.46499 .34277 L
.46499 .34278 L
.46498 .34279 L
Mistroke
.46497 .3428 L
.46497 .34281 L
.46496 .34283 L
.46496 .34284 L
.46495 .34285 L
.46495 .34286 L
.46494 .34288 L
.46493 .34289 L
.46493 .3429 L
.46492 .34291 L
.46492 .34292 L
.46491 .34294 L
.46491 .34295 L
.4649 .34296 L
.46489 .34297 L
.46489 .34299 L
.46488 .343 L
.46488 .34301 L
.46487 .34302 L
.46487 .34303 L
.46486 .34305 L
.46485 .34306 L
.46485 .34307 L
.46484 .34308 L
.46484 .3431 L
.46483 .34311 L
.46482 .34312 L
.46482 .34313 L
.46481 .34314 L
.46481 .34316 L
.4648 .34317 L
.46479 .34318 L
.46479 .34319 L
.46478 .34321 L
.46478 .34322 L
.46477 .34323 L
.46476 .34324 L
.46476 .34325 L
.46475 .34327 L
.46475 .34328 L
.46474 .34329 L
.46473 .3433 L
.46473 .34331 L
.46472 .34333 L
.46472 .34334 L
.46471 .34335 L
.4647 .34336 L
.4647 .34337 L
.46469 .34339 L
.46469 .3434 L
Mistroke
.46468 .34341 L
.46467 .34342 L
.46467 .34343 L
.46466 .34345 L
.46466 .34346 L
.46465 .34347 L
.46464 .34348 L
.46464 .34349 L
.46463 .34351 L
.46462 .34352 L
.46462 .34353 L
.46461 .34354 L
.46461 .34355 L
.4646 .34357 L
.46459 .34358 L
.46459 .34359 L
.46458 .3436 L
.46457 .34361 L
.46457 .34363 L
.46456 .34364 L
.46456 .34365 L
.46455 .34366 L
.46454 .34367 L
.46454 .34369 L
.46453 .3437 L
.46452 .34371 L
.46452 .34372 L
.46451 .34373 L
.46451 .34375 L
.4645 .34376 L
.46449 .34377 L
.46449 .34378 L
.46448 .34379 L
.46447 .3438 L
.46447 .34382 L
.46446 .34383 L
.46445 .34384 L
.46445 .34385 L
.46444 .34386 L
.46443 .34388 L
.46443 .34389 L
.46442 .3439 L
.46442 .34391 L
.46441 .34392 L
.4644 .34393 L
.4644 .34395 L
.46439 .34396 L
.46438 .34397 L
.46438 .34398 L
.46437 .34399 L
Mistroke
.46436 .34401 L
.46436 .34402 L
.46435 .34403 L
.46434 .34404 L
.46434 .34405 L
.46433 .34406 L
.46432 .34408 L
.46432 .34409 L
.46431 .3441 L
.4643 .34411 L
.4643 .34412 L
.46429 .34413 L
.46428 .34415 L
.46428 .34416 L
.46427 .34417 L
.46426 .34418 L
.46426 .34419 L
.46425 .3442 L
.46424 .34422 L
.46424 .34423 L
.46423 .34424 L
.46422 .34425 L
.46422 .34426 L
.46421 .34427 L
.4642 .34429 L
.4642 .3443 L
.46419 .34431 L
.46418 .34432 L
.46418 .34433 L
.46417 .34434 L
.46416 .34436 L
.46416 .34437 L
.46415 .34438 L
.46414 .34439 L
.46414 .3444 L
.46413 .34441 L
.46412 .34442 L
.46412 .34444 L
.46411 .34445 L
.4641 .34446 L
.46409 .34447 L
.46409 .34448 L
.46408 .34449 L
.46407 .34451 L
.46407 .34452 L
.46406 .34453 L
.46405 .34454 L
.46405 .34455 L
.46404 .34456 L
.46403 .34457 L
Mistroke
.46403 .34459 L
.46402 .3446 L
.46401 .34461 L
.464 .34462 L
.464 .34463 L
.46399 .34464 L
.46398 .34465 L
.46398 .34467 L
.46397 .34468 L
.46396 .34469 L
.46396 .3447 L
.46395 .34471 L
.46394 .34472 L
.46393 .34473 L
.46393 .34474 L
.46392 .34476 L
.46391 .34477 L
.46391 .34478 L
.4639 .34479 L
.46389 .3448 L
.46389 .34481 L
.46388 .34482 L
.46387 .34484 L
.46386 .34485 L
.46386 .34486 L
.46385 .34487 L
.46384 .34488 L
.46384 .34489 L
.46383 .3449 L
.46382 .34491 L
.46381 .34493 L
.46381 .34494 L
.4638 .34495 L
.46379 .34496 L
.46379 .34497 L
.46378 .34498 L
.46377 .34499 L
.46376 .345 L
.46376 .34502 L
.46375 .34503 L
.46374 .34504 L
.46373 .34505 L
.46373 .34506 L
.46372 .34507 L
.46371 .34508 L
.46371 .34509 L
.4637 .3451 L
.46369 .34512 L
.46368 .34513 L
.46368 .34514 L
Mistroke
.46367 .34515 L
.46366 .34516 L
.46365 .34517 L
.46365 .34518 L
.46364 .34519 L
.46363 .3452 L
.46363 .34522 L
.46362 .34523 L
.46361 .34524 L
.4636 .34525 L
.4636 .34526 L
.46359 .34527 L
.46358 .34528 L
.46357 .34529 L
.46357 .3453 L
.46356 .34532 L
.46355 .34533 L
.46354 .34534 L
.46354 .34535 L
.46353 .34536 L
.46352 .34537 L
.46351 .34538 L
.46351 .34539 L
.4635 .3454 L
.46349 .34541 L
.46348 .34543 L
.46348 .34544 L
.46347 .34545 L
.46346 .34546 L
.46345 .34547 L
.46345 .34548 L
.46344 .34549 L
.46343 .3455 L
.46342 .34551 L
.46342 .34552 L
.46341 .34553 L
.4634 .34555 L
.46339 .34556 L
.46339 .34557 L
.46338 .34558 L
.46337 .34559 L
.46336 .3456 L
.46336 .34561 L
.46335 .34562 L
.46334 .34563 L
.46333 .34564 L
.46333 .34565 L
.46332 .34566 L
.46331 .34567 L
.4633 .34569 L
Mistroke
.4633 .3457 L
.46329 .34571 L
.46328 .34572 L
.46327 .34573 L
.46327 .34574 L
.46326 .34575 L
.46325 .34576 L
.46324 .34577 L
.46324 .34578 L
.46323 .34579 L
.46322 .3458 L
.46321 .34581 L
.4632 .34583 L
.4632 .34584 L
.46319 .34585 L
.46318 .34586 L
.46317 .34587 L
.46317 .34588 L
.46316 .34589 L
.46315 .3459 L
.46314 .34591 L
.46314 .34592 L
.46313 .34593 L
.46312 .34594 L
.46311 .34595 L
.4631 .34596 L
.4631 .34597 L
.46309 .34598 L
.46308 .346 L
.46307 .34601 L
.46307 .34602 L
.46306 .34603 L
.46305 .34604 L
.46304 .34605 L
.46303 .34606 L
.46303 .34607 L
.46302 .34608 L
.46301 .34609 L
.463 .3461 L
.46299 .34611 L
.46299 .34612 L
.46298 .34613 L
.46297 .34614 L
.46296 .34615 L
.46296 .34616 L
.46295 .34617 L
.46294 .34618 L
.46293 .34619 L
.46292 .34621 L
.46292 .34622 L
Mistroke
.46291 .34623 L
.4629 .34624 L
.46289 .34625 L
.46288 .34626 L
.46288 .34627 L
.46287 .34628 L
.46286 .34629 L
.46285 .3463 L
.46284 .34631 L
.46284 .34632 L
.46283 .34633 L
.46282 .34634 L
.46281 .34635 L
.46281 .34636 L
.4628 .34637 L
.46279 .34638 L
.46278 .34639 L
.46277 .3464 L
.46277 .34641 L
.46276 .34642 L
.46275 .34643 L
.46274 .34644 L
.46273 .34645 L
.46273 .34646 L
.46272 .34647 L
.46271 .34648 L
.4627 .34649 L
.46269 .3465 L
.46269 .34651 L
.46268 .34652 L
.46267 .34653 L
.46266 .34655 L
.46265 .34656 L
.46264 .34657 L
.46264 .34658 L
.46263 .34659 L
.46262 .3466 L
.46261 .34661 L
.4626 .34662 L
.4626 .34663 L
.46259 .34664 L
.46258 .34665 L
.46257 .34666 L
.46256 .34667 L
.46256 .34668 L
.46255 .34669 L
.46254 .3467 L
.46253 .34671 L
.46252 .34672 L
.46252 .34673 L
Mistroke
.46251 .34674 L
.4625 .34675 L
.46249 .34676 L
.46248 .34677 L
.46247 .34678 L
.46247 .34679 L
.46246 .3468 L
.46245 .34681 L
.46244 .34682 L
.46243 .34683 L
.46243 .34684 L
.46242 .34685 L
.46241 .34686 L
.4624 .34687 L
.46239 .34688 L
.46238 .34689 L
.46238 .3469 L
.46237 .34691 L
.46236 .34692 L
.46235 .34693 L
.46234 .34694 L
.46234 .34695 L
.46233 .34696 L
.46232 .34697 L
.46231 .34698 L
.4623 .34699 L
.46229 .347 L
.46229 .34701 L
.46228 .34701 L
.46227 .34702 L
.46226 .34703 L
.46225 .34704 L
.46224 .34705 L
.46224 .34706 L
.46223 .34707 L
.46222 .34708 L
.46221 .34709 L
.4622 .3471 L
.46219 .34711 L
.46219 .34712 L
.46218 .34713 L
.46217 .34714 L
.46216 .34715 L
.46215 .34716 L
.46214 .34717 L
.46214 .34718 L
.46213 .34719 L
.46212 .3472 L
.46211 .34721 L
.4621 .34722 L
Mistroke
.46209 .34723 L
.46209 .34724 L
.46208 .34725 L
.46207 .34726 L
.46206 .34727 L
.46205 .34728 L
.46204 .34729 L
.46204 .3473 L
.46203 .34731 L
.46202 .34732 L
.46201 .34733 L
.462 .34733 L
.46199 .34734 L
.46199 .34735 L
.46198 .34736 L
.46197 .34737 L
.46196 .34738 L
.46195 .34739 L
.46194 .3474 L
.46194 .34741 L
.46193 .34742 L
.46192 .34743 L
.46191 .34744 L
.4619 .34745 L
.46189 .34746 L
.46188 .34747 L
.46188 .34748 L
.46187 .34749 L
.46186 .3475 L
.46185 .34751 L
.46184 .34751 L
.46183 .34752 L
.46183 .34753 L
.46182 .34754 L
.46181 .34755 L
.4618 .34756 L
.46179 .34757 L
.46178 .34758 L
.46177 .34759 L
.46177 .3476 L
.46176 .34761 L
.46175 .34762 L
.46174 .34763 L
.46173 .34764 L
.46172 .34765 L
.46172 .34766 L
.46171 .34766 L
.4617 .34767 L
.46169 .34768 L
.46168 .34769 L
Mistroke
.46167 .3477 L
.46166 .34771 L
.46166 .34772 L
.46165 .34773 L
.46164 .34774 L
.46163 .34775 L
.46162 .34776 L
.46161 .34777 L
.4616 .34778 L
.4616 .34778 L
.46159 .34779 L
.46158 .3478 L
.46157 .34781 L
.46156 .34782 L
.46155 .34783 L
.46154 .34784 L
.46154 .34785 L
.46153 .34786 L
.46152 .34787 L
.46151 .34788 L
.4615 .34788 L
.46149 .34789 L
.46148 .3479 L
.46148 .34791 L
.46147 .34792 L
.46146 .34793 L
.46145 .34794 L
.46144 .34795 L
.46143 .34796 L
.46142 .34797 L
.46142 .34798 L
.46141 .34798 L
.4614 .34799 L
.46139 .348 L
.46138 .34801 L
.46137 .34802 L
.46136 .34803 L
.46136 .34804 L
.46135 .34805 L
.46134 .34806 L
.46133 .34806 L
.46132 .34807 L
.46131 .34808 L
.4613 .34809 L
.4613 .3481 L
.46129 .34811 L
.46128 .34812 L
.46127 .34813 L
.46126 .34814 L
.46125 .34814 L
Mistroke
.46124 .34815 L
.46123 .34816 L
.46123 .34817 L
.46122 .34818 L
.46121 .34819 L
.4612 .3482 L
.46119 .34821 L
.46118 .34822 L
.46117 .34822 L
.46117 .34823 L
.46116 .34824 L
.46115 .34825 L
.46114 .34826 L
.46113 .34827 L
.46112 .34828 L
.46111 .34829 L
.4611 .34829 L
.4611 .3483 L
.46109 .34831 L
.46108 .34832 L
.46107 .34833 L
.46106 .34834 L
.46105 .34835 L
.46104 .34835 L
.46103 .34836 L
.46103 .34837 L
.46102 .34838 L
.46101 .34839 L
.461 .3484 L
.46099 .34841 L
.46098 .34841 L
.46097 .34842 L
.46097 .34843 L
.46096 .34844 L
.46095 .34845 L
.46094 .34846 L
.46093 .34847 L
.46092 .34847 L
.46091 .34848 L
.4609 .34849 L
.4609 .3485 L
.46089 .34851 L
.46088 .34852 L
.46087 .34853 L
.46086 .34853 L
.46085 .34854 L
.46084 .34855 L
.46083 .34856 L
.46083 .34857 L
.46082 .34858 L
Mistroke
.46081 .34858 L
.4608 .34859 L
.46079 .3486 L
.46078 .34861 L
.46077 .34862 L
.46076 .34863 L
.46076 .34864 L
.46075 .34864 L
.46074 .34865 L
.46073 .34866 L
.46072 .34867 L
.46071 .34868 L
.4607 .34869 L
.46069 .34869 L
.46068 .3487 L
.46068 .34871 L
.46067 .34872 L
.46066 .34873 L
.46065 .34874 L
.46064 .34874 L
.46063 .34875 L
.46062 .34876 L
.46061 .34877 L
.46061 .34878 L
.4606 .34878 L
.46059 .34879 L
.46058 .3488 L
.46057 .34881 L
.46056 .34882 L
.46055 .34883 L
.46054 .34883 L
.46054 .34884 L
.46053 .34885 L
.46052 .34886 L
.46051 .34887 L
.4605 .34887 L
.46049 .34888 L
.46048 .34889 L
.46047 .3489 L
.46046 .34891 L
.46046 .34891 L
.46045 .34892 L
.46044 .34893 L
.46043 .34894 L
.46042 .34895 L
.46041 .34896 L
.4604 .34896 L
.46039 .34897 L
.46039 .34898 L
.46038 .34899 L
Mistroke
.46037 .349 L
.46036 .349 L
.46035 .34901 L
.46034 .34902 L
.46033 .34903 L
.46032 .34904 L
.46031 .34904 L
.46031 .34905 L
.4603 .34906 L
.46029 .34907 L
.46028 .34907 L
.46027 .34908 L
.46026 .34909 L
.46025 .3491 L
.46024 .34911 L
.46023 .34911 L
.46023 .34912 L
.46022 .34913 L
.46021 .34914 L
.4602 .34915 L
.46019 .34915 L
.46018 .34916 L
.46017 .34917 L
.46016 .34918 L
.46016 .34918 L
.46015 .34919 L
.46014 .3492 L
.46013 .34921 L
.46012 .34922 L
.46011 .34922 L
.4601 .34923 L
.46009 .34924 L
.46008 .34925 L
.46008 .34925 L
.46007 .34926 L
.46006 .34927 L
.46005 .34928 L
.46004 .34929 L
.46003 .34929 L
.46002 .3493 L
.46001 .34931 L
.46 .34932 L
.46 .34932 L
.45999 .34933 L
.45998 .34934 L
.45997 .34935 L
.45996 .34935 L
.45995 .34936 L
.45994 .34937 L
.45993 .34938 L
Mistroke
.45992 .34938 L
.45992 .34939 L
.45991 .3494 L
.4599 .34941 L
.45989 .34941 L
.45988 .34942 L
.45987 .34943 L
.45986 .34944 L
.45985 .34945 L
.45984 .34945 L
.45984 .34946 L
.45983 .34947 L
.45982 .34948 L
.45981 .34948 L
.4598 .34949 L
.45979 .3495 L
.45978 .3495 L
.45977 .34951 L
.45976 .34952 L
.45976 .34953 L
.45975 .34953 L
.45974 .34954 L
.45973 .34955 L
.45972 .34956 L
.45971 .34956 L
.4597 .34957 L
.45969 .34958 L
.45968 .34959 L
.45968 .34959 L
.45967 .3496 L
.45966 .34961 L
.45965 .34962 L
.45964 .34962 L
.45963 .34963 L
.45962 .34964 L
.45961 .34964 L
.4596 .34965 L
.4596 .34966 L
.45959 .34967 L
.45958 .34967 L
.45957 .34968 L
.45956 .34969 L
.45955 .3497 L
.45954 .3497 L
.45953 .34971 L
.45952 .34972 L
.45952 .34972 L
.45951 .34973 L
.4595 .34974 L
.45949 .34975 L
Mistroke
.45948 .34975 L
.45947 .34976 L
.45946 .34977 L
.45945 .34977 L
.45944 .34978 L
.45944 .34979 L
.45943 .3498 L
.45942 .3498 L
.45941 .34981 L
.4594 .34982 L
.45939 .34982 L
.45938 .34983 L
.45937 .34984 L
.45936 .34984 L
.45936 .34985 L
.45935 .34986 L
.45934 .34987 L
.45933 .34987 L
.45932 .34988 L
.45931 .34989 L
.4593 .34989 L
.45929 .3499 L
.45928 .34991 L
.45928 .34991 L
.45927 .34992 L
.45926 .34993 L
.45925 .34994 L
.45924 .34994 L
.45923 .34995 L
.45922 .34996 L
.45921 .34996 L
.4592 .34997 L
.4592 .34998 L
.45919 .34998 L
.45918 .34999 L
.45917 .35 L
.45916 .35 L
.45915 .35001 L
.45914 .35002 L
.45913 .35002 L
.45912 .35003 L
.45912 .35004 L
.45911 .35005 L
.4591 .35005 L
.45909 .35006 L
.45908 .35007 L
.45907 .35007 L
.45906 .35008 L
.45905 .35009 L
.45904 .35009 L
Mistroke
.45904 .3501 L
.45903 .35011 L
.45902 .35011 L
.45901 .35012 L
.459 .35013 L
.45899 .35013 L
.45898 .35014 L
.45897 .35015 L
.45896 .35015 L
.45896 .35016 L
.45895 .35017 L
.45894 .35017 L
.45893 .35018 L
.45892 .35019 L
.45891 .35019 L
.4589 .3502 L
.45889 .35021 L
.45888 .35021 L
.45888 .35022 L
.45887 .35023 L
.45886 .35023 L
.45885 .35024 L
.45884 .35024 L
.45883 .35025 L
.45882 .35026 L
.45881 .35026 L
.4588 .35027 L
.4588 .35028 L
.45879 .35028 L
.45878 .35029 L
.45877 .3503 L
.45876 .3503 L
.45875 .35031 L
.45874 .35032 L
.45873 .35032 L
.45872 .35033 L
.45872 .35034 L
.45871 .35034 L
.4587 .35035 L
.45869 .35035 L
.45868 .35036 L
.45867 .35037 L
.45866 .35037 L
.45865 .35038 L
.45864 .35039 L
.45864 .35039 L
.45863 .3504 L
.45862 .35041 L
.45861 .35041 L
.4586 .35042 L
Mistroke
.45859 .35042 L
.45858 .35043 L
.45857 .35044 L
.45857 .35044 L
.45856 .35045 L
.45855 .35046 L
.45854 .35046 L
.45853 .35047 L
.45852 .35047 L
.45851 .35048 L
.4585 .35049 L
.45849 .35049 L
.45849 .3505 L
.45848 .35051 L
.45847 .35051 L
.45846 .35052 L
.45845 .35052 L
.45844 .35053 L
.45843 .35054 L
.45842 .35054 L
.45842 .35055 L
.45841 .35055 L
.4584 .35056 L
.45839 .35057 L
.45838 .35057 L
.45837 .35058 L
.45836 .35058 L
.45835 .35059 L
.45834 .3506 L
.45834 .3506 L
.45833 .35061 L
.45832 .35061 L
.45831 .35062 L
.4583 .35063 L
.45829 .35063 L
.45828 .35064 L
.45827 .35064 L
.45827 .35065 L
.45826 .35066 L
.45825 .35066 L
.45824 .35067 L
.45823 .35067 L
.45822 .35068 L
.45821 .35069 L
.4582 .35069 L
.45819 .3507 L
.45819 .3507 L
.45818 .35071 L
.45817 .35072 L
.45816 .35072 L
Mistroke
.45815 .35073 L
.45814 .35073 L
.45813 .35074 L
.45812 .35075 L
.45812 .35075 L
.45811 .35076 L
.4581 .35076 L
.45809 .35077 L
.45808 .35077 L
.45807 .35078 L
.45806 .35079 L
.45805 .35079 L
.45805 .3508 L
.45804 .3508 L
.45803 .35081 L
.45802 .35081 L
.45801 .35082 L
.458 .35083 L
.45799 .35083 L
.45798 .35084 L
.45798 .35084 L
.45797 .35085 L
.45796 .35085 L
.45795 .35086 L
.45794 .35087 L
.45793 .35087 L
.45792 .35088 L
.45791 .35088 L
.45791 .35089 L
.4579 .35089 L
.45789 .3509 L
.45788 .35091 L
.45787 .35091 L
.45786 .35092 L
.45785 .35092 L
.45784 .35093 L
.45784 .35093 L
.45783 .35094 L
.45782 .35094 L
.45781 .35095 L
.4578 .35096 L
.45779 .35096 L
.45778 .35097 L
.45777 .35097 L
.45777 .35098 L
.45776 .35098 L
.45775 .35099 L
.45774 .35099 L
.45773 .351 L
.45772 .351 L
Mistroke
.45771 .35101 L
.45771 .35102 L
.4577 .35102 L
.45769 .35103 L
.45768 .35103 L
.45767 .35104 L
.45766 .35104 L
.45765 .35105 L
.45764 .35105 L
.45764 .35106 L
.45763 .35106 L
.45762 .35107 L
.45761 .35107 L
.4576 .35108 L
.45759 .35109 L
.45758 .35109 L
.45757 .3511 L
.45757 .3511 L
.45756 .35111 L
.45755 .35111 L
.45754 .35112 L
.45753 .35112 L
.45752 .35113 L
.45751 .35113 L
.45751 .35114 L
.4575 .35114 L
.45749 .35115 L
.45748 .35115 L
.45747 .35116 L
.45746 .35116 L
.45745 .35117 L
.45745 .35117 L
.45744 .35118 L
.45743 .35118 L
.45742 .35119 L
.45741 .35119 L
.4574 .3512 L
.45739 .35121 L
.45738 .35121 L
.45738 .35122 L
.45737 .35122 L
.45736 .35123 L
.45735 .35123 L
.45734 .35124 L
.45733 .35124 L
.45732 .35125 L
.45732 .35125 L
.45731 .35126 L
.4573 .35126 L
.45729 .35127 L
Mistroke
.45728 .35127 L
.45727 .35128 L
.45726 .35128 L
.45726 .35129 L
.45725 .35129 L
.45724 .3513 L
.45723 .3513 L
.45722 .35131 L
.45721 .35131 L
.4572 .35132 L
.4572 .35132 L
.45719 .35133 L
.45718 .35133 L
.45717 .35134 L
.45716 .35134 L
.45715 .35135 L
.45714 .35135 L
.45714 .35135 L
.45713 .35136 L
.45712 .35136 L
.45711 .35137 L
.4571 .35137 L
.45709 .35138 L
.45708 .35138 L
.45708 .35139 L
.45707 .35139 L
.45706 .3514 L
.45705 .3514 L
.45704 .35141 L
.45703 .35141 L
.45702 .35142 L
.45702 .35142 L
.45701 .35143 L
.457 .35143 L
.45699 .35144 L
.45698 .35144 L
.45697 .35145 L
.45697 .35145 L
.45696 .35146 L
.45695 .35146 L
.45694 .35146 L
.45693 .35147 L
.45692 .35147 L
.45691 .35148 L
.45691 .35148 L
.4569 .35149 L
.45689 .35149 L
.45688 .3515 L
.45687 .3515 L
.45686 .35151 L
Mistroke
.45686 .35151 L
.45685 .35152 L
.45684 .35152 L
.45683 .35152 L
.45682 .35153 L
.45681 .35153 L
.4568 .35154 L
.4568 .35154 L
.45679 .35155 L
.45678 .35155 L
.45677 .35156 L
.45676 .35156 L
.45675 .35157 L
.45675 .35157 L
.45674 .35157 L
.45673 .35158 L
.45672 .35158 L
.45671 .35159 L
.4567 .35159 L
.45669 .3516 L
.45669 .3516 L
.45668 .35161 L
.45667 .35161 L
.45666 .35161 L
.45665 .35162 L
.45664 .35162 L
.45664 .35163 L
.45663 .35163 L
.45662 .35164 L
.45661 .35164 L
.4566 .35164 L
.45659 .35165 L
.45659 .35165 L
.45658 .35166 L
.45657 .35166 L
.45656 .35167 L
.45655 .35167 L
.45654 .35168 L
.45654 .35168 L
.45653 .35168 L
.45652 .35169 L
.45651 .35169 L
.4565 .3517 L
.45649 .3517 L
.45649 .3517 L
.45648 .35171 L
.45647 .35171 L
.45646 .35172 L
.45645 .35172 L
.45644 .35173 L
Mistroke
.45644 .35173 L
.45643 .35173 L
.45642 .35174 L
.45641 .35174 L
.4564 .35175 L
.45639 .35175 L
.45639 .35176 L
.45638 .35176 L
.45637 .35176 L
.45636 .35177 L
.45635 .35177 L
.45634 .35178 L
.45634 .35178 L
.45633 .35178 L
.45632 .35179 L
.45631 .35179 L
.4563 .3518 L
.45629 .3518 L
.45629 .3518 L
.45628 .35181 L
.45627 .35181 L
.45626 .35182 L
.45625 .35182 L
.45625 .35182 L
.45624 .35183 L
.45623 .35183 L
.45622 .35184 L
.45621 .35184 L
.4562 .35184 L
.4562 .35185 L
.45619 .35185 L
.45618 .35186 L
.45617 .35186 L
.45616 .35186 L
.45616 .35187 L
.45615 .35187 L
.45614 .35188 L
.45613 .35188 L
.45612 .35188 L
.45611 .35189 L
.45611 .35189 L
.4561 .35189 L
.45609 .3519 L
.45608 .3519 L
.45607 .35191 L
.45606 .35191 L
.45606 .35191 L
.45605 .35192 L
.45604 .35192 L
.45603 .35193 L
Mistroke
.45602 .35193 L
.45602 .35193 L
.45601 .35194 L
.456 .35194 L
.45599 .35194 L
.45598 .35195 L
.45598 .35195 L
.45597 .35196 L
.45596 .35196 L
.45595 .35196 L
.45594 .35197 L
.45593 .35197 L
.45593 .35197 L
.45592 .35198 L
.45591 .35198 L
.4559 .35198 L
.45589 .35199 L
.45589 .35199 L
.45588 .352 L
.45587 .352 L
.45586 .352 L
.45585 .35201 L
.45585 .35201 L
.45584 .35201 L
.45583 .35202 L
.45582 .35202 L
.45581 .35202 L
.45581 .35203 L
.4558 .35203 L
.45579 .35204 L
.45578 .35204 L
.45577 .35204 L
.45577 .35205 L
.45576 .35205 L
.45575 .35205 L
.45574 .35206 L
.45573 .35206 L
.45573 .35206 L
.45572 .35207 L
.45571 .35207 L
.4557 .35207 L
.45569 .35208 L
.45569 .35208 L
.45568 .35208 L
.45567 .35209 L
.45566 .35209 L
.45565 .35209 L
.45565 .3521 L
.45564 .3521 L
.45563 .3521 L
Mistroke
.45562 .35211 L
.45561 .35211 L
.45561 .35211 L
.4556 .35212 L
.45559 .35212 L
.45558 .35212 L
.45557 .35213 L
.45557 .35213 L
.45556 .35213 L
.45555 .35214 L
.45554 .35214 L
.45553 .35214 L
.45553 .35215 L
.45552 .35215 L
.45551 .35215 L
.4555 .35216 L
.45549 .35216 L
.45549 .35216 L
.45548 .35217 L
.45547 .35217 L
.45546 .35217 L
.45545 .35218 L
.45545 .35218 L
.45544 .35218 L
.45543 .35219 L
.45542 .35219 L
.45542 .35219 L
.45541 .3522 L
.4554 .3522 L
.45539 .3522 L
.45538 .35221 L
.45538 .35221 L
.45537 .35221 L
.45536 .35222 L
.45535 .35222 L
.45534 .35222 L
.45534 .35222 L
.45533 .35223 L
.45532 .35223 L
.45531 .35223 L
.45531 .35224 L
.4553 .35224 L
.45529 .35224 L
.45528 .35225 L
.45527 .35225 L
.45527 .35225 L
.45526 .35226 L
.45525 .35226 L
.45524 .35226 L
.45524 .35226 L
Mistroke
.45523 .35227 L
.45522 .35227 L
.45521 .35227 L
.4552 .35228 L
.4552 .35228 L
.45519 .35228 L
.45518 .35229 L
.45517 .35229 L
.45517 .35229 L
.45516 .35229 L
.45515 .3523 L
.45514 .3523 L
.45513 .3523 L
.45513 .35231 L
.45512 .35231 L
.45511 .35231 L
.4551 .35231 L
.4551 .35232 L
.45509 .35232 L
.45508 .35232 L
.45507 .35233 L
.45507 .35233 L
.45506 .35233 L
.45505 .35233 L
.45504 .35234 L
.45503 .35234 L
.45503 .35234 L
.45502 .35235 L
.45501 .35235 L
.455 .35235 L
.455 .35235 L
.45499 .35236 L
.45498 .35236 L
.45497 .35236 L
.45497 .35236 L
.45496 .35237 L
.45495 .35237 L
.45494 .35237 L
.45494 .35238 L
.45493 .35238 L
.45492 .35238 L
.45491 .35238 L
.45491 .35239 L
.4549 .35239 L
.45489 .35239 L
.45488 .35239 L
.45487 .3524 L
.45487 .3524 L
.45486 .3524 L
.45485 .3524 L
Mistroke
.45484 .35241 L
.45484 .35241 L
.45483 .35241 L
.45482 .35242 L
.45481 .35242 L
.45481 .35242 L
.4548 .35242 L
.45479 .35243 L
.45478 .35243 L
.45478 .35243 L
.45477 .35243 L
.45476 .35244 L
.45475 .35244 L
.45475 .35244 L
.45474 .35244 L
.45473 .35245 L
.45472 .35245 L
.45472 .35245 L
.45471 .35245 L
.4547 .35246 L
.45469 .35246 L
.45469 .35246 L
.45468 .35246 L
.45467 .35247 L
.45466 .35247 L
.45466 .35247 L
.45465 .35247 L
.45464 .35248 L
.45463 .35248 L
.45463 .35248 L
.45462 .35248 L
.45461 .35248 L
.45461 .35249 L
.4546 .35249 L
.45459 .35249 L
.45458 .35249 L
.45458 .3525 L
.45457 .3525 L
.45456 .3525 L
.45455 .3525 L
.45455 .35251 L
.45454 .35251 L
.45453 .35251 L
.45452 .35251 L
.45452 .35252 L
.45451 .35252 L
.4545 .35252 L
.45449 .35252 L
.45449 .35252 L
.45448 .35253 L
Mistroke
.45447 .35253 L
.45446 .35253 L
.45446 .35253 L
.45445 .35254 L
.45444 .35254 L
.45444 .35254 L
.45443 .35254 L
.45442 .35254 L
.45441 .35255 L
.45441 .35255 L
.4544 .35255 L
.45439 .35255 L
.45438 .35256 L
.45438 .35256 L
.45437 .35256 L
.45436 .35256 L
.45436 .35256 L
.45435 .35257 L
.45434 .35257 L
.45433 .35257 L
.45433 .35257 L
.45432 .35257 L
.45431 .35258 L
.4543 .35258 L
.4543 .35258 L
.45429 .35258 L
.45428 .35258 L
.45428 .35259 L
.45427 .35259 L
.45426 .35259 L
.45425 .35259 L
.45425 .3526 L
.45424 .3526 L
.45423 .3526 L
.45423 .3526 L
.45422 .3526 L
.45421 .35261 L
.4542 .35261 L
.4542 .35261 L
.45419 .35261 L
.45418 .35261 L
.45418 .35262 L
.45417 .35262 L
.45416 .35262 L
.45415 .35262 L
.45415 .35262 L
.45414 .35262 L
.45413 .35263 L
.45413 .35263 L
.45412 .35263 L
Mistroke
.45411 .35263 L
.4541 .35263 L
.4541 .35264 L
.45409 .35264 L
.45408 .35264 L
.45408 .35264 L
.45407 .35264 L
.45406 .35265 L
.45405 .35265 L
.45405 .35265 L
.45404 .35265 L
.45403 .35265 L
.45403 .35265 L
.45402 .35266 L
.45401 .35266 L
.45401 .35266 L
.454 .35266 L
.45399 .35266 L
.45398 .35267 L
.45398 .35267 L
.45397 .35267 L
.45396 .35267 L
.45396 .35267 L
.45395 .35267 L
.45394 .35268 L
.45394 .35268 L
.45393 .35268 L
.45392 .35268 L
.45391 .35268 L
.45391 .35268 L
.4539 .35269 L
.45389 .35269 L
.45389 .35269 L
.45388 .35269 L
.45387 .35269 L
.45387 .35269 L
.45386 .3527 L
.45385 .3527 L
.45384 .3527 L
.45384 .3527 L
.45383 .3527 L
.45382 .3527 L
.45382 .35271 L
.45381 .35271 L
.4538 .35271 L
.4538 .35271 L
.45379 .35271 L
.45378 .35271 L
.45378 .35272 L
.45377 .35272 L
Mistroke
.45376 .35272 L
.45376 .35272 L
.45375 .35272 L
.45374 .35272 L
.45373 .35272 L
.45373 .35273 L
.45372 .35273 L
.45371 .35273 L
.45371 .35273 L
.4537 .35273 L
.45369 .35273 L
.45369 .35273 L
.45368 .35274 L
.45367 .35274 L
.45367 .35274 L
.45366 .35274 L
.45365 .35274 L
.45365 .35274 L
.45364 .35275 L
.45363 .35275 L
.45363 .35275 L
.45362 .35275 L
.45361 .35275 L
.45361 .35275 L
.4536 .35275 L
.45359 .35275 L
.45359 .35276 L
.45358 .35276 L
.45357 .35276 L
.45357 .35276 L
.45356 .35276 L
.45355 .35276 L
.45355 .35276 L
.45354 .35277 L
.45353 .35277 L
.45353 .35277 L
.45352 .35277 L
.45351 .35277 L
.45351 .35277 L
.4535 .35277 L
.45349 .35277 L
.45349 .35278 L
.45348 .35278 L
.45347 .35278 L
.45347 .35278 L
.45346 .35278 L
.45345 .35278 L
.45345 .35278 L
.45344 .35278 L
.45343 .35279 L
Mistroke
.45343 .35279 L
.45342 .35279 L
.45341 .35279 L
.45341 .35279 L
.4534 .35279 L
.45339 .35279 L
.45339 .35279 L
.45338 .3528 L
.45337 .3528 L
.45337 .3528 L
.45336 .3528 L
.45335 .3528 L
.45335 .3528 L
.45334 .3528 L
.45333 .3528 L
.45333 .3528 L
.45332 .35281 L
.45331 .35281 L
.45331 .35281 L
.4533 .35281 L
.45329 .35281 L
.45329 .35281 L
.45328 .35281 L
.45327 .35281 L
.45327 .35281 L
.45326 .35282 L
.45326 .35282 L
.45325 .35282 L
.45324 .35282 L
.45324 .35282 L
.45323 .35282 L
.45322 .35282 L
.45322 .35282 L
.45321 .35282 L
.4532 .35282 L
.4532 .35283 L
.45319 .35283 L
.45318 .35283 L
.45318 .35283 L
.45317 .35283 L
.45317 .35283 L
.45316 .35283 L
.45315 .35283 L
.45315 .35283 L
.45314 .35283 L
.45313 .35284 L
.45313 .35284 L
.45312 .35284 L
.45311 .35284 L
.45311 .35284 L
Mistroke
.4531 .35284 L
.4531 .35284 L
.45309 .35284 L
.45308 .35284 L
.45308 .35284 L
.45307 .35284 L
.45306 .35285 L
.45306 .35285 L
.45305 .35285 L
.45304 .35285 L
.45304 .35285 L
.45303 .35285 L
.45303 .35285 L
.45302 .35285 L
.45301 .35285 L
.45301 .35285 L
.453 .35285 L
.45299 .35285 L
.45299 .35286 L
.45298 .35286 L
.45298 .35286 L
.45297 .35286 L
.45296 .35286 L
.45296 .35286 L
.45295 .35286 L
.45294 .35286 L
.45294 .35286 L
.45293 .35286 L
.45293 .35286 L
.45292 .35286 L
.45291 .35286 L
.45291 .35286 L
.4529 .35287 L
.45289 .35287 L
.45289 .35287 L
.45288 .35287 L
.45288 .35287 L
.45287 .35287 L
.45286 .35287 L
.45286 .35287 L
.45285 .35287 L
.45285 .35287 L
.45284 .35287 L
.45283 .35287 L
.45283 .35287 L
.45282 .35287 L
.45282 .35287 L
.45281 .35288 L
.4528 .35288 L
.4528 .35288 L
Mistroke
.45279 .35288 L
.45278 .35288 L
.45278 .35288 L
.45277 .35288 L
.45277 .35288 L
.45276 .35288 L
.45275 .35288 L
.45275 .35288 L
.45274 .35288 L
.45274 .35288 L
.45273 .35288 L
.45272 .35288 L
.45272 .35288 L
.45271 .35288 L
.45271 .35288 L
.4527 .35289 L
.45269 .35289 L
.45269 .35289 L
.45268 .35289 L
.45268 .35289 L
.45267 .35289 L
.45266 .35289 L
.45266 .35289 L
.45265 .35289 L
.45265 .35289 L
.45264 .35289 L
.45263 .35289 L
.45263 .35289 L
.45262 .35289 L
.45262 .35289 L
.45261 .35289 L
.4526 .35289 L
.4526 .35289 L
.45259 .35289 L
.45259 .35289 L
.45258 .35289 L
.45258 .35289 L
.45257 .35289 L
.45256 .35289 L
.45256 .3529 L
.45255 .3529 L
.45255 .3529 L
.45254 .3529 L
.45253 .3529 L
.45253 .3529 L
.45252 .3529 L
.45252 .3529 L
.45251 .3529 L
.4525 .3529 L
.4525 .3529 L
Mistroke
.45249 .3529 L
.45249 .3529 L
.45248 .3529 L
.45248 .3529 L
.45247 .3529 L
.45246 .3529 L
.45246 .3529 L
.45245 .3529 L
.45245 .3529 L
.45244 .3529 L
.45244 .3529 L
.45243 .3529 L
.45242 .3529 L
.45242 .3529 L
.45241 .3529 L
.45241 .3529 L
.4524 .3529 L
.4524 .3529 L
.45239 .3529 L
.45238 .3529 L
.45238 .3529 L
.45237 .3529 L
.45237 .3529 L
.45236 .3529 L
.45236 .3529 L
.45235 .3529 L
.45234 .3529 L
.45234 .3529 L
.45233 .3529 L
.45233 .3529 L
.45232 .35291 L
.45232 .35291 L
.45231 .35291 L
.4523 .35291 L
.4523 .35291 L
.45229 .35291 L
.45229 .35291 L
.45228 .35291 L
.45228 .35291 L
.45227 .35291 L
.45227 .35291 L
.45226 .35291 L
.45225 .35291 L
.45225 .35291 L
.45224 .35291 L
.45224 .35291 L
.45223 .35291 L
.45223 .35291 L
.45222 .35291 L
.45221 .35291 L
Mistroke
.45221 .35291 L
.4522 .35291 L
.4522 .35291 L
.45219 .35291 L
.45219 .35291 L
.45218 .35291 L
.45218 .35291 L
.45217 .35291 L
.45217 .35291 L
.45216 .35291 L
.45215 .35291 L
.45215 .35291 L
.45214 .35291 L
.45214 .35291 L
.45213 .35291 L
.45213 .35291 L
.45212 .35291 L
.45212 .35291 L
.45211 .35291 L
.45211 .35291 L
.4521 .35291 L
.45209 .35291 L
.45209 .35291 L
.45208 .35291 L
.45208 .35291 L
.45207 .3529 L
.45207 .3529 L
.45206 .3529 L
.45206 .3529 L
.45205 .3529 L
.45205 .3529 L
.45204 .3529 L
.45204 .3529 L
.45203 .3529 L
.45202 .3529 L
.45202 .3529 L
.45201 .3529 L
.45201 .3529 L
.452 .3529 L
.452 .3529 L
.45199 .3529 L
.45199 .3529 L
.45198 .3529 L
.45198 .3529 L
.45197 .3529 L
.45197 .3529 L
.45196 .3529 L
.45196 .3529 L
.45195 .3529 L
.45194 .3529 L
Mistroke
.45194 .3529 L
.45193 .3529 L
.45193 .3529 L
.45192 .3529 L
.45192 .3529 L
.45191 .3529 L
.45191 .3529 L
.4519 .3529 L
.4519 .3529 L
.45189 .3529 L
.45189 .3529 L
.45188 .3529 L
.45188 .3529 L
.45187 .3529 L
.45187 .3529 L
.45186 .3529 L
.45186 .3529 L
.45185 .3529 L
.45185 .35289 L
.45184 .35289 L
.45184 .35289 L
.45183 .35289 L
.45182 .35289 L
.45182 .35289 L
.45181 .35289 L
.45181 .35289 L
.4518 .35289 L
.4518 .35289 L
.45179 .35289 L
.45179 .35289 L
.45178 .35289 L
.45178 .35289 L
.45177 .35289 L
.45177 .35289 L
.45176 .35289 L
.45176 .35289 L
.45175 .35289 L
.45175 .35289 L
.45174 .35289 L
.45174 .35289 L
.45173 .35289 L
.45173 .35289 L
.45172 .35288 L
.45172 .35288 L
.45171 .35288 L
.45171 .35288 L
.4517 .35288 L
.4517 .35288 L
.45169 .35288 L
.45169 .35288 L
Mistroke
.45168 .35288 L
.45168 .35288 L
.45167 .35288 L
.45167 .35288 L
.45166 .35288 L
.45166 .35288 L
.45165 .35288 L
.45165 .35288 L
.45164 .35288 L
.45164 .35288 L
.45163 .35288 L
.45163 .35288 L
.45162 .35287 L
.45162 .35287 L
.45161 .35287 L
.45161 .35287 L
.4516 .35287 L
.4516 .35287 L
.45159 .35287 L
.45159 .35287 L
.45158 .35287 L
.45158 .35287 L
.45158 .35287 L
.45157 .35287 L
.45157 .35287 L
.45156 .35287 L
.45156 .35287 L
.45155 .35287 L
.45155 .35286 L
.45154 .35286 L
.45154 .35286 L
.45153 .35286 L
.45153 .35286 L
.45152 .35286 L
.45152 .35286 L
.45151 .35286 L
.45151 .35286 L
.4515 .35286 L
.4515 .35286 L
.45149 .35286 L
.45149 .35286 L
.45148 .35286 L
.45148 .35286 L
.45147 .35285 L
.45147 .35285 L
.45146 .35285 L
.45146 .35285 L
.45146 .35285 L
.45145 .35285 L
.45145 .35285 L
Mistroke
.45144 .35285 L
.45144 .35285 L
.45143 .35285 L
.45143 .35285 L
.45142 .35285 L
.45142 .35285 L
.45141 .35284 L
.45141 .35284 L
.4514 .35284 L
.4514 .35284 L
.45139 .35284 L
.45139 .35284 L
.45139 .35284 L
.45138 .35284 L
.45138 .35284 L
.45137 .35284 L
.45137 .35284 L
.45136 .35284 L
.45136 .35284 L
.45135 .35283 L
.45135 .35283 L
.45134 .35283 L
.45134 .35283 L
.45133 .35283 L
.45133 .35283 L
.45133 .35283 L
.45132 .35283 L
.45132 .35283 L
.45131 .35283 L
.45131 .35283 L
.4513 .35282 L
.4513 .35282 L
.45129 .35282 L
.45129 .35282 L
.45128 .35282 L
.45128 .35282 L
.45128 .35282 L
.45127 .35282 L
.45127 .35282 L
.45126 .35282 L
.45126 .35282 L
.45125 .35281 L
.45125 .35281 L
.45124 .35281 L
.45124 .35281 L
.45124 .35281 L
.45123 .35281 L
.45123 .35281 L
.45122 .35281 L
.45122 .35281 L
Mistroke
.45121 .35281 L
.45121 .35281 L
.4512 .3528 L
.4512 .3528 L
.4512 .3528 L
.45119 .3528 L
.45119 .3528 L
.45118 .3528 L
.45118 .3528 L
.45117 .3528 L
.45117 .3528 L
.45116 .3528 L
.45116 .35279 L
.45116 .35279 L
.45115 .35279 L
.45115 .35279 L
.45114 .35279 L
.45114 .35279 L
.45113 .35279 L
.45113 .35279 L
.45113 .35279 L
.45112 .35278 L
.45112 .35278 L
.45111 .35278 L
.45111 .35278 L
.4511 .35278 L
.4511 .35278 L
.4511 .35278 L
.45109 .35278 L
.45109 .35278 L
.45108 .35278 L
.45108 .35277 L
.45107 .35277 L
.45107 .35277 L
.45107 .35277 L
.45106 .35277 L
.45106 .35277 L
.45105 .35277 L
.45105 .35277 L
.45104 .35277 L
.45104 .35276 L
.45104 .35276 L
.45103 .35276 L
.45103 .35276 L
.45102 .35276 L
.45102 .35276 L
.45102 .35276 L
.45101 .35276 L
.45101 .35275 L
.451 .35275 L
Mistroke
.451 .35275 L
.45099 .35275 L
.45099 .35275 L
.45099 .35275 L
.45098 .35275 L
.45098 .35275 L
.45097 .35275 L
.45097 .35274 L
.45097 .35274 L
.45096 .35274 L
.45096 .35274 L
.45095 .35274 L
.45095 .35274 L
.45095 .35274 L
.45094 .35274 L
.45094 .35273 L
.45093 .35273 L
.45093 .35273 L
.45093 .35273 L
.45092 .35273 L
.45092 .35273 L
.45091 .35273 L
.45091 .35273 L
.45091 .35272 L
.4509 .35272 L
.4509 .35272 L
.45089 .35272 L
.45089 .35272 L
.45089 .35272 L
.45088 .35272 L
.45088 .35271 L
.45087 .35271 L
.45087 .35271 L
.45087 .35271 L
.45086 .35271 L
.45086 .35271 L
.45085 .35271 L
.45085 .35271 L
.45085 .3527 L
.45084 .3527 L
.45084 .3527 L
.45083 .3527 L
.45083 .3527 L
.45083 .3527 L
.45082 .3527 L
.45082 .35269 L
.45081 .35269 L
.45081 .35269 L
.45081 .35269 L
.4508 .35269 L
Mistroke
.4508 .35269 L
.45079 .35269 L
.45079 .35269 L
.45079 .35268 L
.45078 .35268 L
.45078 .35268 L
.45078 .35268 L
.45077 .35268 L
.45077 .35268 L
.45076 .35268 L
.45076 .35267 L
.45076 .35267 L
.45075 .35267 L
.45075 .35267 L
.45075 .35267 L
.45074 .35267 L
.45074 .35267 L
.45073 .35266 L
.45073 .35266 L
.45073 .35266 L
.45072 .35266 L
.45072 .35266 L
.45071 .35266 L
.45071 .35266 L
.45071 .35265 L
.4507 .35265 L
.4507 .35265 L
.4507 .35265 L
.45069 .35265 L
.45069 .35265 L
.45069 .35264 L
.45068 .35264 L
.45068 .35264 L
.45067 .35264 L
.45067 .35264 L
.45067 .35264 L
.45066 .35264 L
.45066 .35263 L
.45066 .35263 L
.45065 .35263 L
.45065 .35263 L
.45064 .35263 L
.45064 .35263 L
.45064 .35262 L
.45063 .35262 L
.45063 .35262 L
.45063 .35262 L
.45062 .35262 L
.45062 .35262 L
.45062 .35262 L
Mistroke
.45061 .35261 L
.45061 .35261 L
.45061 .35261 L
.4506 .35261 L
.4506 .35261 L
.45059 .35261 L
.45059 .3526 L
.45059 .3526 L
.45058 .3526 L
.45058 .3526 L
.45058 .3526 L
.45057 .3526 L
.45057 .35259 L
.45057 .35259 L
.45056 .35259 L
.45056 .35259 L
.45056 .35259 L
.45055 .35259 L
.45055 .35259 L
.45055 .35258 L
.45054 .35258 L
.45054 .35258 L
.45053 .35258 L
.45053 .35258 L
.45053 .35258 L
.45052 .35257 L
.45052 .35257 L
.45052 .35257 L
.45051 .35257 L
.45051 .35257 L
.45051 .35257 L
.4505 .35256 L
.4505 .35256 L
.4505 .35256 L
.45049 .35256 L
.45049 .35256 L
.45049 .35256 L
.45048 .35255 L
.45048 .35255 L
.45048 .35255 L
.45047 .35255 L
.45047 .35255 L
.45047 .35255 L
.45046 .35254 L
.45046 .35254 L
.45046 .35254 L
.45045 .35254 L
.45045 .35254 L
.45045 .35253 L
.45044 .35253 L
Mistroke
.45044 .35253 L
.45044 .35253 L
.45043 .35253 L
.45043 .35253 L
.45043 .35252 L
.45042 .35252 L
.45042 .35252 L
.45042 .35252 L
.45041 .35252 L
.45041 .35252 L
.45041 .35251 L
.4504 .35251 L
.4504 .35251 L
.4504 .35251 L
.45039 .35251 L
.45039 .3525 L
.45039 .3525 L
.45038 .3525 L
.45038 .3525 L
.45038 .3525 L
.45037 .3525 L
.45037 .35249 L
.45037 .35249 L
.45036 .35249 L
.45036 .35249 L
.45036 .35249 L
.45036 .35249 L
.45035 .35248 L
.45035 .35248 L
.45035 .35248 L
.45034 .35248 L
.45034 .35248 L
.45034 .35247 L
.45033 .35247 L
.45033 .35247 L
.45033 .35247 L
.45032 .35247 L
.45032 .35246 L
.45032 .35246 L
.45031 .35246 L
.45031 .35246 L
.45031 .35246 L
.45031 .35246 L
.4503 .35245 L
.4503 .35245 L
.4503 .35245 L
.45029 .35245 L
.45029 .35245 L
.45029 .35244 L
.45028 .35244 L
Mistroke
.45028 .35244 L
.45028 .35244 L
.45027 .35244 L
.45027 .35243 L
.45027 .35243 L
.45027 .35243 L
.45026 .35243 L
.45026 .35243 L
.45026 .35243 L
.45025 .35242 L
.45025 .35242 L
.45025 .35242 L
.45024 .35242 L
.45024 .35242 L
.45024 .35241 L
.45024 .35241 L
.45023 .35241 L
.45023 .35241 L
.45023 .35241 L
.45022 .3524 L
.45022 .3524 L
.45022 .3524 L
.45021 .3524 L
.45021 .3524 L
.45021 .35239 L
.45021 .35239 L
.4502 .35239 L
.4502 .35239 L
.4502 .35239 L
.45019 .35238 L
.45019 .35238 L
.45019 .35238 L
.45019 .35238 L
.45018 .35238 L
.45018 .35237 L
.45018 .35237 L
.45017 .35237 L
.45017 .35237 L
.45017 .35237 L
.45017 .35236 L
.45016 .35236 L
.45016 .35236 L
.45016 .35236 L
.45015 .35236 L
.45015 .35235 L
.45015 .35235 L
.45015 .35235 L
.45014 .35235 L
.45014 .35235 L
.45014 .35234 L
Mistroke
.45013 .35234 L
.45013 .35234 L
.45013 .35234 L
.45013 .35234 L
.45012 .35233 L
.45012 .35233 L
.45012 .35233 L
.45012 .35233 L
.45011 .35233 L
.45011 .35232 L
.45011 .35232 L
.4501 .35232 L
.4501 .35232 L
.4501 .35232 L
.4501 .35231 L
.45009 .35231 L
.45009 .35231 L
.45009 .35231 L
.45009 .3523 L
.45008 .3523 L
.45008 .3523 L
.45008 .3523 L
.45007 .3523 L
.45007 .35229 L
.45007 .35229 L
.45007 .35229 L
.45006 .35229 L
.45006 .35229 L
.45006 .35228 L
.45006 .35228 L
.45005 .35228 L
.45005 .35228 L
.45005 .35228 L
.45005 .35227 L
.45004 .35227 L
.45004 .35227 L
.45004 .35227 L
.45004 .35226 L
.45003 .35226 L
.45003 .35226 L
.45003 .35226 L
.45002 .35226 L
.45002 .35225 L
.45002 .35225 L
.45002 .35225 L
.45001 .35225 L
.45001 .35225 L
.45001 .35224 L
.45001 .35224 L
.45 .35224 L
Mistroke
.45 .35224 L
.45 .35223 L
.45 .35223 L
.44999 .35223 L
.44999 .35223 L
.44999 .35223 L
.44999 .35222 L
.44998 .35222 L
.44998 .35222 L
.44998 .35222 L
.44998 .35221 L
.44997 .35221 L
.44997 .35221 L
.44997 .35221 L
.44997 .35221 L
.44996 .3522 L
.44996 .3522 L
.44996 .3522 L
.44996 .3522 L
.44995 .35219 L
.44995 .35219 L
.44995 .35219 L
.44995 .35219 L
.44995 .35219 L
.44994 .35218 L
.44994 .35218 L
.44994 .35218 L
.44994 .35218 L
.44993 .35217 L
.44993 .35217 L
.44993 .35217 L
.44993 .35217 L
.44992 .35217 L
.44992 .35216 L
.44992 .35216 L
.44992 .35216 L
.44991 .35216 L
.44991 .35215 L
.44991 .35215 L
.44991 .35215 L
.44991 .35215 L
.4499 .35215 L
.4499 .35214 L
.4499 .35214 L
.4499 .35214 L
.44989 .35214 L
.44989 .35213 L
.44989 .35213 L
.44989 .35213 L
.44988 .35213 L
Mistroke
.44988 .35213 L
.44988 .35212 L
.44988 .35212 L
.44988 .35212 L
.44987 .35212 L
.44987 .35211 L
.44987 .35211 L
.44987 .35211 L
.44986 .35211 L
.44986 .3521 L
.44986 .3521 L
.44986 .3521 L
.44986 .3521 L
.44985 .3521 L
.44985 .35209 L
.44985 .35209 L
.44985 .35209 L
.44984 .35209 L
.44984 .35208 L
.44984 .35208 L
.44984 .35208 L
.44984 .35208 L
.44983 .35207 L
.44983 .35207 L
.44983 .35207 L
.44983 .35207 L
.44982 .35206 L
.44982 .35206 L
.44982 .35206 L
.44982 .35206 L
.44982 .35206 L
.44981 .35205 L
.44981 .35205 L
.44981 .35205 L
.44981 .35205 L
.44981 .35204 L
.4498 .35204 L
.4498 .35204 L
.4498 .35204 L
.4498 .35203 L
.4498 .35203 L
.44979 .35203 L
.44979 .35203 L
.44979 .35202 L
.44979 .35202 L
.44979 .35202 L
.44978 .35202 L
.44978 .35202 L
.44978 .35201 L
.44978 .35201 L
Mistroke
.44977 .35201 L
.44977 .35201 L
.44977 .352 L
.44977 .352 L
.44977 .352 L
.44976 .352 L
.44976 .35199 L
.44976 .35199 L
.44976 .35199 L
.44976 .35199 L
.44975 .35198 L
.44975 .35198 L
.44975 .35198 L
.44975 .35198 L
.44975 .35197 L
.44975 .35197 L
.44974 .35197 L
.44974 .35197 L
.44974 .35196 L
.44974 .35196 L
.44974 .35196 L
.44973 .35196 L
.44973 .35195 L
.44973 .35195 L
.44973 .35195 L
.44973 .35195 L
.44972 .35195 L
.44972 .35194 L
.44972 .35194 L
.44972 .35194 L
.44972 .35194 L
.44971 .35193 L
.44971 .35193 L
.44971 .35193 L
.44971 .35193 L
.44971 .35192 L
.44971 .35192 L
.4497 .35192 L
.4497 .35192 L
.4497 .35191 L
.4497 .35191 L
.4497 .35191 L
.44969 .35191 L
.44969 .3519 L
.44969 .3519 L
.44969 .3519 L
.44969 .3519 L
.44969 .35189 L
.44968 .35189 L
.44968 .35189 L
Mistroke
.44968 .35189 L
.44968 .35188 L
.44968 .35188 L
.44967 .35188 L
.44967 .35188 L
.44967 .35187 L
.44967 .35187 L
.44967 .35187 L
.44967 .35187 L
.44966 .35186 L
.44966 .35186 L
.44966 .35186 L
.44966 .35186 L
.44966 .35185 L
.44966 .35185 L
.44965 .35185 L
.44965 .35185 L
.44965 .35184 L
.44965 .35184 L
.44965 .35184 L
.44965 .35184 L
.44964 .35183 L
.44964 .35183 L
.44964 .35183 L
.44964 .35183 L
.44964 .35182 L
.44964 .35182 L
.44963 .35182 L
.44963 .35182 L
.44963 .35181 L
.44963 .35181 L
.44963 .35181 L
.44963 .35181 L
.44962 .3518 L
.44962 .3518 L
.44962 .3518 L
.44962 .3518 L
.44962 .35179 L
.44962 .35179 L
.44961 .35179 L
.44961 .35179 L
.44961 .35178 L
.44961 .35178 L
.44961 .35178 L
.44961 .35178 L
.4496 .35177 L
.4496 .35177 L
.4496 .35177 L
.4496 .35176 L
.4496 .35176 L
Mistroke
.4496 .35176 L
.4496 .35176 L
.44959 .35175 L
.44959 .35175 L
.44959 .35175 L
.44959 .35175 L
.44959 .35174 L
.44959 .35174 L
.44958 .35174 L
.44958 .35174 L
.44958 .35173 L
.44958 .35173 L
.44958 .35173 L
.44958 .35173 L
.44958 .35172 L
.44957 .35172 L
.44957 .35172 L
.44957 .35172 L
.44957 .35171 L
.44957 .35171 L
.44957 .35171 L
.44957 .35171 L
.44956 .3517 L
.44956 .3517 L
.44956 .3517 L
.44956 .3517 L
.44956 .35169 L
.44956 .35169 L
.44956 .35169 L
.44955 .35168 L
.44955 .35168 L
.44955 .35168 L
.44955 .35168 L
.44955 .35167 L
.44955 .35167 L
.44955 .35167 L
.44954 .35167 L
.44954 .35166 L
.44954 .35166 L
.44954 .35166 L
.44954 .35166 L
.44954 .35165 L
.44954 .35165 L
.44953 .35165 L
.44953 .35165 L
.44953 .35164 L
.44953 .35164 L
.44953 .35164 L
.44953 .35163 L
.44953 .35163 L
Mistroke
.44953 .35163 L
.44952 .35163 L
.44952 .35162 L
.44952 .35162 L
.44952 .35162 L
.44952 .35162 L
.44952 .35161 L
.44952 .35161 L
.44952 .35161 L
.44951 .35161 L
.44951 .3516 L
.44951 .3516 L
.44951 .3516 L
.44951 .3516 L
.44951 .35159 L
.44951 .35159 L
.44951 .35159 L
.4495 .35158 L
.4495 .35158 L
.4495 .35158 L
.4495 .35158 L
.4495 .35157 L
.4495 .35157 L
.4495 .35157 L
.4495 .35157 L
.44949 .35156 L
.44949 .35156 L
.44949 .35156 L
.44949 .35156 L
.44949 .35155 L
.44949 .35155 L
.44949 .35155 L
.44949 .35154 L
.44948 .35154 L
.44948 .35154 L
.44948 .35154 L
.44948 .35153 L
.44948 .35153 L
.44948 .35153 L
.44948 .35153 L
.44948 .35152 L
.44948 .35152 L
.44947 .35152 L
.44947 .35152 L
.44947 .35151 L
.44947 .35151 L
.44947 .35151 L
.44947 .3515 L
.44947 .3515 L
.44947 .3515 L
Mistroke
.44947 .3515 L
.44946 .35149 L
.44946 .35149 L
.44946 .35149 L
.44946 .35149 L
.44946 .35148 L
.44946 .35148 L
.44946 .35148 L
.44946 .35147 L
.44946 .35147 L
.44945 .35147 L
.44945 .35147 L
.44945 .35146 L
.44945 .35146 L
.44945 .35146 L
.44945 .35146 L
.44945 .35145 L
.44945 .35145 L
.44945 .35145 L
.44945 .35144 L
.44944 .35144 L
.44944 .35144 L
.44944 .35144 L
.44944 .35143 L
.44944 .35143 L
.44944 .35143 L
.44944 .35143 L
.44944 .35142 L
.44944 .35142 L
.44944 .35142 L
.44943 .35141 L
.44943 .35141 L
.44943 .35141 L
.44943 .35141 L
.44943 .3514 L
.44943 .3514 L
.44943 .3514 L
.44943 .3514 L
.44943 .35139 L
.44943 .35139 L
.44943 .35139 L
.44942 .35138 L
.44942 .35138 L
.44942 .35138 L
.44942 .35138 L
.44942 .35137 L
.44942 .35137 L
.44942 .35137 L
.44942 .35137 L
.44942 .35136 L
Mistroke
.44942 .35136 L
.44942 .35136 L
.44941 .35135 L
.44941 .35135 L
.44941 .35135 L
.44941 .35135 L
.44941 .35134 L
.44941 .35134 L
.44941 .35134 L
.44941 .35134 L
.44941 .35133 L
.44941 .35133 L
.44941 .35133 L
.4494 .35132 L
.4494 .35132 L
.4494 .35132 L
.4494 .35132 L
.4494 .35131 L
.4494 .35131 L
.4494 .35131 L
.4494 .35131 L
.4494 .3513 L
.4494 .3513 L
.4494 .3513 L
.4494 .35129 L
.4494 .35129 L
.44939 .35129 L
.44939 .35129 L
.44939 .35128 L
.44939 .35128 L
.44939 .35128 L
.44939 .35127 L
.44939 .35127 L
.44939 .35127 L
.44939 .35127 L
.44939 .35126 L
.44939 .35126 L
.44939 .35126 L
.44939 .35126 L
.44938 .35125 L
.44938 .35125 L
.44938 .35125 L
.44938 .35124 L
.44938 .35124 L
.44938 .35124 L
.44938 .35124 L
.44938 .35123 L
.44938 .35123 L
.44938 .35123 L
.44938 .35122 L
Mistroke
.44938 .35122 L
.44938 .35122 L
.44938 .35122 L
.44938 .35121 L
.44937 .35121 L
.44937 .35121 L
.44937 .35121 L
.44937 .3512 L
.44937 .3512 L
.44937 .3512 L
.44937 .35119 L
.44937 .35119 L
.44937 .35119 L
.44937 .35119 L
.44937 .35118 L
.44937 .35118 L
.44937 .35118 L
.44937 .35117 L
.44937 .35117 L
.44937 .35117 L
.44936 .35117 L
.44936 .35116 L
.44936 .35116 L
.44936 .35116 L
.44936 .35116 L
.44936 .35115 L
.44936 .35115 L
.44936 .35115 L
.44936 .35114 L
.44936 .35114 L
.44936 .35114 L
.44936 .35114 L
.44936 .35113 L
.44936 .35113 L
.44936 .35113 L
.44936 .35112 L
.44936 .35112 L
.44936 .35112 L
.44935 .35112 L
.44935 .35111 L
.44935 .35111 L
.44935 .35111 L
.44935 .3511 L
.44935 .3511 L
.44935 .3511 L
.44935 .3511 L
.44935 .35109 L
.44935 .35109 L
.44935 .35109 L
.44935 .35109 L
Mistroke
.44935 .35108 L
.44935 .35108 L
.44935 .35108 L
.44935 .35107 L
.44935 .35107 L
.44935 .35107 L
.44935 .35107 L
.44935 .35106 L
.44934 .35106 L
.44934 .35106 L
.44934 .35105 L
.44934 .35105 L
.44934 .35105 L
.44934 .35105 L
.44934 .35104 L
.44934 .35104 L
.44934 .35104 L
.44934 .35103 L
.44934 .35103 L
.44934 .35103 L
.44934 .35103 L
.44934 .35102 L
.44934 .35102 L
.44934 .35102 L
.44934 .35101 L
.44934 .35101 L
.44934 .35101 L
.44934 .35101 L
.44934 .351 L
.44934 .351 L
.44934 .351 L
.44934 .351 L
.44934 .35099 L
.44933 .35099 L
.44933 .35099 L
.44933 .35098 L
.44933 .35098 L
.44933 .35098 L
.44933 .35098 L
.44933 .35097 L
.44933 .35097 L
.44933 .35097 L
.44933 .35096 L
.44933 .35096 L
.44933 .35096 L
.44933 .35096 L
.44933 .35095 L
.44933 .35095 L
.44933 .35095 L
.44933 .35094 L
Mistroke
.44933 .35094 L
.44933 .35094 L
.44933 .35094 L
.44933 .35093 L
.44933 .35093 L
.44933 .35093 L
.44933 .35092 L
.44933 .35092 L
.44933 .35092 L
.44933 .35092 L
.44933 .35091 L
.44933 .35091 L
.44933 .35091 L
.44933 .3509 L
.44933 .3509 L
.44933 .3509 L
.44933 .3509 L
.44933 .35089 L
.44932 .35089 L
.44932 .35089 L
.44932 .35088 L
.44932 .35088 L
.44932 .35088 L
.44932 .35088 L
.44932 .35087 L
.44932 .35087 L
.44932 .35087 L
.44932 .35087 L
.44932 .35086 L
.44932 .35086 L
.44932 .35086 L
.44932 .35085 L
.44932 .35085 L
.44932 .35085 L
.44932 .35085 L
.44932 .35084 L
.44932 .35084 L
.44932 .35084 L
.44932 .35083 L
.44932 .35083 L
.44932 .35083 L
.44932 .35083 L
.44932 .35082 L
.44932 .35082 L
.44932 .35082 L
.44932 .35081 L
.44932 .35081 L
.44932 .35081 L
.44932 .35081 L
.44932 .3508 L
Mistroke
.44932 .3508 L
.44932 .3508 L
.44932 .35079 L
.44932 .35079 L
.44932 .35079 L
.44932 .35079 L
.44932 .35078 L
.44932 .35078 L
.44932 .35078 L
.44932 .35077 L
.44932 .35077 L
.44932 .35077 L
.44932 .35077 L
.44932 .35076 L
.44932 .35076 L
.44932 .35076 L
.44932 .35075 L
.44932 .35075 L
.44932 .35075 L
.44932 .35075 L
.44932 .35074 L
.44932 .35074 L
.44932 .35074 L
.44932 .35073 L
.44932 .35073 L
.44932 .35073 L
.44932 .35073 L
.44932 .35072 L
.44932 .35072 L
.44932 .35072 L
.44932 .35071 L
.44932 .35071 L
.44932 .35071 L
.44932 .35071 L
.44932 .3507 L
.44932 .3507 L
.44932 .3507 L
.44932 .35069 L
.44932 .35069 L
.44932 .35069 L
.44932 .35069 L
.44932 .35068 L
.44932 .35068 L
.44932 .35068 L
.44932 .35068 L
.44932 .35067 L
.44932 .35067 L
.44932 .35067 L
.44932 .35066 L
.44932 .35066 L
Mistroke
.44932 .35066 L
.44932 .35066 L
.44932 .35065 L
.44932 .35065 L
.44932 .35065 L
.44932 .35064 L
.44932 .35064 L
.44932 .35064 L
.44932 .35064 L
.44932 .35063 L
.44932 .35063 L
.44932 .35063 L
.44932 .35062 L
.44932 .35062 L
.44932 .35062 L
.44932 .35062 L
.44932 .35061 L
.44932 .35061 L
.44932 .35061 L
.44932 .3506 L
.44932 .3506 L
.44932 .3506 L
.44932 .3506 L
.44932 .35059 L
.44932 .35059 L
.44932 .35059 L
.44932 .35058 L
.44932 .35058 L
.44932 .35058 L
.44932 .35058 L
.44932 .35057 L
.44932 .35057 L
.44932 .35057 L
.44932 .35056 L
.44932 .35056 L
.44932 .35056 L
.44932 .35056 L
.44932 .35055 L
.44932 .35055 L
.44932 .35055 L
.44932 .35054 L
.44932 .35054 L
.44932 .35054 L
.44932 .35054 L
.44932 .35053 L
.44932 .35053 L
.44933 .35053 L
.44933 .35053 L
.44933 .35052 L
.44933 .35052 L
Mistroke
.44933 .35052 L
.44933 .35051 L
.44933 .35051 L
.44933 .35051 L
.44933 .35051 L
.44933 .3505 L
.44933 .3505 L
.44933 .3505 L
.44933 .35049 L
.44933 .35049 L
.44933 .35049 L
.44933 .35049 L
.44933 .35048 L
.44933 .35048 L
.44933 .35048 L
.44933 .35047 L
.44933 .35047 L
.44933 .35047 L
.44933 .35047 L
.44933 .35046 L
.44933 .35046 L
.44933 .35046 L
.44933 .35045 L
.44933 .35045 L
.44933 .35045 L
.44933 .35045 L
.44933 .35044 L
.44933 .35044 L
.44933 .35044 L
.44933 .35043 L
.44933 .35043 L
.44933 .35043 L
.44934 .35043 L
.44934 .35042 L
.44934 .35042 L
.44934 .35042 L
.44934 .35042 L
.44934 .35041 L
.44934 .35041 L
.44934 .35041 L
.44934 .3504 L
.44934 .3504 L
.44934 .3504 L
.44934 .3504 L
.44934 .35039 L
.44934 .35039 L
.44934 .35039 L
.44934 .35038 L
.44934 .35038 L
.44934 .35038 L
Mistroke
.44934 .35038 L
.44934 .35037 L
.44934 .35037 L
.44934 .35037 L
.44934 .35036 L
.44934 .35036 L
.44934 .35036 L
.44934 .35036 L
.44934 .35035 L
.44935 .35035 L
.44935 .35035 L
.44935 .35034 L
.44935 .35034 L
.44935 .35034 L
.44935 .35034 L
.44935 .35033 L
.44935 .35033 L
.44935 .35033 L
.44935 .35033 L
.44935 .35032 L
.44935 .35032 L
.44935 .35032 L
.44935 .35031 L
.44935 .35031 L
.44935 .35031 L
.44935 .35031 L
.44935 .3503 L
.44935 .3503 L
.44935 .3503 L
.44935 .35029 L
.44935 .35029 L
.44935 .35029 L
.44936 .35029 L
.44936 .35028 L
.44936 .35028 L
.44936 .35028 L
.44936 .35027 L
.44936 .35027 L
.44936 .35027 L
.44936 .35027 L
.44936 .35026 L
.44936 .35026 L
.44936 .35026 L
.44936 .35026 L
.44936 .35025 L
.44936 .35025 L
.44936 .35025 L
.44936 .35024 L
.44936 .35024 L
.44936 .35024 L
Mistroke
.44936 .35024 L
.44936 .35023 L
.44937 .35023 L
.44937 .35023 L
.44937 .35022 L
.44937 .35022 L
.44937 .35022 L
.44937 .35022 L
.44937 .35021 L
.44937 .35021 L
.44937 .35021 L
.44937 .35021 L
.44937 .3502 L
.44937 .3502 L
.44937 .3502 L
.44937 .35019 L
.44937 .35019 L
.44937 .35019 L
.44937 .35019 L
.44938 .35018 L
.44938 .35018 L
.44938 .35018 L
.44938 .35017 L
.44938 .35017 L
.44938 .35017 L
.44938 .35017 L
.44938 .35016 L
.44938 .35016 L
.44938 .35016 L
.44938 .35016 L
.44938 .35015 L
.44938 .35015 L
.44938 .35015 L
.44938 .35014 L
.44938 .35014 L
.44938 .35014 L
.44939 .35014 L
.44939 .35013 L
.44939 .35013 L
.44939 .35013 L
.44939 .35012 L
.44939 .35012 L
.44939 .35012 L
.44939 .35012 L
.44939 .35011 L
.44939 .35011 L
.44939 .35011 L
.44939 .35011 L
.44939 .3501 L
.44939 .3501 L
Mistroke
.44939 .3501 L
.4494 .35009 L
.4494 .35009 L
.4494 .35009 L
.4494 .35009 L
.4494 .35008 L
.4494 .35008 L
.4494 .35008 L
.4494 .35008 L
.4494 .35007 L
.4494 .35007 L
.4494 .35007 L
.4494 .35006 L
.4494 .35006 L
.4494 .35006 L
.4494 .35006 L
.44941 .35005 L
.44941 .35005 L
.44941 .35005 L
.44941 .35004 L
.44941 .35004 L
.44941 .35004 L
.44941 .35004 L
.44941 .35003 L
.44941 .35003 L
.44941 .35003 L
.44941 .35003 L
.44941 .35002 L
.44941 .35002 L
.44942 .35002 L
.44942 .35001 L
.44942 .35001 L
.44942 .35001 L
.44942 .35001 L
.44942 .35 L
.44942 .35 L
.44942 .35 L
.44942 .35 L
.44942 .34999 L
.44942 .34999 L
.44942 .34999 L
.44942 .34998 L
.44942 .34998 L
.44943 .34998 L
.44943 .34998 L
.44943 .34997 L
.44943 .34997 L
.44943 .34997 L
.44943 .34997 L
.44943 .34996 L
Mistroke
.44943 .34996 L
.44943 .34996 L
.44943 .34995 L
.44943 .34995 L
.44943 .34995 L
.44944 .34995 L
.44944 .34994 L
.44944 .34994 L
.44944 .34994 L
.44944 .34994 L
.44944 .34993 L
.44944 .34993 L
.44944 .34993 L
.44944 .34993 L
.44944 .34992 L
.44944 .34992 L
.44944 .34992 L
.44945 .34991 L
.44945 .34991 L
.44945 .34991 L
.44945 .34991 L
.44945 .3499 L
.44945 .3499 L
.44945 .3499 L
.44945 .3499 L
.44945 .34989 L
.44945 .34989 L
.44945 .34989 L
.44945 .34988 L
.44946 .34988 L
.44946 .34988 L
.44946 .34988 L
.44946 .34987 L
.44946 .34987 L
.44946 .34987 L
.44946 .34987 L
.44946 .34986 L
.44946 .34986 L
.44946 .34986 L
.44946 .34985 L
.44947 .34985 L
.44947 .34985 L
.44947 .34985 L
.44947 .34984 L
.44947 .34984 L
.44947 .34984 L
.44947 .34984 L
.44947 .34983 L
.44947 .34983 L
.44947 .34983 L
Mistroke
.44947 .34983 L
.44948 .34982 L
.44948 .34982 L
.44948 .34982 L
.44948 .34981 L
.44948 .34981 L
.44948 .34981 L
.44948 .34981 L
.44948 .3498 L
.44948 .3498 L
.44948 .3498 L
.44948 .3498 L
.44949 .34979 L
.44949 .34979 L
.44949 .34979 L
.44949 .34979 L
.44949 .34978 L
.44949 .34978 L
.44949 .34978 L
.44949 .34977 L
.44949 .34977 L
.44949 .34977 L
.4495 .34977 L
.4495 .34976 L
.4495 .34976 L
.4495 .34976 L
.4495 .34976 L
.4495 .34975 L
.4495 .34975 L
.4495 .34975 L
.4495 .34975 L
.4495 .34974 L
.4495 .34974 L
.44951 .34974 L
.44951 .34973 L
.44951 .34973 L
.44951 .34973 L
.44951 .34973 L
.44951 .34972 L
.44951 .34972 L
.44951 .34972 L
.44951 .34972 L
.44951 .34971 L
.44952 .34971 L
.44952 .34971 L
.44952 .34971 L
.44952 .3497 L
.44952 .3497 L
.44952 .3497 L
.44952 .3497 L
Mistroke
.44952 .34969 L
.44952 .34969 L
.44953 .34969 L
.44953 .34968 L
.44953 .34968 L
.44953 .34968 L
.44953 .34968 L
.44953 .34967 L
.44953 .34967 L
.44953 .34967 L
.44953 .34967 L
.44953 .34966 L
.44954 .34966 L
.44954 .34966 L
.44954 .34966 L
.44954 .34965 L
.44954 .34965 L
.44954 .34965 L
.44954 .34965 L
.44954 .34964 L
.44954 .34964 L
.44955 .34964 L
.44955 .34964 L
.44955 .34963 L
.44955 .34963 L
.44955 .34963 L
.44955 .34962 L
.44955 .34962 L
.44955 .34962 L
.44955 .34962 L
.44955 .34961 L
.44956 .34961 L
.44956 .34961 L
.44956 .34961 L
.44956 .3496 L
.44956 .3496 L
.44956 .3496 L
.44956 .3496 L
.44956 .34959 L
.44956 .34959 L
.44957 .34959 L
.44957 .34959 L
.44957 .34958 L
.44957 .34958 L
.44957 .34958 L
.44957 .34958 L
.44957 .34957 L
.44957 .34957 L
.44957 .34957 L
.44958 .34957 L
Mistroke
.44958 .34956 L
.44958 .34956 L
.44958 .34956 L
.44958 .34956 L
.44958 .34955 L
.44958 .34955 L
.44958 .34955 L
.44959 .34954 L
.44959 .34954 L
.44959 .34954 L
.44959 .34954 L
.44959 .34953 L
.44959 .34953 L
.44959 .34953 L
.44959 .34953 L
.44959 .34952 L
.4496 .34952 L
.4496 .34952 L
.4496 .34952 L
.4496 .34951 L
.4496 .34951 L
.4496 .34951 L
.4496 .34951 L
.4496 .3495 L
.44961 .3495 L
.44961 .3495 L
.44961 .3495 L
.44961 .34949 L
.44961 .34949 L
.44961 .34949 L
.44961 .34949 L
.44961 .34948 L
.44961 .34948 L
.44962 .34948 L
.44962 .34948 L
.44962 .34947 L
.44962 .34947 L
.44962 .34947 L
.44962 .34947 L
.44962 .34946 L
.44962 .34946 L
.44963 .34946 L
.44963 .34946 L
.44963 .34945 L
.44963 .34945 L
.44963 .34945 L
.44963 .34945 L
.44963 .34944 L
.44963 .34944 L
.44964 .34944 L
Mistroke
.44964 .34944 L
.44964 .34943 L
.44964 .34943 L
.44964 .34943 L
.44964 .34943 L
.44964 .34942 L
.44964 .34942 L
.44965 .34942 L
.44965 .34942 L
.44965 .34941 L
.44965 .34941 L
.44965 .34941 L
.44965 .34941 L
.44965 .3494 L
.44965 .3494 L
.44966 .3494 L
.44966 .3494 L
.44966 .34939 L
.44966 .34939 L
.44966 .34939 L
.44966 .34939 L
.44966 .34938 L
.44966 .34938 L
.44967 .34938 L
.44967 .34938 L
.44967 .34937 L
.44967 .34937 L
.44967 .34937 L
.44967 .34937 L
.44967 .34936 L
.44967 .34936 L
.44968 .34936 L
.44968 .34936 L
.44968 .34935 L
.44968 .34935 L
.44968 .34935 L
.44968 .34935 L
.44968 .34934 L
.44968 .34934 L
.44969 .34934 L
.44969 .34934 L
.44969 .34933 L
.44969 .34933 L
.44969 .34933 L
.44969 .34933 L
.44969 .34932 L
.44969 .34932 L
.4497 .34932 L
.4497 .34932 L
.4497 .34931 L
Mistroke
.4497 .34931 L
.4497 .34931 L
.4497 .34931 L
.4497 .3493 L
.44971 .3493 L
.44971 .3493 L
.44971 .3493 L
.44971 .34929 L
.44971 .34929 L
.44971 .34929 L
.44971 .34929 L
.44971 .34928 L
.44972 .34928 L
.44972 .34928 L
.44972 .34928 L
.44972 .34927 L
.44972 .34927 L
.44972 .34927 L
.44972 .34927 L
.44973 .34927 L
.44973 .34926 L
.44973 .34926 L
.44973 .34926 L
.44973 .34926 L
.44973 .34925 L
.44973 .34925 L
.44973 .34925 L
.44974 .34925 L
.44974 .34924 L
.44974 .34924 L
.44974 .34924 L
.44974 .34924 L
.44974 .34923 L
.44974 .34923 L
.44975 .34923 L
.44975 .34923 L
.44975 .34922 L
.44975 .34922 L
.44975 .34922 L
.44975 .34922 L
.44975 .34921 L
.44976 .34921 L
.44976 .34921 L
.44976 .34921 L
.44976 .3492 L
.44976 .3492 L
.44976 .3492 L
.44976 .3492 L
.44977 .3492 L
.44977 .34919 L
Mistroke
.44977 .34919 L
.44977 .34919 L
.44977 .34919 L
.44977 .34918 L
.44977 .34918 L
.44978 .34918 L
.44978 .34918 L
.44978 .34917 L
.44978 .34917 L
.44978 .34917 L
.44978 .34917 L
.44978 .34916 L
.44978 .34916 L
.44979 .34916 L
.44979 .34916 L
.44979 .34915 L
.44979 .34915 L
.44979 .34915 L
.44979 .34915 L
.44979 .34915 L
.4498 .34914 L
.4498 .34914 L
.4498 .34914 L
.4498 .34914 L
.4498 .34913 L
.4498 .34913 L
.4498 .34913 L
.44981 .34913 L
.44981 .34912 L
.44981 .34912 L
.44981 .34912 L
.44981 .34912 L
.44981 .34912 L
.44981 .34911 L
.44982 .34911 L
.44982 .34911 L
.44982 .34911 L
.44982 .3491 L
.44982 .3491 L
.44982 .3491 L
.44983 .3491 L
.44983 .34909 L
.44983 .34909 L
.44983 .34909 L
.44983 .34909 L
.44983 .34908 L
.44983 .34908 L
.44984 .34908 L
.44984 .34908 L
.44984 .34908 L
Mistroke
.44984 .34907 L
.44984 .34907 L
.44984 .34907 L
.44984 .34907 L
.44985 .34906 L
.44985 .34906 L
.44985 .34906 L
.44985 .34906 L
.44985 .34905 L
.44985 .34905 L
.44985 .34905 L
.44986 .34905 L
.44986 .34905 L
.44986 .34904 L
.44986 .34904 L
.44986 .34904 L
.44986 .34904 L
.44986 .34903 L
.44987 .34903 L
.44987 .34903 L
.44987 .34903 L
.44987 .34902 L
.44987 .34902 L
.44987 .34902 L
.44988 .34902 L
.44988 .34902 L
.44988 .34901 L
.44988 .34901 L
.44988 .34901 L
.44988 .34901 L
.44988 .349 L
.44989 .349 L
.44989 .349 L
.44989 .349 L
.44989 .349 L
.44989 .34899 L
.44989 .34899 L
.44989 .34899 L
.4499 .34899 L
.4499 .34898 L
.4499 .34898 L
.4499 .34898 L
.4499 .34898 L
.4499 .34898 L
.44991 .34897 L
.44991 .34897 L
.44991 .34897 L
.44991 .34897 L
.44991 .34896 L
.44991 .34896 L
Mistroke
.44991 .34896 L
.44992 .34896 L
.44992 .34895 L
.44992 .34895 L
.44992 .34895 L
.44992 .34895 L
.44992 .34895 L
.44993 .34894 L
.44993 .34894 L
.44993 .34894 L
.44993 .34894 L
.44993 .34893 L
.44993 .34893 L
.44993 .34893 L
.44994 .34893 L
.44994 .34893 L
.44994 .34892 L
.44994 .34892 L
.44994 .34892 L
.44994 .34892 L
.44995 .34891 L
.44995 .34891 L
.44995 .34891 L
.44995 .34891 L
.44995 .34891 L
.44995 .3489 L
.44995 .3489 L
.44996 .3489 L
.44996 .3489 L
.44996 .3489 L
.44996 .34889 L
.44996 .34889 L
.44996 .34889 L
.44997 .34889 L
.44997 .34888 L
.44997 .34888 L
.44997 .34888 L
.44997 .34888 L
.44997 .34888 L
.44998 .34887 L
.44998 .34887 L
.44998 .34887 L
.44998 .34887 L
.44998 .34886 L
.44998 .34886 L
.44998 .34886 L
.44999 .34886 L
.44999 .34886 L
.44999 .34885 L
.44999 .34885 L
Mistroke
.44999 .34885 L
.44999 .34885 L
.45 .34885 L
.45 .34884 L
.45 .34884 L
.45 .34884 L
.45 .34884 L
.45 .34883 L
.45001 .34883 L
.45001 .34883 L
.45001 .34883 L
.45001 .34883 L
.45001 .34882 L
.45001 .34882 L
.45002 .34882 L
.45002 .34882 L
.45002 .34881 L
.45002 .34881 L
.45002 .34881 L
.45002 .34881 L
.45002 .34881 L
.45003 .3488 L
.45003 .3488 L
.45003 .3488 L
.45003 .3488 L
.45003 .3488 L
.45003 .34879 L
.45004 .34879 L
.45004 .34879 L
.45004 .34879 L
.45004 .34879 L
.45004 .34878 L
.45004 .34878 L
.45005 .34878 L
.45005 .34878 L
.45005 .34877 L
.45005 .34877 L
.45005 .34877 L
.45005 .34877 L
.45006 .34877 L
.45006 .34876 L
.45006 .34876 L
.45006 .34876 L
.45006 .34876 L
.45006 .34876 L
.45007 .34875 L
.45007 .34875 L
.45007 .34875 L
.45007 .34875 L
.45007 .34875 L
Mistroke
.45007 .34874 L
.45008 .34874 L
.45008 .34874 L
.45008 .34874 L
.45008 .34873 L
.45008 .34873 L
.45008 .34873 L
.45008 .34873 L
.45009 .34873 L
.45009 .34872 L
.45009 .34872 L
.45009 .34872 L
.45009 .34872 L
.45009 .34872 L
.4501 .34871 L
.4501 .34871 L
.4501 .34871 L
.4501 .34871 L
.4501 .34871 L
.4501 .3487 L
.45011 .3487 L
.45011 .3487 L
.45011 .3487 L
.45011 .3487 L
.45011 .34869 L
.45011 .34869 L
.45012 .34869 L
.45012 .34869 L
.45012 .34869 L
.45012 .34868 L
.45012 .34868 L
.45012 .34868 L
.45013 .34868 L
.45013 .34868 L
.45013 .34867 L
.45013 .34867 L
.45013 .34867 L
.45013 .34867 L
.45014 .34867 L
.45014 .34866 L
.45014 .34866 L
.45014 .34866 L
.45014 .34866 L
.45014 .34866 L
.45015 .34865 L
.45015 .34865 L
.45015 .34865 L
.45015 .34865 L
.45015 .34865 L
.45015 .34864 L
Mistroke
.45016 .34864 L
.45016 .34864 L
.45016 .34864 L
.45016 .34864 L
.45016 .34863 L
.45016 .34863 L
.45017 .34863 L
.45017 .34863 L
.45017 .34863 L
.45017 .34862 L
.45017 .34862 L
.45017 .34862 L
.45018 .34862 L
.45018 .34862 L
.45018 .34861 L
.45018 .34861 L
.45018 .34861 L
.45019 .34861 L
.45019 .34861 L
.45019 .3486 L
.45019 .3486 L
.45019 .3486 L
.45019 .3486 L
.4502 .3486 L
.4502 .34859 L
.4502 .34859 L
.4502 .34859 L
.4502 .34859 L
.4502 .34859 L
.45021 .34858 L
.45021 .34858 L
.45021 .34858 L
.45021 .34858 L
.45021 .34858 L
.45021 .34857 L
.45022 .34857 L
.45022 .34857 L
.45022 .34857 L
.45022 .34857 L
.45022 .34856 L
.45022 .34856 L
.45023 .34856 L
.45023 .34856 L
.45023 .34856 L
.45023 .34855 L
.45023 .34855 L
.45023 .34855 L
.45024 .34855 L
.45024 .34855 L
.45024 .34855 L
Mistroke
.45024 .34854 L
.45024 .34854 L
.45024 .34854 L
.45025 .34854 L
.45025 .34854 L
.45025 .34853 L
.45025 .34853 L
.45025 .34853 L
.45025 .34853 L
.45026 .34853 L
.45026 .34852 L
.45026 .34852 L
.45026 .34852 L
.45026 .34852 L
.45027 .34852 L
.45027 .34851 L
.45027 .34851 L
.45027 .34851 L
.45027 .34851 L
.45027 .34851 L
.45028 .34851 L
.45028 .3485 L
.45028 .3485 L
.45028 .3485 L
.45028 .3485 L
.45028 .3485 L
.45029 .34849 L
.45029 .34849 L
.45029 .34849 L
.45029 .34849 L
.45029 .34849 L
.45029 .34848 L
.4503 .34848 L
.4503 .34848 L
.4503 .34848 L
.4503 .34848 L
.4503 .34848 L
.45031 .34847 L
.45031 .34847 L
.45031 .34847 L
.45031 .34847 L
.45031 .34847 L
.45031 .34846 L
.45032 .34846 L
.45032 .34846 L
.45032 .34846 L
.45032 .34846 L
.45032 .34846 L
.45032 .34845 L
.45033 .34845 L
Mistroke
.45033 .34845 L
.45033 .34845 L
.45033 .34845 L
.45033 .34844 L
.45033 .34844 L
.45034 .34844 L
.45034 .34844 L
.45034 .34844 L
.45034 .34843 L
.45034 .34843 L
.45035 .34843 L
.45035 .34843 L
.45035 .34843 L
.45035 .34843 L
.45035 .34842 L
.45035 .34842 L
.45036 .34842 L
.45036 .34842 L
.45036 .34842 L
.45036 .34842 L
.45036 .34841 L
.45036 .34841 L
.45037 .34841 L
.45037 .34841 L
.45037 .34841 L
.45037 .3484 L
.45037 .3484 L
.45037 .3484 L
.45038 .3484 L
.45038 .3484 L
.45038 .3484 L
.45038 .34839 L
.45038 .34839 L
.45039 .34839 L
.45039 .34839 L
.45039 .34839 L
.45039 .34838 L
.45039 .34838 L
.45039 .34838 L
.4504 .34838 L
.4504 .34838 L
.4504 .34838 L
.4504 .34837 L
.4504 .34837 L
.4504 .34837 L
.45041 .34837 L
.45041 .34837 L
.45041 .34837 L
.45041 .34836 L
.45041 .34836 L
Mistroke
.45042 .34836 L
.45042 .34836 L
.45042 .34836 L
.45042 .34835 L
.45042 .34835 L
.45042 .34835 L
.45043 .34835 L
.45043 .34835 L
.45043 .34835 L
.45043 .34834 L
.45043 .34834 L
.45043 .34834 L
.45044 .34834 L
.45044 .34834 L
.45044 .34834 L
.45044 .34833 L
.45044 .34833 L
.45045 .34833 L
.45045 .34833 L
.45045 .34833 L
.45045 .34833 L
.45045 .34832 L
.45045 .34832 L
.45046 .34832 L
.45046 .34832 L
.45046 .34832 L
.45046 .34832 L
.45046 .34831 L
.45046 .34831 L
.45047 .34831 L
.45047 .34831 L
.45047 .34831 L
.45047 .34831 L
.45047 .3483 L
.45048 .3483 L
.45048 .3483 L
.45048 .3483 L
.45048 .3483 L
.45048 .34829 L
.45048 .34829 L
.45049 .34829 L
.45049 .34829 L
.45049 .34829 L
.45049 .34829 L
.45049 .34828 L
.4505 .34828 L
.4505 .34828 L
.4505 .34828 L
.4505 .34828 L
.4505 .34828 L
Mistroke
.4505 .34827 L
.45051 .34827 L
.45051 .34827 L
.45051 .34827 L
.45051 .34827 L
.45051 .34827 L
.45051 .34827 L
.45052 .34826 L
.45052 .34826 L
.45052 .34826 L
.45052 .34826 L
.45052 .34826 L
.45053 .34826 L
.45053 .34825 L
.45053 .34825 L
.45053 .34825 L
.45053 .34825 L
.45053 .34825 L
.45054 .34825 L
.45054 .34824 L
.45054 .34824 L
.45054 .34824 L
.45054 .34824 L
.45054 .34824 L
.45055 .34824 L
.45055 .34823 L
.45055 .34823 L
.45055 .34823 L
.45055 .34823 L
.45056 .34823 L
.45056 .34823 L
.45056 .34822 L
.45056 .34822 L
.45056 .34822 L
.45056 .34822 L
.45057 .34822 L
.45057 .34822 L
.45057 .34821 L
.45057 .34821 L
.45057 .34821 L
.45058 .34821 L
.45058 .34821 L
.45058 .34821 L
.45058 .34821 L
.45058 .3482 L
.45058 .3482 L
.45059 .3482 L
.45059 .3482 L
.45059 .3482 L
.45059 .3482 L
Mistroke
.45059 .34819 L
.45059 .34819 L
.4506 .34819 L
.4506 .34819 L
.4506 .34819 L
.4506 .34819 L
.4506 .34818 L
.45061 .34818 L
.45061 .34818 L
.45061 .34818 L
.45061 .34818 L
.45061 .34818 L
.45061 .34818 L
.45062 .34817 L
.45062 .34817 L
.45062 .34817 L
.45062 .34817 L
.45062 .34817 L
.45063 .34817 L
.45063 .34816 L
.45063 .34816 L
.45063 .34816 L
.45063 .34816 L
.45063 .34816 L
.45064 .34816 L
.45064 .34816 L
.45064 .34815 L
.45064 .34815 L
.45064 .34815 L
.45065 .34815 L
.45065 .34815 L
.45065 .34815 L
.45065 .34814 L
.45065 .34814 L
.45065 .34814 L
.45066 .34814 L
.45066 .34814 L
.45066 .34814 L
.45066 .34814 L
.45066 .34813 L
.45066 .34813 L
.45067 .34813 L
.45067 .34813 L
.45067 .34813 L
.45067 .34813 L
.45067 .34813 L
.45068 .34812 L
.45068 .34812 L
.45068 .34812 L
.45068 .34812 L
Mistroke
.45068 .34812 L
.45068 .34812 L
.45069 .34811 L
.45069 .34811 L
.45069 .34811 L
.45069 .34811 L
.45069 .34811 L
.4507 .34811 L
.4507 .34811 L
.4507 .3481 L
.4507 .3481 L
.4507 .3481 L
.4507 .3481 L
.45071 .3481 L
.45071 .3481 L
.45071 .3481 L
.45071 .34809 L
.45071 .34809 L
.45072 .34809 L
.45072 .34809 L
.45072 .34809 L
.45072 .34809 L
.45072 .34809 L
.45072 .34808 L
.45073 .34808 L
.45073 .34808 L
.45073 .34808 L
.45073 .34808 L
.45073 .34808 L
.45073 .34808 L
.45074 .34807 L
.45074 .34807 L
.45074 .34807 L
.45074 .34807 L
.45074 .34807 L
.45075 .34807 L
.45075 .34807 L
.45075 .34806 L
.45075 .34806 L
.45075 .34806 L
.45075 .34806 L
.45076 .34806 L
.45076 .34806 L
.45076 .34806 L
.45076 .34805 L
.45076 .34805 L
.45077 .34805 L
.45077 .34805 L
.45077 .34805 L
.45077 .34805 L
Mistroke
.45077 .34805 L
.45077 .34804 L
.45078 .34804 L
.45078 .34804 L
.45078 .34804 L
.45078 .34804 L
.45078 .34804 L
.45079 .34804 L
.45079 .34803 L
.45079 .34803 L
.45079 .34803 L
.45079 .34803 L
.45079 .34803 L
.4508 .34803 L
.4508 .34803 L
.4508 .34803 L
.4508 .34802 L
.4508 .34802 L
.4508 .34802 L
.45081 .34802 L
.45081 .34802 L
.45081 .34802 L
.45081 .34802 L
.45081 .34801 L
.45082 .34801 L
.45082 .34801 L
.45082 .34801 L
.45082 .34801 L
.45082 .34801 L
.45082 .34801 L
.45083 .348 L
.45083 .348 L
.45083 .348 L
.45083 .348 L
.45083 .348 L
.45084 .348 L
.45084 .348 L
.45084 .348 L
.45084 .34799 L
.45084 .34799 L
.45084 .34799 L
.45085 .34799 L
.45085 .34799 L
.45085 .34799 L
.45085 .34799 L
.45085 .34798 L
.45085 .34798 L
.45086 .34798 L
.45086 .34798 L
.45086 .34798 L
Mistroke
.45086 .34798 L
.45086 .34798 L
.45087 .34798 L
.45087 .34797 L
.45087 .34797 L
.45087 .34797 L
.45087 .34797 L
.45087 .34797 L
.45088 .34797 L
.45088 .34797 L
.45088 .34797 L
.45088 .34796 L
.45088 .34796 L
.45089 .34796 L
.45089 .34796 L
.45089 .34796 L
.45089 .34796 L
.45089 .34796 L
.45089 .34796 L
.4509 .34795 L
.4509 .34795 L
.4509 .34795 L
.4509 .34795 L
.4509 .34795 L
.4509 .34795 L
.45091 .34795 L
.45091 .34794 L
.45091 .34794 L
.45091 .34794 L
.45091 .34794 L
.45092 .34794 L
.45092 .34794 L
.45092 .34794 L
.45092 .34794 L
.45092 .34793 L
.45092 .34793 L
.45093 .34793 L
.45093 .34793 L
.45093 .34793 L
.45093 .34793 L
.45093 .34793 L
.45094 .34793 L
.45094 .34792 L
.45094 .34792 L
.45094 .34792 L
.45094 .34792 L
.45094 .34792 L
.45095 .34792 L
.45095 .34792 L
.45095 .34792 L
Mistroke
.45095 .34792 L
.45095 .34791 L
.45095 .34791 L
.45096 .34791 L
.45096 .34791 L
.45096 .34791 L
.45096 .34791 L
.45096 .34791 L
.45097 .34791 L
.45097 .3479 L
.45097 .3479 L
.45097 .3479 L
.45097 .3479 L
.45097 .3479 L
.45098 .3479 L
.45098 .3479 L
.45098 .3479 L
.45098 .34789 L
.45098 .34789 L
.45098 .34789 L
.45099 .34789 L
.45099 .34789 L
.45099 .34789 L
.45099 .34789 L
.45099 .34789 L
.451 .34789 L
.451 .34788 L
.451 .34788 L
.451 .34788 L
.451 .34788 L
.451 .34788 L
.45101 .34788 L
.45101 .34788 L
.45101 .34788 L
.45101 .34787 L
.45101 .34787 L
.45101 .34787 L
.45102 .34787 L
.45102 .34787 L
.45102 .34787 L
.45102 .34787 L
.45102 .34787 L
.45103 .34787 L
.45103 .34786 L
.45103 .34786 L
.45103 .34786 L
.45103 .34786 L
.45103 .34786 L
.45104 .34786 L
.45104 .34786 L
Mistroke
.45104 .34786 L
.45104 .34786 L
.45104 .34785 L
.45104 .34785 L
.45105 .34785 L
.45105 .34785 L
.45105 .34785 L
.45105 .34785 L
.45105 .34785 L
.45106 .34785 L
.45106 .34784 L
.45106 .34784 L
.45106 .34784 L
.45106 .34784 L
.45106 .34784 L
.45107 .34784 L
.45107 .34784 L
.45107 .34784 L
.45107 .34784 L
.45107 .34783 L
.45107 .34783 L
.45108 .34783 L
.45108 .34783 L
.45108 .34783 L
.45108 .34783 L
.45108 .34783 L
.45109 .34783 L
.45109 .34783 L
.45109 .34783 L
.45109 .34782 L
.45109 .34782 L
.45109 .34782 L
.4511 .34782 L
.4511 .34782 L
.4511 .34782 L
.4511 .34782 L
.4511 .34782 L
.4511 .34782 L
.45111 .34781 L
.45111 .34781 L
.45111 .34781 L
.45111 .34781 L
.45111 .34781 L
.45111 .34781 L
.45112 .34781 L
.45112 .34781 L
.45112 .34781 L
.45112 .3478 L
.45112 .3478 L
.45113 .3478 L
Mistroke
.45113 .3478 L
.45113 .3478 L
.45113 .3478 L
.45113 .3478 L
.45113 .3478 L
.45114 .3478 L
.45114 .3478 L
.45114 .34779 L
.45114 .34779 L
.45114 .34779 L
.45114 .34779 L
.45115 .34779 L
.45115 .34779 L
.45115 .34779 L
.45115 .34779 L
.45115 .34779 L
.45115 .34779 L
.45116 .34778 L
.45116 .34778 L
.45116 .34778 L
.45116 .34778 L
.45116 .34778 L
.45117 .34778 L
.45117 .34778 L
.45117 .34778 L
.45117 .34778 L
.45117 .34777 L
.45117 .34777 L
.45118 .34777 L
.45118 .34777 L
.45118 .34777 L
.45118 .34777 L
.45118 .34777 L
.45118 .34777 L
.45119 .34777 L
.45119 .34777 L
.45119 .34776 L
.45119 .34776 L
.45119 .34776 L
.45119 .34776 L
.4512 .34776 L
.4512 .34776 L
.4512 .34776 L
.4512 .34776 L
.4512 .34776 L
.4512 .34776 L
.45121 .34776 L
.45121 .34775 L
.45121 .34775 L
.45121 .34775 L
Mistroke
.45121 .34775 L
.45122 .34775 L
.45122 .34775 L
.45122 .34775 L
.45122 .34775 L
.45122 .34775 L
.45122 .34775 L
.45123 .34774 L
.45123 .34774 L
.45123 .34774 L
.45123 .34774 L
.45123 .34774 L
.45123 .34774 L
.45124 .34774 L
.45124 .34774 L
.45124 .34774 L
.45124 .34774 L
.45124 .34774 L
.45124 .34773 L
.45125 .34773 L
.45125 .34773 L
.45125 .34773 L
.45125 .34773 L
.45125 .34773 L
.45125 .34773 L
.45126 .34773 L
.45126 .34773 L
.45126 .34773 L
.45126 .34772 L
.45126 .34772 L
.45126 .34772 L
.45127 .34772 L
.45127 .34772 L
.45127 .34772 L
.45127 .34772 L
.45127 .34772 L
.45127 .34772 L
.45128 .34772 L
.45128 .34772 L
.45128 .34771 L
.45128 .34771 L
.45128 .34771 L
.45129 .34771 L
.45129 .34771 L
.45129 .34771 L
.45129 .34771 L
.45129 .34771 L
.45129 .34771 L
.4513 .34771 L
.4513 .34771 L
Mistroke
.4513 .34771 L
.4513 .3477 L
.4513 .3477 L
.4513 .3477 L
.45131 .3477 L
.45131 .3477 L
.45131 .3477 L
.45131 .3477 L
.45131 .3477 L
.45131 .3477 L
.45132 .3477 L
.45132 .3477 L
.45132 .34769 L
.45132 .34769 L
.45132 .34769 L
.45132 .34769 L
.45133 .34769 L
.45133 .34769 L
.45133 .34769 L
.45133 .34769 L
.45133 .34769 L
.45133 .34769 L
.45134 .34769 L
.45134 .34769 L
.45134 .34768 L
.45134 .34768 L
.45134 .34768 L
.45134 .34768 L
.45135 .34768 L
.45135 .34768 L
.45135 .34768 L
.45135 .34768 L
.45135 .34768 L
.45135 .34768 L
.45136 .34768 L
.45136 .34768 L
.45136 .34767 L
.45136 .34767 L
.45136 .34767 L
.45136 .34767 L
.45137 .34767 L
.45137 .34767 L
.45137 .34767 L
.45137 .34767 L
.45137 .34767 L
.45137 .34767 L
.45138 .34767 L
.45138 .34767 L
.45138 .34766 L
.45138 .34766 L
Mistroke
.45138 .34766 L
.45138 .34766 L
.45139 .34766 L
.45139 .34766 L
.45139 .34766 L
.45139 .34766 L
.45139 .34766 L
.45139 .34766 L
.4514 .34766 L
.4514 .34766 L
.4514 .34766 L
.4514 .34765 L
.4514 .34765 L
.4514 .34765 L
.45141 .34765 L
.45141 .34765 L
.45141 .34765 L
.45141 .34765 L
.45141 .34765 L
.45141 .34765 L
.45142 .34765 L
.45142 .34765 L
.45142 .34765 L
.45142 .34765 L
.45142 .34764 L
.45142 .34764 L
.45143 .34764 L
.45143 .34764 L
.45143 .34764 L
.45143 .34764 L
.45143 .34764 L
.45143 .34764 L
.45143 .34764 L
.45144 .34764 L
.45144 .34764 L
.45144 .34764 L
.45144 .34764 L
.45144 .34763 L
.45144 .34763 L
.45145 .34763 L
.45145 .34763 L
.45145 .34763 L
.45145 .34763 L
.45145 .34763 L
.45145 .34763 L
.45146 .34763 L
.45146 .34763 L
.45146 .34763 L
.45146 .34763 L
.45146 .34763 L
Mistroke
.45146 .34763 L
.45147 .34762 L
.45147 .34762 L
.45147 .34762 L
.45147 .34762 L
.45147 .34762 L
.45147 .34762 L
.45148 .34762 L
.45148 .34762 L
.45148 .34762 L
.45148 .34762 L
.45148 .34762 L
.45148 .34762 L
.45149 .34762 L
.45149 .34762 L
.45149 .34761 L
.45149 .34761 L
.45149 .34761 L
.45149 .34761 L
.4515 .34761 L
.4515 .34761 L
.4515 .34761 L
.4515 .34761 L
.4515 .34761 L
.4515 .34761 L
.4515 .34761 L
.45151 .34761 L
.45151 .34761 L
.45151 .34761 L
.45151 .34761 L
.45151 .3476 L
.45151 .3476 L
.45152 .3476 L
.45152 .3476 L
.45152 .3476 L
.45152 .3476 L
.45152 .3476 L
.45152 .3476 L
.45153 .3476 L
.45153 .3476 L
.45153 .3476 L
.45153 .3476 L
.45153 .3476 L
.45153 .3476 L
.45153 .3476 L
.45154 .34759 L
.45154 .34759 L
.45154 .34759 L
.45154 .34759 L
.45154 .34759 L
Mistroke
.45154 .34759 L
.45155 .34759 L
.45155 .34759 L
.45155 .34759 L
.45155 .34759 L
.45155 .34759 L
.45155 .34759 L
.45156 .34759 L
.45156 .34759 L
.45156 .34759 L
.45156 .34758 L
.45156 .34758 L
.45156 .34758 L
.45157 .34758 L
.45157 .34758 L
.45157 .34758 L
.45157 .34758 L
.45157 .34758 L
.45157 .34758 L
.45157 .34758 L
.45158 .34758 L
.45158 .34758 L
.45158 .34758 L
.45158 .34758 L
.45158 .34758 L
.45158 .34758 L
.45159 .34758 L
.45159 .34757 L
.45159 .34757 L
.45159 .34757 L
.45159 .34757 L
.45159 .34757 L
.45159 .34757 L
.4516 .34757 L
.4516 .34757 L
.4516 .34757 L
.4516 .34757 L
.4516 .34757 L
.4516 .34757 L
.45161 .34757 L
.45161 .34757 L
.45161 .34757 L
.45161 .34757 L
.45161 .34757 L
.45161 .34756 L
.45162 .34756 L
.45162 .34756 L
.45162 .34756 L
.45162 .34756 L
.45162 .34756 L
Mistroke
.45162 .34756 L
.45162 .34756 L
.45163 .34756 L
.45163 .34756 L
.45163 .34756 L
.45163 .34756 L
.45163 .34756 L
.45163 .34756 L
.45164 .34756 L
.45164 .34756 L
.45164 .34756 L
.45164 .34756 L
.45164 .34755 L
.45164 .34755 L
.45164 .34755 L
.45165 .34755 L
.45165 .34755 L
.45165 .34755 L
.45165 .34755 L
.45165 .34755 L
.45165 .34755 L
.45166 .34755 L
.45166 .34755 L
.45166 .34755 L
.45166 .34755 L
.45166 .34755 L
.45166 .34755 L
.45166 .34755 L
.45167 .34755 L
.45167 .34755 L
.45167 .34754 L
.45167 .34754 L
.45167 .34754 L
.45167 .34754 L
.45167 .34754 L
.45168 .34754 L
.45168 .34754 L
.45168 .34754 L
.45168 .34754 L
.45168 .34754 L
.45168 .34754 L
.45169 .34754 L
.45169 .34754 L
.45169 .34754 L
.45169 .34754 L
.45169 .34754 L
.45169 .34754 L
.45169 .34754 L
.4517 .34754 L
.4517 .34754 L
Mistroke
.4517 .34753 L
.4517 .34753 L
.4517 .34753 L
.4517 .34753 L
.4517 .34753 L
.45171 .34753 L
.45171 .34753 L
.45171 .34753 L
.45171 .34753 L
.45171 .34753 L
.45171 .34753 L
.45172 .34753 L
.45172 .34753 L
.45172 .34753 L
.45172 .34753 L
.45172 .34753 L
.45172 .34753 L
.45172 .34753 L
.45173 .34753 L
.45173 .34753 L
.45173 .34753 L
.45173 .34752 L
.45173 .34752 L
.45173 .34752 L
.45173 .34752 L
.45174 .34752 L
.45174 .34752 L
.45174 .34752 L
.45174 .34752 L
.45174 .34752 L
.45174 .34752 L
.45175 .34752 L
.45175 .34752 L
.45175 .34752 L
.45175 .34752 L
.45175 .34752 L
.45175 .34752 L
.45175 .34752 L
.45176 .34752 L
.45176 .34752 L
.45176 .34752 L
.45176 .34752 L
.45176 .34752 L
.45176 .34752 L
.45176 .34751 L
.45177 .34751 L
.45177 .34751 L
.45177 .34751 L
.45177 .34751 L
.45177 .34751 L
Mistroke
.45177 .34751 L
.45177 .34751 L
.45178 .34751 L
.45178 .34751 L
.45178 .34751 L
.45178 .34751 L
.45178 .34751 L
.45178 .34751 L
.45178 .34751 L
.45179 .34751 L
.45179 .34751 L
.45179 .34751 L
.45179 .34751 L
.45179 .34751 L
.45179 .34751 L
.45179 .34751 L
.4518 .34751 L
.4518 .34751 L
.4518 .3475 L
.4518 .3475 L
.4518 .3475 L
.4518 .3475 L
.4518 .3475 L
.45181 .3475 L
.45181 .3475 L
.45181 .3475 L
.45181 .3475 L
.45181 .3475 L
.45181 .3475 L
.45181 .3475 L
.45182 .3475 L
.45182 .3475 L
.45182 .3475 L
.45182 .3475 L
.45182 .3475 L
.45182 .3475 L
.45182 .3475 L
.45183 .3475 L
.45183 .3475 L
.45183 .3475 L
.45183 .3475 L
.45183 .3475 L
.45183 .3475 L
.45183 .3475 L
.45184 .3475 L
.45184 .34749 L
.45184 .34749 L
.45184 .34749 L
.45184 .34749 L
.45184 .34749 L
Mistroke
.45184 .34749 L
.45185 .34749 L
.45185 .34749 L
.45185 .34749 L
.45185 .34749 L
.45185 .34749 L
.45185 .34749 L
.45185 .34749 L
.45186 .34749 L
.45186 .34749 L
.45186 .34749 L
.45186 .34749 L
.45186 .34749 L
.45186 .34749 L
.45186 .34749 L
.45187 .34749 L
.45187 .34749 L
.45187 .34749 L
.45187 .34749 L
.45187 .34749 L
.45187 .34749 L
.45187 .34749 L
.45188 .34749 L
.45188 .34749 L
.45188 .34748 L
.45188 .34748 L
.45188 .34748 L
.45188 .34748 L
.45188 .34748 L
.45188 .34748 L
.45189 .34748 L
.45189 .34748 L
.45189 .34748 L
.45189 .34748 L
.45189 .34748 L
.45189 .34748 L
.45189 .34748 L
.4519 .34748 L
.4519 .34748 L
.4519 .34748 L
.4519 .34748 L
.4519 .34748 L
.4519 .34748 L
.4519 .34748 L
.45191 .34748 L
.45191 .34748 L
.45191 .34748 L
.45191 .34748 L
.45191 .34748 L
.45191 .34748 L
Mistroke
.45191 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45192 .34748 L
.45193 .34747 L
.45193 .34747 L
.45193 .34747 L
.45193 .34747 L
.45193 .34747 L
.45193 .34747 L
.45193 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45194 .34747 L
.45195 .34747 L
.45195 .34747 L
.45195 .34747 L
.45195 .34747 L
.45195 .34747 L
.45195 .34747 L
.45195 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45196 .34747 L
.45197 .34747 L
.45197 .34747 L
.45197 .34747 L
.45197 .34747 L
.45197 .34747 L
.45197 .34747 L
.45197 .34747 L
.45198 .34747 L
.45198 .34747 L
.45198 .34747 L
.45198 .34747 L
Mistroke
.45198 .34746 L
.45198 .34746 L
.45198 .34746 L
.45198 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.45199 .34746 L
.452 .34746 L
.452 .34746 L
.452 .34746 L
.452 .34746 L
.452 .34746 L
.452 .34746 L
.452 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45201 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45202 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45203 .34746 L
.45204 .34746 L
.45204 .34746 L
.45204 .34746 L
.45204 .34746 L
.45204 .34746 L
.45204 .34746 L
.45204 .34746 L
Mistroke
.45204 .34746 L
.45205 .34746 L
.45205 .34746 L
.45205 .34746 L
.45205 .34746 L
.45205 .34745 L
.45205 .34745 L
.45205 .34745 L
.45205 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45206 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45207 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45208 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.45209 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.4521 .34745 L
.45211 .34745 L
Mistroke
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45211 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45212 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45213 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45214 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45215 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
.45216 .34745 L
Mistroke
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45217 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45218 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.45219 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.4522 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45221 .34745 L
.45222 .34745 L
.45222 .34745 L
.45222 .34745 L
.45222 .34745 L
.45222 .34745 L
Mistroke
.45222 .34745 L
.45222 .34745 L
.45222 .34745 L
.45222 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45223 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45224 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45225 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45226 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
.45227 .34745 L
Mistroke
.45227 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45228 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.45229 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.4523 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45231 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
.45232 .34745 L
Mistroke
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45233 .34745 L
.45234 .34745 L
.45234 .34745 L
.45234 .34745 L
.45234 .34745 L
.45234 .34745 L
.45234 .34745 L
.45234 .34746 L
.45234 .34746 L
.45234 .34746 L
.45234 .34746 L
.45234 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45235 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45236 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
.45237 .34746 L
Mistroke
.45237 .34746 L
.45237 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45238 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.45239 .34746 L
.4524 .34746 L
.4524 .34746 L
.4524 .34746 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.4524 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45241 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
Mistroke
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45242 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45243 .34747 L
.45244 .34747 L
.45244 .34747 L
.45244 .34747 L
.45244 .34747 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45244 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45245 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
Mistroke
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45246 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34748 L
.45247 .34749 L
.45247 .34749 L
.45247 .34749 L
.45247 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45248 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.45249 .34749 L
.4525 .34749 L
.4525 .34749 L
.4525 .34749 L
.4525 .34749 L
.4525 .34749 L
.4525 .34749 L
Mistroke
.4525 .3475 L
.4525 .3475 L
.4525 .3475 L
.4525 .3475 L
.4525 .3475 L
.4525 .3475 L
.4525 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45251 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .3475 L
.45252 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45253 .34751 L
.45254 .34751 L
.45254 .34751 L
Mistroke
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45254 .34751 L
.45255 .34751 L
.45255 .34751 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45255 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45256 .34752 L
.45257 .34752 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
Mistroke
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45257 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34753 L
.45258 .34754 L
.45258 .34754 L
.45258 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.45259 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34754 L
.4526 .34755 L
.4526 .34755 L
.4526 .34755 L
Mistroke
.4526 .34755 L
.4526 .34755 L
.4526 .34755 L
.4526 .34755 L
.4526 .34755 L
.4526 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34755 L
.45261 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45262 .34756 L
.45263 .34756 L
.45263 .34756 L
.45263 .34756 L
.45263 .34756 L
.45263 .34756 L
.45263 .34756 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
Mistroke
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45263 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34757 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45264 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34758 L
.45265 .34759 L
.45265 .34759 L
.45265 .34759 L
.45265 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
Mistroke
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .34759 L
.45266 .3476 L
.45266 .3476 L
.45266 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .3476 L
.45267 .34761 L
.45267 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
Mistroke
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34761 L
.45268 .34762 L
.45268 .34762 L
.45268 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34762 L
.45269 .34763 L
.45269 .34763 L
.45269 .34763 L
.45269 .34763 L
.45269 .34763 L
.45269 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
.4527 .34763 L
Mistroke
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.4527 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34764 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45271 .34765 L
.45272 .34765 L
.45272 .34765 L
.45272 .34765 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
Mistroke
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34766 L
.45272 .34767 L
.45272 .34767 L
.45272 .34767 L
.45272 .34767 L
.45272 .34767 L
.45272 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34767 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45273 .34768 L
.45274 .34769 L
Mistroke
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .34769 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45274 .3477 L
.45275 .3477 L
.45275 .3477 L
.45275 .3477 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
Mistroke
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34771 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45275 .34772 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34773 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
Mistroke
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34774 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45276 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34775 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34776 L
.45277 .34777 L
.45277 .34777 L
Mistroke
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34777 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45277 .34778 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
.45278 .34779 L
Mistroke
.45278 .34779 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .3478 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34781 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
Mistroke
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34782 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34783 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45278 .34784 L
.45279 .34784 L
.45279 .34784 L
.45279 .34784 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
Mistroke
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34785 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34786 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34787 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
Mistroke
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34788 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .34789 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .3479 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
Mistroke
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34791 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34792 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45279 .34793 L
.45278 .34793 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
Mistroke
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34794 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34795 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
.45278 .34796 L
Mistroke
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34797 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34798 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
Mistroke
.45278 .34799 L
.45278 .34799 L
.45278 .34799 L
.45278 .348 L
.45278 .348 L
.45278 .348 L
.45278 .348 L
.45278 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .348 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34801 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
Mistroke
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34802 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34803 L
.45277 .34804 L
.45277 .34804 L
.45277 .34804 L
.45277 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34804 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
Mistroke
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34805 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34806 L
.45276 .34807 L
.45276 .34807 L
.45276 .34807 L
.45276 .34807 L
.45276 .34807 L
.45276 .34807 L
.45276 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34807 L
.45275 .34808 L
.45275 .34808 L
Mistroke
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34808 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .34809 L
.45275 .3481 L
.45275 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
Mistroke
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .3481 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34811 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45274 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34812 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
Mistroke
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34813 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45273 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34814 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
.45272 .34815 L
Mistroke
.45272 .34815 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45272 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34816 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34817 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
.45271 .34818 L
Mistroke
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34818 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .34819 L
.4527 .3482 L
.4527 .3482 L
.4527 .3482 L
.4527 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
Mistroke
.45269 .3482 L
.45269 .3482 L
.45269 .3482 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45269 .34821 L
.45268 .34821 L
.45268 .34821 L
.45268 .34821 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34822 L
.45268 .34823 L
.45268 .34823 L
.45268 .34823 L
.45268 .34823 L
.45268 .34823 L
Mistroke
.45268 .34823 L
.45268 .34823 L
.45268 .34823 L
.45268 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34823 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45267 .34824 L
.45266 .34824 L
.45266 .34824 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
Mistroke
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34825 L
.45266 .34826 L
.45266 .34826 L
.45266 .34826 L
.45266 .34826 L
.45266 .34826 L
.45266 .34826 L
.45266 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34826 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45265 .34827 L
.45264 .34827 L
Mistroke
.45264 .34827 L
.45264 .34827 L
.45264 .34827 L
.45264 .34827 L
.45264 .34827 L
.45264 .34827 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45264 .34828 L
.45263 .34828 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
Mistroke
.45263 .34829 L
.45263 .34829 L
.45263 .34829 L
.45263 .3483 L
.45263 .3483 L
.45263 .3483 L
.45263 .3483 L
.45263 .3483 L
.45263 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .3483 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45262 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
.45261 .34831 L
Mistroke
.45261 .34831 L
.45261 .34831 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.45261 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34832 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.4526 .34833 L
.45259 .34833 L
.45259 .34833 L
.45259 .34833 L
.45259 .34833 L
Mistroke
.45259 .34833 L
.45259 .34833 L
.45259 .34833 L
.45259 .34833 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45259 .34834 L
.45258 .34834 L
.45258 .34834 L
.45258 .34834 L
.45258 .34834 L
.45258 .34834 L
.45258 .34834 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
.45258 .34835 L
Mistroke
.45258 .34835 L
.45258 .34835 L
.45257 .34835 L
.45257 .34835 L
.45257 .34835 L
.45257 .34835 L
.45257 .34835 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45257 .34836 L
.45256 .34836 L
.45256 .34836 L
.45256 .34836 L
.45256 .34836 L
.45256 .34836 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
Mistroke
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45256 .34837 L
.45255 .34837 L
.45255 .34837 L
.45255 .34837 L
.45255 .34837 L
.45255 .34837 L
.45255 .34837 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45255 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34838 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
Mistroke
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45254 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .34839 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45253 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
Mistroke
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .3484 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45252 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34841 L
.45251 .34842 L
.45251 .34842 L
.45251 .34842 L
.45251 .34842 L
.45251 .34842 L
.45251 .34842 L
.45251 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
Mistroke
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.4525 .34842 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45249 .34843 L
.45248 .34843 L
Mistroke
.45248 .34843 L
.45248 .34843 L
.45248 .34843 L
.45248 .34843 L
.45248 .34843 L
.45248 .34843 L
.45248 .34843 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45248 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34844 L
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
Mistroke
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
.45247 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45246 .34845 L
.45245 .34845 L
.45245 .34845 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
Mistroke
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45245 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34846 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45244 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
Mistroke
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45243 .34847 L
.45242 .34847 L
.45242 .34847 L
.45242 .34847 L
.45242 .34847 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45242 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
Mistroke
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34848 L
.45241 .34849 L
.45241 .34849 L
.45241 .34849 L
.45241 .34849 L
.45241 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
.4524 .34849 L
Mistroke
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .34849 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45239 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
Mistroke
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45238 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .3485 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45237 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
Mistroke
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45236 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34851 L
.45235 .34852 L
.45235 .34852 L
.45235 .34852 L
.45235 .34852 L
.45235 .34852 L
.45235 .34852 L
.45234 .34852 L
.45234 .34852 L
Mistroke
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45234 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
Mistroke
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45233 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34852 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45232 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
Mistroke
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.45231 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
Mistroke
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.4523 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34853 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45229 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
Mistroke
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45228 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
Mistroke
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45227 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45226 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
Mistroke
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34854 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45225 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
Mistroke
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45224 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
Mistroke
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45223 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
.45222 .34855 L
Mistroke
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.45221 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
Mistroke
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.4522 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
Mistroke
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45219 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
Mistroke
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45218 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
Mistroke
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45217 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
Mistroke
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34855 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45216 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
Mistroke
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45215 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
Mistroke
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
Mistroke
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45214 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
Mistroke
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34854 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45213 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
Mistroke
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
Mistroke
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45212 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34853 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
Mistroke
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
Mistroke
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.45211 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34852 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
Mistroke
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
Mistroke
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.4521 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .34851 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
Mistroke
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
Mistroke
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .3485 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
Mistroke
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
Mistroke
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45209 .34849 L
.45208 .34849 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
Mistroke
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
Mistroke
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34848 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
Mistroke
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34847 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
Mistroke
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
Mistroke
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34846 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
Mistroke
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
Mistroke
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34845 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
Mistroke
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
Mistroke
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34844 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45208 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
Mistroke
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34843 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
Mistroke
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
Mistroke
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34842 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
Mistroke
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
Mistroke
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.45209 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .34841 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
Mistroke
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
Mistroke
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .3484 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
Mistroke
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.4521 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
Mistroke
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34839 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
Mistroke
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
Mistroke
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45211 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
.45212 .34838 L
Mistroke
.45212 .34838 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
Mistroke
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
Mistroke
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34837 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45212 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
Mistroke
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
Mistroke
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
Mistroke
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34836 L
.45213 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
Mistroke
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
Mistroke
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
Mistroke
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45214 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34835 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
Mistroke
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
Mistroke
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45215 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
Mistroke
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
Mistroke
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
Mistroke
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34834 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45216 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
Mistroke
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
Mistroke
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
Mistroke
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45217 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
Mistroke
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
Mistroke
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
Mistroke
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45218 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
Mistroke
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.45219 .34833 L
.4522 .34833 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
Mistroke
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
Mistroke
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
Mistroke
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
Mistroke
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.4522 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
Mistroke
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34832 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
Mistroke
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45221 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
Mistroke
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34833 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
.45222 .34834 L
Mistroke
.45222 .34834 L
Mfstroke
.481 0 1 r
.33105 .31173 m
.33121 .31162 L
.33136 .31151 L
.33151 .31141 L
.33166 .3113 L
.33181 .3112 L
.33197 .31109 L
.33212 .31098 L
.33227 .31088 L
.33242 .31077 L
.33257 .31067 L
.33273 .31056 L
.33288 .31046 L
.33303 .31035 L
.33318 .31025 L
.33333 .31014 L
.33349 .31004 L
.33364 .30994 L
.33379 .30983 L
.33394 .30973 L
.33409 .30963 L
.33424 .30952 L
.33439 .30942 L
.33455 .30932 L
.3347 .30921 L
.33485 .30911 L
.335 .30901 L
.33515 .3089 L
.3353 .3088 L
.33545 .3087 L
.3356 .3086 L
.33576 .3085 L
.33591 .3084 L
.33606 .30829 L
.33621 .30819 L
.33636 .30809 L
.33651 .30799 L
.33666 .30789 L
.33681 .30779 L
.33696 .30769 L
.33711 .30759 L
.33726 .30749 L
.33741 .30739 L
.33757 .30729 L
.33772 .30719 L
.33787 .30709 L
.33802 .30699 L
.33817 .30689 L
.33832 .30679 L
.33847 .30669 L
Mistroke
.33862 .30659 L
.33877 .3065 L
.33892 .3064 L
.33907 .3063 L
.33922 .3062 L
.33937 .3061 L
.33952 .30601 L
.33967 .30591 L
.33982 .30581 L
.33997 .30571 L
.34012 .30562 L
.34027 .30552 L
.34042 .30542 L
.34057 .30533 L
.34072 .30523 L
.34087 .30513 L
.34102 .30504 L
.34117 .30494 L
.34132 .30484 L
.34147 .30475 L
.34162 .30465 L
.34177 .30456 L
.34191 .30446 L
.34206 .30437 L
.34221 .30427 L
.34236 .30418 L
.34251 .30408 L
.34266 .30399 L
.34281 .30389 L
.34296 .3038 L
.34311 .30371 L
.34326 .30361 L
.34341 .30352 L
.34356 .30343 L
.3437 .30333 L
.34385 .30324 L
.344 .30315 L
.34415 .30305 L
.3443 .30296 L
.34445 .30287 L
.3446 .30278 L
.34474 .30268 L
.34489 .30259 L
.34504 .3025 L
.34519 .30241 L
.34534 .30232 L
.34549 .30222 L
.34564 .30213 L
.34578 .30204 L
.34593 .30195 L
Mistroke
.34608 .30186 L
.34623 .30177 L
.34638 .30168 L
.34652 .30159 L
.34667 .3015 L
.34682 .30141 L
.34697 .30132 L
.34712 .30123 L
.34726 .30114 L
.34741 .30105 L
.34756 .30096 L
.34771 .30087 L
.34786 .30078 L
.348 .30069 L
.34815 .3006 L
.3483 .30051 L
.34845 .30043 L
.34859 .30034 L
.34874 .30025 L
.34889 .30016 L
.34904 .30007 L
.34918 .29999 L
.34933 .2999 L
.34948 .29981 L
.34962 .29972 L
.34977 .29964 L
.34992 .29955 L
.35007 .29946 L
.35021 .29938 L
.35036 .29929 L
.35051 .2992 L
.35065 .29912 L
.3508 .29903 L
.35095 .29894 L
.35109 .29886 L
.35124 .29877 L
.35139 .29869 L
.35153 .2986 L
.35168 .29852 L
.35183 .29843 L
.35197 .29835 L
.35212 .29826 L
.35227 .29818 L
.35241 .29809 L
.35256 .29801 L
.3527 .29792 L
.35285 .29784 L
.353 .29776 L
.35314 .29767 L
.35329 .29759 L
Mistroke
.35343 .29751 L
.35358 .29742 L
.35373 .29734 L
.35387 .29726 L
.35402 .29717 L
.35416 .29709 L
.35431 .29701 L
.35446 .29693 L
.3546 .29684 L
.35475 .29676 L
.35489 .29668 L
.35504 .2966 L
.35518 .29652 L
.35533 .29643 L
.35547 .29635 L
.35562 .29627 L
.35576 .29619 L
.35591 .29611 L
.35606 .29603 L
.3562 .29595 L
.35635 .29587 L
.35649 .29579 L
.35664 .29571 L
.35678 .29563 L
.35693 .29555 L
.35707 .29547 L
.35721 .29539 L
.35736 .29531 L
.3575 .29523 L
.35765 .29515 L
.35779 .29507 L
.35794 .29499 L
.35808 .29491 L
.35823 .29483 L
.35837 .29475 L
.35852 .29467 L
.35866 .2946 L
.35881 .29452 L
.35895 .29444 L
.35909 .29436 L
.35924 .29428 L
.35938 .29421 L
.35953 .29413 L
.35967 .29405 L
.35981 .29397 L
.35996 .2939 L
.3601 .29382 L
.36025 .29374 L
.36039 .29367 L
.36053 .29359 L
Mistroke
.36068 .29351 L
.36082 .29344 L
.36096 .29336 L
.36111 .29329 L
.36125 .29321 L
.3614 .29313 L
.36154 .29306 L
.36168 .29298 L
.36183 .29291 L
.36197 .29283 L
.36211 .29276 L
.36226 .29268 L
.3624 .29261 L
.36254 .29253 L
.36268 .29246 L
.36283 .29238 L
.36297 .29231 L
.36311 .29224 L
.36326 .29216 L
.3634 .29209 L
.36354 .29201 L
.36368 .29194 L
.36383 .29187 L
.36397 .29179 L
.36411 .29172 L
.36426 .29165 L
.3644 .29158 L
.36454 .2915 L
.36468 .29143 L
.36483 .29136 L
.36497 .29129 L
.36511 .29121 L
.36525 .29114 L
.36539 .29107 L
.36554 .291 L
.36568 .29093 L
.36582 .29085 L
.36596 .29078 L
.3661 .29071 L
.36625 .29064 L
.36639 .29057 L
.36653 .2905 L
.36667 .29043 L
.36681 .29036 L
.36695 .29029 L
.3671 .29022 L
.36724 .29015 L
.36738 .29008 L
.36752 .29001 L
.36766 .28994 L
Mistroke
.3678 .28987 L
.36795 .2898 L
.36809 .28973 L
.36823 .28966 L
.36837 .28959 L
.36851 .28952 L
.36865 .28945 L
.36879 .28938 L
.36893 .28932 L
.36907 .28925 L
.36921 .28918 L
.36936 .28911 L
.3695 .28904 L
.36964 .28897 L
.36978 .28891 L
.36992 .28884 L
.37006 .28877 L
.3702 .2887 L
.37034 .28864 L
.37048 .28857 L
.37062 .2885 L
.37076 .28844 L
.3709 .28837 L
.37104 .2883 L
.37118 .28824 L
.37132 .28817 L
.37146 .2881 L
.3716 .28804 L
.37174 .28797 L
.37188 .2879 L
.37202 .28784 L
.37216 .28777 L
.3723 .28771 L
.37244 .28764 L
.37258 .28758 L
.37272 .28751 L
.37286 .28745 L
.373 .28738 L
.37314 .28732 L
.37328 .28725 L
.37342 .28719 L
.37356 .28712 L
.3737 .28706 L
.37384 .287 L
.37398 .28693 L
.37411 .28687 L
.37425 .2868 L
.37439 .28674 L
.37453 .28668 L
.37467 .28661 L
Mistroke
.37481 .28655 L
.37495 .28649 L
.37509 .28643 L
.37523 .28636 L
.37536 .2863 L
.3755 .28624 L
.37564 .28617 L
.37578 .28611 L
.37592 .28605 L
.37606 .28599 L
.3762 .28593 L
.37633 .28586 L
.37647 .2858 L
.37661 .28574 L
.37675 .28568 L
.37689 .28562 L
.37702 .28556 L
.37716 .2855 L
.3773 .28544 L
.37744 .28537 L
.37758 .28531 L
.37771 .28525 L
.37785 .28519 L
.37799 .28513 L
.37813 .28507 L
.37827 .28501 L
.3784 .28495 L
.37854 .28489 L
.37868 .28483 L
.37882 .28477 L
.37895 .28471 L
.37909 .28465 L
.37923 .28459 L
.37936 .28454 L
.3795 .28448 L
.37964 .28442 L
.37978 .28436 L
.37991 .2843 L
.38005 .28424 L
.38019 .28418 L
.38032 .28413 L
.38046 .28407 L
.3806 .28401 L
.38073 .28395 L
.38087 .28389 L
.38101 .28384 L
.38114 .28378 L
.38128 .28372 L
.38142 .28366 L
.38155 .28361 L
Mistroke
.38169 .28355 L
.38183 .28349 L
.38196 .28344 L
.3821 .28338 L
.38223 .28332 L
.38237 .28327 L
.38251 .28321 L
.38264 .28315 L
.38278 .2831 L
.38291 .28304 L
.38305 .28299 L
.38318 .28293 L
.38332 .28288 L
.38346 .28282 L
.38359 .28276 L
.38373 .28271 L
.38386 .28265 L
.384 .2826 L
.38413 .28254 L
.38427 .28249 L
.3844 .28243 L
.38454 .28238 L
.38467 .28233 L
.38481 .28227 L
.38494 .28222 L
.38508 .28216 L
.38521 .28211 L
.38535 .28206 L
.38548 .282 L
.38562 .28195 L
.38575 .28189 L
.38589 .28184 L
.38602 .28179 L
.38616 .28174 L
.38629 .28168 L
.38643 .28163 L
.38656 .28158 L
.3867 .28152 L
.38683 .28147 L
.38696 .28142 L
.3871 .28137 L
.38723 .28131 L
.38737 .28126 L
.3875 .28121 L
.38763 .28116 L
.38777 .28111 L
.3879 .28106 L
.38804 .281 L
.38817 .28095 L
.3883 .2809 L
Mistroke
.38844 .28085 L
.38857 .2808 L
.3887 .28075 L
.38884 .2807 L
.38897 .28065 L
.38911 .2806 L
.38924 .28055 L
.38937 .2805 L
.3895 .28045 L
.38964 .2804 L
.38977 .28035 L
.3899 .2803 L
.39004 .28025 L
.39017 .2802 L
.3903 .28015 L
.39044 .2801 L
.39057 .28005 L
.3907 .28 L
.39083 .27995 L
.39097 .2799 L
.3911 .27985 L
.39123 .2798 L
.39136 .27975 L
.3915 .27971 L
.39163 .27966 L
.39176 .27961 L
.39189 .27956 L
.39203 .27951 L
.39216 .27947 L
.39229 .27942 L
.39242 .27937 L
.39255 .27932 L
.39269 .27927 L
.39282 .27923 L
.39295 .27918 L
.39308 .27913 L
.39321 .27909 L
.39334 .27904 L
.39348 .27899 L
.39361 .27895 L
.39374 .2789 L
.39387 .27885 L
.394 .27881 L
.39413 .27876 L
.39426 .27871 L
.3944 .27867 L
.39453 .27862 L
.39466 .27858 L
.39479 .27853 L
.39492 .27849 L
Mistroke
.39505 .27844 L
.39518 .27839 L
.39531 .27835 L
.39544 .2783 L
.39557 .27826 L
.3957 .27821 L
.39583 .27817 L
.39597 .27812 L
.3961 .27808 L
.39623 .27804 L
.39636 .27799 L
.39649 .27795 L
.39662 .2779 L
.39675 .27786 L
.39688 .27781 L
.39701 .27777 L
.39714 .27773 L
.39727 .27768 L
.3974 .27764 L
.39753 .2776 L
.39766 .27755 L
.39779 .27751 L
.39792 .27747 L
.39805 .27742 L
.39817 .27738 L
.3983 .27734 L
.39843 .2773 L
.39856 .27725 L
.39869 .27721 L
.39882 .27717 L
.39895 .27713 L
.39908 .27708 L
.39921 .27704 L
.39934 .277 L
.39947 .27696 L
.3996 .27692 L
.39972 .27688 L
.39985 .27683 L
.39998 .27679 L
.40011 .27675 L
.40024 .27671 L
.40037 .27667 L
.4005 .27663 L
.40062 .27659 L
.40075 .27655 L
.40088 .27651 L
.40101 .27647 L
.40114 .27643 L
.40127 .27639 L
.40139 .27635 L
Mistroke
.40152 .27631 L
.40165 .27627 L
.40178 .27623 L
.40191 .27619 L
.40203 .27615 L
.40216 .27611 L
.40229 .27607 L
.40242 .27603 L
.40254 .27599 L
.40267 .27595 L
.4028 .27591 L
.40293 .27587 L
.40305 .27583 L
.40318 .27579 L
.40331 .27576 L
.40344 .27572 L
.40356 .27568 L
.40369 .27564 L
.40382 .2756 L
.40394 .27556 L
.40407 .27553 L
.4042 .27549 L
.40432 .27545 L
.40445 .27541 L
.40458 .27538 L
.4047 .27534 L
.40483 .2753 L
.40496 .27526 L
.40508 .27523 L
.40521 .27519 L
.40534 .27515 L
.40546 .27512 L
.40559 .27508 L
.40571 .27504 L
.40584 .27501 L
.40597 .27497 L
.40609 .27493 L
.40622 .2749 L
.40634 .27486 L
.40647 .27483 L
.40659 .27479 L
.40672 .27475 L
.40685 .27472 L
.40697 .27468 L
.4071 .27465 L
.40722 .27461 L
.40735 .27458 L
.40747 .27454 L
.4076 .27451 L
.40772 .27447 L
Mistroke
.40785 .27444 L
.40797 .2744 L
.4081 .27437 L
.40822 .27433 L
.40835 .2743 L
.40847 .27426 L
.4086 .27423 L
.40872 .2742 L
.40885 .27416 L
.40897 .27413 L
.40909 .27409 L
.40922 .27406 L
.40934 .27403 L
.40947 .27399 L
.40959 .27396 L
.40972 .27393 L
.40984 .27389 L
.40996 .27386 L
.41009 .27383 L
.41021 .27379 L
.41034 .27376 L
.41046 .27373 L
.41058 .2737 L
.41071 .27366 L
.41083 .27363 L
.41095 .2736 L
.41108 .27357 L
.4112 .27354 L
.41132 .2735 L
.41145 .27347 L
.41157 .27344 L
.41169 .27341 L
.41182 .27338 L
.41194 .27334 L
.41206 .27331 L
.41219 .27328 L
.41231 .27325 L
.41243 .27322 L
.41255 .27319 L
.41268 .27316 L
.4128 .27313 L
.41292 .2731 L
.41304 .27307 L
.41317 .27303 L
.41329 .273 L
.41341 .27297 L
.41353 .27294 L
.41366 .27291 L
.41378 .27288 L
.4139 .27285 L
Mistroke
.41402 .27282 L
.41414 .27279 L
.41427 .27276 L
.41439 .27274 L
.41451 .27271 L
.41463 .27268 L
.41475 .27265 L
.41487 .27262 L
.415 .27259 L
.41512 .27256 L
.41524 .27253 L
.41536 .2725 L
.41548 .27247 L
.4156 .27245 L
.41572 .27242 L
.41584 .27239 L
.41596 .27236 L
.41609 .27233 L
.41621 .2723 L
.41633 .27228 L
.41645 .27225 L
.41657 .27222 L
.41669 .27219 L
.41681 .27216 L
.41693 .27214 L
.41705 .27211 L
.41717 .27208 L
.41729 .27206 L
.41741 .27203 L
.41753 .272 L
.41765 .27197 L
.41777 .27195 L
.41789 .27192 L
.41801 .27189 L
.41813 .27187 L
.41825 .27184 L
.41837 .27181 L
.41849 .27179 L
.41861 .27176 L
.41873 .27174 L
.41885 .27171 L
.41897 .27168 L
.41909 .27166 L
.41921 .27163 L
.41933 .27161 L
.41945 .27158 L
.41956 .27156 L
.41968 .27153 L
.4198 .27151 L
.41992 .27148 L
Mistroke
.42004 .27146 L
.42016 .27143 L
.42028 .27141 L
.4204 .27138 L
.42051 .27136 L
.42063 .27133 L
.42075 .27131 L
.42087 .27128 L
.42099 .27126 L
.42111 .27123 L
.42122 .27121 L
.42134 .27119 L
.42146 .27116 L
.42158 .27114 L
.4217 .27112 L
.42181 .27109 L
.42193 .27107 L
.42205 .27104 L
.42217 .27102 L
.42228 .271 L
.4224 .27097 L
.42252 .27095 L
.42264 .27093 L
.42275 .27091 L
.42287 .27088 L
.42299 .27086 L
.42311 .27084 L
.42322 .27082 L
.42334 .27079 L
.42346 .27077 L
.42357 .27075 L
.42369 .27073 L
.42381 .2707 L
.42392 .27068 L
.42404 .27066 L
.42416 .27064 L
.42427 .27062 L
.42439 .2706 L
.42451 .27057 L
.42462 .27055 L
.42474 .27053 L
.42485 .27051 L
.42497 .27049 L
.42509 .27047 L
.4252 .27045 L
.42532 .27043 L
.42543 .27041 L
.42555 .27038 L
.42566 .27036 L
.42578 .27034 L
Mistroke
.4259 .27032 L
.42601 .2703 L
.42613 .27028 L
.42624 .27026 L
.42636 .27024 L
.42647 .27022 L
.42659 .2702 L
.4267 .27018 L
.42682 .27016 L
.42693 .27014 L
.42705 .27012 L
.42716 .2701 L
.42728 .27009 L
.42739 .27007 L
.42751 .27005 L
.42762 .27003 L
.42773 .27001 L
.42785 .26999 L
.42796 .26997 L
.42808 .26995 L
.42819 .26993 L
.42831 .26992 L
.42842 .2699 L
.42853 .26988 L
.42865 .26986 L
.42876 .26984 L
.42888 .26982 L
.42899 .26981 L
.4291 .26979 L
.42922 .26977 L
.42933 .26975 L
.42944 .26974 L
.42956 .26972 L
.42967 .2697 L
.42978 .26968 L
.4299 .26967 L
.43001 .26965 L
.43012 .26963 L
.43024 .26961 L
.43035 .2696 L
.43046 .26958 L
.43057 .26956 L
.43069 .26955 L
.4308 .26953 L
.43091 .26951 L
.43102 .2695 L
.43114 .26948 L
.43125 .26947 L
.43136 .26945 L
.43147 .26943 L
Mistroke
.43159 .26942 L
.4317 .2694 L
.43181 .26939 L
.43192 .26937 L
.43203 .26935 L
.43214 .26934 L
.43226 .26932 L
.43237 .26931 L
.43248 .26929 L
.43259 .26928 L
.4327 .26926 L
.43281 .26925 L
.43293 .26923 L
.43304 .26922 L
.43315 .2692 L
.43326 .26919 L
.43337 .26917 L
.43348 .26916 L
.43359 .26914 L
.4337 .26913 L
.43381 .26912 L
.43392 .2691 L
.43403 .26909 L
.43415 .26907 L
.43426 .26906 L
.43437 .26905 L
.43448 .26903 L
.43459 .26902 L
.4347 .26901 L
.43481 .26899 L
.43492 .26898 L
.43503 .26897 L
.43514 .26895 L
.43525 .26894 L
.43536 .26893 L
.43547 .26891 L
.43558 .2689 L
.43569 .26889 L
.4358 .26887 L
.4359 .26886 L
.43601 .26885 L
.43612 .26884 L
.43623 .26882 L
.43634 .26881 L
.43645 .2688 L
.43656 .26879 L
.43667 .26878 L
.43678 .26876 L
.43689 .26875 L
.43699 .26874 L
Mistroke
.4371 .26873 L
.43721 .26872 L
.43732 .26871 L
.43743 .26869 L
.43754 .26868 L
.43765 .26867 L
.43775 .26866 L
.43786 .26865 L
.43797 .26864 L
.43808 .26863 L
.43819 .26862 L
.43829 .26861 L
.4384 .2686 L
.43851 .26858 L
.43862 .26857 L
.43872 .26856 L
.43883 .26855 L
.43894 .26854 L
.43905 .26853 L
.43915 .26852 L
.43926 .26851 L
.43937 .2685 L
.43948 .26849 L
.43958 .26848 L
.43969 .26847 L
.4398 .26846 L
.4399 .26845 L
.44001 .26844 L
.44012 .26844 L
.44022 .26843 L
.44033 .26842 L
.44044 .26841 L
.44054 .2684 L
.44065 .26839 L
.44076 .26838 L
.44086 .26837 L
.44097 .26836 L
.44107 .26836 L
.44118 .26835 L
.44129 .26834 L
.44139 .26833 L
.4415 .26832 L
.4416 .26831 L
.44171 .26831 L
.44181 .2683 L
.44192 .26829 L
.44202 .26828 L
.44213 .26827 L
.44224 .26827 L
.44234 .26826 L
Mistroke
.44245 .26825 L
.44255 .26824 L
.44266 .26824 L
.44276 .26823 L
.44287 .26822 L
.44297 .26821 L
.44307 .26821 L
.44318 .2682 L
.44328 .26819 L
.44339 .26819 L
.44349 .26818 L
.4436 .26817 L
.4437 .26817 L
.4438 .26816 L
.44391 .26815 L
.44401 .26815 L
.44412 .26814 L
.44422 .26813 L
.44432 .26813 L
.44443 .26812 L
.44453 .26812 L
.44464 .26811 L
.44474 .2681 L
.44484 .2681 L
.44495 .26809 L
.44505 .26809 L
.44515 .26808 L
.44526 .26808 L
.44536 .26807 L
.44546 .26807 L
.44556 .26806 L
.44567 .26806 L
.44577 .26805 L
.44587 .26805 L
.44597 .26804 L
.44608 .26804 L
.44618 .26803 L
.44628 .26803 L
.44638 .26802 L
.44649 .26802 L
.44659 .26801 L
.44669 .26801 L
.44679 .26801 L
.4469 .268 L
.447 .268 L
.4471 .26799 L
.4472 .26799 L
.4473 .26799 L
.4474 .26798 L
.44751 .26798 L
Mistroke
.44761 .26797 L
.44771 .26797 L
.44781 .26797 L
.44791 .26796 L
.44801 .26796 L
.44811 .26796 L
.44821 .26795 L
.44831 .26795 L
.44842 .26795 L
.44852 .26795 L
.44862 .26794 L
.44872 .26794 L
.44882 .26794 L
.44892 .26793 L
.44902 .26793 L
.44912 .26793 L
.44922 .26793 L
.44932 .26792 L
.44942 .26792 L
.44952 .26792 L
.44962 .26792 L
.44972 .26792 L
.44982 .26791 L
.44992 .26791 L
.45002 .26791 L
.45012 .26791 L
.45022 .26791 L
.45032 .26791 L
.45042 .2679 L
.45052 .2679 L
.45061 .2679 L
.45071 .2679 L
.45081 .2679 L
.45091 .2679 L
.45101 .2679 L
.45111 .2679 L
.45121 .2679 L
.45131 .2679 L
.45141 .26789 L
.4515 .26789 L
.4516 .26789 L
.4517 .26789 L
.4518 .26789 L
.4519 .26789 L
.452 .26789 L
.45209 .26789 L
.45219 .26789 L
.45229 .26789 L
.45239 .26789 L
.45248 .26789 L
Mistroke
.45258 .26789 L
.45268 .26789 L
.45278 .26789 L
.45288 .26789 L
.45297 .26789 L
.45307 .26789 L
.45317 .2679 L
.45326 .2679 L
.45336 .2679 L
.45346 .2679 L
.45356 .2679 L
.45365 .2679 L
.45375 .2679 L
.45385 .2679 L
.45394 .2679 L
.45404 .2679 L
.45414 .26791 L
.45423 .26791 L
.45433 .26791 L
.45442 .26791 L
.45452 .26791 L
.45462 .26791 L
.45471 .26792 L
.45481 .26792 L
.4549 .26792 L
.455 .26792 L
.4551 .26792 L
.45519 .26793 L
.45529 .26793 L
.45538 .26793 L
.45548 .26793 L
.45557 .26794 L
.45567 .26794 L
.45576 .26794 L
.45586 .26794 L
.45595 .26795 L
.45605 .26795 L
.45614 .26795 L
.45624 .26796 L
.45633 .26796 L
.45643 .26796 L
.45652 .26796 L
.45662 .26797 L
.45671 .26797 L
.4568 .26797 L
.4569 .26798 L
.45699 .26798 L
.45709 .26799 L
.45718 .26799 L
.45728 .26799 L
Mistroke
.45737 .268 L
.45746 .268 L
.45756 .26801 L
.45765 .26801 L
.45774 .26801 L
.45784 .26802 L
.45793 .26802 L
.45802 .26803 L
.45812 .26803 L
.45821 .26804 L
.4583 .26804 L
.4584 .26804 L
.45849 .26805 L
.45858 .26805 L
.45868 .26806 L
.45877 .26806 L
.45886 .26807 L
.45895 .26807 L
.45905 .26808 L
.45914 .26808 L
.45923 .26809 L
.45932 .2681 L
.45941 .2681 L
.45951 .26811 L
.4596 .26811 L
.45969 .26812 L
.45978 .26812 L
.45987 .26813 L
.45997 .26814 L
.46006 .26814 L
.46015 .26815 L
.46024 .26815 L
.46033 .26816 L
.46042 .26817 L
.46051 .26817 L
.46061 .26818 L
.4607 .26818 L
.46079 .26819 L
.46088 .2682 L
.46097 .2682 L
.46106 .26821 L
.46115 .26822 L
.46124 .26822 L
.46133 .26823 L
.46142 .26824 L
.46151 .26825 L
.4616 .26825 L
.46169 .26826 L
.46178 .26827 L
.46187 .26827 L
Mistroke
.46196 .26828 L
.46205 .26829 L
.46214 .2683 L
.46223 .2683 L
.46232 .26831 L
.46241 .26832 L
.4625 .26833 L
.46259 .26834 L
.46268 .26834 L
.46277 .26835 L
.46286 .26836 L
.46295 .26837 L
.46304 .26838 L
.46312 .26838 L
.46321 .26839 L
.4633 .2684 L
.46339 .26841 L
.46348 .26842 L
.46357 .26843 L
.46366 .26844 L
.46374 .26844 L
.46383 .26845 L
.46392 .26846 L
.46401 .26847 L
.4641 .26848 L
.46419 .26849 L
.46427 .2685 L
.46436 .26851 L
.46445 .26852 L
.46454 .26853 L
.46462 .26854 L
.46471 .26855 L
.4648 .26856 L
.46489 .26857 L
.46497 .26858 L
.46506 .26858 L
.46515 .26859 L
.46523 .2686 L
.46532 .26861 L
.46541 .26862 L
.4655 .26864 L
.46558 .26865 L
.46567 .26866 L
.46576 .26867 L
.46584 .26868 L
.46593 .26869 L
.46601 .2687 L
.4661 .26871 L
.46619 .26872 L
.46627 .26873 L
Mistroke
.46636 .26874 L
.46644 .26875 L
.46653 .26876 L
.46662 .26877 L
.4667 .26878 L
.46679 .2688 L
.46687 .26881 L
.46696 .26882 L
.46704 .26883 L
.46713 .26884 L
.46721 .26885 L
.4673 .26886 L
.46738 .26887 L
.46747 .26889 L
.46755 .2689 L
.46764 .26891 L
.46772 .26892 L
.46781 .26893 L
.46789 .26895 L
.46798 .26896 L
.46806 .26897 L
.46815 .26898 L
.46823 .26899 L
.46831 .26901 L
.4684 .26902 L
.46848 .26903 L
.46857 .26904 L
.46865 .26906 L
.46873 .26907 L
.46882 .26908 L
.4689 .26909 L
.46898 .26911 L
.46907 .26912 L
.46915 .26913 L
.46923 .26915 L
.46932 .26916 L
.4694 .26917 L
.46948 .26919 L
.46957 .2692 L
.46965 .26921 L
.46973 .26923 L
.46981 .26924 L
.4699 .26925 L
.46998 .26927 L
.47006 .26928 L
.47014 .26929 L
.47023 .26931 L
.47031 .26932 L
.47039 .26934 L
.47047 .26935 L
Mistroke
.47055 .26936 L
.47064 .26938 L
.47072 .26939 L
.4708 .26941 L
.47088 .26942 L
.47096 .26944 L
.47104 .26945 L
.47113 .26946 L
.47121 .26948 L
.47129 .26949 L
.47137 .26951 L
.47145 .26952 L
.47153 .26954 L
.47161 .26955 L
.47169 .26957 L
.47177 .26958 L
.47185 .2696 L
.47193 .26961 L
.47202 .26963 L
.4721 .26964 L
.47218 .26966 L
.47226 .26967 L
.47234 .26969 L
.47242 .26971 L
.4725 .26972 L
.47258 .26974 L
.47266 .26975 L
.47274 .26977 L
.47282 .26978 L
.47289 .2698 L
.47297 .26982 L
.47305 .26983 L
.47313 .26985 L
.47321 .26986 L
.47329 .26988 L
.47337 .2699 L
.47345 .26991 L
.47353 .26993 L
.47361 .26995 L
.47369 .26996 L
.47376 .26998 L
.47384 .26999 L
.47392 .27001 L
.474 .27003 L
.47408 .27005 L
.47416 .27006 L
.47423 .27008 L
.47431 .2701 L
.47439 .27011 L
.47447 .27013 L
Mistroke
.47455 .27015 L
.47462 .27016 L
.4747 .27018 L
.47478 .2702 L
.47486 .27022 L
.47493 .27023 L
.47501 .27025 L
.47509 .27027 L
.47517 .27029 L
.47524 .2703 L
.47532 .27032 L
.4754 .27034 L
.47547 .27036 L
.47555 .27038 L
.47563 .27039 L
.4757 .27041 L
.47578 .27043 L
.47586 .27045 L
.47593 .27047 L
.47601 .27049 L
.47609 .2705 L
.47616 .27052 L
.47624 .27054 L
.47631 .27056 L
.47639 .27058 L
.47647 .2706 L
.47654 .27062 L
.47662 .27063 L
.47669 .27065 L
.47677 .27067 L
.47684 .27069 L
.47692 .27071 L
.47699 .27073 L
.47707 .27075 L
.47714 .27077 L
.47722 .27079 L
.47729 .27081 L
.47737 .27083 L
.47744 .27085 L
.47752 .27086 L
.47759 .27088 L
.47767 .2709 L
.47774 .27092 L
.47782 .27094 L
.47789 .27096 L
.47796 .27098 L
.47804 .271 L
.47811 .27102 L
.47819 .27104 L
.47826 .27106 L
Mistroke
.47833 .27108 L
.47841 .2711 L
.47848 .27112 L
.47855 .27114 L
.47863 .27116 L
.4787 .27119 L
.47877 .27121 L
.47885 .27123 L
.47892 .27125 L
.47899 .27127 L
.47906 .27129 L
.47914 .27131 L
.47921 .27133 L
.47928 .27135 L
.47936 .27137 L
.47943 .27139 L
.4795 .27141 L
.47957 .27144 L
.47964 .27146 L
.47972 .27148 L
.47979 .2715 L
.47986 .27152 L
.47993 .27154 L
.48 .27156 L
.48008 .27159 L
.48015 .27161 L
.48022 .27163 L
.48029 .27165 L
.48036 .27167 L
.48043 .27169 L
.4805 .27172 L
.48058 .27174 L
.48065 .27176 L
.48072 .27178 L
.48079 .2718 L
.48086 .27183 L
.48093 .27185 L
.481 .27187 L
.48107 .27189 L
.48114 .27192 L
.48121 .27194 L
.48128 .27196 L
.48135 .27198 L
.48142 .27201 L
.48149 .27203 L
.48156 .27205 L
.48163 .27207 L
.4817 .2721 L
.48177 .27212 L
.48184 .27214 L
Mistroke
.48191 .27217 L
.48198 .27219 L
.48205 .27221 L
.48212 .27223 L
.48219 .27226 L
.48226 .27228 L
.48232 .2723 L
.48239 .27233 L
.48246 .27235 L
.48253 .27238 L
.4826 .2724 L
.48267 .27242 L
.48274 .27245 L
.48281 .27247 L
.48287 .27249 L
.48294 .27252 L
.48301 .27254 L
.48308 .27257 L
.48315 .27259 L
.48321 .27261 L
.48328 .27264 L
.48335 .27266 L
.48342 .27269 L
.48348 .27271 L
.48355 .27273 L
.48362 .27276 L
.48369 .27278 L
.48375 .27281 L
.48382 .27283 L
.48389 .27286 L
.48396 .27288 L
.48402 .27291 L
.48409 .27293 L
.48416 .27296 L
.48422 .27298 L
.48429 .27301 L
.48435 .27303 L
.48442 .27306 L
.48449 .27308 L
.48455 .27311 L
.48462 .27313 L
.48469 .27316 L
.48475 .27318 L
.48482 .27321 L
.48488 .27323 L
.48495 .27326 L
.48501 .27328 L
.48508 .27331 L
.48515 .27334 L
.48521 .27336 L
Mistroke
.48528 .27339 L
.48534 .27341 L
.48541 .27344 L
.48547 .27346 L
.48554 .27349 L
.4856 .27352 L
.48567 .27354 L
.48573 .27357 L
.4858 .2736 L
.48586 .27362 L
.48592 .27365 L
.48599 .27367 L
.48605 .2737 L
.48612 .27373 L
.48618 .27375 L
.48624 .27378 L
.48631 .27381 L
.48637 .27383 L
.48644 .27386 L
.4865 .27389 L
.48656 .27391 L
.48663 .27394 L
.48669 .27397 L
.48675 .27399 L
.48682 .27402 L
.48688 .27405 L
.48694 .27408 L
.48701 .2741 L
.48707 .27413 L
.48713 .27416 L
.48719 .27418 L
.48726 .27421 L
.48732 .27424 L
.48738 .27427 L
.48744 .27429 L
.48751 .27432 L
.48757 .27435 L
.48763 .27438 L
.48769 .2744 L
.48775 .27443 L
.48782 .27446 L
.48788 .27449 L
.48794 .27452 L
.488 .27454 L
.48806 .27457 L
.48812 .2746 L
.48819 .27463 L
.48825 .27466 L
.48831 .27468 L
.48837 .27471 L
Mistroke
.48843 .27474 L
.48849 .27477 L
.48855 .2748 L
.48861 .27483 L
.48867 .27486 L
.48873 .27488 L
.48879 .27491 L
.48885 .27494 L
.48892 .27497 L
.48898 .275 L
.48904 .27503 L
.4891 .27506 L
.48916 .27509 L
.48922 .27511 L
.48928 .27514 L
.48933 .27517 L
.48939 .2752 L
.48945 .27523 L
.48951 .27526 L
.48957 .27529 L
.48963 .27532 L
.48969 .27535 L
.48975 .27538 L
.48981 .27541 L
.48987 .27544 L
.48993 .27547 L
.48999 .2755 L
.49004 .27553 L
.4901 .27556 L
.49016 .27559 L
.49022 .27562 L
.49028 .27565 L
.49034 .27568 L
.49039 .27571 L
.49045 .27574 L
.49051 .27577 L
.49057 .2758 L
.49063 .27583 L
.49068 .27586 L
.49074 .27589 L
.4908 .27592 L
.49086 .27595 L
.49091 .27598 L
.49097 .27601 L
.49103 .27604 L
.49109 .27607 L
.49114 .2761 L
.4912 .27613 L
.49126 .27616 L
.49131 .27619 L
Mistroke
.49137 .27622 L
.49143 .27625 L
.49148 .27628 L
.49154 .27631 L
.4916 .27635 L
.49165 .27638 L
.49171 .27641 L
.49177 .27644 L
.49182 .27647 L
.49188 .2765 L
.49193 .27653 L
.49199 .27656 L
.49204 .2766 L
.4921 .27663 L
.49216 .27666 L
.49221 .27669 L
.49227 .27672 L
.49232 .27675 L
.49238 .27678 L
.49243 .27682 L
.49249 .27685 L
.49254 .27688 L
.4926 .27691 L
.49265 .27694 L
.49271 .27698 L
.49276 .27701 L
.49281 .27704 L
.49287 .27707 L
.49292 .2771 L
.49298 .27714 L
.49303 .27717 L
.49309 .2772 L
.49314 .27723 L
.49319 .27727 L
.49325 .2773 L
.4933 .27733 L
.49335 .27736 L
.49341 .2774 L
.49346 .27743 L
.49352 .27746 L
.49357 .27749 L
.49362 .27753 L
.49367 .27756 L
.49373 .27759 L
.49378 .27762 L
.49383 .27766 L
.49389 .27769 L
.49394 .27772 L
.49399 .27776 L
.49404 .27779 L
Mistroke
.4941 .27782 L
.49415 .27786 L
.4942 .27789 L
.49425 .27792 L
.49431 .27796 L
.49436 .27799 L
.49441 .27802 L
.49446 .27806 L
.49451 .27809 L
.49456 .27812 L
.49462 .27816 L
.49467 .27819 L
.49472 .27822 L
.49477 .27826 L
.49482 .27829 L
.49487 .27832 L
.49492 .27836 L
.49497 .27839 L
.49503 .27843 L
.49508 .27846 L
.49513 .27849 L
.49518 .27853 L
.49523 .27856 L
.49528 .2786 L
.49533 .27863 L
.49538 .27867 L
.49543 .2787 L
.49548 .27873 L
.49553 .27877 L
.49558 .2788 L
.49563 .27884 L
.49568 .27887 L
.49573 .27891 L
.49578 .27894 L
.49583 .27898 L
.49588 .27901 L
.49593 .27905 L
.49598 .27908 L
.49602 .27911 L
.49607 .27915 L
.49612 .27918 L
.49617 .27922 L
.49622 .27925 L
.49627 .27929 L
.49632 .27932 L
.49637 .27936 L
.49642 .27939 L
.49646 .27943 L
.49651 .27947 L
.49656 .2795 L
Mistroke
.49661 .27954 L
.49666 .27957 L
.4967 .27961 L
.49675 .27964 L
.4968 .27968 L
.49685 .27971 L
.49689 .27975 L
.49694 .27978 L
.49699 .27982 L
.49704 .27986 L
.49708 .27989 L
.49713 .27993 L
.49718 .27996 L
.49723 .28 L
.49727 .28003 L
.49732 .28007 L
.49737 .28011 L
.49741 .28014 L
.49746 .28018 L
.49751 .28021 L
.49755 .28025 L
.4976 .28029 L
.49765 .28032 L
.49769 .28036 L
.49774 .2804 L
.49778 .28043 L
.49783 .28047 L
.49787 .28051 L
.49792 .28054 L
.49797 .28058 L
.49801 .28061 L
.49806 .28065 L
.4981 .28069 L
.49815 .28072 L
.49819 .28076 L
.49824 .2808 L
.49828 .28084 L
.49833 .28087 L
.49837 .28091 L
.49842 .28095 L
.49846 .28098 L
.49851 .28102 L
.49855 .28106 L
.4986 .28109 L
.49864 .28113 L
.49868 .28117 L
.49873 .28121 L
.49877 .28124 L
.49882 .28128 L
.49886 .28132 L
Mistroke
.4989 .28135 L
.49895 .28139 L
.49899 .28143 L
.49904 .28147 L
.49908 .2815 L
.49912 .28154 L
.49917 .28158 L
.49921 .28162 L
.49925 .28166 L
.4993 .28169 L
.49934 .28173 L
.49938 .28177 L
.49942 .28181 L
.49947 .28184 L
.49951 .28188 L
.49955 .28192 L
.49959 .28196 L
.49964 .282 L
.49968 .28203 L
.49972 .28207 L
.49976 .28211 L
.49981 .28215 L
.49985 .28219 L
.49989 .28223 L
.49993 .28226 L
.49997 .2823 L
.50001 .28234 L
.50006 .28238 L
.5001 .28242 L
.50014 .28246 L
.50018 .28249 L
.50022 .28253 L
.50026 .28257 L
.5003 .28261 L
.50034 .28265 L
.50039 .28269 L
.50043 .28273 L
.50047 .28277 L
.50051 .2828 L
.50055 .28284 L
.50059 .28288 L
.50063 .28292 L
.50067 .28296 L
.50071 .283 L
.50075 .28304 L
.50079 .28308 L
.50083 .28312 L
.50087 .28316 L
.50091 .28319 L
.50095 .28323 L
Mistroke
.50099 .28327 L
.50103 .28331 L
.50107 .28335 L
.50111 .28339 L
.50115 .28343 L
.50118 .28347 L
.50122 .28351 L
.50126 .28355 L
.5013 .28359 L
.50134 .28363 L
.50138 .28367 L
.50142 .28371 L
.50146 .28375 L
.50149 .28379 L
.50153 .28383 L
.50157 .28387 L
.50161 .28391 L
.50165 .28395 L
.50169 .28399 L
.50172 .28403 L
.50176 .28407 L
.5018 .28411 L
.50184 .28415 L
.50187 .28419 L
.50191 .28423 L
.50195 .28427 L
.50199 .28431 L
.50202 .28435 L
.50206 .28439 L
.5021 .28443 L
.50214 .28447 L
.50217 .28451 L
.50221 .28455 L
.50225 .28459 L
.50228 .28463 L
.50232 .28467 L
.50236 .28471 L
.50239 .28475 L
.50243 .28479 L
.50247 .28483 L
.5025 .28488 L
.50254 .28492 L
.50257 .28496 L
.50261 .285 L
.50265 .28504 L
.50268 .28508 L
.50272 .28512 L
.50275 .28516 L
.50279 .2852 L
.50282 .28524 L
Mistroke
.50286 .28528 L
.50289 .28533 L
.50293 .28537 L
.50296 .28541 L
.503 .28545 L
.50303 .28549 L
.50307 .28553 L
.5031 .28557 L
.50314 .28561 L
.50317 .28566 L
.50321 .2857 L
.50324 .28574 L
.50328 .28578 L
.50331 .28582 L
.50334 .28586 L
.50338 .2859 L
.50341 .28595 L
.50345 .28599 L
.50348 .28603 L
.50351 .28607 L
.50355 .28611 L
.50358 .28615 L
.50361 .2862 L
.50365 .28624 L
.50368 .28628 L
.50371 .28632 L
.50375 .28636 L
.50378 .28641 L
.50381 .28645 L
.50385 .28649 L
.50388 .28653 L
.50391 .28657 L
.50394 .28662 L
.50398 .28666 L
.50401 .2867 L
.50404 .28674 L
.50407 .28679 L
.50411 .28683 L
.50414 .28687 L
.50417 .28691 L
.5042 .28695 L
.50423 .287 L
.50427 .28704 L
.5043 .28708 L
.50433 .28712 L
.50436 .28717 L
.50439 .28721 L
.50442 .28725 L
.50446 .2873 L
.50449 .28734 L
Mistroke
.50452 .28738 L
.50455 .28742 L
.50458 .28747 L
.50461 .28751 L
.50464 .28755 L
.50467 .28759 L
.5047 .28764 L
.50473 .28768 L
.50476 .28772 L
.50479 .28777 L
.50482 .28781 L
.50485 .28785 L
.50488 .2879 L
.50491 .28794 L
.50494 .28798 L
.50497 .28803 L
.505 .28807 L
.50503 .28811 L
.50506 .28815 L
.50509 .2882 L
.50512 .28824 L
.50515 .28828 L
.50518 .28833 L
.50521 .28837 L
.50524 .28842 L
.50527 .28846 L
.5053 .2885 L
.50533 .28855 L
.50536 .28859 L
.50538 .28863 L
.50541 .28868 L
.50544 .28872 L
.50547 .28876 L
.5055 .28881 L
.50553 .28885 L
.50555 .28889 L
.50558 .28894 L
.50561 .28898 L
.50564 .28903 L
.50567 .28907 L
.50569 .28911 L
.50572 .28916 L
.50575 .2892 L
.50578 .28925 L
.50581 .28929 L
.50583 .28933 L
.50586 .28938 L
.50589 .28942 L
.50591 .28947 L
.50594 .28951 L
Mistroke
.50597 .28956 L
.506 .2896 L
.50602 .28964 L
.50605 .28969 L
.50608 .28973 L
.5061 .28978 L
.50613 .28982 L
.50615 .28987 L
.50618 .28991 L
.50621 .28995 L
.50623 .29 L
.50626 .29004 L
.50629 .29009 L
.50631 .29013 L
.50634 .29018 L
.50636 .29022 L
.50639 .29027 L
.50641 .29031 L
.50644 .29036 L
.50647 .2904 L
.50649 .29045 L
.50652 .29049 L
.50654 .29053 L
.50657 .29058 L
.50659 .29062 L
.50662 .29067 L
.50664 .29071 L
.50667 .29076 L
.50669 .2908 L
.50671 .29085 L
.50674 .29089 L
.50676 .29094 L
.50679 .29098 L
.50681 .29103 L
.50684 .29107 L
.50686 .29112 L
.50688 .29117 L
.50691 .29121 L
.50693 .29126 L
.50696 .2913 L
.50698 .29135 L
.507 .29139 L
.50703 .29144 L
.50705 .29148 L
.50707 .29153 L
.5071 .29157 L
.50712 .29162 L
.50714 .29166 L
.50717 .29171 L
.50719 .29176 L
Mistroke
.50721 .2918 L
.50724 .29185 L
.50726 .29189 L
.50728 .29194 L
.5073 .29198 L
.50733 .29203 L
.50735 .29207 L
.50737 .29212 L
.50739 .29217 L
.50741 .29221 L
.50744 .29226 L
.50746 .2923 L
.50748 .29235 L
.5075 .2924 L
.50752 .29244 L
.50755 .29249 L
.50757 .29253 L
.50759 .29258 L
.50761 .29263 L
.50763 .29267 L
.50765 .29272 L
.50767 .29276 L
.5077 .29281 L
.50772 .29286 L
.50774 .2929 L
.50776 .29295 L
.50778 .29299 L
.5078 .29304 L
.50782 .29309 L
.50784 .29313 L
.50786 .29318 L
.50788 .29323 L
.5079 .29327 L
.50792 .29332 L
.50794 .29336 L
.50796 .29341 L
.50798 .29346 L
.508 .2935 L
.50802 .29355 L
.50804 .2936 L
.50806 .29364 L
.50808 .29369 L
.5081 .29374 L
.50812 .29378 L
.50814 .29383 L
.50816 .29388 L
.50818 .29392 L
.5082 .29397 L
.50822 .29402 L
.50824 .29406 L
Mistroke
.50825 .29411 L
.50827 .29416 L
.50829 .2942 L
.50831 .29425 L
.50833 .2943 L
.50835 .29434 L
.50837 .29439 L
.50838 .29444 L
.5084 .29449 L
.50842 .29453 L
.50844 .29458 L
.50846 .29463 L
.50847 .29467 L
.50849 .29472 L
.50851 .29477 L
.50853 .29481 L
.50854 .29486 L
.50856 .29491 L
.50858 .29496 L
.5086 .295 L
.50861 .29505 L
.50863 .2951 L
.50865 .29514 L
.50867 .29519 L
.50868 .29524 L
.5087 .29529 L
.50872 .29533 L
.50873 .29538 L
.50875 .29543 L
.50877 .29548 L
.50878 .29552 L
.5088 .29557 L
.50882 .29562 L
.50883 .29567 L
.50885 .29571 L
.50886 .29576 L
.50888 .29581 L
.5089 .29586 L
.50891 .2959 L
.50893 .29595 L
.50894 .296 L
.50896 .29605 L
.50897 .29609 L
.50899 .29614 L
.50901 .29619 L
.50902 .29624 L
.50904 .29629 L
.50905 .29633 L
.50907 .29638 L
.50908 .29643 L
Mistroke
.5091 .29648 L
.50911 .29652 L
.50913 .29657 L
.50914 .29662 L
.50915 .29667 L
.50917 .29672 L
.50918 .29676 L
.5092 .29681 L
.50921 .29686 L
.50923 .29691 L
.50924 .29696 L
.50925 .297 L
.50927 .29705 L
.50928 .2971 L
.5093 .29715 L
.50931 .2972 L
.50932 .29724 L
.50934 .29729 L
.50935 .29734 L
.50936 .29739 L
.50938 .29744 L
.50939 .29749 L
.5094 .29753 L
.50942 .29758 L
.50943 .29763 L
.50944 .29768 L
.50946 .29773 L
.50947 .29777 L
.50948 .29782 L
.50949 .29787 L
.50951 .29792 L
.50952 .29797 L
.50953 .29802 L
.50954 .29807 L
.50956 .29811 L
.50957 .29816 L
.50958 .29821 L
.50959 .29826 L
.50961 .29831 L
.50962 .29836 L
.50963 .2984 L
.50964 .29845 L
.50965 .2985 L
.50966 .29855 L
.50968 .2986 L
.50969 .29865 L
.5097 .2987 L
.50971 .29875 L
.50972 .29879 L
.50973 .29884 L
Mistroke
.50974 .29889 L
.50975 .29894 L
.50976 .29899 L
.50978 .29904 L
.50979 .29909 L
.5098 .29914 L
.50981 .29918 L
.50982 .29923 L
.50983 .29928 L
.50984 .29933 L
.50985 .29938 L
.50986 .29943 L
.50987 .29948 L
.50988 .29953 L
.50989 .29958 L
.5099 .29962 L
.50991 .29967 L
.50992 .29972 L
.50993 .29977 L
.50994 .29982 L
.50995 .29987 L
.50996 .29992 L
.50997 .29997 L
.50998 .30002 L
.50999 .30007 L
.50999 .30012 L
.51 .30016 L
.51001 .30021 L
.51002 .30026 L
.51003 .30031 L
.51004 .30036 L
.51005 .30041 L
.51006 .30046 L
.51007 .30051 L
.51007 .30056 L
.51008 .30061 L
.51009 .30066 L
.5101 .30071 L
.51011 .30076 L
.51012 .3008 L
.51012 .30085 L
.51013 .3009 L
.51014 .30095 L
.51015 .301 L
.51015 .30105 L
.51016 .3011 L
.51017 .30115 L
.51018 .3012 L
.51018 .30125 L
.51019 .3013 L
Mistroke
.5102 .30135 L
.51021 .3014 L
.51021 .30145 L
.51022 .3015 L
.51023 .30155 L
.51023 .3016 L
.51024 .30165 L
.51025 .3017 L
.51026 .30175 L
.51026 .30179 L
.51027 .30184 L
.51027 .30189 L
.51028 .30194 L
.51029 .30199 L
.51029 .30204 L
.5103 .30209 L
.51031 .30214 L
.51031 .30219 L
.51032 .30224 L
.51032 .30229 L
.51033 .30234 L
.51034 .30239 L
.51034 .30244 L
.51035 .30249 L
.51035 .30254 L
.51036 .30259 L
.51036 .30264 L
.51037 .30269 L
.51037 .30274 L
.51038 .30279 L
.51038 .30284 L
.51039 .30289 L
.51039 .30294 L
.5104 .30299 L
.5104 .30304 L
.51041 .30309 L
.51041 .30314 L
.51042 .30319 L
.51042 .30324 L
.51043 .30329 L
.51043 .30334 L
.51044 .30339 L
.51044 .30344 L
.51044 .30349 L
.51045 .30354 L
.51045 .30359 L
.51046 .30364 L
.51046 .30369 L
.51046 .30374 L
.51047 .30379 L
Mistroke
.51047 .30384 L
.51047 .30389 L
.51048 .30394 L
.51048 .30399 L
.51048 .30404 L
.51049 .30409 L
.51049 .30414 L
.51049 .30419 L
.5105 .30424 L
.5105 .30429 L
.5105 .30434 L
.51051 .30439 L
.51051 .30444 L
.51051 .30449 L
.51051 .30454 L
.51052 .30459 L
.51052 .30464 L
.51052 .30469 L
.51052 .30474 L
.51053 .30479 L
.51053 .30484 L
.51053 .3049 L
.51053 .30495 L
.51053 .305 L
.51054 .30505 L
.51054 .3051 L
.51054 .30515 L
.51054 .3052 L
.51054 .30525 L
.51055 .3053 L
.51055 .30535 L
.51055 .3054 L
.51055 .30545 L
.51055 .3055 L
.51055 .30555 L
.51055 .3056 L
.51055 .30565 L
.51056 .3057 L
.51056 .30575 L
.51056 .3058 L
.51056 .30585 L
.51056 .3059 L
.51056 .30595 L
.51056 .306 L
.51056 .30606 L
.51056 .30611 L
.51056 .30616 L
.51056 .30621 L
.51056 .30626 L
.51056 .30631 L
Mistroke
.51056 .30636 L
.51056 .30641 L
.51056 .30646 L
.51056 .30651 L
.51056 .30656 L
.51056 .30661 L
.51056 .30666 L
.51056 .30671 L
.51056 .30676 L
.51056 .30681 L
.51056 .30686 L
.51056 .30692 L
.51056 .30697 L
.51056 .30702 L
.51056 .30707 L
.51056 .30712 L
.51055 .30717 L
.51055 .30722 L
.51055 .30727 L
.51055 .30732 L
.51055 .30737 L
.51055 .30742 L
.51055 .30747 L
.51055 .30752 L
.51054 .30757 L
.51054 .30763 L
.51054 .30768 L
.51054 .30773 L
.51054 .30778 L
.51054 .30783 L
.51053 .30788 L
.51053 .30793 L
.51053 .30798 L
.51053 .30803 L
.51052 .30808 L
.51052 .30813 L
.51052 .30818 L
.51052 .30824 L
.51052 .30829 L
.51051 .30834 L
.51051 .30839 L
.51051 .30844 L
.5105 .30849 L
.5105 .30854 L
.5105 .30859 L
.5105 .30864 L
.51049 .30869 L
.51049 .30874 L
.51049 .3088 L
.51048 .30885 L
Mistroke
.51048 .3089 L
.51048 .30895 L
.51047 .309 L
.51047 .30905 L
.51047 .3091 L
.51046 .30915 L
.51046 .3092 L
.51046 .30925 L
.51045 .3093 L
.51045 .30936 L
.51044 .30941 L
.51044 .30946 L
.51044 .30951 L
.51043 .30956 L
.51043 .30961 L
.51042 .30966 L
.51042 .30971 L
.51041 .30976 L
.51041 .30981 L
.5104 .30986 L
.5104 .30992 L
.5104 .30997 L
.51039 .31002 L
.51039 .31007 L
.51038 .31012 L
.51038 .31017 L
.51037 .31022 L
.51037 .31027 L
.51036 .31032 L
.51036 .31038 L
.51035 .31043 L
.51034 .31048 L
.51034 .31053 L
.51033 .31058 L
.51033 .31063 L
.51032 .31068 L
.51032 .31073 L
.51031 .31078 L
.51031 .31083 L
.5103 .31089 L
.51029 .31094 L
.51029 .31099 L
.51028 .31104 L
.51028 .31109 L
.51027 .31114 L
.51026 .31119 L
.51026 .31124 L
.51025 .31129 L
.51024 .31135 L
.51024 .3114 L
Mistroke
.51023 .31145 L
.51022 .3115 L
.51022 .31155 L
.51021 .3116 L
.5102 .31165 L
.5102 .3117 L
.51019 .31175 L
.51018 .3118 L
.51018 .31186 L
.51017 .31191 L
.51016 .31196 L
.51015 .31201 L
.51015 .31206 L
.51014 .31211 L
.51013 .31216 L
.51012 .31221 L
.51012 .31226 L
.51011 .31232 L
.5101 .31237 L
.51009 .31242 L
.51009 .31247 L
.51008 .31252 L
.51007 .31257 L
.51006 .31262 L
.51005 .31267 L
.51005 .31272 L
.51004 .31278 L
.51003 .31283 L
.51002 .31288 L
.51001 .31293 L
.51 .31298 L
.51 .31303 L
.50999 .31308 L
.50998 .31313 L
.50997 .31318 L
.50996 .31324 L
.50995 .31329 L
.50994 .31334 L
.50993 .31339 L
.50992 .31344 L
.50992 .31349 L
.50991 .31354 L
.5099 .31359 L
.50989 .31365 L
.50988 .3137 L
.50987 .31375 L
.50986 .3138 L
.50985 .31385 L
.50984 .3139 L
.50983 .31395 L
Mistroke
.50982 .314 L
.50981 .31405 L
.5098 .31411 L
.50979 .31416 L
.50978 .31421 L
.50977 .31426 L
.50976 .31431 L
.50975 .31436 L
.50974 .31441 L
.50973 .31446 L
.50972 .31451 L
.50971 .31456 L
.5097 .31462 L
.50969 .31467 L
.50968 .31472 L
.50967 .31477 L
.50966 .31482 L
.50965 .31487 L
.50964 .31492 L
.50963 .31497 L
.50961 .31502 L
.5096 .31508 L
.50959 .31513 L
.50958 .31518 L
.50957 .31523 L
.50956 .31528 L
.50955 .31533 L
.50954 .31538 L
.50952 .31543 L
.50951 .31548 L
.5095 .31554 L
.50949 .31559 L
.50948 .31564 L
.50947 .31569 L
.50945 .31574 L
.50944 .31579 L
.50943 .31584 L
.50942 .31589 L
.50941 .31594 L
.5094 .31599 L
.50938 .31605 L
.50937 .3161 L
.50936 .31615 L
.50935 .3162 L
.50933 .31625 L
.50932 .3163 L
.50931 .31635 L
.5093 .3164 L
.50928 .31645 L
.50927 .31651 L
Mistroke
.50926 .31656 L
.50925 .31661 L
.50923 .31666 L
.50922 .31671 L
.50921 .31676 L
.50919 .31681 L
.50918 .31686 L
.50917 .31691 L
.50915 .31696 L
.50914 .31701 L
.50913 .31707 L
.50911 .31712 L
.5091 .31717 L
.50909 .31722 L
.50907 .31727 L
.50906 .31732 L
.50905 .31737 L
.50903 .31742 L
.50902 .31747 L
.50901 .31752 L
.50899 .31758 L
.50898 .31763 L
.50896 .31768 L
.50895 .31773 L
.50894 .31778 L
.50892 .31783 L
.50891 .31788 L
.50889 .31793 L
.50888 .31798 L
.50886 .31803 L
.50885 .31808 L
.50884 .31813 L
.50882 .31819 L
.50881 .31824 L
.50879 .31829 L
.50878 .31834 L
.50876 .31839 L
.50875 .31844 L
.50873 .31849 L
.50872 .31854 L
.5087 .31859 L
.50869 .31864 L
.50867 .31869 L
.50866 .31874 L
.50864 .3188 L
.50863 .31885 L
.50861 .3189 L
.5086 .31895 L
.50858 .319 L
.50857 .31905 L
Mistroke
.50855 .3191 L
.50853 .31915 L
.50852 .3192 L
.5085 .31925 L
.50849 .3193 L
.50847 .31935 L
.50846 .3194 L
.50844 .31946 L
.50842 .31951 L
.50841 .31956 L
.50839 .31961 L
.50838 .31966 L
.50836 .31971 L
.50834 .31976 L
.50833 .31981 L
.50831 .31986 L
.50829 .31991 L
.50828 .31996 L
.50826 .32001 L
.50824 .32006 L
.50823 .32011 L
.50821 .32016 L
.50819 .32021 L
.50818 .32027 L
.50816 .32032 L
.50814 .32037 L
.50813 .32042 L
.50811 .32047 L
.50809 .32052 L
.50808 .32057 L
.50806 .32062 L
.50804 .32067 L
.50802 .32072 L
.50801 .32077 L
.50799 .32082 L
.50797 .32087 L
.50795 .32092 L
.50794 .32097 L
.50792 .32102 L
.5079 .32107 L
.50788 .32112 L
.50787 .32117 L
.50785 .32122 L
.50783 .32128 L
.50781 .32133 L
.50779 .32138 L
.50778 .32143 L
.50776 .32148 L
.50774 .32153 L
.50772 .32158 L
Mistroke
.5077 .32163 L
.50769 .32168 L
.50767 .32173 L
.50765 .32178 L
.50763 .32183 L
.50761 .32188 L
.50759 .32193 L
.50757 .32198 L
.50756 .32203 L
.50754 .32208 L
.50752 .32213 L
.5075 .32218 L
.50748 .32223 L
.50746 .32228 L
.50744 .32233 L
.50742 .32238 L
.5074 .32243 L
.50739 .32248 L
.50737 .32253 L
.50735 .32258 L
.50733 .32263 L
.50731 .32268 L
.50729 .32273 L
.50727 .32278 L
.50725 .32283 L
.50723 .32288 L
.50721 .32293 L
.50719 .32298 L
.50717 .32303 L
.50715 .32308 L
.50713 .32313 L
.50711 .32318 L
.50709 .32323 L
.50707 .32328 L
.50705 .32333 L
.50703 .32338 L
.50701 .32343 L
.50699 .32348 L
.50697 .32353 L
.50695 .32358 L
.50693 .32363 L
.50691 .32368 L
.50689 .32373 L
.50687 .32378 L
.50685 .32383 L
.50683 .32388 L
.50681 .32393 L
.50679 .32398 L
.50677 .32403 L
.50675 .32408 L
Mistroke
.50673 .32413 L
.50671 .32418 L
.50669 .32423 L
.50666 .32428 L
.50664 .32433 L
.50662 .32438 L
.5066 .32443 L
.50658 .32448 L
.50656 .32453 L
.50654 .32458 L
.50652 .32463 L
.5065 .32468 L
.50647 .32473 L
.50645 .32478 L
.50643 .32483 L
.50641 .32488 L
.50639 .32493 L
.50637 .32498 L
.50635 .32503 L
.50632 .32508 L
.5063 .32513 L
.50628 .32518 L
.50626 .32523 L
.50624 .32528 L
.50621 .32533 L
.50619 .32537 L
.50617 .32542 L
.50615 .32547 L
.50613 .32552 L
.5061 .32557 L
.50608 .32562 L
.50606 .32567 L
.50604 .32572 L
.50602 .32577 L
.50599 .32582 L
.50597 .32587 L
.50595 .32592 L
.50593 .32597 L
.5059 .32602 L
.50588 .32607 L
.50586 .32612 L
.50583 .32617 L
.50581 .32621 L
.50579 .32626 L
.50577 .32631 L
.50574 .32636 L
.50572 .32641 L
.5057 .32646 L
.50567 .32651 L
.50565 .32656 L
Mistroke
.50563 .32661 L
.50561 .32666 L
.50558 .32671 L
.50556 .32676 L
.50554 .3268 L
.50551 .32685 L
.50549 .3269 L
.50547 .32695 L
.50544 .327 L
.50542 .32705 L
.5054 .3271 L
.50537 .32715 L
.50535 .3272 L
.50532 .32725 L
.5053 .3273 L
.50528 .32734 L
.50525 .32739 L
.50523 .32744 L
.50521 .32749 L
.50518 .32754 L
.50516 .32759 L
.50513 .32764 L
.50511 .32769 L
.50508 .32774 L
.50506 .32778 L
.50504 .32783 L
.50501 .32788 L
.50499 .32793 L
.50496 .32798 L
.50494 .32803 L
.50491 .32808 L
.50489 .32813 L
.50487 .32817 L
.50484 .32822 L
.50482 .32827 L
.50479 .32832 L
.50477 .32837 L
.50474 .32842 L
.50472 .32847 L
.50469 .32851 L
.50467 .32856 L
.50464 .32861 L
.50462 .32866 L
.50459 .32871 L
.50457 .32876 L
.50454 .32881 L
.50452 .32885 L
.50449 .3289 L
.50447 .32895 L
.50444 .329 L
Mistroke
.50442 .32905 L
.50439 .3291 L
.50437 .32914 L
.50434 .32919 L
.50432 .32924 L
.50429 .32929 L
.50426 .32934 L
.50424 .32939 L
.50421 .32943 L
.50419 .32948 L
.50416 .32953 L
.50414 .32958 L
.50411 .32963 L
.50408 .32968 L
.50406 .32972 L
.50403 .32977 L
.50401 .32982 L
.50398 .32987 L
.50395 .32992 L
.50393 .32996 L
.5039 .33001 L
.50388 .33006 L
.50385 .33011 L
.50382 .33016 L
.5038 .3302 L
.50377 .33025 L
.50375 .3303 L
.50372 .33035 L
.50369 .3304 L
.50367 .33044 L
.50364 .33049 L
.50361 .33054 L
.50359 .33059 L
.50356 .33064 L
.50353 .33068 L
.50351 .33073 L
.50348 .33078 L
.50345 .33083 L
.50343 .33087 L
.5034 .33092 L
.50337 .33097 L
.50335 .33102 L
.50332 .33106 L
.50329 .33111 L
.50326 .33116 L
.50324 .33121 L
.50321 .33126 L
.50318 .3313 L
.50316 .33135 L
.50313 .3314 L
Mistroke
.5031 .33145 L
.50307 .33149 L
.50305 .33154 L
.50302 .33159 L
.50299 .33164 L
.50296 .33168 L
.50294 .33173 L
.50291 .33178 L
.50288 .33182 L
.50285 .33187 L
.50283 .33192 L
.5028 .33197 L
.50277 .33201 L
.50274 .33206 L
.50271 .33211 L
.50269 .33216 L
.50266 .3322 L
.50263 .33225 L
.5026 .3323 L
.50257 .33234 L
.50255 .33239 L
.50252 .33244 L
.50249 .33249 L
.50246 .33253 L
.50243 .33258 L
.50241 .33263 L
.50238 .33267 L
.50235 .33272 L
.50232 .33277 L
.50229 .33281 L
.50226 .33286 L
.50224 .33291 L
.50221 .33295 L
.50218 .333 L
.50215 .33305 L
.50212 .3331 L
.50209 .33314 L
.50206 .33319 L
.50204 .33324 L
.50201 .33328 L
.50198 .33333 L
.50195 .33338 L
.50192 .33342 L
.50189 .33347 L
.50186 .33352 L
.50183 .33356 L
.5018 .33361 L
.50178 .33366 L
.50175 .3337 L
.50172 .33375 L
Mistroke
.50169 .3338 L
.50166 .33384 L
.50163 .33389 L
.5016 .33393 L
.50157 .33398 L
.50154 .33403 L
.50151 .33407 L
.50148 .33412 L
.50145 .33417 L
.50142 .33421 L
.50139 .33426 L
.50137 .33431 L
.50134 .33435 L
.50131 .3344 L
.50128 .33444 L
.50125 .33449 L
.50122 .33454 L
.50119 .33458 L
.50116 .33463 L
.50113 .33467 L
.5011 .33472 L
.50107 .33477 L
.50104 .33481 L
.50101 .33486 L
.50098 .3349 L
.50095 .33495 L
.50092 .335 L
.50089 .33504 L
.50086 .33509 L
.50083 .33513 L
.5008 .33518 L
.50077 .33523 L
.50074 .33527 L
.50071 .33532 L
.50068 .33536 L
.50065 .33541 L
.50062 .33545 L
.50059 .3355 L
.50056 .33555 L
.50053 .33559 L
.50049 .33564 L
.50046 .33568 L
.50043 .33573 L
.5004 .33577 L
.50037 .33582 L
.50034 .33586 L
.50031 .33591 L
.50028 .33596 L
.50025 .336 L
.50022 .33605 L
Mistroke
.50019 .33609 L
.50016 .33614 L
.50013 .33618 L
.5001 .33623 L
.50006 .33627 L
.50003 .33632 L
.5 .33636 L
.49997 .33641 L
.49994 .33645 L
.49991 .3365 L
.49988 .33654 L
.49985 .33659 L
.49982 .33663 L
.49978 .33668 L
.49975 .33672 L
.49972 .33677 L
.49969 .33681 L
.49966 .33686 L
.49963 .3369 L
.4996 .33695 L
.49957 .33699 L
.49953 .33704 L
.4995 .33708 L
.49947 .33713 L
.49944 .33717 L
.49941 .33722 L
.49938 .33726 L
.49934 .33731 L
.49931 .33735 L
.49928 .3374 L
.49925 .33744 L
.49922 .33749 L
.49919 .33753 L
.49915 .33758 L
.49912 .33762 L
.49909 .33766 L
.49906 .33771 L
.49903 .33775 L
.49899 .3378 L
.49896 .33784 L
.49893 .33789 L
.4989 .33793 L
.49887 .33798 L
.49883 .33802 L
.4988 .33806 L
.49877 .33811 L
.49874 .33815 L
.49871 .3382 L
.49867 .33824 L
.49864 .33829 L
Mistroke
.49861 .33833 L
.49858 .33837 L
.49854 .33842 L
.49851 .33846 L
.49848 .33851 L
.49845 .33855 L
.49841 .33859 L
.49838 .33864 L
.49835 .33868 L
.49832 .33873 L
.49828 .33877 L
.49825 .33881 L
.49822 .33886 L
.49819 .3389 L
.49815 .33895 L
.49812 .33899 L
.49809 .33903 L
.49806 .33908 L
.49802 .33912 L
.49799 .33916 L
.49796 .33921 L
.49792 .33925 L
.49789 .33929 L
.49786 .33934 L
.49783 .33938 L
.49779 .33943 L
.49776 .33947 L
.49773 .33951 L
.49769 .33956 L
.49766 .3396 L
.49763 .33964 L
.49759 .33969 L
.49756 .33973 L
.49753 .33977 L
.49749 .33982 L
.49746 .33986 L
.49743 .3399 L
.49739 .33995 L
.49736 .33999 L
.49733 .34003 L
.49729 .34007 L
.49726 .34012 L
.49723 .34016 L
.49719 .3402 L
.49716 .34025 L
.49713 .34029 L
.49709 .34033 L
.49706 .34038 L
.49703 .34042 L
.49699 .34046 L
Mistroke
.49696 .3405 L
.49693 .34055 L
.49689 .34059 L
.49686 .34063 L
.49682 .34068 L
.49679 .34072 L
.49676 .34076 L
.49672 .3408 L
.49669 .34085 L
.49666 .34089 L
.49662 .34093 L
.49659 .34097 L
.49655 .34102 L
.49652 .34106 L
.49649 .3411 L
.49645 .34114 L
.49642 .34119 L
.49638 .34123 L
.49635 .34127 L
.49632 .34131 L
.49628 .34136 L
.49625 .3414 L
.49621 .34144 L
.49618 .34148 L
.49614 .34152 L
.49611 .34157 L
.49608 .34161 L
.49604 .34165 L
.49601 .34169 L
.49597 .34174 L
.49594 .34178 L
.4959 .34182 L
.49587 .34186 L
.49584 .3419 L
.4958 .34194 L
.49577 .34199 L
.49573 .34203 L
.4957 .34207 L
.49566 .34211 L
.49563 .34215 L
.49559 .3422 L
.49556 .34224 L
.49553 .34228 L
.49549 .34232 L
.49546 .34236 L
.49542 .3424 L
.49539 .34245 L
.49535 .34249 L
.49532 .34253 L
.49528 .34257 L
Mistroke
.49525 .34261 L
.49521 .34265 L
.49518 .34269 L
.49514 .34274 L
.49511 .34278 L
.49507 .34282 L
.49504 .34286 L
.495 .3429 L
.49497 .34294 L
.49493 .34298 L
.4949 .34302 L
.49486 .34307 L
.49483 .34311 L
.49479 .34315 L
.49476 .34319 L
.49472 .34323 L
.49469 .34327 L
.49465 .34331 L
.49462 .34335 L
.49458 .34339 L
.49455 .34343 L
.49451 .34348 L
.49448 .34352 L
.49444 .34356 L
.49441 .3436 L
.49437 .34364 L
.49434 .34368 L
.4943 .34372 L
.49427 .34376 L
.49423 .3438 L
.49419 .34384 L
.49416 .34388 L
.49412 .34392 L
.49409 .34396 L
.49405 .344 L
.49402 .34404 L
.49398 .34408 L
.49395 .34412 L
.49391 .34416 L
.49387 .34421 L
.49384 .34425 L
.4938 .34429 L
.49377 .34433 L
.49373 .34437 L
.4937 .34441 L
.49366 .34445 L
.49363 .34449 L
.49359 .34453 L
.49355 .34457 L
.49352 .34461 L
Mistroke
.49348 .34465 L
.49345 .34469 L
.49341 .34473 L
.49338 .34477 L
.49334 .34481 L
.4933 .34485 L
.49327 .34489 L
.49323 .34493 L
.4932 .34497 L
.49316 .345 L
.49312 .34504 L
.49309 .34508 L
.49305 .34512 L
.49302 .34516 L
.49298 .3452 L
.49294 .34524 L
.49291 .34528 L
.49287 .34532 L
.49284 .34536 L
.4928 .3454 L
.49276 .34544 L
.49273 .34548 L
.49269 .34552 L
.49265 .34556 L
.49262 .3456 L
.49258 .34564 L
.49255 .34568 L
.49251 .34571 L
.49247 .34575 L
.49244 .34579 L
.4924 .34583 L
.49236 .34587 L
.49233 .34591 L
.49229 .34595 L
.49226 .34599 L
.49222 .34603 L
.49218 .34607 L
.49215 .3461 L
.49211 .34614 L
.49207 .34618 L
.49204 .34622 L
.492 .34626 L
.49196 .3463 L
.49193 .34634 L
.49189 .34638 L
.49186 .34641 L
.49182 .34645 L
.49178 .34649 L
.49175 .34653 L
.49171 .34657 L
Mistroke
.49167 .34661 L
.49164 .34664 L
.4916 .34668 L
.49156 .34672 L
.49153 .34676 L
.49149 .3468 L
.49145 .34684 L
.49142 .34687 L
.49138 .34691 L
.49134 .34695 L
.49131 .34699 L
.49127 .34703 L
.49123 .34706 L
.4912 .3471 L
.49116 .34714 L
.49112 .34718 L
.49108 .34722 L
.49105 .34725 L
.49101 .34729 L
.49097 .34733 L
.49094 .34737 L
.4909 .34741 L
.49086 .34744 L
.49083 .34748 L
.49079 .34752 L
.49075 .34756 L
.49072 .34759 L
.49068 .34763 L
.49064 .34767 L
.4906 .34771 L
.49057 .34774 L
.49053 .34778 L
.49049 .34782 L
.49046 .34786 L
.49042 .34789 L
.49038 .34793 L
.49035 .34797 L
.49031 .34801 L
.49027 .34804 L
.49023 .34808 L
.4902 .34812 L
.49016 .34815 L
.49012 .34819 L
.49009 .34823 L
.49005 .34827 L
.49001 .3483 L
.48997 .34834 L
.48994 .34838 L
.4899 .34841 L
.48986 .34845 L
Mistroke
.48982 .34849 L
.48979 .34852 L
.48975 .34856 L
.48971 .3486 L
.48968 .34863 L
.48964 .34867 L
.4896 .34871 L
.48956 .34874 L
.48953 .34878 L
.48949 .34882 L
.48945 .34885 L
.48941 .34889 L
.48938 .34893 L
.48934 .34896 L
.4893 .349 L
.48926 .34903 L
.48923 .34907 L
.48919 .34911 L
.48915 .34914 L
.48911 .34918 L
.48908 .34922 L
.48904 .34925 L
.489 .34929 L
.48896 .34932 L
.48893 .34936 L
.48889 .3494 L
.48885 .34943 L
.48881 .34947 L
.48878 .3495 L
.48874 .34954 L
.4887 .34958 L
.48866 .34961 L
.48863 .34965 L
.48859 .34968 L
.48855 .34972 L
.48851 .34975 L
.48848 .34979 L
.48844 .34983 L
.4884 .34986 L
.48836 .3499 L
.48833 .34993 L
.48829 .34997 L
.48825 .35 L
.48821 .35004 L
.48817 .35007 L
.48814 .35011 L
.4881 .35014 L
.48806 .35018 L
.48802 .35021 L
.48799 .35025 L
Mistroke
.48795 .35029 L
.48791 .35032 L
.48787 .35036 L
.48783 .35039 L
.4878 .35043 L
.48776 .35046 L
.48772 .3505 L
.48768 .35053 L
.48765 .35057 L
.48761 .3506 L
.48757 .35063 L
.48753 .35067 L
.48749 .3507 L
.48746 .35074 L
.48742 .35077 L
.48738 .35081 L
.48734 .35084 L
.4873 .35088 L
.48727 .35091 L
.48723 .35095 L
.48719 .35098 L
.48715 .35102 L
.48712 .35105 L
.48708 .35108 L
.48704 .35112 L
.487 .35115 L
.48696 .35119 L
.48693 .35122 L
.48689 .35126 L
.48685 .35129 L
.48681 .35132 L
.48677 .35136 L
.48674 .35139 L
.4867 .35143 L
.48666 .35146 L
.48662 .35149 L
.48658 .35153 L
.48655 .35156 L
.48651 .3516 L
.48647 .35163 L
.48643 .35166 L
.48639 .3517 L
.48635 .35173 L
.48632 .35176 L
.48628 .3518 L
.48624 .35183 L
.4862 .35187 L
.48616 .3519 L
.48613 .35193 L
.48609 .35197 L
Mistroke
.48605 .352 L
.48601 .35203 L
.48597 .35207 L
.48594 .3521 L
.4859 .35213 L
.48586 .35217 L
.48582 .3522 L
.48578 .35223 L
.48574 .35227 L
.48571 .3523 L
.48567 .35233 L
.48563 .35236 L
.48559 .3524 L
.48555 .35243 L
.48552 .35246 L
.48548 .3525 L
.48544 .35253 L
.4854 .35256 L
.48536 .3526 L
.48532 .35263 L
.48529 .35266 L
.48525 .35269 L
.48521 .35273 L
.48517 .35276 L
.48513 .35279 L
.4851 .35282 L
.48506 .35286 L
.48502 .35289 L
.48498 .35292 L
.48494 .35295 L
.4849 .35299 L
.48487 .35302 L
.48483 .35305 L
.48479 .35308 L
.48475 .35312 L
.48471 .35315 L
.48467 .35318 L
.48464 .35321 L
.4846 .35324 L
.48456 .35328 L
.48452 .35331 L
.48448 .35334 L
.48444 .35337 L
.48441 .3534 L
.48437 .35344 L
.48433 .35347 L
.48429 .3535 L
.48425 .35353 L
.48421 .35356 L
.48418 .35359 L
Mistroke
.48414 .35363 L
.4841 .35366 L
.48406 .35369 L
.48402 .35372 L
.48398 .35375 L
.48395 .35378 L
.48391 .35382 L
.48387 .35385 L
.48383 .35388 L
.48379 .35391 L
.48375 .35394 L
.48372 .35397 L
.48368 .354 L
.48364 .35404 L
.4836 .35407 L
.48356 .3541 L
.48352 .35413 L
.48349 .35416 L
.48345 .35419 L
.48341 .35422 L
.48337 .35425 L
.48333 .35428 L
.48329 .35431 L
.48325 .35435 L
.48322 .35438 L
.48318 .35441 L
.48314 .35444 L
.4831 .35447 L
.48306 .3545 L
.48302 .35453 L
.48299 .35456 L
.48295 .35459 L
.48291 .35462 L
.48287 .35465 L
.48283 .35468 L
.48279 .35471 L
.48276 .35474 L
.48272 .35477 L
.48268 .3548 L
.48264 .35483 L
.4826 .35487 L
.48256 .3549 L
.48252 .35493 L
.48249 .35496 L
.48245 .35499 L
.48241 .35502 L
.48237 .35505 L
.48233 .35508 L
.48229 .35511 L
.48226 .35514 L
Mistroke
.48222 .35517 L
.48218 .3552 L
.48214 .35523 L
.4821 .35526 L
.48206 .35529 L
.48203 .35531 L
.48199 .35534 L
.48195 .35537 L
.48191 .3554 L
.48187 .35543 L
.48183 .35546 L
.48179 .35549 L
.48176 .35552 L
.48172 .35555 L
.48168 .35558 L
.48164 .35561 L
.4816 .35564 L
.48156 .35567 L
.48153 .3557 L
.48149 .35573 L
.48145 .35576 L
.48141 .35579 L
.48137 .35581 L
.48133 .35584 L
.4813 .35587 L
.48126 .3559 L
.48122 .35593 L
.48118 .35596 L
.48114 .35599 L
.4811 .35602 L
.48107 .35605 L
.48103 .35608 L
.48099 .3561 L
.48095 .35613 L
.48091 .35616 L
.48087 .35619 L
.48083 .35622 L
.4808 .35625 L
.48076 .35628 L
.48072 .3563 L
.48068 .35633 L
.48064 .35636 L
.4806 .35639 L
.48057 .35642 L
.48053 .35645 L
.48049 .35647 L
.48045 .3565 L
.48041 .35653 L
.48037 .35656 L
.48034 .35659 L
Mistroke
.4803 .35662 L
.48026 .35664 L
.48022 .35667 L
.48018 .3567 L
.48014 .35673 L
.48011 .35676 L
.48007 .35678 L
.48003 .35681 L
.47999 .35684 L
.47995 .35687 L
.47991 .35689 L
.47988 .35692 L
.47984 .35695 L
.4798 .35698 L
.47976 .35701 L
.47972 .35703 L
.47968 .35706 L
.47965 .35709 L
.47961 .35712 L
.47957 .35714 L
.47953 .35717 L
.47949 .3572 L
.47945 .35722 L
.47942 .35725 L
.47938 .35728 L
.47934 .35731 L
.4793 .35733 L
.47926 .35736 L
.47922 .35739 L
.47919 .35741 L
.47915 .35744 L
.47911 .35747 L
.47907 .3575 L
.47903 .35752 L
.47899 .35755 L
.47896 .35758 L
.47892 .3576 L
.47888 .35763 L
.47884 .35766 L
.4788 .35768 L
.47877 .35771 L
.47873 .35774 L
.47869 .35776 L
.47865 .35779 L
.47861 .35782 L
.47857 .35784 L
.47854 .35787 L
.4785 .3579 L
.47846 .35792 L
.47842 .35795 L
Mistroke
.47838 .35797 L
.47834 .358 L
.47831 .35803 L
.47827 .35805 L
.47823 .35808 L
.47819 .35811 L
.47815 .35813 L
.47812 .35816 L
.47808 .35818 L
.47804 .35821 L
.478 .35824 L
.47796 .35826 L
.47793 .35829 L
.47789 .35831 L
.47785 .35834 L
.47781 .35836 L
.47777 .35839 L
.47773 .35842 L
.4777 .35844 L
.47766 .35847 L
.47762 .35849 L
.47758 .35852 L
.47754 .35854 L
.47751 .35857 L
.47747 .35859 L
.47743 .35862 L
.47739 .35864 L
.47735 .35867 L
.47732 .3587 L
.47728 .35872 L
.47724 .35875 L
.4772 .35877 L
.47716 .3588 L
.47713 .35882 L
.47709 .35885 L
.47705 .35887 L
.47701 .3589 L
.47697 .35892 L
.47694 .35895 L
.4769 .35897 L
.47686 .359 L
.47682 .35902 L
.47678 .35905 L
.47675 .35907 L
.47671 .35909 L
.47667 .35912 L
.47663 .35914 L
.47659 .35917 L
.47656 .35919 L
.47652 .35922 L
Mistroke
.47648 .35924 L
.47644 .35927 L
.4764 .35929 L
.47637 .35932 L
.47633 .35934 L
.47629 .35936 L
.47625 .35939 L
.47622 .35941 L
.47618 .35944 L
.47614 .35946 L
.4761 .35948 L
.47606 .35951 L
.47603 .35953 L
.47599 .35956 L
.47595 .35958 L
.47591 .3596 L
.47588 .35963 L
.47584 .35965 L
.4758 .35968 L
.47576 .3597 L
.47572 .35972 L
.47569 .35975 L
.47565 .35977 L
.47561 .35979 L
.47557 .35982 L
.47554 .35984 L
.4755 .35987 L
.47546 .35989 L
.47542 .35991 L
.47539 .35994 L
.47535 .35996 L
.47531 .35998 L
.47527 .36001 L
.47523 .36003 L
.4752 .36005 L
.47516 .36008 L
.47512 .3601 L
.47508 .36012 L
.47505 .36014 L
.47501 .36017 L
.47497 .36019 L
.47493 .36021 L
.4749 .36024 L
.47486 .36026 L
.47482 .36028 L
.47478 .3603 L
.47475 .36033 L
.47471 .36035 L
.47467 .36037 L
.47463 .3604 L
Mistroke
.4746 .36042 L
.47456 .36044 L
.47452 .36046 L
.47448 .36049 L
.47445 .36051 L
.47441 .36053 L
.47437 .36055 L
.47433 .36058 L
.4743 .3606 L
.47426 .36062 L
.47422 .36064 L
.47418 .36067 L
.47415 .36069 L
.47411 .36071 L
.47407 .36073 L
.47404 .36075 L
.474 .36078 L
.47396 .3608 L
.47392 .36082 L
.47389 .36084 L
.47385 .36086 L
.47381 .36089 L
.47377 .36091 L
.47374 .36093 L
.4737 .36095 L
.47366 .36097 L
.47363 .36099 L
.47359 .36102 L
.47355 .36104 L
.47351 .36106 L
.47348 .36108 L
.47344 .3611 L
.4734 .36112 L
.47336 .36114 L
.47333 .36117 L
.47329 .36119 L
.47325 .36121 L
.47322 .36123 L
.47318 .36125 L
.47314 .36127 L
.4731 .36129 L
.47307 .36132 L
.47303 .36134 L
.47299 .36136 L
.47296 .36138 L
.47292 .3614 L
.47288 .36142 L
.47285 .36144 L
.47281 .36146 L
.47277 .36148 L
Mistroke
.47273 .3615 L
.4727 .36152 L
.47266 .36155 L
.47262 .36157 L
.47259 .36159 L
.47255 .36161 L
.47251 .36163 L
.47248 .36165 L
.47244 .36167 L
.4724 .36169 L
.47237 .36171 L
.47233 .36173 L
.47229 .36175 L
.47226 .36177 L
.47222 .36179 L
.47218 .36181 L
.47214 .36183 L
.47211 .36185 L
.47207 .36187 L
.47203 .36189 L
.472 .36191 L
.47196 .36193 L
.47192 .36195 L
.47189 .36197 L
.47185 .36199 L
.47181 .36201 L
.47178 .36203 L
.47174 .36205 L
.4717 .36207 L
.47167 .36209 L
.47163 .36211 L
.47159 .36213 L
.47156 .36215 L
.47152 .36217 L
.47148 .36219 L
.47145 .36221 L
.47141 .36223 L
.47138 .36225 L
.47134 .36227 L
.4713 .36229 L
.47127 .36231 L
.47123 .36233 L
.47119 .36235 L
.47116 .36236 L
.47112 .36238 L
.47108 .3624 L
.47105 .36242 L
.47101 .36244 L
.47097 .36246 L
.47094 .36248 L
Mistroke
.4709 .3625 L
.47087 .36252 L
.47083 .36254 L
.47079 .36256 L
.47076 .36257 L
.47072 .36259 L
.47068 .36261 L
.47065 .36263 L
.47061 .36265 L
.47058 .36267 L
.47054 .36269 L
.4705 .3627 L
.47047 .36272 L
.47043 .36274 L
.47039 .36276 L
.47036 .36278 L
.47032 .3628 L
.47029 .36282 L
.47025 .36283 L
.47021 .36285 L
.47018 .36287 L
.47014 .36289 L
.47011 .36291 L
.47007 .36293 L
.47003 .36294 L
.47 .36296 L
.46996 .36298 L
.46993 .363 L
.46989 .36302 L
.46985 .36303 L
.46982 .36305 L
.46978 .36307 L
.46975 .36309 L
.46971 .36311 L
.46967 .36312 L
.46964 .36314 L
.4696 .36316 L
.46957 .36318 L
.46953 .36319 L
.46949 .36321 L
.46946 .36323 L
.46942 .36325 L
.46939 .36326 L
.46935 .36328 L
.46932 .3633 L
.46928 .36332 L
.46924 .36333 L
.46921 .36335 L
.46917 .36337 L
.46914 .36339 L
Mistroke
.4691 .3634 L
.46907 .36342 L
.46903 .36344 L
.46899 .36345 L
.46896 .36347 L
.46892 .36349 L
.46889 .36351 L
.46885 .36352 L
.46882 .36354 L
.46878 .36356 L
.46875 .36357 L
.46871 .36359 L
.46867 .36361 L
.46864 .36362 L
.4686 .36364 L
.46857 .36366 L
.46853 .36367 L
.4685 .36369 L
.46846 .36371 L
.46843 .36372 L
.46839 .36374 L
.46836 .36376 L
.46832 .36377 L
.46829 .36379 L
.46825 .36381 L
.46821 .36382 L
.46818 .36384 L
.46814 .36385 L
.46811 .36387 L
.46807 .36389 L
.46804 .3639 L
.468 .36392 L
.46797 .36394 L
.46793 .36395 L
.4679 .36397 L
.46786 .36398 L
.46783 .364 L
.46779 .36402 L
.46776 .36403 L
.46772 .36405 L
.46769 .36406 L
.46765 .36408 L
.46762 .36409 L
.46758 .36411 L
.46755 .36413 L
.46751 .36414 L
.46748 .36416 L
.46744 .36417 L
.46741 .36419 L
.46737 .3642 L
Mistroke
.46734 .36422 L
.4673 .36423 L
.46727 .36425 L
.46723 .36427 L
.4672 .36428 L
.46716 .3643 L
.46713 .36431 L
.46709 .36433 L
.46706 .36434 L
.46703 .36436 L
.46699 .36437 L
.46696 .36439 L
.46692 .3644 L
.46689 .36442 L
.46685 .36443 L
.46682 .36445 L
.46678 .36446 L
.46675 .36448 L
.46671 .36449 L
.46668 .36451 L
.46664 .36452 L
.46661 .36454 L
.46658 .36455 L
.46654 .36456 L
.46651 .36458 L
.46647 .36459 L
.46644 .36461 L
.4664 .36462 L
.46637 .36464 L
.46633 .36465 L
.4663 .36467 L
.46627 .36468 L
.46623 .3647 L
.4662 .36471 L
.46616 .36472 L
.46613 .36474 L
.46609 .36475 L
.46606 .36477 L
.46603 .36478 L
.46599 .36479 L
.46596 .36481 L
.46592 .36482 L
.46589 .36484 L
.46585 .36485 L
.46582 .36486 L
.46579 .36488 L
.46575 .36489 L
.46572 .36491 L
.46568 .36492 L
.46565 .36493 L
Mistroke
.46562 .36495 L
.46558 .36496 L
.46555 .36498 L
.46551 .36499 L
.46548 .365 L
.46545 .36502 L
.46541 .36503 L
.46538 .36504 L
.46534 .36506 L
.46531 .36507 L
.46528 .36508 L
.46524 .3651 L
.46521 .36511 L
.46518 .36512 L
.46514 .36514 L
.46511 .36515 L
.46507 .36516 L
.46504 .36518 L
.46501 .36519 L
.46497 .3652 L
.46494 .36522 L
.46491 .36523 L
.46487 .36524 L
.46484 .36525 L
.46481 .36527 L
.46477 .36528 L
.46474 .36529 L
.4647 .36531 L
.46467 .36532 L
.46464 .36533 L
.4646 .36534 L
.46457 .36536 L
.46454 .36537 L
.4645 .36538 L
.46447 .36539 L
.46444 .36541 L
.4644 .36542 L
.46437 .36543 L
.46434 .36544 L
.4643 .36546 L
.46427 .36547 L
.46424 .36548 L
.4642 .36549 L
.46417 .36551 L
.46414 .36552 L
.4641 .36553 L
.46407 .36554 L
.46404 .36555 L
.464 .36557 L
.46397 .36558 L
Mistroke
.46394 .36559 L
.46391 .3656 L
.46387 .36561 L
.46384 .36563 L
.46381 .36564 L
.46377 .36565 L
.46374 .36566 L
.46371 .36567 L
.46367 .36569 L
.46364 .3657 L
.46361 .36571 L
.46358 .36572 L
.46354 .36573 L
.46351 .36574 L
.46348 .36576 L
.46344 .36577 L
.46341 .36578 L
.46338 .36579 L
.46335 .3658 L
.46331 .36581 L
.46328 .36582 L
.46325 .36584 L
.46322 .36585 L
.46318 .36586 L
.46315 .36587 L
.46312 .36588 L
.46309 .36589 L
.46305 .3659 L
.46302 .36591 L
.46299 .36593 L
.46295 .36594 L
.46292 .36595 L
.46289 .36596 L
.46286 .36597 L
.46283 .36598 L
.46279 .36599 L
.46276 .366 L
.46273 .36601 L
.4627 .36602 L
.46266 .36603 L
.46263 .36605 L
.4626 .36606 L
.46257 .36607 L
.46253 .36608 L
.4625 .36609 L
.46247 .3661 L
.46244 .36611 L
.46241 .36612 L
.46237 .36613 L
.46234 .36614 L
Mistroke
.46231 .36615 L
.46228 .36616 L
.46224 .36617 L
.46221 .36618 L
.46218 .36619 L
.46215 .3662 L
.46212 .36621 L
.46208 .36622 L
.46205 .36623 L
.46202 .36624 L
.46199 .36625 L
.46196 .36626 L
.46193 .36627 L
.46189 .36628 L
.46186 .36629 L
.46183 .3663 L
.4618 .36631 L
.46177 .36632 L
.46173 .36633 L
.4617 .36634 L
.46167 .36635 L
.46164 .36636 L
.46161 .36637 L
.46158 .36638 L
.46154 .36639 L
.46151 .3664 L
.46148 .36641 L
.46145 .36642 L
.46142 .36643 L
.46139 .36644 L
.46136 .36645 L
.46132 .36646 L
.46129 .36647 L
.46126 .36647 L
.46123 .36648 L
.4612 .36649 L
.46117 .3665 L
.46114 .36651 L
.4611 .36652 L
.46107 .36653 L
.46104 .36654 L
.46101 .36655 L
.46098 .36656 L
.46095 .36657 L
.46092 .36658 L
.46089 .36658 L
.46085 .36659 L
.46082 .3666 L
.46079 .36661 L
.46076 .36662 L
Mistroke
.46073 .36663 L
.4607 .36664 L
.46067 .36665 L
.46064 .36665 L
.46061 .36666 L
.46057 .36667 L
.46054 .36668 L
.46051 .36669 L
.46048 .3667 L
.46045 .36671 L
.46042 .36671 L
.46039 .36672 L
.46036 .36673 L
.46033 .36674 L
.4603 .36675 L
.46027 .36676 L
.46024 .36676 L
.46021 .36677 L
.46017 .36678 L
.46014 .36679 L
.46011 .3668 L
.46008 .36681 L
.46005 .36681 L
.46002 .36682 L
.45999 .36683 L
.45996 .36684 L
.45993 .36685 L
.4599 .36685 L
.45987 .36686 L
.45984 .36687 L
.45981 .36688 L
.45978 .36688 L
.45975 .36689 L
.45972 .3669 L
.45969 .36691 L
.45966 .36692 L
.45963 .36692 L
.4596 .36693 L
.45957 .36694 L
.45954 .36695 L
.4595 .36695 L
.45947 .36696 L
.45944 .36697 L
.45941 .36698 L
.45938 .36698 L
.45935 .36699 L
.45932 .367 L
.45929 .36701 L
.45926 .36701 L
.45923 .36702 L
Mistroke
.4592 .36703 L
.45917 .36703 L
.45914 .36704 L
.45911 .36705 L
.45908 .36706 L
.45905 .36706 L
.45902 .36707 L
.45899 .36708 L
.45896 .36708 L
.45894 .36709 L
.45891 .3671 L
.45888 .3671 L
.45885 .36711 L
.45882 .36712 L
.45879 .36713 L
.45876 .36713 L
.45873 .36714 L
.4587 .36715 L
.45867 .36715 L
.45864 .36716 L
.45861 .36717 L
.45858 .36717 L
.45855 .36718 L
.45852 .36718 L
.45849 .36719 L
.45846 .3672 L
.45843 .3672 L
.4584 .36721 L
.45837 .36722 L
.45834 .36722 L
.45831 .36723 L
.45829 .36724 L
.45826 .36724 L
.45823 .36725 L
.4582 .36725 L
.45817 .36726 L
.45814 .36727 L
.45811 .36727 L
.45808 .36728 L
.45805 .36729 L
.45802 .36729 L
.45799 .3673 L
.45796 .3673 L
.45794 .36731 L
.45791 .36731 L
.45788 .36732 L
.45785 .36733 L
.45782 .36733 L
.45779 .36734 L
.45776 .36734 L
Mistroke
.45773 .36735 L
.4577 .36736 L
.45768 .36736 L
.45765 .36737 L
.45762 .36737 L
.45759 .36738 L
.45756 .36738 L
.45753 .36739 L
.4575 .36739 L
.45747 .3674 L
.45745 .36741 L
.45742 .36741 L
.45739 .36742 L
.45736 .36742 L
.45733 .36743 L
.4573 .36743 L
.45727 .36744 L
.45725 .36744 L
.45722 .36745 L
.45719 .36745 L
.45716 .36746 L
.45713 .36746 L
.4571 .36747 L
.45708 .36747 L
.45705 .36748 L
.45702 .36748 L
.45699 .36749 L
.45696 .36749 L
.45693 .3675 L
.45691 .3675 L
.45688 .36751 L
.45685 .36751 L
.45682 .36752 L
.45679 .36752 L
.45677 .36753 L
.45674 .36753 L
.45671 .36754 L
.45668 .36754 L
.45665 .36754 L
.45663 .36755 L
.4566 .36755 L
.45657 .36756 L
.45654 .36756 L
.45651 .36757 L
.45649 .36757 L
.45646 .36758 L
.45643 .36758 L
.4564 .36759 L
.45638 .36759 L
.45635 .36759 L
Mistroke
.45632 .3676 L
.45629 .3676 L
.45626 .36761 L
.45624 .36761 L
.45621 .36761 L
.45618 .36762 L
.45615 .36762 L
.45613 .36763 L
.4561 .36763 L
.45607 .36764 L
.45604 .36764 L
.45602 .36764 L
.45599 .36765 L
.45596 .36765 L
.45593 .36765 L
.45591 .36766 L
.45588 .36766 L
.45585 .36767 L
.45583 .36767 L
.4558 .36767 L
.45577 .36768 L
.45574 .36768 L
.45572 .36768 L
.45569 .36769 L
.45566 .36769 L
.45564 .3677 L
.45561 .3677 L
.45558 .3677 L
.45555 .36771 L
.45553 .36771 L
.4555 .36771 L
.45547 .36772 L
.45545 .36772 L
.45542 .36772 L
.45539 .36773 L
.45537 .36773 L
.45534 .36773 L
.45531 .36774 L
.45529 .36774 L
.45526 .36774 L
.45523 .36775 L
.4552 .36775 L
.45518 .36775 L
.45515 .36775 L
.45512 .36776 L
.4551 .36776 L
.45507 .36776 L
.45504 .36777 L
.45502 .36777 L
.45499 .36777 L
Mistroke
.45497 .36778 L
.45494 .36778 L
.45491 .36778 L
.45489 .36778 L
.45486 .36779 L
.45483 .36779 L
.45481 .36779 L
.45478 .36779 L
.45475 .3678 L
.45473 .3678 L
.4547 .3678 L
.45468 .36781 L
.45465 .36781 L
.45462 .36781 L
.4546 .36781 L
.45457 .36782 L
.45454 .36782 L
.45452 .36782 L
.45449 .36782 L
.45447 .36782 L
.45444 .36783 L
.45441 .36783 L
.45439 .36783 L
.45436 .36783 L
.45434 .36784 L
.45431 .36784 L
.45428 .36784 L
.45426 .36784 L
.45423 .36784 L
.45421 .36785 L
.45418 .36785 L
.45416 .36785 L
.45413 .36785 L
.4541 .36785 L
.45408 .36786 L
.45405 .36786 L
.45403 .36786 L
.454 .36786 L
.45398 .36786 L
.45395 .36787 L
.45392 .36787 L
.4539 .36787 L
.45387 .36787 L
.45385 .36787 L
.45382 .36788 L
.4538 .36788 L
.45377 .36788 L
.45375 .36788 L
.45372 .36788 L
.4537 .36788 L
Mistroke
.45367 .36788 L
.45365 .36789 L
.45362 .36789 L
.45359 .36789 L
.45357 .36789 L
.45354 .36789 L
.45352 .36789 L
.45349 .36789 L
.45347 .3679 L
.45344 .3679 L
.45342 .3679 L
.45339 .3679 L
.45337 .3679 L
.45334 .3679 L
.45332 .3679 L
.45329 .3679 L
.45327 .36791 L
.45324 .36791 L
.45322 .36791 L
.45319 .36791 L
.45317 .36791 L
.45315 .36791 L
.45312 .36791 L
.4531 .36791 L
.45307 .36791 L
.45305 .36791 L
.45302 .36792 L
.453 .36792 L
.45297 .36792 L
.45295 .36792 L
.45292 .36792 L
.4529 .36792 L
.45287 .36792 L
.45285 .36792 L
.45283 .36792 L
.4528 .36792 L
.45278 .36792 L
.45275 .36792 L
.45273 .36792 L
.4527 .36792 L
.45268 .36793 L
.45265 .36793 L
.45263 .36793 L
.45261 .36793 L
.45258 .36793 L
.45256 .36793 L
.45253 .36793 L
.45251 .36793 L
.45249 .36793 L
.45246 .36793 L
Mistroke
.45244 .36793 L
.45241 .36793 L
.45239 .36793 L
.45236 .36793 L
.45234 .36793 L
.45232 .36793 L
.45229 .36793 L
.45227 .36793 L
.45225 .36793 L
.45222 .36793 L
.4522 .36793 L
.45217 .36793 L
.45215 .36793 L
.45213 .36793 L
.4521 .36793 L
.45208 .36793 L
.45206 .36793 L
.45203 .36793 L
.45201 .36793 L
.45198 .36793 L
.45196 .36793 L
.45194 .36793 L
.45191 .36793 L
.45189 .36793 L
.45187 .36793 L
.45184 .36793 L
.45182 .36793 L
.4518 .36793 L
.45177 .36793 L
.45175 .36793 L
.45173 .36793 L
.4517 .36793 L
.45168 .36792 L
.45166 .36792 L
.45163 .36792 L
.45161 .36792 L
.45159 .36792 L
.45156 .36792 L
.45154 .36792 L
.45152 .36792 L
.45149 .36792 L
.45147 .36792 L
.45145 .36792 L
.45143 .36792 L
.4514 .36792 L
.45138 .36792 L
.45136 .36791 L
.45133 .36791 L
.45131 .36791 L
.45129 .36791 L
Mistroke
.45126 .36791 L
.45124 .36791 L
.45122 .36791 L
.4512 .36791 L
.45117 .36791 L
.45115 .36791 L
.45113 .36791 L
.45111 .3679 L
.45108 .3679 L
.45106 .3679 L
.45104 .3679 L
.45102 .3679 L
.45099 .3679 L
.45097 .3679 L
.45095 .3679 L
.45093 .36789 L
.4509 .36789 L
.45088 .36789 L
.45086 .36789 L
.45084 .36789 L
.45081 .36789 L
.45079 .36789 L
.45077 .36788 L
.45075 .36788 L
.45072 .36788 L
.4507 .36788 L
.45068 .36788 L
.45066 .36788 L
.45064 .36788 L
.45061 .36787 L
.45059 .36787 L
.45057 .36787 L
.45055 .36787 L
.45053 .36787 L
.4505 .36787 L
.45048 .36786 L
.45046 .36786 L
.45044 .36786 L
.45042 .36786 L
.45039 .36786 L
.45037 .36785 L
.45035 .36785 L
.45033 .36785 L
.45031 .36785 L
.45028 .36785 L
.45026 .36785 L
.45024 .36784 L
.45022 .36784 L
.4502 .36784 L
.45018 .36784 L
Mistroke
.45015 .36783 L
.45013 .36783 L
.45011 .36783 L
.45009 .36783 L
.45007 .36783 L
.45005 .36782 L
.45003 .36782 L
.45 .36782 L
.44998 .36782 L
.44996 .36782 L
.44994 .36781 L
.44992 .36781 L
.4499 .36781 L
.44988 .36781 L
.44986 .3678 L
.44983 .3678 L
.44981 .3678 L
.44979 .3678 L
.44977 .36779 L
.44975 .36779 L
.44973 .36779 L
.44971 .36779 L
.44969 .36778 L
.44967 .36778 L
.44964 .36778 L
.44962 .36778 L
.4496 .36777 L
.44958 .36777 L
.44956 .36777 L
.44954 .36776 L
.44952 .36776 L
.4495 .36776 L
.44948 .36776 L
.44946 .36775 L
.44944 .36775 L
.44941 .36775 L
.44939 .36775 L
.44937 .36774 L
.44935 .36774 L
.44933 .36774 L
.44931 .36773 L
.44929 .36773 L
.44927 .36773 L
.44925 .36772 L
.44923 .36772 L
.44921 .36772 L
.44919 .36772 L
.44917 .36771 L
.44915 .36771 L
.44913 .36771 L
Mistroke
.44911 .3677 L
.44909 .3677 L
.44907 .3677 L
.44905 .36769 L
.44903 .36769 L
.44901 .36769 L
.44899 .36768 L
.44897 .36768 L
.44895 .36768 L
.44893 .36767 L
.4489 .36767 L
.44888 .36767 L
.44886 .36766 L
.44884 .36766 L
.44882 .36766 L
.4488 .36765 L
.44878 .36765 L
.44877 .36765 L
.44875 .36764 L
.44873 .36764 L
.44871 .36764 L
.44869 .36763 L
.44867 .36763 L
.44865 .36762 L
.44863 .36762 L
.44861 .36762 L
.44859 .36761 L
.44857 .36761 L
.44855 .36761 L
.44853 .3676 L
.44851 .3676 L
.44849 .36759 L
.44847 .36759 L
.44845 .36759 L
.44843 .36758 L
.44841 .36758 L
.44839 .36758 L
.44837 .36757 L
.44835 .36757 L
.44833 .36756 L
.44831 .36756 L
.44829 .36756 L
.44828 .36755 L
.44826 .36755 L
.44824 .36754 L
.44822 .36754 L
.4482 .36754 L
.44818 .36753 L
.44816 .36753 L
.44814 .36752 L
Mistroke
.44812 .36752 L
.4481 .36751 L
.44808 .36751 L
.44806 .36751 L
.44805 .3675 L
.44803 .3675 L
.44801 .36749 L
.44799 .36749 L
.44797 .36748 L
.44795 .36748 L
.44793 .36748 L
.44791 .36747 L
.44789 .36747 L
.44788 .36746 L
.44786 .36746 L
.44784 .36745 L
.44782 .36745 L
.4478 .36745 L
.44778 .36744 L
.44776 .36744 L
.44774 .36743 L
.44773 .36743 L
.44771 .36742 L
.44769 .36742 L
.44767 .36741 L
.44765 .36741 L
.44763 .3674 L
.44762 .3674 L
.4476 .36739 L
.44758 .36739 L
.44756 .36738 L
.44754 .36738 L
.44752 .36738 L
.44751 .36737 L
.44749 .36737 L
.44747 .36736 L
.44745 .36736 L
.44743 .36735 L
.44741 .36735 L
.4474 .36734 L
.44738 .36734 L
.44736 .36733 L
.44734 .36733 L
.44732 .36732 L
.44731 .36732 L
.44729 .36731 L
.44727 .36731 L
.44725 .3673 L
.44723 .3673 L
.44722 .36729 L
Mistroke
.4472 .36729 L
.44718 .36728 L
.44716 .36728 L
.44714 .36727 L
.44713 .36727 L
.44711 .36726 L
.44709 .36725 L
.44707 .36725 L
.44706 .36724 L
.44704 .36724 L
.44702 .36723 L
.447 .36723 L
.44699 .36722 L
.44697 .36722 L
.44695 .36721 L
.44693 .36721 L
.44692 .3672 L
.4469 .3672 L
.44688 .36719 L
.44686 .36719 L
.44685 .36718 L
.44683 .36717 L
.44681 .36717 L
.44679 .36716 L
.44678 .36716 L
.44676 .36715 L
.44674 .36715 L
.44673 .36714 L
.44671 .36714 L
.44669 .36713 L
.44667 .36712 L
.44666 .36712 L
.44664 .36711 L
.44662 .36711 L
.44661 .3671 L
.44659 .3671 L
.44657 .36709 L
.44655 .36708 L
.44654 .36708 L
.44652 .36707 L
.4465 .36707 L
.44649 .36706 L
.44647 .36705 L
.44645 .36705 L
.44644 .36704 L
.44642 .36704 L
.4464 .36703 L
.44639 .36703 L
.44637 .36702 L
.44635 .36701 L
Mistroke
.44634 .36701 L
.44632 .367 L
.4463 .367 L
.44629 .36699 L
.44627 .36698 L
.44625 .36698 L
.44624 .36697 L
.44622 .36696 L
.4462 .36696 L
.44619 .36695 L
.44617 .36695 L
.44616 .36694 L
.44614 .36693 L
.44612 .36693 L
.44611 .36692 L
.44609 .36692 L
.44607 .36691 L
.44606 .3669 L
.44604 .3669 L
.44603 .36689 L
.44601 .36688 L
.44599 .36688 L
.44598 .36687 L
.44596 .36686 L
.44594 .36686 L
.44593 .36685 L
.44591 .36685 L
.4459 .36684 L
.44588 .36683 L
.44586 .36683 L
.44585 .36682 L
.44583 .36681 L
.44582 .36681 L
.4458 .3668 L
.44579 .36679 L
.44577 .36679 L
.44575 .36678 L
.44574 .36677 L
.44572 .36677 L
.44571 .36676 L
.44569 .36675 L
.44568 .36675 L
.44566 .36674 L
.44564 .36673 L
.44563 .36673 L
.44561 .36672 L
.4456 .36671 L
.44558 .36671 L
.44557 .3667 L
.44555 .36669 L
Mistroke
.44554 .36669 L
.44552 .36668 L
.44551 .36667 L
.44549 .36667 L
.44547 .36666 L
.44546 .36665 L
.44544 .36664 L
.44543 .36664 L
.44541 .36663 L
.4454 .36662 L
.44538 .36662 L
.44537 .36661 L
.44535 .3666 L
.44534 .3666 L
.44532 .36659 L
.44531 .36658 L
.44529 .36657 L
.44528 .36657 L
.44526 .36656 L
.44525 .36655 L
.44523 .36655 L
.44522 .36654 L
.4452 .36653 L
.44519 .36652 L
.44517 .36652 L
.44516 .36651 L
.44514 .3665 L
.44513 .3665 L
.44511 .36649 L
.4451 .36648 L
.44508 .36647 L
.44507 .36647 L
.44506 .36646 L
.44504 .36645 L
.44503 .36644 L
.44501 .36644 L
.445 .36643 L
.44498 .36642 L
.44497 .36642 L
.44495 .36641 L
.44494 .3664 L
.44492 .36639 L
.44491 .36639 L
.4449 .36638 L
.44488 .36637 L
.44487 .36636 L
.44485 .36636 L
.44484 .36635 L
.44482 .36634 L
.44481 .36633 L
Mistroke
.4448 .36633 L
.44478 .36632 L
.44477 .36631 L
.44475 .3663 L
.44474 .3663 L
.44473 .36629 L
.44471 .36628 L
.4447 .36627 L
.44468 .36626 L
.44467 .36626 L
.44465 .36625 L
.44464 .36624 L
.44463 .36623 L
.44461 .36623 L
.4446 .36622 L
.44459 .36621 L
.44457 .3662 L
.44456 .36619 L
.44454 .36619 L
.44453 .36618 L
.44452 .36617 L
.4445 .36616 L
.44449 .36616 L
.44448 .36615 L
.44446 .36614 L
.44445 .36613 L
.44443 .36612 L
.44442 .36612 L
.44441 .36611 L
.44439 .3661 L
.44438 .36609 L
.44437 .36608 L
.44435 .36608 L
.44434 .36607 L
.44433 .36606 L
.44431 .36605 L
.4443 .36604 L
.44429 .36604 L
.44427 .36603 L
.44426 .36602 L
.44425 .36601 L
.44423 .366 L
.44422 .36599 L
.44421 .36599 L
.44419 .36598 L
.44418 .36597 L
.44417 .36596 L
.44415 .36595 L
.44414 .36595 L
.44413 .36594 L
Mistroke
.44411 .36593 L
.4441 .36592 L
.44409 .36591 L
.44408 .3659 L
.44406 .3659 L
.44405 .36589 L
.44404 .36588 L
.44402 .36587 L
.44401 .36586 L
.444 .36585 L
.44399 .36585 L
.44397 .36584 L
.44396 .36583 L
.44395 .36582 L
.44393 .36581 L
.44392 .3658 L
.44391 .3658 L
.4439 .36579 L
.44388 .36578 L
.44387 .36577 L
.44386 .36576 L
.44385 .36575 L
.44383 .36574 L
.44382 .36574 L
.44381 .36573 L
.4438 .36572 L
.44378 .36571 L
.44377 .3657 L
.44376 .36569 L
.44375 .36568 L
.44373 .36568 L
.44372 .36567 L
.44371 .36566 L
.4437 .36565 L
.44369 .36564 L
.44367 .36563 L
.44366 .36562 L
.44365 .36561 L
.44364 .36561 L
.44362 .3656 L
.44361 .36559 L
.4436 .36558 L
.44359 .36557 L
.44358 .36556 L
.44356 .36555 L
.44355 .36554 L
.44354 .36554 L
.44353 .36553 L
.44352 .36552 L
.4435 .36551 L
Mistroke
.44349 .3655 L
.44348 .36549 L
.44347 .36548 L
.44346 .36547 L
.44345 .36546 L
.44343 .36546 L
.44342 .36545 L
.44341 .36544 L
.4434 .36543 L
.44339 .36542 L
.44337 .36541 L
.44336 .3654 L
.44335 .36539 L
.44334 .36538 L
.44333 .36537 L
.44332 .36536 L
.44331 .36536 L
.44329 .36535 L
.44328 .36534 L
.44327 .36533 L
.44326 .36532 L
.44325 .36531 L
.44324 .3653 L
.44323 .36529 L
.44321 .36528 L
.4432 .36527 L
.44319 .36526 L
.44318 .36526 L
.44317 .36525 L
.44316 .36524 L
.44315 .36523 L
.44314 .36522 L
.44312 .36521 L
.44311 .3652 L
.4431 .36519 L
.44309 .36518 L
.44308 .36517 L
.44307 .36516 L
.44306 .36515 L
.44305 .36514 L
.44304 .36513 L
.44302 .36513 L
.44301 .36512 L
.443 .36511 L
.44299 .3651 L
.44298 .36509 L
.44297 .36508 L
.44296 .36507 L
.44295 .36506 L
.44294 .36505 L
Mistroke
.44293 .36504 L
.44292 .36503 L
.44291 .36502 L
.44289 .36501 L
.44288 .365 L
.44287 .36499 L
.44286 .36498 L
.44285 .36497 L
.44284 .36496 L
.44283 .36495 L
.44282 .36495 L
.44281 .36494 L
.4428 .36493 L
.44279 .36492 L
.44278 .36491 L
.44277 .3649 L
.44276 .36489 L
.44275 .36488 L
.44274 .36487 L
.44273 .36486 L
.44272 .36485 L
.44271 .36484 L
.4427 .36483 L
.44269 .36482 L
.44268 .36481 L
.44267 .3648 L
.44266 .36479 L
.44265 .36478 L
.44263 .36477 L
.44262 .36476 L
.44261 .36475 L
.4426 .36474 L
.44259 .36473 L
.44258 .36472 L
.44257 .36471 L
.44256 .3647 L
.44255 .36469 L
.44254 .36468 L
.44253 .36467 L
.44252 .36466 L
.44252 .36465 L
.44251 .36464 L
.4425 .36463 L
.44249 .36462 L
.44248 .36461 L
.44247 .3646 L
.44246 .36459 L
.44245 .36458 L
.44244 .36457 L
.44243 .36456 L
Mistroke
.44242 .36455 L
.44241 .36454 L
.4424 .36453 L
.44239 .36452 L
.44238 .36451 L
.44237 .3645 L
.44236 .36449 L
.44235 .36448 L
.44234 .36447 L
.44233 .36446 L
.44232 .36445 L
.44231 .36444 L
.4423 .36443 L
.44229 .36442 L
.44228 .36441 L
.44228 .3644 L
.44227 .36439 L
.44226 .36438 L
.44225 .36437 L
.44224 .36436 L
.44223 .36435 L
.44222 .36434 L
.44221 .36433 L
.4422 .36432 L
.44219 .36431 L
.44218 .3643 L
.44217 .36429 L
.44217 .36428 L
.44216 .36427 L
.44215 .36426 L
.44214 .36425 L
.44213 .36424 L
.44212 .36423 L
.44211 .36422 L
.4421 .36421 L
.44209 .3642 L
.44208 .36419 L
.44208 .36418 L
.44207 .36417 L
.44206 .36416 L
.44205 .36415 L
.44204 .36414 L
.44203 .36413 L
.44202 .36412 L
.44201 .36411 L
.44201 .3641 L
.442 .36409 L
.44199 .36408 L
.44198 .36406 L
.44197 .36405 L
Mistroke
.44196 .36404 L
.44195 .36403 L
.44195 .36402 L
.44194 .36401 L
.44193 .364 L
.44192 .36399 L
.44191 .36398 L
.4419 .36397 L
.44189 .36396 L
.44189 .36395 L
.44188 .36394 L
.44187 .36393 L
.44186 .36392 L
.44185 .36391 L
.44184 .3639 L
.44184 .36389 L
.44183 .36388 L
.44182 .36387 L
.44181 .36386 L
.4418 .36384 L
.4418 .36383 L
.44179 .36382 L
.44178 .36381 L
.44177 .3638 L
.44176 .36379 L
.44176 .36378 L
.44175 .36377 L
.44174 .36376 L
.44173 .36375 L
.44172 .36374 L
.44172 .36373 L
.44171 .36372 L
.4417 .36371 L
.44169 .3637 L
.44168 .36368 L
.44168 .36367 L
.44167 .36366 L
.44166 .36365 L
.44165 .36364 L
.44164 .36363 L
.44164 .36362 L
.44163 .36361 L
.44162 .3636 L
.44161 .36359 L
.44161 .36358 L
.4416 .36357 L
.44159 .36356 L
.44158 .36355 L
.44158 .36353 L
.44157 .36352 L
Mistroke
.44156 .36351 L
.44155 .3635 L
.44155 .36349 L
.44154 .36348 L
.44153 .36347 L
.44152 .36346 L
.44152 .36345 L
.44151 .36344 L
.4415 .36343 L
.44149 .36342 L
.44149 .3634 L
.44148 .36339 L
.44147 .36338 L
.44146 .36337 L
.44146 .36336 L
.44145 .36335 L
.44144 .36334 L
.44144 .36333 L
.44143 .36332 L
.44142 .36331 L
.44141 .36329 L
.44141 .36328 L
.4414 .36327 L
.44139 .36326 L
.44139 .36325 L
.44138 .36324 L
.44137 .36323 L
.44137 .36322 L
.44136 .36321 L
.44135 .3632 L
.44134 .36318 L
.44134 .36317 L
.44133 .36316 L
.44132 .36315 L
.44132 .36314 L
.44131 .36313 L
.4413 .36312 L
.4413 .36311 L
.44129 .3631 L
.44128 .36309 L
.44128 .36307 L
.44127 .36306 L
.44126 .36305 L
.44126 .36304 L
.44125 .36303 L
.44124 .36302 L
.44124 .36301 L
.44123 .363 L
.44122 .36299 L
.44122 .36297 L
Mistroke
.44121 .36296 L
.4412 .36295 L
.4412 .36294 L
.44119 .36293 L
.44118 .36292 L
.44118 .36291 L
.44117 .3629 L
.44117 .36288 L
.44116 .36287 L
.44115 .36286 L
.44115 .36285 L
.44114 .36284 L
.44113 .36283 L
.44113 .36282 L
.44112 .36281 L
.44111 .36279 L
.44111 .36278 L
.4411 .36277 L
.4411 .36276 L
.44109 .36275 L
.44108 .36274 L
.44108 .36273 L
.44107 .36272 L
.44107 .3627 L
.44106 .36269 L
.44105 .36268 L
.44105 .36267 L
.44104 .36266 L
.44104 .36265 L
.44103 .36264 L
.44102 .36263 L
.44102 .36261 L
.44101 .3626 L
.44101 .36259 L
.441 .36258 L
.44099 .36257 L
.44099 .36256 L
.44098 .36255 L
.44098 .36253 L
.44097 .36252 L
.44097 .36251 L
.44096 .3625 L
.44095 .36249 L
.44095 .36248 L
.44094 .36247 L
.44094 .36245 L
.44093 .36244 L
.44093 .36243 L
.44092 .36242 L
.44091 .36241 L
Mistroke
.44091 .3624 L
.4409 .36239 L
.4409 .36237 L
.44089 .36236 L
.44089 .36235 L
.44088 .36234 L
.44088 .36233 L
.44087 .36232 L
.44087 .36231 L
.44086 .36229 L
.44086 .36228 L
.44085 .36227 L
.44084 .36226 L
.44084 .36225 L
.44083 .36224 L
.44083 .36223 L
.44082 .36221 L
.44082 .3622 L
.44081 .36219 L
.44081 .36218 L
.4408 .36217 L
.4408 .36216 L
.44079 .36214 L
.44079 .36213 L
.44078 .36212 L
.44078 .36211 L
.44077 .3621 L
.44077 .36209 L
.44076 .36208 L
.44076 .36206 L
.44075 .36205 L
.44075 .36204 L
.44074 .36203 L
.44074 .36202 L
.44073 .36201 L
.44073 .36199 L
.44072 .36198 L
.44072 .36197 L
.44071 .36196 L
.44071 .36195 L
.4407 .36194 L
.4407 .36192 L
.44069 .36191 L
.44069 .3619 L
.44068 .36189 L
.44068 .36188 L
.44068 .36187 L
.44067 .36185 L
.44067 .36184 L
.44066 .36183 L
Mistroke
.44066 .36182 L
.44065 .36181 L
.44065 .3618 L
.44064 .36178 L
.44064 .36177 L
.44063 .36176 L
.44063 .36175 L
.44063 .36174 L
.44062 .36173 L
.44062 .36171 L
.44061 .3617 L
.44061 .36169 L
.4406 .36168 L
.4406 .36167 L
.44059 .36165 L
.44059 .36164 L
.44059 .36163 L
.44058 .36162 L
.44058 .36161 L
.44057 .3616 L
.44057 .36158 L
.44056 .36157 L
.44056 .36156 L
.44056 .36155 L
.44055 .36154 L
.44055 .36153 L
.44054 .36151 L
.44054 .3615 L
.44054 .36149 L
.44053 .36148 L
.44053 .36147 L
.44052 .36145 L
.44052 .36144 L
.44052 .36143 L
.44051 .36142 L
.44051 .36141 L
.4405 .3614 L
.4405 .36138 L
.4405 .36137 L
.44049 .36136 L
.44049 .36135 L
.44048 .36134 L
.44048 .36132 L
.44048 .36131 L
.44047 .3613 L
.44047 .36129 L
.44047 .36128 L
.44046 .36127 L
.44046 .36125 L
.44045 .36124 L
Mistroke
.44045 .36123 L
.44045 .36122 L
.44044 .36121 L
.44044 .36119 L
.44044 .36118 L
.44043 .36117 L
.44043 .36116 L
.44043 .36115 L
.44042 .36113 L
.44042 .36112 L
.44041 .36111 L
.44041 .3611 L
.44041 .36109 L
.4404 .36107 L
.4404 .36106 L
.4404 .36105 L
.44039 .36104 L
.44039 .36103 L
.44039 .36102 L
.44038 .361 L
.44038 .36099 L
.44038 .36098 L
.44037 .36097 L
.44037 .36096 L
.44037 .36094 L
.44036 .36093 L
.44036 .36092 L
.44036 .36091 L
.44035 .3609 L
.44035 .36088 L
.44035 .36087 L
.44035 .36086 L
.44034 .36085 L
.44034 .36084 L
.44034 .36082 L
.44033 .36081 L
.44033 .3608 L
.44033 .36079 L
.44032 .36078 L
.44032 .36076 L
.44032 .36075 L
.44031 .36074 L
.44031 .36073 L
.44031 .36072 L
.44031 .3607 L
.4403 .36069 L
.4403 .36068 L
.4403 .36067 L
.44029 .36066 L
.44029 .36064 L
Mistroke
.44029 .36063 L
.44029 .36062 L
.44028 .36061 L
.44028 .3606 L
.44028 .36058 L
.44028 .36057 L
.44027 .36056 L
.44027 .36055 L
.44027 .36054 L
.44026 .36052 L
.44026 .36051 L
.44026 .3605 L
.44026 .36049 L
.44025 .36048 L
.44025 .36046 L
.44025 .36045 L
.44025 .36044 L
.44024 .36043 L
.44024 .36042 L
.44024 .3604 L
.44024 .36039 L
.44023 .36038 L
.44023 .36037 L
.44023 .36035 L
.44023 .36034 L
.44022 .36033 L
.44022 .36032 L
.44022 .36031 L
.44022 .36029 L
.44022 .36028 L
.44021 .36027 L
.44021 .36026 L
.44021 .36025 L
.44021 .36023 L
.4402 .36022 L
.4402 .36021 L
.4402 .3602 L
.4402 .36019 L
.44019 .36017 L
.44019 .36016 L
.44019 .36015 L
.44019 .36014 L
.44019 .36012 L
.44018 .36011 L
.44018 .3601 L
.44018 .36009 L
.44018 .36008 L
.44018 .36006 L
.44017 .36005 L
.44017 .36004 L
Mistroke
.44017 .36003 L
.44017 .36002 L
.44017 .36 L
.44016 .35999 L
.44016 .35998 L
.44016 .35997 L
.44016 .35996 L
.44016 .35994 L
.44016 .35993 L
.44015 .35992 L
.44015 .35991 L
.44015 .35989 L
.44015 .35988 L
.44015 .35987 L
.44014 .35986 L
.44014 .35985 L
.44014 .35983 L
.44014 .35982 L
.44014 .35981 L
.44014 .3598 L
.44013 .35979 L
.44013 .35977 L
.44013 .35976 L
.44013 .35975 L
.44013 .35974 L
.44013 .35972 L
.44012 .35971 L
.44012 .3597 L
.44012 .35969 L
.44012 .35968 L
.44012 .35966 L
.44012 .35965 L
.44012 .35964 L
.44011 .35963 L
.44011 .35961 L
.44011 .3596 L
.44011 .35959 L
.44011 .35958 L
.44011 .35957 L
.44011 .35955 L
.4401 .35954 L
.4401 .35953 L
.4401 .35952 L
.4401 .35951 L
.4401 .35949 L
.4401 .35948 L
.4401 .35947 L
.4401 .35946 L
.44009 .35944 L
.44009 .35943 L
Mistroke
.44009 .35942 L
.44009 .35941 L
.44009 .3594 L
.44009 .35938 L
.44009 .35937 L
.44009 .35936 L
.44009 .35935 L
.44008 .35933 L
.44008 .35932 L
.44008 .35931 L
.44008 .3593 L
.44008 .35929 L
.44008 .35927 L
.44008 .35926 L
.44008 .35925 L
.44008 .35924 L
.44008 .35922 L
.44007 .35921 L
.44007 .3592 L
.44007 .35919 L
.44007 .35918 L
.44007 .35916 L
.44007 .35915 L
.44007 .35914 L
.44007 .35913 L
.44007 .35912 L
.44007 .3591 L
.44007 .35909 L
.44007 .35908 L
.44007 .35907 L
.44006 .35905 L
.44006 .35904 L
.44006 .35903 L
.44006 .35902 L
.44006 .35901 L
.44006 .35899 L
.44006 .35898 L
.44006 .35897 L
.44006 .35896 L
.44006 .35894 L
.44006 .35893 L
.44006 .35892 L
.44006 .35891 L
.44006 .3589 L
.44006 .35888 L
.44006 .35887 L
.44006 .35886 L
.44005 .35885 L
.44005 .35883 L
.44005 .35882 L
Mistroke
.44005 .35881 L
.44005 .3588 L
.44005 .35879 L
.44005 .35877 L
.44005 .35876 L
.44005 .35875 L
.44005 .35874 L
.44005 .35872 L
.44005 .35871 L
.44005 .3587 L
.44005 .35869 L
.44005 .35868 L
.44005 .35866 L
.44005 .35865 L
.44005 .35864 L
.44005 .35863 L
.44005 .35861 L
.44005 .3586 L
.44005 .35859 L
.44005 .35858 L
.44005 .35857 L
.44005 .35855 L
.44005 .35854 L
.44005 .35853 L
.44005 .35852 L
.44005 .3585 L
.44005 .35849 L
.44005 .35848 L
.44005 .35847 L
.44005 .35846 L
.44005 .35844 L
.44005 .35843 L
.44005 .35842 L
.44005 .35841 L
.44005 .3584 L
.44005 .35838 L
.44005 .35837 L
.44005 .35836 L
.44005 .35835 L
.44005 .35833 L
.44005 .35832 L
.44005 .35831 L
.44005 .3583 L
.44005 .35829 L
.44005 .35827 L
.44005 .35826 L
.44005 .35825 L
.44005 .35824 L
.44005 .35822 L
.44005 .35821 L
Mistroke
.44005 .3582 L
.44005 .35819 L
.44005 .35818 L
.44005 .35816 L
.44005 .35815 L
.44005 .35814 L
.44005 .35813 L
.44005 .35811 L
.44005 .3581 L
.44006 .35809 L
.44006 .35808 L
.44006 .35807 L
.44006 .35805 L
.44006 .35804 L
.44006 .35803 L
.44006 .35802 L
.44006 .35801 L
.44006 .35799 L
.44006 .35798 L
.44006 .35797 L
.44006 .35796 L
.44006 .35794 L
.44006 .35793 L
.44006 .35792 L
.44006 .35791 L
.44006 .3579 L
.44006 .35788 L
.44007 .35787 L
.44007 .35786 L
.44007 .35785 L
.44007 .35783 L
.44007 .35782 L
.44007 .35781 L
.44007 .3578 L
.44007 .35779 L
.44007 .35777 L
.44007 .35776 L
.44007 .35775 L
.44007 .35774 L
.44007 .35773 L
.44008 .35771 L
.44008 .3577 L
.44008 .35769 L
.44008 .35768 L
.44008 .35766 L
.44008 .35765 L
.44008 .35764 L
.44008 .35763 L
.44008 .35762 L
.44008 .3576 L
Mistroke
.44009 .35759 L
.44009 .35758 L
.44009 .35757 L
.44009 .35756 L
.44009 .35754 L
.44009 .35753 L
.44009 .35752 L
.44009 .35751 L
.44009 .35749 L
.44009 .35748 L
.4401 .35747 L
.4401 .35746 L
.4401 .35745 L
.4401 .35743 L
.4401 .35742 L
.4401 .35741 L
.4401 .3574 L
.4401 .35739 L
.44011 .35737 L
.44011 .35736 L
.44011 .35735 L
.44011 .35734 L
.44011 .35733 L
.44011 .35731 L
.44011 .3573 L
.44011 .35729 L
.44012 .35728 L
.44012 .35726 L
.44012 .35725 L
.44012 .35724 L
.44012 .35723 L
.44012 .35722 L
.44012 .3572 L
.44013 .35719 L
.44013 .35718 L
.44013 .35717 L
.44013 .35716 L
.44013 .35714 L
.44013 .35713 L
.44013 .35712 L
.44014 .35711 L
.44014 .3571 L
.44014 .35708 L
.44014 .35707 L
.44014 .35706 L
.44014 .35705 L
.44015 .35704 L
.44015 .35702 L
.44015 .35701 L
.44015 .357 L
Mistroke
.44015 .35699 L
.44015 .35698 L
.44016 .35696 L
.44016 .35695 L
.44016 .35694 L
.44016 .35693 L
.44016 .35691 L
.44016 .3569 L
.44017 .35689 L
.44017 .35688 L
.44017 .35687 L
.44017 .35685 L
.44017 .35684 L
.44017 .35683 L
.44018 .35682 L
.44018 .35681 L
.44018 .35679 L
.44018 .35678 L
.44018 .35677 L
.44019 .35676 L
.44019 .35675 L
.44019 .35673 L
.44019 .35672 L
.44019 .35671 L
.4402 .3567 L
.4402 .35669 L
.4402 .35667 L
.4402 .35666 L
.4402 .35665 L
.44021 .35664 L
.44021 .35663 L
.44021 .35661 L
.44021 .3566 L
.44021 .35659 L
.44022 .35658 L
.44022 .35657 L
.44022 .35655 L
.44022 .35654 L
.44022 .35653 L
.44023 .35652 L
.44023 .35651 L
.44023 .35649 L
.44023 .35648 L
.44024 .35647 L
.44024 .35646 L
.44024 .35645 L
.44024 .35644 L
.44024 .35642 L
.44025 .35641 L
.44025 .3564 L
Mistroke
.44025 .35639 L
.44025 .35638 L
.44026 .35636 L
.44026 .35635 L
.44026 .35634 L
.44026 .35633 L
.44026 .35632 L
.44027 .3563 L
.44027 .35629 L
.44027 .35628 L
.44027 .35627 L
.44028 .35626 L
.44028 .35624 L
.44028 .35623 L
.44028 .35622 L
.44029 .35621 L
.44029 .3562 L
.44029 .35618 L
.44029 .35617 L
.4403 .35616 L
.4403 .35615 L
.4403 .35614 L
.4403 .35613 L
.44031 .35611 L
.44031 .3561 L
.44031 .35609 L
.44031 .35608 L
.44032 .35607 L
.44032 .35605 L
.44032 .35604 L
.44032 .35603 L
.44033 .35602 L
.44033 .35601 L
.44033 .356 L
.44033 .35598 L
.44034 .35597 L
.44034 .35596 L
.44034 .35595 L
.44035 .35594 L
.44035 .35592 L
.44035 .35591 L
.44035 .3559 L
.44036 .35589 L
.44036 .35588 L
.44036 .35587 L
.44036 .35585 L
.44037 .35584 L
.44037 .35583 L
.44037 .35582 L
.44038 .35581 L
Mistroke
.44038 .35579 L
.44038 .35578 L
.44038 .35577 L
.44039 .35576 L
.44039 .35575 L
.44039 .35574 L
.4404 .35572 L
.4404 .35571 L
.4404 .3557 L
.4404 .35569 L
.44041 .35568 L
.44041 .35566 L
.44041 .35565 L
.44042 .35564 L
.44042 .35563 L
.44042 .35562 L
.44043 .35561 L
.44043 .35559 L
.44043 .35558 L
.44043 .35557 L
.44044 .35556 L
.44044 .35555 L
.44044 .35554 L
.44045 .35552 L
.44045 .35551 L
.44045 .3555 L
.44046 .35549 L
.44046 .35548 L
.44046 .35547 L
.44047 .35545 L
.44047 .35544 L
.44047 .35543 L
.44048 .35542 L
.44048 .35541 L
.44048 .3554 L
.44049 .35538 L
.44049 .35537 L
.44049 .35536 L
.44049 .35535 L
.4405 .35534 L
.4405 .35533 L
.4405 .35531 L
.44051 .3553 L
.44051 .35529 L
.44051 .35528 L
.44052 .35527 L
.44052 .35526 L
.44052 .35524 L
.44053 .35523 L
.44053 .35522 L
Mistroke
.44053 .35521 L
.44054 .3552 L
.44054 .35519 L
.44054 .35517 L
.44055 .35516 L
.44055 .35515 L
.44056 .35514 L
.44056 .35513 L
.44056 .35512 L
.44057 .3551 L
.44057 .35509 L
.44057 .35508 L
.44058 .35507 L
.44058 .35506 L
.44058 .35505 L
.44059 .35504 L
.44059 .35502 L
.44059 .35501 L
.4406 .355 L
.4406 .35499 L
.4406 .35498 L
.44061 .35497 L
.44061 .35495 L
.44062 .35494 L
.44062 .35493 L
.44062 .35492 L
.44063 .35491 L
.44063 .3549 L
.44063 .35489 L
.44064 .35487 L
.44064 .35486 L
.44064 .35485 L
.44065 .35484 L
.44065 .35483 L
.44066 .35482 L
.44066 .35481 L
.44066 .35479 L
.44067 .35478 L
.44067 .35477 L
.44067 .35476 L
.44068 .35475 L
.44068 .35474 L
.44069 .35472 L
.44069 .35471 L
.44069 .3547 L
.4407 .35469 L
.4407 .35468 L
.44071 .35467 L
.44071 .35466 L
.44071 .35464 L
Mistroke
.44072 .35463 L
.44072 .35462 L
.44072 .35461 L
.44073 .3546 L
.44073 .35459 L
.44074 .35458 L
.44074 .35457 L
.44074 .35455 L
.44075 .35454 L
.44075 .35453 L
.44076 .35452 L
.44076 .35451 L
.44076 .3545 L
.44077 .35449 L
.44077 .35447 L
.44078 .35446 L
.44078 .35445 L
.44078 .35444 L
.44079 .35443 L
.44079 .35442 L
.4408 .35441 L
.4408 .35439 L
.4408 .35438 L
.44081 .35437 L
.44081 .35436 L
.44082 .35435 L
.44082 .35434 L
.44082 .35433 L
.44083 .35432 L
.44083 .3543 L
.44084 .35429 L
.44084 .35428 L
.44085 .35427 L
.44085 .35426 L
.44085 .35425 L
.44086 .35424 L
.44086 .35423 L
.44087 .35421 L
.44087 .3542 L
.44088 .35419 L
.44088 .35418 L
.44088 .35417 L
.44089 .35416 L
.44089 .35415 L
.4409 .35414 L
.4409 .35412 L
.44091 .35411 L
.44091 .3541 L
.44091 .35409 L
.44092 .35408 L
Mistroke
.44092 .35407 L
.44093 .35406 L
.44093 .35405 L
.44094 .35403 L
.44094 .35402 L
.44094 .35401 L
.44095 .354 L
.44095 .35399 L
.44096 .35398 L
.44096 .35397 L
.44097 .35396 L
.44097 .35395 L
.44098 .35393 L
.44098 .35392 L
.44098 .35391 L
.44099 .3539 L
.44099 .35389 L
.441 .35388 L
.441 .35387 L
.44101 .35386 L
.44101 .35385 L
.44102 .35383 L
.44102 .35382 L
.44102 .35381 L
.44103 .3538 L
.44103 .35379 L
.44104 .35378 L
.44104 .35377 L
.44105 .35376 L
.44105 .35375 L
.44106 .35373 L
.44106 .35372 L
.44107 .35371 L
.44107 .3537 L
.44108 .35369 L
.44108 .35368 L
.44108 .35367 L
.44109 .35366 L
.44109 .35365 L
.4411 .35364 L
.4411 .35362 L
.44111 .35361 L
.44111 .3536 L
.44112 .35359 L
.44112 .35358 L
.44113 .35357 L
.44113 .35356 L
.44114 .35355 L
.44114 .35354 L
.44115 .35353 L
Mistroke
.44115 .35351 L
.44116 .3535 L
.44116 .35349 L
.44117 .35348 L
.44117 .35347 L
.44117 .35346 L
.44118 .35345 L
.44118 .35344 L
.44119 .35343 L
.44119 .35342 L
.4412 .35341 L
.4412 .35339 L
.44121 .35338 L
.44121 .35337 L
.44122 .35336 L
.44122 .35335 L
.44123 .35334 L
.44123 .35333 L
.44124 .35332 L
.44124 .35331 L
.44125 .3533 L
.44125 .35329 L
.44126 .35327 L
.44126 .35326 L
.44127 .35325 L
.44127 .35324 L
.44128 .35323 L
.44128 .35322 L
.44129 .35321 L
.44129 .3532 L
.4413 .35319 L
.4413 .35318 L
.44131 .35317 L
.44131 .35316 L
.44132 .35315 L
.44132 .35313 L
.44133 .35312 L
.44133 .35311 L
.44134 .3531 L
.44134 .35309 L
.44135 .35308 L
.44135 .35307 L
.44136 .35306 L
.44136 .35305 L
.44137 .35304 L
.44137 .35303 L
.44138 .35302 L
.44138 .35301 L
.44139 .35299 L
.44139 .35298 L
Mistroke
.4414 .35297 L
.44141 .35296 L
.44141 .35295 L
.44142 .35294 L
.44142 .35293 L
.44143 .35292 L
.44143 .35291 L
.44144 .3529 L
.44144 .35289 L
.44145 .35288 L
.44145 .35287 L
.44146 .35286 L
.44146 .35285 L
.44147 .35283 L
.44147 .35282 L
.44148 .35281 L
.44148 .3528 L
.44149 .35279 L
.44149 .35278 L
.4415 .35277 L
.4415 .35276 L
.44151 .35275 L
.44152 .35274 L
.44152 .35273 L
.44153 .35272 L
.44153 .35271 L
.44154 .3527 L
.44154 .35269 L
.44155 .35268 L
.44155 .35267 L
.44156 .35266 L
.44156 .35264 L
.44157 .35263 L
.44157 .35262 L
.44158 .35261 L
.44159 .3526 L
.44159 .35259 L
.4416 .35258 L
.4416 .35257 L
.44161 .35256 L
.44161 .35255 L
.44162 .35254 L
.44162 .35253 L
.44163 .35252 L
.44163 .35251 L
.44164 .3525 L
.44165 .35249 L
.44165 .35248 L
.44166 .35247 L
.44166 .35246 L
Mistroke
.44167 .35245 L
.44167 .35244 L
.44168 .35242 L
.44168 .35241 L
.44169 .3524 L
.4417 .35239 L
.4417 .35238 L
.44171 .35237 L
.44171 .35236 L
.44172 .35235 L
.44172 .35234 L
.44173 .35233 L
.44173 .35232 L
.44174 .35231 L
.44175 .3523 L
.44175 .35229 L
.44176 .35228 L
.44176 .35227 L
.44177 .35226 L
.44177 .35225 L
.44178 .35224 L
.44179 .35223 L
.44179 .35222 L
.4418 .35221 L
.4418 .3522 L
.44181 .35219 L
.44181 .35218 L
.44182 .35217 L
.44183 .35216 L
.44183 .35215 L
.44184 .35214 L
.44184 .35213 L
.44185 .35212 L
.44185 .35211 L
.44186 .3521 L
.44187 .35208 L
.44187 .35207 L
.44188 .35206 L
.44188 .35205 L
.44189 .35204 L
.44189 .35203 L
.4419 .35202 L
.44191 .35201 L
.44191 .352 L
.44192 .35199 L
.44192 .35198 L
.44193 .35197 L
.44193 .35196 L
.44194 .35195 L
.44195 .35194 L
Mistroke
.44195 .35193 L
.44196 .35192 L
.44196 .35191 L
.44197 .3519 L
.44198 .35189 L
.44198 .35188 L
.44199 .35187 L
.44199 .35186 L
.442 .35185 L
.44201 .35184 L
.44201 .35183 L
.44202 .35182 L
.44202 .35181 L
.44203 .3518 L
.44204 .35179 L
.44204 .35178 L
.44205 .35177 L
.44205 .35176 L
.44206 .35175 L
.44206 .35174 L
.44207 .35173 L
.44208 .35172 L
.44208 .35171 L
.44209 .3517 L
.44209 .35169 L
.4421 .35168 L
.44211 .35167 L
.44211 .35166 L
.44212 .35165 L
.44212 .35164 L
.44213 .35163 L
.44214 .35162 L
.44214 .35161 L
.44215 .3516 L
.44216 .35159 L
.44216 .35158 L
.44217 .35157 L
.44217 .35156 L
.44218 .35155 L
.44219 .35154 L
.44219 .35153 L
.4422 .35152 L
.4422 .35151 L
.44221 .3515 L
.44222 .35149 L
.44222 .35148 L
.44223 .35147 L
.44223 .35146 L
.44224 .35145 L
.44225 .35144 L
Mistroke
.44225 .35143 L
.44226 .35142 L
.44227 .35141 L
.44227 .35141 L
.44228 .3514 L
.44228 .35139 L
.44229 .35138 L
.4423 .35137 L
.4423 .35136 L
.44231 .35135 L
.44231 .35134 L
.44232 .35133 L
.44233 .35132 L
.44233 .35131 L
.44234 .3513 L
.44235 .35129 L
.44235 .35128 L
.44236 .35127 L
.44236 .35126 L
.44237 .35125 L
.44238 .35124 L
.44238 .35123 L
.44239 .35122 L
.4424 .35121 L
.4424 .3512 L
.44241 .35119 L
.44241 .35118 L
.44242 .35117 L
.44243 .35116 L
.44243 .35115 L
.44244 .35114 L
.44245 .35113 L
.44245 .35112 L
.44246 .35111 L
.44247 .3511 L
.44247 .3511 L
.44248 .35109 L
.44248 .35108 L
.44249 .35107 L
.4425 .35106 L
.4425 .35105 L
.44251 .35104 L
.44252 .35103 L
.44252 .35102 L
.44253 .35101 L
.44254 .351 L
.44254 .35099 L
.44255 .35098 L
.44255 .35097 L
.44256 .35096 L
Mistroke
.44257 .35095 L
.44257 .35094 L
.44258 .35093 L
.44259 .35092 L
.44259 .35091 L
.4426 .3509 L
.44261 .3509 L
.44261 .35089 L
.44262 .35088 L
.44263 .35087 L
.44263 .35086 L
.44264 .35085 L
.44264 .35084 L
.44265 .35083 L
.44266 .35082 L
.44266 .35081 L
.44267 .3508 L
.44268 .35079 L
.44268 .35078 L
.44269 .35077 L
.4427 .35076 L
.4427 .35075 L
.44271 .35075 L
.44272 .35074 L
.44272 .35073 L
.44273 .35072 L
.44274 .35071 L
.44274 .3507 L
.44275 .35069 L
.44276 .35068 L
.44276 .35067 L
.44277 .35066 L
.44278 .35065 L
.44278 .35064 L
.44279 .35063 L
.44279 .35062 L
.4428 .35062 L
.44281 .35061 L
.44281 .3506 L
.44282 .35059 L
.44283 .35058 L
.44283 .35057 L
.44284 .35056 L
.44285 .35055 L
.44285 .35054 L
.44286 .35053 L
.44287 .35052 L
.44287 .35051 L
.44288 .3505 L
.44289 .3505 L
Mistroke
.44289 .35049 L
.4429 .35048 L
.44291 .35047 L
.44291 .35046 L
.44292 .35045 L
.44293 .35044 L
.44293 .35043 L
.44294 .35042 L
.44295 .35041 L
.44295 .3504 L
.44296 .3504 L
.44297 .35039 L
.44297 .35038 L
.44298 .35037 L
.44299 .35036 L
.44299 .35035 L
.443 .35034 L
.44301 .35033 L
.44301 .35032 L
.44302 .35031 L
.44303 .3503 L
.44303 .3503 L
.44304 .35029 L
.44305 .35028 L
.44305 .35027 L
.44306 .35026 L
.44307 .35025 L
.44307 .35024 L
.44308 .35023 L
.44309 .35022 L
.4431 .35021 L
.4431 .35021 L
.44311 .3502 L
.44312 .35019 L
.44312 .35018 L
.44313 .35017 L
.44314 .35016 L
.44314 .35015 L
.44315 .35014 L
.44316 .35013 L
.44316 .35013 L
.44317 .35012 L
.44318 .35011 L
.44318 .3501 L
.44319 .35009 L
.4432 .35008 L
.4432 .35007 L
.44321 .35006 L
.44322 .35005 L
.44322 .35005 L
Mistroke
.44323 .35004 L
.44324 .35003 L
.44325 .35002 L
.44325 .35001 L
.44326 .35 L
.44327 .34999 L
.44327 .34998 L
.44328 .34998 L
.44329 .34997 L
.44329 .34996 L
.4433 .34995 L
.44331 .34994 L
.44331 .34993 L
.44332 .34992 L
.44333 .34991 L
.44333 .34991 L
.44334 .3499 L
.44335 .34989 L
.44336 .34988 L
.44336 .34987 L
.44337 .34986 L
.44338 .34985 L
.44338 .34985 L
.44339 .34984 L
.4434 .34983 L
.4434 .34982 L
.44341 .34981 L
.44342 .3498 L
.44342 .34979 L
.44343 .34978 L
.44344 .34978 L
.44345 .34977 L
.44345 .34976 L
.44346 .34975 L
.44347 .34974 L
.44347 .34973 L
.44348 .34972 L
.44349 .34972 L
.44349 .34971 L
.4435 .3497 L
.44351 .34969 L
.44352 .34968 L
.44352 .34967 L
.44353 .34966 L
.44354 .34966 L
.44354 .34965 L
.44355 .34964 L
.44356 .34963 L
.44356 .34962 L
.44357 .34961 L
Mistroke
.44358 .34961 L
.44359 .3496 L
.44359 .34959 L
.4436 .34958 L
.44361 .34957 L
.44361 .34956 L
.44362 .34955 L
.44363 .34955 L
.44363 .34954 L
.44364 .34953 L
.44365 .34952 L
.44366 .34951 L
.44366 .3495 L
.44367 .3495 L
.44368 .34949 L
.44368 .34948 L
.44369 .34947 L
.4437 .34946 L
.44371 .34945 L
.44371 .34945 L
.44372 .34944 L
.44373 .34943 L
.44373 .34942 L
.44374 .34941 L
.44375 .3494 L
.44375 .3494 L
.44376 .34939 L
.44377 .34938 L
.44378 .34937 L
.44378 .34936 L
.44379 .34935 L
.4438 .34935 L
.4438 .34934 L
.44381 .34933 L
.44382 .34932 L
.44383 .34931 L
.44383 .34931 L
.44384 .3493 L
.44385 .34929 L
.44385 .34928 L
.44386 .34927 L
.44387 .34926 L
.44388 .34926 L
.44388 .34925 L
.44389 .34924 L
.4439 .34923 L
.4439 .34922 L
.44391 .34922 L
.44392 .34921 L
.44393 .3492 L
Mistroke
.44393 .34919 L
.44394 .34918 L
.44395 .34918 L
.44395 .34917 L
.44396 .34916 L
.44397 .34915 L
.44398 .34914 L
.44398 .34913 L
.44399 .34913 L
.444 .34912 L
.444 .34911 L
.44401 .3491 L
.44402 .34909 L
.44403 .34909 L
.44403 .34908 L
.44404 .34907 L
.44405 .34906 L
.44406 .34905 L
.44406 .34905 L
.44407 .34904 L
.44408 .34903 L
.44408 .34902 L
.44409 .34901 L
.4441 .34901 L
.44411 .349 L
.44411 .34899 L
.44412 .34898 L
.44413 .34898 L
.44413 .34897 L
.44414 .34896 L
.44415 .34895 L
.44416 .34894 L
.44416 .34894 L
.44417 .34893 L
.44418 .34892 L
.44419 .34891 L
.44419 .3489 L
.4442 .3489 L
.44421 .34889 L
.44421 .34888 L
.44422 .34887 L
.44423 .34887 L
.44424 .34886 L
.44424 .34885 L
.44425 .34884 L
.44426 .34883 L
.44426 .34883 L
.44427 .34882 L
.44428 .34881 L
.44429 .3488 L
Mistroke
.44429 .3488 L
.4443 .34879 L
.44431 .34878 L
.44432 .34877 L
.44432 .34876 L
.44433 .34876 L
.44434 .34875 L
.44435 .34874 L
.44435 .34873 L
.44436 .34873 L
.44437 .34872 L
.44437 .34871 L
.44438 .3487 L
.44439 .3487 L
.4444 .34869 L
.4444 .34868 L
.44441 .34867 L
.44442 .34866 L
.44443 .34866 L
.44443 .34865 L
.44444 .34864 L
.44445 .34863 L
.44445 .34863 L
.44446 .34862 L
.44447 .34861 L
.44448 .3486 L
.44448 .3486 L
.44449 .34859 L
.4445 .34858 L
.44451 .34857 L
.44451 .34857 L
.44452 .34856 L
.44453 .34855 L
.44454 .34854 L
.44454 .34854 L
.44455 .34853 L
.44456 .34852 L
.44456 .34851 L
.44457 .34851 L
.44458 .3485 L
.44459 .34849 L
.44459 .34848 L
.4446 .34848 L
.44461 .34847 L
.44462 .34846 L
.44462 .34845 L
.44463 .34845 L
.44464 .34844 L
.44465 .34843 L
.44465 .34842 L
Mistroke
.44466 .34842 L
.44467 .34841 L
.44468 .3484 L
.44468 .3484 L
.44469 .34839 L
.4447 .34838 L
.4447 .34837 L
.44471 .34837 L
.44472 .34836 L
.44473 .34835 L
.44473 .34834 L
.44474 .34834 L
.44475 .34833 L
.44476 .34832 L
.44476 .34832 L
.44477 .34831 L
.44478 .3483 L
.44479 .34829 L
.44479 .34829 L
.4448 .34828 L
.44481 .34827 L
.44482 .34826 L
.44482 .34826 L
.44483 .34825 L
.44484 .34824 L
.44485 .34824 L
.44485 .34823 L
.44486 .34822 L
.44487 .34821 L
.44487 .34821 L
.44488 .3482 L
.44489 .34819 L
.4449 .34819 L
.4449 .34818 L
.44491 .34817 L
.44492 .34816 L
.44493 .34816 L
.44493 .34815 L
.44494 .34814 L
.44495 .34814 L
.44496 .34813 L
.44496 .34812 L
.44497 .34811 L
.44498 .34811 L
.44499 .3481 L
.44499 .34809 L
.445 .34809 L
.44501 .34808 L
.44502 .34807 L
.44502 .34807 L
Mistroke
.44503 .34806 L
.44504 .34805 L
.44505 .34804 L
.44505 .34804 L
.44506 .34803 L
.44507 .34802 L
.44508 .34802 L
.44508 .34801 L
.44509 .348 L
.4451 .348 L
.44511 .34799 L
.44511 .34798 L
.44512 .34797 L
.44513 .34797 L
.44513 .34796 L
.44514 .34795 L
.44515 .34795 L
.44516 .34794 L
.44516 .34793 L
.44517 .34793 L
.44518 .34792 L
.44519 .34791 L
.44519 .34791 L
.4452 .3479 L
.44521 .34789 L
.44522 .34789 L
.44522 .34788 L
.44523 .34787 L
.44524 .34786 L
.44525 .34786 L
.44525 .34785 L
.44526 .34784 L
.44527 .34784 L
.44528 .34783 L
.44528 .34782 L
.44529 .34782 L
.4453 .34781 L
.44531 .3478 L
.44531 .3478 L
.44532 .34779 L
.44533 .34778 L
.44534 .34778 L
.44534 .34777 L
.44535 .34776 L
.44536 .34776 L
.44537 .34775 L
.44537 .34774 L
.44538 .34774 L
.44539 .34773 L
.4454 .34772 L
Mistroke
.4454 .34772 L
.44541 .34771 L
.44542 .3477 L
.44543 .3477 L
.44543 .34769 L
.44544 .34768 L
.44545 .34768 L
.44546 .34767 L
.44546 .34766 L
.44547 .34766 L
.44548 .34765 L
.44549 .34764 L
.44549 .34764 L
.4455 .34763 L
.44551 .34762 L
.44552 .34762 L
.44552 .34761 L
.44553 .34761 L
.44554 .3476 L
.44555 .34759 L
.44555 .34759 L
.44556 .34758 L
.44557 .34757 L
.44558 .34757 L
.44558 .34756 L
.44559 .34755 L
.4456 .34755 L
.44561 .34754 L
.44561 .34753 L
.44562 .34753 L
.44563 .34752 L
.44564 .34751 L
.44564 .34751 L
.44565 .3475 L
.44566 .3475 L
.44567 .34749 L
.44567 .34748 L
.44568 .34748 L
.44569 .34747 L
.4457 .34746 L
.4457 .34746 L
.44571 .34745 L
.44572 .34744 L
.44573 .34744 L
.44573 .34743 L
.44574 .34743 L
.44575 .34742 L
.44576 .34741 L
.44576 .34741 L
.44577 .3474 L
Mistroke
.44578 .34739 L
.44579 .34739 L
.44579 .34738 L
.4458 .34738 L
.44581 .34737 L
.44582 .34736 L
.44582 .34736 L
.44583 .34735 L
.44584 .34734 L
.44585 .34734 L
.44585 .34733 L
.44586 .34733 L
.44587 .34732 L
.44588 .34731 L
.44588 .34731 L
.44589 .3473 L
.4459 .3473 L
.44591 .34729 L
.44591 .34728 L
.44592 .34728 L
.44593 .34727 L
.44594 .34726 L
.44594 .34726 L
.44595 .34725 L
.44596 .34725 L
.44597 .34724 L
.44597 .34723 L
.44598 .34723 L
.44599 .34722 L
.446 .34722 L
.446 .34721 L
.44601 .3472 L
.44602 .3472 L
.44603 .34719 L
.44603 .34719 L
.44604 .34718 L
.44605 .34717 L
.44606 .34717 L
.44606 .34716 L
.44607 .34716 L
.44608 .34715 L
.44609 .34714 L
.44609 .34714 L
.4461 .34713 L
.44611 .34713 L
.44612 .34712 L
.44612 .34711 L
.44613 .34711 L
.44614 .3471 L
.44615 .3471 L
Mistroke
.44615 .34709 L
.44616 .34708 L
.44617 .34708 L
.44618 .34707 L
.44618 .34707 L
.44619 .34706 L
.4462 .34706 L
.44621 .34705 L
.44621 .34704 L
.44622 .34704 L
.44623 .34703 L
.44624 .34703 L
.44624 .34702 L
.44625 .34701 L
.44626 .34701 L
.44627 .347 L
.44627 .347 L
.44628 .34699 L
.44629 .34699 L
.4463 .34698 L
.4463 .34697 L
.44631 .34697 L
.44632 .34696 L
.44633 .34696 L
.44633 .34695 L
.44634 .34695 L
.44635 .34694 L
.44636 .34693 L
.44636 .34693 L
.44637 .34692 L
.44638 .34692 L
.44639 .34691 L
.44639 .34691 L
.4464 .3469 L
.44641 .34689 L
.44641 .34689 L
.44642 .34688 L
.44643 .34688 L
.44644 .34687 L
.44644 .34687 L
.44645 .34686 L
.44646 .34686 L
.44647 .34685 L
.44647 .34684 L
.44648 .34684 L
.44649 .34683 L
.4465 .34683 L
.4465 .34682 L
.44651 .34682 L
.44652 .34681 L
Mistroke
.44653 .34681 L
.44653 .3468 L
.44654 .34679 L
.44655 .34679 L
.44656 .34678 L
.44656 .34678 L
.44657 .34677 L
.44658 .34677 L
.44659 .34676 L
.44659 .34676 L
.4466 .34675 L
.44661 .34674 L
.44662 .34674 L
.44662 .34673 L
.44663 .34673 L
.44664 .34672 L
.44665 .34672 L
.44665 .34671 L
.44666 .34671 L
.44667 .3467 L
.44668 .3467 L
.44668 .34669 L
.44669 .34669 L
.4467 .34668 L
.44671 .34667 L
.44671 .34667 L
.44672 .34666 L
.44673 .34666 L
.44674 .34665 L
.44674 .34665 L
.44675 .34664 L
.44676 .34664 L
.44677 .34663 L
.44677 .34663 L
.44678 .34662 L
.44679 .34662 L
.4468 .34661 L
.4468 .34661 L
.44681 .3466 L
.44682 .3466 L
.44683 .34659 L
.44683 .34658 L
.44684 .34658 L
.44685 .34657 L
.44685 .34657 L
.44686 .34656 L
.44687 .34656 L
.44688 .34655 L
.44688 .34655 L
.44689 .34654 L
Mistroke
.4469 .34654 L
.44691 .34653 L
.44691 .34653 L
.44692 .34652 L
.44693 .34652 L
.44694 .34651 L
.44694 .34651 L
.44695 .3465 L
.44696 .3465 L
.44697 .34649 L
.44697 .34649 L
.44698 .34648 L
.44699 .34648 L
.447 .34647 L
.447 .34647 L
.44701 .34646 L
.44702 .34646 L
.44703 .34645 L
.44703 .34645 L
.44704 .34644 L
.44705 .34644 L
.44706 .34643 L
.44706 .34643 L
.44707 .34642 L
.44708 .34642 L
.44708 .34641 L
.44709 .34641 L
.4471 .3464 L
.44711 .3464 L
.44711 .34639 L
.44712 .34639 L
.44713 .34638 L
.44714 .34638 L
.44714 .34637 L
.44715 .34637 L
.44716 .34636 L
.44717 .34636 L
.44717 .34635 L
.44718 .34635 L
.44719 .34634 L
.4472 .34634 L
.4472 .34633 L
.44721 .34633 L
.44722 .34632 L
.44722 .34632 L
.44723 .34631 L
.44724 .34631 L
.44725 .3463 L
.44725 .3463 L
.44726 .34629 L
Mistroke
.44727 .34629 L
.44728 .34628 L
.44728 .34628 L
.44729 .34627 L
.4473 .34627 L
.44731 .34627 L
.44731 .34626 L
.44732 .34626 L
.44733 .34625 L
.44734 .34625 L
.44734 .34624 L
.44735 .34624 L
.44736 .34623 L
.44736 .34623 L
.44737 .34622 L
.44738 .34622 L
.44739 .34621 L
.44739 .34621 L
.4474 .3462 L
.44741 .3462 L
.44742 .34619 L
.44742 .34619 L
.44743 .34619 L
.44744 .34618 L
.44745 .34618 L
.44745 .34617 L
.44746 .34617 L
.44747 .34616 L
.44747 .34616 L
.44748 .34615 L
.44749 .34615 L
.4475 .34614 L
.4475 .34614 L
.44751 .34613 L
.44752 .34613 L
.44753 .34613 L
.44753 .34612 L
.44754 .34612 L
.44755 .34611 L
.44755 .34611 L
.44756 .3461 L
.44757 .3461 L
.44758 .34609 L
.44758 .34609 L
.44759 .34609 L
.4476 .34608 L
.44761 .34608 L
.44761 .34607 L
.44762 .34607 L
.44763 .34606 L
Mistroke
.44764 .34606 L
.44764 .34605 L
.44765 .34605 L
.44766 .34604 L
.44766 .34604 L
.44767 .34604 L
.44768 .34603 L
.44769 .34603 L
.44769 .34602 L
.4477 .34602 L
.44771 .34601 L
.44772 .34601 L
.44772 .34601 L
.44773 .346 L
.44774 .346 L
.44774 .34599 L
.44775 .34599 L
.44776 .34598 L
.44777 .34598 L
.44777 .34598 L
.44778 .34597 L
.44779 .34597 L
.44779 .34596 L
.4478 .34596 L
.44781 .34595 L
.44782 .34595 L
.44782 .34595 L
.44783 .34594 L
.44784 .34594 L
.44785 .34593 L
.44785 .34593 L
.44786 .34592 L
.44787 .34592 L
.44787 .34592 L
.44788 .34591 L
.44789 .34591 L
.4479 .3459 L
.4479 .3459 L
.44791 .34589 L
.44792 .34589 L
.44792 .34589 L
.44793 .34588 L
.44794 .34588 L
.44795 .34587 L
.44795 .34587 L
.44796 .34587 L
.44797 .34586 L
.44798 .34586 L
.44798 .34585 L
.44799 .34585 L
Mistroke
.448 .34585 L
.448 .34584 L
.44801 .34584 L
.44802 .34583 L
.44803 .34583 L
.44803 .34582 L
.44804 .34582 L
.44805 .34582 L
.44805 .34581 L
.44806 .34581 L
.44807 .3458 L
.44808 .3458 L
.44808 .3458 L
.44809 .34579 L
.4481 .34579 L
.4481 .34578 L
.44811 .34578 L
.44812 .34578 L
.44813 .34577 L
.44813 .34577 L
.44814 .34576 L
.44815 .34576 L
.44815 .34576 L
.44816 .34575 L
.44817 .34575 L
.44818 .34575 L
.44818 .34574 L
.44819 .34574 L
.4482 .34573 L
.4482 .34573 L
.44821 .34573 L
.44822 .34572 L
.44823 .34572 L
.44823 .34571 L
.44824 .34571 L
.44825 .34571 L
.44825 .3457 L
.44826 .3457 L
.44827 .3457 L
.44828 .34569 L
.44828 .34569 L
.44829 .34568 L
.4483 .34568 L
.4483 .34568 L
.44831 .34567 L
.44832 .34567 L
.44832 .34566 L
.44833 .34566 L
.44834 .34566 L
.44835 .34565 L
Mistroke
.44835 .34565 L
.44836 .34565 L
.44837 .34564 L
.44837 .34564 L
.44838 .34563 L
.44839 .34563 L
.4484 .34563 L
.4484 .34562 L
.44841 .34562 L
.44842 .34562 L
.44842 .34561 L
.44843 .34561 L
.44844 .34561 L
.44844 .3456 L
.44845 .3456 L
.44846 .34559 L
.44847 .34559 L
.44847 .34559 L
.44848 .34558 L
.44849 .34558 L
.44849 .34558 L
.4485 .34557 L
.44851 .34557 L
.44852 .34557 L
.44852 .34556 L
.44853 .34556 L
.44854 .34555 L
.44854 .34555 L
.44855 .34555 L
.44856 .34554 L
.44856 .34554 L
.44857 .34554 L
.44858 .34553 L
.44859 .34553 L
.44859 .34553 L
.4486 .34552 L
.44861 .34552 L
.44861 .34552 L
.44862 .34551 L
.44863 .34551 L
.44863 .34551 L
.44864 .3455 L
.44865 .3455 L
.44865 .3455 L
.44866 .34549 L
.44867 .34549 L
.44868 .34549 L
.44868 .34548 L
.44869 .34548 L
.4487 .34547 L
Mistroke
.4487 .34547 L
.44871 .34547 L
.44872 .34546 L
.44872 .34546 L
.44873 .34546 L
.44874 .34545 L
.44875 .34545 L
.44875 .34545 L
.44876 .34544 L
.44877 .34544 L
.44877 .34544 L
.44878 .34543 L
.44879 .34543 L
.44879 .34543 L
.4488 .34542 L
.44881 .34542 L
.44881 .34542 L
.44882 .34541 L
.44883 .34541 L
.44883 .34541 L
.44884 .3454 L
.44885 .3454 L
.44886 .3454 L
.44886 .3454 L
.44887 .34539 L
.44888 .34539 L
.44888 .34539 L
.44889 .34538 L
.4489 .34538 L
.4489 .34538 L
.44891 .34537 L
.44892 .34537 L
.44892 .34537 L
.44893 .34536 L
.44894 .34536 L
.44894 .34536 L
.44895 .34535 L
.44896 .34535 L
.44897 .34535 L
.44897 .34534 L
.44898 .34534 L
.44899 .34534 L
.44899 .34533 L
.449 .34533 L
.44901 .34533 L
.44901 .34533 L
.44902 .34532 L
.44903 .34532 L
.44903 .34532 L
.44904 .34531 L
Mistroke
.44905 .34531 L
.44905 .34531 L
.44906 .3453 L
.44907 .3453 L
.44907 .3453 L
.44908 .34529 L
.44909 .34529 L
.44909 .34529 L
.4491 .34529 L
.44911 .34528 L
.44911 .34528 L
.44912 .34528 L
.44913 .34527 L
.44914 .34527 L
.44914 .34527 L
.44915 .34526 L
.44916 .34526 L
.44916 .34526 L
.44917 .34526 L
.44918 .34525 L
.44918 .34525 L
.44919 .34525 L
.4492 .34524 L
.4492 .34524 L
.44921 .34524 L
.44922 .34524 L
.44922 .34523 L
.44923 .34523 L
.44924 .34523 L
.44924 .34522 L
.44925 .34522 L
.44926 .34522 L
.44926 .34522 L
.44927 .34521 L
.44928 .34521 L
.44928 .34521 L
.44929 .3452 L
.4493 .3452 L
.4493 .3452 L
.44931 .3452 L
.44932 .34519 L
.44932 .34519 L
.44933 .34519 L
.44934 .34518 L
.44934 .34518 L
.44935 .34518 L
.44936 .34518 L
.44936 .34517 L
.44937 .34517 L
.44938 .34517 L
Mistroke
.44938 .34517 L
.44939 .34516 L
.4494 .34516 L
.4494 .34516 L
.44941 .34515 L
.44942 .34515 L
.44942 .34515 L
.44943 .34515 L
.44944 .34514 L
.44944 .34514 L
.44945 .34514 L
.44946 .34514 L
.44946 .34513 L
.44947 .34513 L
.44948 .34513 L
.44948 .34513 L
.44949 .34512 L
.4495 .34512 L
.4495 .34512 L
.44951 .34511 L
.44952 .34511 L
.44952 .34511 L
.44953 .34511 L
.44954 .3451 L
.44954 .3451 L
.44955 .3451 L
.44955 .3451 L
.44956 .34509 L
.44957 .34509 L
.44957 .34509 L
.44958 .34509 L
.44959 .34508 L
.44959 .34508 L
.4496 .34508 L
.44961 .34508 L
.44961 .34507 L
.44962 .34507 L
.44963 .34507 L
.44963 .34507 L
.44964 .34506 L
.44965 .34506 L
.44965 .34506 L
.44966 .34506 L
.44967 .34505 L
.44967 .34505 L
.44968 .34505 L
.44969 .34505 L
.44969 .34504 L
.4497 .34504 L
.4497 .34504 L
Mistroke
.44971 .34504 L
.44972 .34503 L
.44972 .34503 L
.44973 .34503 L
.44974 .34503 L
.44974 .34502 L
.44975 .34502 L
.44976 .34502 L
.44976 .34502 L
.44977 .34502 L
.44978 .34501 L
.44978 .34501 L
.44979 .34501 L
.4498 .34501 L
.4498 .345 L
.44981 .345 L
.44981 .345 L
.44982 .345 L
.44983 .34499 L
.44983 .34499 L
.44984 .34499 L
.44985 .34499 L
.44985 .34499 L
.44986 .34498 L
.44987 .34498 L
.44987 .34498 L
.44988 .34498 L
.44989 .34497 L
.44989 .34497 L
.4499 .34497 L
.4499 .34497 L
.44991 .34496 L
.44992 .34496 L
.44992 .34496 L
.44993 .34496 L
.44994 .34496 L
.44994 .34495 L
.44995 .34495 L
.44996 .34495 L
.44996 .34495 L
.44997 .34495 L
.44997 .34494 L
.44998 .34494 L
.44999 .34494 L
.44999 .34494 L
.45 .34493 L
.45001 .34493 L
.45001 .34493 L
.45002 .34493 L
.45002 .34493 L
Mistroke
.45003 .34492 L
.45004 .34492 L
.45004 .34492 L
.45005 .34492 L
.45006 .34492 L
.45006 .34491 L
.45007 .34491 L
.45008 .34491 L
.45008 .34491 L
.45009 .34491 L
.45009 .3449 L
.4501 .3449 L
.45011 .3449 L
.45011 .3449 L
.45012 .34489 L
.45013 .34489 L
.45013 .34489 L
.45014 .34489 L
.45014 .34489 L
.45015 .34488 L
.45016 .34488 L
.45016 .34488 L
.45017 .34488 L
.45018 .34488 L
.45018 .34488 L
.45019 .34487 L
.45019 .34487 L
.4502 .34487 L
.45021 .34487 L
.45021 .34487 L
.45022 .34486 L
.45022 .34486 L
.45023 .34486 L
.45024 .34486 L
.45024 .34486 L
.45025 .34485 L
.45026 .34485 L
.45026 .34485 L
.45027 .34485 L
.45027 .34485 L
.45028 .34484 L
.45029 .34484 L
.45029 .34484 L
.4503 .34484 L
.45031 .34484 L
.45031 .34484 L
.45032 .34483 L
.45032 .34483 L
.45033 .34483 L
.45034 .34483 L
Mistroke
.45034 .34483 L
.45035 .34482 L
.45035 .34482 L
.45036 .34482 L
.45037 .34482 L
.45037 .34482 L
.45038 .34482 L
.45038 .34481 L
.45039 .34481 L
.4504 .34481 L
.4504 .34481 L
.45041 .34481 L
.45042 .3448 L
.45042 .3448 L
.45043 .3448 L
.45043 .3448 L
.45044 .3448 L
.45045 .3448 L
.45045 .34479 L
.45046 .34479 L
.45046 .34479 L
.45047 .34479 L
.45048 .34479 L
.45048 .34479 L
.45049 .34478 L
.45049 .34478 L
.4505 .34478 L
.45051 .34478 L
.45051 .34478 L
.45052 .34478 L
.45052 .34477 L
.45053 .34477 L
.45054 .34477 L
.45054 .34477 L
.45055 .34477 L
.45055 .34477 L
.45056 .34477 L
.45057 .34476 L
.45057 .34476 L
.45058 .34476 L
.45058 .34476 L
.45059 .34476 L
.4506 .34476 L
.4506 .34475 L
.45061 .34475 L
.45061 .34475 L
.45062 .34475 L
.45063 .34475 L
.45063 .34475 L
.45064 .34474 L
Mistroke
.45064 .34474 L
.45065 .34474 L
.45065 .34474 L
.45066 .34474 L
.45067 .34474 L
.45067 .34474 L
.45068 .34473 L
.45068 .34473 L
.45069 .34473 L
.4507 .34473 L
.4507 .34473 L
.45071 .34473 L
.45071 .34473 L
.45072 .34472 L
.45073 .34472 L
.45073 .34472 L
.45074 .34472 L
.45074 .34472 L
.45075 .34472 L
.45075 .34472 L
.45076 .34471 L
.45077 .34471 L
.45077 .34471 L
.45078 .34471 L
.45078 .34471 L
.45079 .34471 L
.4508 .34471 L
.4508 .3447 L
.45081 .3447 L
.45081 .3447 L
.45082 .3447 L
.45082 .3447 L
.45083 .3447 L
.45084 .3447 L
.45084 .3447 L
.45085 .34469 L
.45085 .34469 L
.45086 .34469 L
.45087 .34469 L
.45087 .34469 L
.45088 .34469 L
.45088 .34469 L
.45089 .34468 L
.45089 .34468 L
.4509 .34468 L
.45091 .34468 L
.45091 .34468 L
.45092 .34468 L
.45092 .34468 L
.45093 .34468 L
Mistroke
.45093 .34467 L
.45094 .34467 L
.45095 .34467 L
.45095 .34467 L
.45096 .34467 L
.45096 .34467 L
.45097 .34467 L
.45097 .34467 L
.45098 .34467 L
.45099 .34466 L
.45099 .34466 L
.451 .34466 L
.451 .34466 L
.45101 .34466 L
.45101 .34466 L
.45102 .34466 L
.45103 .34466 L
.45103 .34465 L
.45104 .34465 L
.45104 .34465 L
.45105 .34465 L
.45105 .34465 L
.45106 .34465 L
.45107 .34465 L
.45107 .34465 L
.45108 .34465 L
.45108 .34464 L
.45109 .34464 L
.45109 .34464 L
.4511 .34464 L
.4511 .34464 L
.45111 .34464 L
.45112 .34464 L
.45112 .34464 L
.45113 .34464 L
.45113 .34464 L
.45114 .34463 L
.45114 .34463 L
.45115 .34463 L
.45115 .34463 L
.45116 .34463 L
.45117 .34463 L
.45117 .34463 L
.45118 .34463 L
.45118 .34463 L
.45119 .34463 L
.45119 .34462 L
.4512 .34462 L
.4512 .34462 L
.45121 .34462 L
Mistroke
.45122 .34462 L
.45122 .34462 L
.45123 .34462 L
.45123 .34462 L
.45124 .34462 L
.45124 .34462 L
.45125 .34461 L
.45125 .34461 L
.45126 .34461 L
.45126 .34461 L
.45127 .34461 L
.45128 .34461 L
.45128 .34461 L
.45129 .34461 L
.45129 .34461 L
.4513 .34461 L
.4513 .34461 L
.45131 .3446 L
.45131 .3446 L
.45132 .3446 L
.45132 .3446 L
.45133 .3446 L
.45134 .3446 L
.45134 .3446 L
.45135 .3446 L
.45135 .3446 L
.45136 .3446 L
.45136 .3446 L
.45137 .3446 L
.45137 .34459 L
.45138 .34459 L
.45138 .34459 L
.45139 .34459 L
.4514 .34459 L
.4514 .34459 L
.45141 .34459 L
.45141 .34459 L
.45142 .34459 L
.45142 .34459 L
.45143 .34459 L
.45143 .34459 L
.45144 .34459 L
.45144 .34458 L
.45145 .34458 L
.45145 .34458 L
.45146 .34458 L
.45146 .34458 L
.45147 .34458 L
.45148 .34458 L
.45148 .34458 L
Mistroke
.45149 .34458 L
.45149 .34458 L
.4515 .34458 L
.4515 .34458 L
.45151 .34458 L
.45151 .34458 L
.45152 .34458 L
.45152 .34457 L
.45153 .34457 L
.45153 .34457 L
.45154 .34457 L
.45154 .34457 L
.45155 .34457 L
.45155 .34457 L
.45156 .34457 L
.45157 .34457 L
.45157 .34457 L
.45158 .34457 L
.45158 .34457 L
.45159 .34457 L
.45159 .34457 L
.4516 .34457 L
.4516 .34457 L
.45161 .34456 L
.45161 .34456 L
.45162 .34456 L
.45162 .34456 L
.45163 .34456 L
.45163 .34456 L
.45164 .34456 L
.45164 .34456 L
.45165 .34456 L
.45165 .34456 L
.45166 .34456 L
.45166 .34456 L
.45167 .34456 L
.45167 .34456 L
.45168 .34456 L
.45168 .34456 L
.45169 .34456 L
.45169 .34456 L
.4517 .34455 L
.4517 .34455 L
.45171 .34455 L
.45172 .34455 L
.45172 .34455 L
.45173 .34455 L
.45173 .34455 L
.45174 .34455 L
.45174 .34455 L
Mistroke
.45175 .34455 L
.45175 .34455 L
.45176 .34455 L
.45176 .34455 L
.45177 .34455 L
.45177 .34455 L
.45178 .34455 L
.45178 .34455 L
.45179 .34455 L
.45179 .34455 L
.4518 .34455 L
.4518 .34455 L
.45181 .34455 L
.45181 .34455 L
.45182 .34455 L
.45182 .34454 L
.45183 .34454 L
.45183 .34454 L
.45184 .34454 L
.45184 .34454 L
.45185 .34454 L
.45185 .34454 L
.45186 .34454 L
.45186 .34454 L
.45187 .34454 L
.45187 .34454 L
.45188 .34454 L
.45188 .34454 L
.45189 .34454 L
.45189 .34454 L
.4519 .34454 L
.4519 .34454 L
.45191 .34454 L
.45191 .34454 L
.45192 .34454 L
.45192 .34454 L
.45193 .34454 L
.45193 .34454 L
.45194 .34454 L
.45194 .34454 L
.45195 .34454 L
.45195 .34454 L
.45196 .34454 L
.45196 .34454 L
.45197 .34454 L
.45197 .34454 L
.45197 .34454 L
.45198 .34454 L
.45198 .34454 L
.45199 .34453 L
Mistroke
.45199 .34453 L
.452 .34453 L
.452 .34453 L
.45201 .34453 L
.45201 .34453 L
.45202 .34453 L
.45202 .34453 L
.45203 .34453 L
.45203 .34453 L
.45204 .34453 L
.45204 .34453 L
.45205 .34453 L
.45205 .34453 L
.45206 .34453 L
.45206 .34453 L
.45207 .34453 L
.45207 .34453 L
.45208 .34453 L
.45208 .34453 L
.45209 .34453 L
.45209 .34453 L
.4521 .34453 L
.4521 .34453 L
.4521 .34453 L
.45211 .34453 L
.45211 .34453 L
.45212 .34453 L
.45212 .34453 L
.45213 .34453 L
.45213 .34453 L
.45214 .34453 L
.45214 .34453 L
.45215 .34453 L
.45215 .34453 L
.45216 .34453 L
.45216 .34453 L
.45217 .34453 L
.45217 .34453 L
.45218 .34453 L
.45218 .34453 L
.45219 .34453 L
.45219 .34453 L
.45219 .34453 L
.4522 .34453 L
.4522 .34453 L
.45221 .34453 L
.45221 .34453 L
.45222 .34453 L
.45222 .34453 L
.45223 .34453 L
Mistroke
.45223 .34453 L
.45224 .34453 L
.45224 .34453 L
.45225 .34453 L
.45225 .34453 L
.45225 .34453 L
.45226 .34453 L
.45226 .34453 L
.45227 .34453 L
.45227 .34453 L
.45228 .34453 L
.45228 .34453 L
.45229 .34453 L
.45229 .34453 L
.4523 .34453 L
.4523 .34453 L
.45231 .34453 L
.45231 .34453 L
.45231 .34453 L
.45232 .34453 L
.45232 .34453 L
.45233 .34453 L
.45233 .34453 L
.45234 .34453 L
.45234 .34453 L
.45235 .34453 L
.45235 .34453 L
.45236 .34453 L
.45236 .34453 L
.45236 .34453 L
.45237 .34453 L
.45237 .34453 L
.45238 .34453 L
.45238 .34453 L
.45239 .34453 L
.45239 .34453 L
.4524 .34453 L
.4524 .34453 L
.4524 .34453 L
.45241 .34453 L
.45241 .34454 L
.45242 .34454 L
.45242 .34454 L
.45243 .34454 L
.45243 .34454 L
.45244 .34454 L
.45244 .34454 L
.45244 .34454 L
.45245 .34454 L
.45245 .34454 L
Mistroke
.45246 .34454 L
.45246 .34454 L
.45247 .34454 L
.45247 .34454 L
.45248 .34454 L
.45248 .34454 L
.45248 .34454 L
.45249 .34454 L
.45249 .34454 L
.4525 .34454 L
.4525 .34454 L
.45251 .34454 L
.45251 .34454 L
.45251 .34454 L
.45252 .34454 L
.45252 .34454 L
.45253 .34454 L
.45253 .34454 L
.45254 .34454 L
.45254 .34454 L
.45254 .34454 L
.45255 .34454 L
.45255 .34454 L
.45256 .34454 L
.45256 .34454 L
.45257 .34454 L
.45257 .34455 L
.45257 .34455 L
.45258 .34455 L
.45258 .34455 L
.45259 .34455 L
.45259 .34455 L
.4526 .34455 L
.4526 .34455 L
.4526 .34455 L
.45261 .34455 L
.45261 .34455 L
.45262 .34455 L
.45262 .34455 L
.45263 .34455 L
.45263 .34455 L
.45263 .34455 L
.45264 .34455 L
.45264 .34455 L
.45265 .34455 L
.45265 .34455 L
.45266 .34455 L
.45266 .34455 L
.45266 .34455 L
.45267 .34455 L
Mistroke
.45267 .34455 L
.45268 .34456 L
.45268 .34456 L
.45268 .34456 L
.45269 .34456 L
.45269 .34456 L
.4527 .34456 L
.4527 .34456 L
.45271 .34456 L
.45271 .34456 L
.45271 .34456 L
.45272 .34456 L
.45272 .34456 L
.45273 .34456 L
.45273 .34456 L
.45273 .34456 L
.45274 .34456 L
.45274 .34456 L
.45275 .34456 L
.45275 .34456 L
.45275 .34456 L
.45276 .34457 L
.45276 .34457 L
.45277 .34457 L
.45277 .34457 L
.45278 .34457 L
.45278 .34457 L
.45278 .34457 L
.45279 .34457 L
.45279 .34457 L
.4528 .34457 L
.4528 .34457 L
.4528 .34457 L
.45281 .34457 L
.45281 .34457 L
.45282 .34457 L
.45282 .34457 L
.45282 .34457 L
.45283 .34457 L
.45283 .34458 L
.45284 .34458 L
.45284 .34458 L
.45284 .34458 L
.45285 .34458 L
.45285 .34458 L
.45286 .34458 L
.45286 .34458 L
.45286 .34458 L
.45287 .34458 L
.45287 .34458 L
Mistroke
.45288 .34458 L
.45288 .34458 L
.45288 .34458 L
.45289 .34458 L
.45289 .34459 L
.45289 .34459 L
.4529 .34459 L
.4529 .34459 L
.45291 .34459 L
.45291 .34459 L
.45291 .34459 L
.45292 .34459 L
.45292 .34459 L
.45293 .34459 L
.45293 .34459 L
.45293 .34459 L
.45294 .34459 L
.45294 .34459 L
.45295 .34459 L
.45295 .3446 L
.45295 .3446 L
.45296 .3446 L
.45296 .3446 L
.45296 .3446 L
.45297 .3446 L
.45297 .3446 L
.45298 .3446 L
.45298 .3446 L
.45298 .3446 L
.45299 .3446 L
.45299 .3446 L
.453 .3446 L
.453 .34461 L
.453 .34461 L
.45301 .34461 L
.45301 .34461 L
.45301 .34461 L
.45302 .34461 L
.45302 .34461 L
.45303 .34461 L
.45303 .34461 L
.45303 .34461 L
.45304 .34461 L
.45304 .34461 L
.45304 .34461 L
.45305 .34462 L
.45305 .34462 L
.45306 .34462 L
.45306 .34462 L
.45306 .34462 L
Mistroke
.45307 .34462 L
.45307 .34462 L
.45307 .34462 L
.45308 .34462 L
.45308 .34462 L
.45309 .34462 L
.45309 .34462 L
.45309 .34463 L
.4531 .34463 L
.4531 .34463 L
.4531 .34463 L
.45311 .34463 L
.45311 .34463 L
.45311 .34463 L
.45312 .34463 L
.45312 .34463 L
.45313 .34463 L
.45313 .34463 L
.45313 .34464 L
.45314 .34464 L
.45314 .34464 L
.45314 .34464 L
.45315 .34464 L
.45315 .34464 L
.45315 .34464 L
.45316 .34464 L
.45316 .34464 L
.45317 .34464 L
.45317 .34464 L
.45317 .34465 L
.45318 .34465 L
.45318 .34465 L
.45318 .34465 L
.45319 .34465 L
.45319 .34465 L
.45319 .34465 L
.4532 .34465 L
.4532 .34465 L
.4532 .34465 L
.45321 .34466 L
.45321 .34466 L
.45321 .34466 L
.45322 .34466 L
.45322 .34466 L
.45323 .34466 L
.45323 .34466 L
.45323 .34466 L
.45324 .34466 L
.45324 .34466 L
.45324 .34466 L
Mistroke
.45325 .34467 L
.45325 .34467 L
.45325 .34467 L
.45326 .34467 L
.45326 .34467 L
.45326 .34467 L
.45327 .34467 L
.45327 .34467 L
.45327 .34467 L
.45328 .34468 L
.45328 .34468 L
.45328 .34468 L
.45329 .34468 L
.45329 .34468 L
.45329 .34468 L
.4533 .34468 L
.4533 .34468 L
.4533 .34468 L
.45331 .34468 L
.45331 .34469 L
.45331 .34469 L
.45332 .34469 L
.45332 .34469 L
.45333 .34469 L
.45333 .34469 L
.45333 .34469 L
.45334 .34469 L
.45334 .34469 L
.45334 .3447 L
.45335 .3447 L
.45335 .3447 L
.45335 .3447 L
.45336 .3447 L
.45336 .3447 L
.45336 .3447 L
.45337 .3447 L
.45337 .3447 L
.45337 .34471 L
.45338 .34471 L
.45338 .34471 L
.45338 .34471 L
.45338 .34471 L
.45339 .34471 L
.45339 .34471 L
.45339 .34471 L
.4534 .34471 L
.4534 .34472 L
.4534 .34472 L
.45341 .34472 L
.45341 .34472 L
Mistroke
.45341 .34472 L
.45342 .34472 L
.45342 .34472 L
.45342 .34472 L
.45343 .34473 L
.45343 .34473 L
.45343 .34473 L
.45344 .34473 L
.45344 .34473 L
.45344 .34473 L
.45345 .34473 L
.45345 .34473 L
.45345 .34473 L
.45346 .34474 L
.45346 .34474 L
.45346 .34474 L
.45347 .34474 L
.45347 .34474 L
.45347 .34474 L
.45348 .34474 L
.45348 .34474 L
.45348 .34475 L
.45348 .34475 L
.45349 .34475 L
.45349 .34475 L
.45349 .34475 L
.4535 .34475 L
.4535 .34475 L
.4535 .34475 L
.45351 .34476 L
.45351 .34476 L
.45351 .34476 L
.45352 .34476 L
.45352 .34476 L
.45352 .34476 L
.45353 .34476 L
.45353 .34476 L
.45353 .34477 L
.45353 .34477 L
.45354 .34477 L
.45354 .34477 L
.45354 .34477 L
.45355 .34477 L
.45355 .34477 L
.45355 .34478 L
.45356 .34478 L
.45356 .34478 L
.45356 .34478 L
.45357 .34478 L
.45357 .34478 L
Mistroke
.45357 .34478 L
.45357 .34478 L
.45358 .34479 L
.45358 .34479 L
.45358 .34479 L
.45359 .34479 L
.45359 .34479 L
.45359 .34479 L
.4536 .34479 L
.4536 .3448 L
.4536 .3448 L
.4536 .3448 L
.45361 .3448 L
.45361 .3448 L
.45361 .3448 L
.45362 .3448 L
.45362 .3448 L
.45362 .34481 L
.45362 .34481 L
.45363 .34481 L
.45363 .34481 L
.45363 .34481 L
.45364 .34481 L
.45364 .34481 L
.45364 .34482 L
.45365 .34482 L
.45365 .34482 L
.45365 .34482 L
.45365 .34482 L
.45366 .34482 L
.45366 .34482 L
.45366 .34483 L
.45367 .34483 L
.45367 .34483 L
.45367 .34483 L
.45367 .34483 L
.45368 .34483 L
.45368 .34483 L
.45368 .34484 L
.45369 .34484 L
.45369 .34484 L
.45369 .34484 L
.45369 .34484 L
.4537 .34484 L
.4537 .34484 L
.4537 .34485 L
.45371 .34485 L
.45371 .34485 L
.45371 .34485 L
.45371 .34485 L
Mistroke
.45372 .34485 L
.45372 .34485 L
.45372 .34486 L
.45372 .34486 L
.45373 .34486 L
.45373 .34486 L
.45373 .34486 L
.45374 .34486 L
.45374 .34486 L
.45374 .34487 L
.45374 .34487 L
.45375 .34487 L
.45375 .34487 L
.45375 .34487 L
.45375 .34487 L
.45376 .34488 L
.45376 .34488 L
.45376 .34488 L
.45377 .34488 L
.45377 .34488 L
.45377 .34488 L
.45377 .34488 L
.45378 .34489 L
.45378 .34489 L
.45378 .34489 L
.45378 .34489 L
.45379 .34489 L
.45379 .34489 L
.45379 .34489 L
.4538 .3449 L
.4538 .3449 L
.4538 .3449 L
.4538 .3449 L
.45381 .3449 L
.45381 .3449 L
.45381 .34491 L
.45381 .34491 L
.45382 .34491 L
.45382 .34491 L
.45382 .34491 L
.45382 .34491 L
.45383 .34492 L
.45383 .34492 L
.45383 .34492 L
.45383 .34492 L
.45384 .34492 L
.45384 .34492 L
.45384 .34492 L
.45385 .34493 L
.45385 .34493 L
Mistroke
.45385 .34493 L
.45385 .34493 L
.45386 .34493 L
.45386 .34493 L
.45386 .34494 L
.45386 .34494 L
.45387 .34494 L
.45387 .34494 L
.45387 .34494 L
.45387 .34494 L
.45388 .34495 L
.45388 .34495 L
.45388 .34495 L
.45388 .34495 L
.45389 .34495 L
.45389 .34495 L
.45389 .34496 L
.45389 .34496 L
.4539 .34496 L
.4539 .34496 L
.4539 .34496 L
.4539 .34496 L
.45391 .34497 L
.45391 .34497 L
.45391 .34497 L
.45391 .34497 L
.45392 .34497 L
.45392 .34497 L
.45392 .34498 L
.45392 .34498 L
.45393 .34498 L
.45393 .34498 L
.45393 .34498 L
.45393 .34498 L
.45393 .34499 L
.45394 .34499 L
.45394 .34499 L
.45394 .34499 L
.45394 .34499 L
.45395 .34499 L
.45395 .345 L
.45395 .345 L
.45395 .345 L
.45396 .345 L
.45396 .345 L
.45396 .345 L
.45396 .34501 L
.45397 .34501 L
.45397 .34501 L
.45397 .34501 L
Mistroke
.45397 .34501 L
.45398 .34501 L
.45398 .34502 L
.45398 .34502 L
.45398 .34502 L
.45398 .34502 L
.45399 .34502 L
.45399 .34502 L
.45399 .34503 L
.45399 .34503 L
.454 .34503 L
.454 .34503 L
.454 .34503 L
.454 .34503 L
.45401 .34504 L
.45401 .34504 L
.45401 .34504 L
.45401 .34504 L
.45401 .34504 L
.45402 .34505 L
.45402 .34505 L
.45402 .34505 L
.45402 .34505 L
.45403 .34505 L
.45403 .34505 L
.45403 .34506 L
.45403 .34506 L
.45403 .34506 L
.45404 .34506 L
.45404 .34506 L
.45404 .34506 L
.45404 .34507 L
.45405 .34507 L
.45405 .34507 L
.45405 .34507 L
.45405 .34507 L
.45405 .34508 L
.45406 .34508 L
.45406 .34508 L
.45406 .34508 L
.45406 .34508 L
.45407 .34508 L
.45407 .34509 L
.45407 .34509 L
.45407 .34509 L
.45407 .34509 L
.45408 .34509 L
.45408 .3451 L
.45408 .3451 L
.45408 .3451 L
Mistroke
.45408 .3451 L
.45409 .3451 L
.45409 .3451 L
.45409 .34511 L
.45409 .34511 L
.4541 .34511 L
.4541 .34511 L
.4541 .34511 L
.4541 .34512 L
.4541 .34512 L
.45411 .34512 L
.45411 .34512 L
.45411 .34512 L
.45411 .34512 L
.45411 .34513 L
.45412 .34513 L
.45412 .34513 L
.45412 .34513 L
.45412 .34513 L
.45412 .34514 L
.45413 .34514 L
.45413 .34514 L
.45413 .34514 L
.45413 .34514 L
.45413 .34515 L
.45414 .34515 L
.45414 .34515 L
.45414 .34515 L
.45414 .34515 L
.45414 .34515 L
.45415 .34516 L
.45415 .34516 L
.45415 .34516 L
.45415 .34516 L
.45415 .34516 L
.45416 .34517 L
.45416 .34517 L
.45416 .34517 L
.45416 .34517 L
.45416 .34517 L
.45417 .34518 L
.45417 .34518 L
.45417 .34518 L
.45417 .34518 L
.45417 .34518 L
.45418 .34518 L
.45418 .34519 L
.45418 .34519 L
.45418 .34519 L
.45418 .34519 L
Mistroke
.45419 .34519 L
.45419 .3452 L
.45419 .3452 L
.45419 .3452 L
.45419 .3452 L
.4542 .3452 L
.4542 .34521 L
.4542 .34521 L
.4542 .34521 L
.4542 .34521 L
.4542 .34521 L
.45421 .34522 L
.45421 .34522 L
.45421 .34522 L
.45421 .34522 L
.45421 .34522 L
.45422 .34523 L
.45422 .34523 L
.45422 .34523 L
.45422 .34523 L
.45422 .34523 L
.45423 .34524 L
.45423 .34524 L
.45423 .34524 L
.45423 .34524 L
.45423 .34524 L
.45423 .34525 L
.45424 .34525 L
.45424 .34525 L
.45424 .34525 L
.45424 .34525 L
.45424 .34525 L
.45425 .34526 L
.45425 .34526 L
.45425 .34526 L
.45425 .34526 L
.45425 .34526 L
.45425 .34527 L
.45426 .34527 L
.45426 .34527 L
.45426 .34527 L
.45426 .34527 L
.45426 .34528 L
.45426 .34528 L
.45427 .34528 L
.45427 .34528 L
.45427 .34528 L
.45427 .34529 L
.45427 .34529 L
.45427 .34529 L
Mistroke
.45428 .34529 L
.45428 .34529 L
.45428 .3453 L
.45428 .3453 L
.45428 .3453 L
.45429 .3453 L
.45429 .3453 L
.45429 .34531 L
.45429 .34531 L
.45429 .34531 L
.45429 .34531 L
.4543 .34532 L
.4543 .34532 L
.4543 .34532 L
.4543 .34532 L
.4543 .34532 L
.4543 .34533 L
.4543 .34533 L
.45431 .34533 L
.45431 .34533 L
.45431 .34533 L
.45431 .34534 L
.45431 .34534 L
.45431 .34534 L
.45432 .34534 L
.45432 .34534 L
.45432 .34535 L
.45432 .34535 L
.45432 .34535 L
.45432 .34535 L
.45433 .34535 L
.45433 .34536 L
.45433 .34536 L
.45433 .34536 L
.45433 .34536 L
.45433 .34536 L
.45434 .34537 L
.45434 .34537 L
.45434 .34537 L
.45434 .34537 L
.45434 .34537 L
.45434 .34538 L
.45434 .34538 L
.45435 .34538 L
.45435 .34538 L
.45435 .34539 L
.45435 .34539 L
.45435 .34539 L
.45435 .34539 L
.45436 .34539 L
Mistroke
.45436 .3454 L
.45436 .3454 L
.45436 .3454 L
.45436 .3454 L
.45436 .3454 L
.45436 .34541 L
.45437 .34541 L
.45437 .34541 L
.45437 .34541 L
.45437 .34541 L
.45437 .34542 L
.45437 .34542 L
.45437 .34542 L
.45438 .34542 L
.45438 .34542 L
.45438 .34543 L
.45438 .34543 L
.45438 .34543 L
.45438 .34543 L
.45438 .34544 L
.45439 .34544 L
.45439 .34544 L
.45439 .34544 L
.45439 .34544 L
.45439 .34545 L
.45439 .34545 L
.45439 .34545 L
.4544 .34545 L
.4544 .34545 L
.4544 .34546 L
.4544 .34546 L
.4544 .34546 L
.4544 .34546 L
.4544 .34547 L
.45441 .34547 L
.45441 .34547 L
.45441 .34547 L
.45441 .34547 L
.45441 .34548 L
.45441 .34548 L
.45441 .34548 L
.45441 .34548 L
.45442 .34548 L
.45442 .34549 L
.45442 .34549 L
.45442 .34549 L
.45442 .34549 L
.45442 .3455 L
.45442 .3455 L
.45443 .3455 L
Mistroke
.45443 .3455 L
.45443 .3455 L
.45443 .34551 L
.45443 .34551 L
.45443 .34551 L
.45443 .34551 L
.45443 .34551 L
.45444 .34552 L
.45444 .34552 L
.45444 .34552 L
.45444 .34552 L
.45444 .34553 L
.45444 .34553 L
.45444 .34553 L
.45444 .34553 L
.45445 .34553 L
.45445 .34554 L
.45445 .34554 L
.45445 .34554 L
.45445 .34554 L
.45445 .34555 L
.45445 .34555 L
.45445 .34555 L
.45446 .34555 L
.45446 .34555 L
.45446 .34556 L
.45446 .34556 L
.45446 .34556 L
.45446 .34556 L
.45446 .34556 L
.45446 .34557 L
.45447 .34557 L
.45447 .34557 L
.45447 .34557 L
.45447 .34558 L
.45447 .34558 L
.45447 .34558 L
.45447 .34558 L
.45447 .34558 L
.45447 .34559 L
.45448 .34559 L
.45448 .34559 L
.45448 .34559 L
.45448 .3456 L
.45448 .3456 L
.45448 .3456 L
.45448 .3456 L
.45448 .3456 L
.45448 .34561 L
.45449 .34561 L
Mistroke
.45449 .34561 L
.45449 .34561 L
.45449 .34562 L
.45449 .34562 L
.45449 .34562 L
.45449 .34562 L
.45449 .34562 L
.45449 .34563 L
.4545 .34563 L
.4545 .34563 L
.4545 .34563 L
.4545 .34564 L
.4545 .34564 L
.4545 .34564 L
.4545 .34564 L
.4545 .34564 L
.4545 .34565 L
.45451 .34565 L
.45451 .34565 L
.45451 .34565 L
.45451 .34566 L
.45451 .34566 L
.45451 .34566 L
.45451 .34566 L
.45451 .34566 L
.45451 .34567 L
.45451 .34567 L
.45452 .34567 L
.45452 .34567 L
.45452 .34568 L
.45452 .34568 L
.45452 .34568 L
.45452 .34568 L
.45452 .34568 L
.45452 .34569 L
.45452 .34569 L
.45452 .34569 L
.45453 .34569 L
.45453 .3457 L
.45453 .3457 L
.45453 .3457 L
.45453 .3457 L
.45453 .34571 L
.45453 .34571 L
.45453 .34571 L
.45453 .34571 L
.45453 .34571 L
.45454 .34572 L
.45454 .34572 L
.45454 .34572 L
Mistroke
.45454 .34572 L
.45454 .34573 L
.45454 .34573 L
.45454 .34573 L
.45454 .34573 L
.45454 .34573 L
.45454 .34574 L
.45454 .34574 L
.45455 .34574 L
.45455 .34574 L
.45455 .34575 L
.45455 .34575 L
.45455 .34575 L
.45455 .34575 L
.45455 .34576 L
.45455 .34576 L
.45455 .34576 L
.45455 .34576 L
.45455 .34576 L
.45455 .34577 L
.45456 .34577 L
.45456 .34577 L
.45456 .34577 L
.45456 .34578 L
.45456 .34578 L
.45456 .34578 L
.45456 .34578 L
.45456 .34578 L
.45456 .34579 L
.45456 .34579 L
.45456 .34579 L
.45456 .34579 L
.45457 .3458 L
.45457 .3458 L
.45457 .3458 L
.45457 .3458 L
.45457 .34581 L
.45457 .34581 L
.45457 .34581 L
.45457 .34581 L
.45457 .34581 L
.45457 .34582 L
.45457 .34582 L
.45457 .34582 L
.45458 .34582 L
.45458 .34583 L
.45458 .34583 L
.45458 .34583 L
.45458 .34583 L
.45458 .34584 L
Mistroke
.45458 .34584 L
.45458 .34584 L
.45458 .34584 L
.45458 .34584 L
.45458 .34585 L
.45458 .34585 L
.45458 .34585 L
.45458 .34585 L
.45459 .34586 L
.45459 .34586 L
.45459 .34586 L
.45459 .34586 L
.45459 .34587 L
.45459 .34587 L
.45459 .34587 L
.45459 .34587 L
.45459 .34587 L
.45459 .34588 L
.45459 .34588 L
.45459 .34588 L
.45459 .34588 L
.45459 .34589 L
.4546 .34589 L
.4546 .34589 L
.4546 .34589 L
.4546 .3459 L
.4546 .3459 L
.4546 .3459 L
.4546 .3459 L
.4546 .3459 L
.4546 .34591 L
.4546 .34591 L
.4546 .34591 L
.4546 .34591 L
.4546 .34592 L
.4546 .34592 L
.4546 .34592 L
.4546 .34592 L
.45461 .34593 L
.45461 .34593 L
.45461 .34593 L
.45461 .34593 L
.45461 .34594 L
.45461 .34594 L
.45461 .34594 L
.45461 .34594 L
.45461 .34594 L
.45461 .34595 L
.45461 .34595 L
.45461 .34595 L
Mistroke
.45461 .34595 L
.45461 .34596 L
.45461 .34596 L
.45461 .34596 L
.45461 .34596 L
.45462 .34597 L
.45462 .34597 L
.45462 .34597 L
.45462 .34597 L
.45462 .34598 L
.45462 .34598 L
.45462 .34598 L
.45462 .34598 L
.45462 .34598 L
.45462 .34599 L
.45462 .34599 L
.45462 .34599 L
.45462 .34599 L
.45462 .346 L
.45462 .346 L
.45462 .346 L
.45462 .346 L
.45462 .34601 L
.45462 .34601 L
.45463 .34601 L
.45463 .34601 L
.45463 .34602 L
.45463 .34602 L
.45463 .34602 L
.45463 .34602 L
.45463 .34602 L
.45463 .34603 L
.45463 .34603 L
.45463 .34603 L
.45463 .34603 L
.45463 .34604 L
.45463 .34604 L
.45463 .34604 L
.45463 .34604 L
.45463 .34605 L
.45463 .34605 L
.45463 .34605 L
.45463 .34605 L
.45463 .34606 L
.45463 .34606 L
.45463 .34606 L
.45464 .34606 L
.45464 .34606 L
.45464 .34607 L
.45464 .34607 L
Mistroke
.45464 .34607 L
.45464 .34607 L
.45464 .34608 L
.45464 .34608 L
.45464 .34608 L
.45464 .34608 L
.45464 .34609 L
.45464 .34609 L
.45464 .34609 L
.45464 .34609 L
.45464 .3461 L
.45464 .3461 L
.45464 .3461 L
.45464 .3461 L
.45464 .3461 L
.45464 .34611 L
.45464 .34611 L
.45464 .34611 L
.45464 .34611 L
.45464 .34612 L
.45464 .34612 L
.45464 .34612 L
.45464 .34612 L
.45465 .34613 L
.45465 .34613 L
.45465 .34613 L
.45465 .34613 L
.45465 .34614 L
.45465 .34614 L
.45465 .34614 L
.45465 .34614 L
.45465 .34615 L
.45465 .34615 L
.45465 .34615 L
.45465 .34615 L
.45465 .34615 L
.45465 .34616 L
.45465 .34616 L
.45465 .34616 L
.45465 .34616 L
.45465 .34617 L
.45465 .34617 L
.45465 .34617 L
.45465 .34617 L
.45465 .34618 L
.45465 .34618 L
.45465 .34618 L
.45465 .34618 L
.45465 .34619 L
.45465 .34619 L
Mistroke
.45465 .34619 L
.45465 .34619 L
.45465 .3462 L
.45465 .3462 L
.45465 .3462 L
.45465 .3462 L
.45465 .3462 L
.45465 .34621 L
.45465 .34621 L
.45465 .34621 L
.45465 .34621 L
.45466 .34622 L
.45466 .34622 L
.45466 .34622 L
.45466 .34622 L
.45466 .34623 L
.45466 .34623 L
.45466 .34623 L
.45466 .34623 L
.45466 .34624 L
.45466 .34624 L
.45466 .34624 L
.45466 .34624 L
.45466 .34625 L
.45466 .34625 L
.45466 .34625 L
.45466 .34625 L
.45466 .34625 L
.45466 .34626 L
.45466 .34626 L
.45466 .34626 L
.45466 .34626 L
.45466 .34627 L
.45466 .34627 L
.45466 .34627 L
.45466 .34627 L
.45466 .34628 L
.45466 .34628 L
.45466 .34628 L
.45466 .34628 L
.45466 .34629 L
.45466 .34629 L
.45466 .34629 L
.45466 .34629 L
.45466 .3463 L
.45466 .3463 L
.45466 .3463 L
.45466 .3463 L
.45466 .34631 L
.45466 .34631 L
Mistroke
.45466 .34631 L
.45466 .34631 L
.45466 .34631 L
.45466 .34632 L
.45466 .34632 L
.45466 .34632 L
.45466 .34632 L
.45466 .34633 L
.45466 .34633 L
.45466 .34633 L
.45466 .34633 L
.45466 .34634 L
.45466 .34634 L
.45466 .34634 L
.45466 .34634 L
.45466 .34635 L
.45466 .34635 L
.45466 .34635 L
.45466 .34635 L
.45466 .34636 L
.45466 .34636 L
.45466 .34636 L
.45466 .34636 L
.45466 .34636 L
.45466 .34637 L
.45466 .34637 L
.45466 .34637 L
.45466 .34637 L
.45466 .34638 L
.45466 .34638 L
.45466 .34638 L
.45466 .34638 L
.45466 .34639 L
.45466 .34639 L
.45466 .34639 L
.45466 .34639 L
.45466 .3464 L
.45466 .3464 L
.45466 .3464 L
.45466 .3464 L
.45466 .34641 L
.45466 .34641 L
.45466 .34641 L
.45466 .34641 L
.45466 .34642 L
.45466 .34642 L
.45466 .34642 L
.45466 .34642 L
.45466 .34642 L
.45466 .34643 L
Mistroke
.45466 .34643 L
.45466 .34643 L
.45466 .34643 L
.45466 .34644 L
.45466 .34644 L
.45466 .34644 L
.45466 .34644 L
.45466 .34645 L
.45466 .34645 L
.45466 .34645 L
.45466 .34645 L
.45466 .34646 L
.45466 .34646 L
.45466 .34646 L
.45466 .34646 L
.45466 .34647 L
.45466 .34647 L
.45466 .34647 L
.45466 .34647 L
.45466 .34647 L
.45466 .34648 L
.45466 .34648 L
.45466 .34648 L
.45466 .34648 L
.45466 .34649 L
.45466 .34649 L
.45466 .34649 L
.45466 .34649 L
.45466 .3465 L
.45466 .3465 L
.45466 .3465 L
.45466 .3465 L
.45466 .34651 L
.45466 .34651 L
.45466 .34651 L
.45466 .34651 L
.45466 .34652 L
.45466 .34652 L
.45466 .34652 L
.45466 .34652 L
.45466 .34653 L
.45466 .34653 L
.45466 .34653 L
.45466 .34653 L
.45466 .34653 L
.45466 .34654 L
.45466 .34654 L
.45466 .34654 L
.45466 .34654 L
.45466 .34655 L
Mistroke
.45465 .34655 L
.45465 .34655 L
.45465 .34655 L
.45465 .34656 L
.45465 .34656 L
.45465 .34656 L
.45465 .34656 L
.45465 .34657 L
.45465 .34657 L
.45465 .34657 L
.45465 .34657 L
.45465 .34658 L
.45465 .34658 L
.45465 .34658 L
.45465 .34658 L
.45465 .34658 L
.45465 .34659 L
.45465 .34659 L
.45465 .34659 L
.45465 .34659 L
.45465 .3466 L
.45465 .3466 L
.45465 .3466 L
.45465 .3466 L
.45465 .34661 L
.45465 .34661 L
.45465 .34661 L
.45465 .34661 L
.45465 .34662 L
.45465 .34662 L
.45465 .34662 L
.45465 .34662 L
.45465 .34663 L
.45465 .34663 L
.45465 .34663 L
.45465 .34663 L
.45465 .34663 L
.45465 .34664 L
.45465 .34664 L
.45464 .34664 L
.45464 .34664 L
.45464 .34665 L
.45464 .34665 L
.45464 .34665 L
.45464 .34665 L
.45464 .34666 L
.45464 .34666 L
.45464 .34666 L
.45464 .34666 L
.45464 .34667 L
Mistroke
.45464 .34667 L
.45464 .34667 L
.45464 .34667 L
.45464 .34668 L
.45464 .34668 L
.45464 .34668 L
.45464 .34668 L
.45464 .34668 L
.45464 .34669 L
.45464 .34669 L
.45464 .34669 L
.45464 .34669 L
.45464 .3467 L
.45464 .3467 L
.45464 .3467 L
.45464 .3467 L
.45464 .34671 L
.45464 .34671 L
.45464 .34671 L
.45463 .34671 L
.45463 .34672 L
.45463 .34672 L
.45463 .34672 L
.45463 .34672 L
.45463 .34672 L
.45463 .34673 L
.45463 .34673 L
.45463 .34673 L
.45463 .34673 L
.45463 .34674 L
.45463 .34674 L
.45463 .34674 L
.45463 .34674 L
.45463 .34675 L
.45463 .34675 L
.45463 .34675 L
.45463 .34675 L
.45463 .34676 L
.45463 .34676 L
.45463 .34676 L
.45463 .34676 L
.45463 .34677 L
.45463 .34677 L
.45462 .34677 L
.45462 .34677 L
.45462 .34677 L
.45462 .34678 L
.45462 .34678 L
.45462 .34678 L
.45462 .34678 L
Mistroke
.45462 .34679 L
.45462 .34679 L
.45462 .34679 L
.45462 .34679 L
.45462 .3468 L
.45462 .3468 L
.45462 .3468 L
.45462 .3468 L
.45462 .34681 L
.45462 .34681 L
.45462 .34681 L
.45462 .34681 L
.45462 .34681 L
.45462 .34682 L
.45462 .34682 L
.45461 .34682 L
.45461 .34682 L
.45461 .34683 L
.45461 .34683 L
.45461 .34683 L
.45461 .34683 L
.45461 .34684 L
.45461 .34684 L
.45461 .34684 L
.45461 .34684 L
.45461 .34685 L
.45461 .34685 L
.45461 .34685 L
.45461 .34685 L
.45461 .34685 L
.45461 .34686 L
.45461 .34686 L
.45461 .34686 L
.45461 .34686 L
.4546 .34687 L
.4546 .34687 L
.4546 .34687 L
.4546 .34687 L
.4546 .34688 L
.4546 .34688 L
.4546 .34688 L
.4546 .34688 L
.4546 .34688 L
.4546 .34689 L
.4546 .34689 L
.4546 .34689 L
.4546 .34689 L
.4546 .3469 L
.4546 .3469 L
.4546 .3469 L
Mistroke
.4546 .3469 L
.4546 .34691 L
.45459 .34691 L
.45459 .34691 L
.45459 .34691 L
.45459 .34692 L
.45459 .34692 L
.45459 .34692 L
.45459 .34692 L
.45459 .34692 L
.45459 .34693 L
.45459 .34693 L
.45459 .34693 L
.45459 .34693 L
.45459 .34694 L
.45459 .34694 L
.45459 .34694 L
.45459 .34694 L
.45459 .34695 L
.45458 .34695 L
.45458 .34695 L
.45458 .34695 L
.45458 .34695 L
.45458 .34696 L
.45458 .34696 L
.45458 .34696 L
.45458 .34696 L
.45458 .34697 L
.45458 .34697 L
.45458 .34697 L
.45458 .34697 L
.45458 .34698 L
.45458 .34698 L
.45458 .34698 L
.45457 .34698 L
.45457 .34698 L
.45457 .34699 L
.45457 .34699 L
.45457 .34699 L
.45457 .34699 L
.45457 .347 L
.45457 .347 L
.45457 .347 L
.45457 .347 L
.45457 .34701 L
.45457 .34701 L
.45457 .34701 L
.45457 .34701 L
.45457 .34701 L
.45456 .34702 L
Mistroke
.45456 .34702 L
.45456 .34702 L
.45456 .34702 L
.45456 .34703 L
.45456 .34703 L
.45456 .34703 L
.45456 .34703 L
.45456 .34704 L
.45456 .34704 L
.45456 .34704 L
.45456 .34704 L
.45456 .34704 L
.45456 .34705 L
.45456 .34705 L
.45455 .34705 L
.45455 .34705 L
.45455 .34706 L
.45455 .34706 L
.45455 .34706 L
.45455 .34706 L
.45455 .34707 L
.45455 .34707 L
.45455 .34707 L
.45455 .34707 L
.45455 .34707 L
.45455 .34708 L
.45455 .34708 L
.45454 .34708 L
.45454 .34708 L
.45454 .34709 L
.45454 .34709 L
.45454 .34709 L
.45454 .34709 L
.45454 .34709 L
.45454 .3471 L
.45454 .3471 L
.45454 .3471 L
.45454 .3471 L
.45454 .34711 L
.45454 .34711 L
.45453 .34711 L
.45453 .34711 L
.45453 .34712 L
.45453 .34712 L
.45453 .34712 L
.45453 .34712 L
.45453 .34712 L
.45453 .34713 L
.45453 .34713 L
.45453 .34713 L
Mistroke
.45453 .34713 L
.45453 .34714 L
.45453 .34714 L
.45452 .34714 L
.45452 .34714 L
.45452 .34714 L
.45452 .34715 L
.45452 .34715 L
.45452 .34715 L
.45452 .34715 L
.45452 .34716 L
.45452 .34716 L
.45452 .34716 L
.45452 .34716 L
.45452 .34717 L
.45452 .34717 L
.45451 .34717 L
.45451 .34717 L
.45451 .34717 L
.45451 .34718 L
.45451 .34718 L
.45451 .34718 L
.45451 .34718 L
.45451 .34719 L
.45451 .34719 L
.45451 .34719 L
.45451 .34719 L
.45451 .34719 L
.4545 .3472 L
.4545 .3472 L
.4545 .3472 L
.4545 .3472 L
.4545 .34721 L
.4545 .34721 L
.4545 .34721 L
.4545 .34721 L
.4545 .34721 L
.4545 .34722 L
.4545 .34722 L
.45449 .34722 L
.45449 .34722 L
.45449 .34723 L
.45449 .34723 L
.45449 .34723 L
.45449 .34723 L
.45449 .34723 L
.45449 .34724 L
.45449 .34724 L
.45449 .34724 L
.45449 .34724 L
Mistroke
.45449 .34725 L
.45448 .34725 L
.45448 .34725 L
.45448 .34725 L
.45448 .34725 L
.45448 .34726 L
.45448 .34726 L
.45448 .34726 L
.45448 .34726 L
.45448 .34727 L
.45448 .34727 L
.45448 .34727 L
.45447 .34727 L
.45447 .34727 L
.45447 .34728 L
.45447 .34728 L
.45447 .34728 L
.45447 .34728 L
.45447 .34729 L
.45447 .34729 L
.45447 .34729 L
.45447 .34729 L
.45447 .34729 L
.45446 .3473 L
.45446 .3473 L
.45446 .3473 L
.45446 .3473 L
.45446 .34731 L
.45446 .34731 L
.45446 .34731 L
.45446 .34731 L
.45446 .34731 L
.45446 .34732 L
.45445 .34732 L
.45445 .34732 L
.45445 .34732 L
.45445 .34733 L
.45445 .34733 L
.45445 .34733 L
.45445 .34733 L
.45445 .34733 L
.45445 .34734 L
.45445 .34734 L
.45445 .34734 L
.45444 .34734 L
.45444 .34735 L
.45444 .34735 L
.45444 .34735 L
.45444 .34735 L
.45444 .34735 L
Mistroke
.45444 .34736 L
.45444 .34736 L
.45444 .34736 L
.45444 .34736 L
.45443 .34736 L
.45443 .34737 L
.45443 .34737 L
.45443 .34737 L
.45443 .34737 L
.45443 .34738 L
.45443 .34738 L
.45443 .34738 L
.45443 .34738 L
.45443 .34738 L
.45442 .34739 L
.45442 .34739 L
.45442 .34739 L
.45442 .34739 L
.45442 .3474 L
.45442 .3474 L
.45442 .3474 L
.45442 .3474 L
.45442 .3474 L
.45442 .34741 L
.45441 .34741 L
.45441 .34741 L
.45441 .34741 L
.45441 .34741 L
.45441 .34742 L
.45441 .34742 L
.45441 .34742 L
.45441 .34742 L
.45441 .34743 L
.45441 .34743 L
.4544 .34743 L
.4544 .34743 L
.4544 .34743 L
.4544 .34744 L
.4544 .34744 L
.4544 .34744 L
.4544 .34744 L
.4544 .34744 L
.4544 .34745 L
.4544 .34745 L
.45439 .34745 L
.45439 .34745 L
.45439 .34746 L
.45439 .34746 L
.45439 .34746 L
.45439 .34746 L
Mistroke
.45439 .34746 L
.45439 .34747 L
.45439 .34747 L
.45438 .34747 L
.45438 .34747 L
.45438 .34747 L
.45438 .34748 L
.45438 .34748 L
.45438 .34748 L
.45438 .34748 L
.45438 .34749 L
.45438 .34749 L
.45437 .34749 L
.45437 .34749 L
.45437 .34749 L
.45437 .3475 L
.45437 .3475 L
.45437 .3475 L
.45437 .3475 L
.45437 .3475 L
.45437 .34751 L
.45437 .34751 L
.45436 .34751 L
.45436 .34751 L
.45436 .34751 L
.45436 .34752 L
.45436 .34752 L
.45436 .34752 L
.45436 .34752 L
.45436 .34753 L
.45436 .34753 L
.45435 .34753 L
.45435 .34753 L
.45435 .34753 L
.45435 .34754 L
.45435 .34754 L
.45435 .34754 L
.45435 .34754 L
.45435 .34754 L
.45435 .34755 L
.45434 .34755 L
.45434 .34755 L
.45434 .34755 L
.45434 .34755 L
.45434 .34756 L
.45434 .34756 L
.45434 .34756 L
.45434 .34756 L
.45434 .34757 L
.45433 .34757 L
Mistroke
.45433 .34757 L
.45433 .34757 L
.45433 .34757 L
.45433 .34758 L
.45433 .34758 L
.45433 .34758 L
.45433 .34758 L
.45432 .34758 L
.45432 .34759 L
.45432 .34759 L
.45432 .34759 L
.45432 .34759 L
.45432 .34759 L
.45432 .3476 L
.45432 .3476 L
.45432 .3476 L
.45431 .3476 L
.45431 .3476 L
.45431 .34761 L
.45431 .34761 L
.45431 .34761 L
.45431 .34761 L
.45431 .34761 L
.45431 .34762 L
.45431 .34762 L
.4543 .34762 L
.4543 .34762 L
.4543 .34763 L
.4543 .34763 L
.4543 .34763 L
.4543 .34763 L
.4543 .34763 L
.4543 .34764 L
.45429 .34764 L
.45429 .34764 L
.45429 .34764 L
.45429 .34764 L
.45429 .34765 L
.45429 .34765 L
.45429 .34765 L
.45429 .34765 L
.45429 .34765 L
.45428 .34766 L
.45428 .34766 L
.45428 .34766 L
.45428 .34766 L
.45428 .34766 L
.45428 .34767 L
.45428 .34767 L
.45428 .34767 L
Mistroke
.45427 .34767 L
.45427 .34767 L
.45427 .34768 L
.45427 .34768 L
.45427 .34768 L
.45427 .34768 L
.45427 .34768 L
.45427 .34769 L
.45426 .34769 L
.45426 .34769 L
.45426 .34769 L
.45426 .34769 L
.45426 .3477 L
.45426 .3477 L
.45426 .3477 L
.45426 .3477 L
.45426 .3477 L
.45425 .34771 L
.45425 .34771 L
.45425 .34771 L
.45425 .34771 L
.45425 .34771 L
.45425 .34772 L
.45425 .34772 L
.45425 .34772 L
.45424 .34772 L
.45424 .34772 L
.45424 .34773 L
.45424 .34773 L
.45424 .34773 L
.45424 .34773 L
.45424 .34773 L
.45424 .34774 L
.45423 .34774 L
.45423 .34774 L
.45423 .34774 L
.45423 .34774 L
.45423 .34775 L
.45423 .34775 L
.45423 .34775 L
.45423 .34775 L
.45422 .34775 L
.45422 .34776 L
.45422 .34776 L
.45422 .34776 L
.45422 .34776 L
.45422 .34776 L
.45422 .34777 L
.45422 .34777 L
.45421 .34777 L
Mistroke
.45421 .34777 L
.45421 .34777 L
.45421 .34778 L
.45421 .34778 L
.45421 .34778 L
.45421 .34778 L
.45421 .34778 L
.4542 .34779 L
.4542 .34779 L
.4542 .34779 L
.4542 .34779 L
.4542 .34779 L
.4542 .3478 L
.4542 .3478 L
.4542 .3478 L
.45419 .3478 L
.45419 .3478 L
.45419 .3478 L
.45419 .34781 L
.45419 .34781 L
.45419 .34781 L
.45419 .34781 L
.45418 .34781 L
.45418 .34782 L
.45418 .34782 L
.45418 .34782 L
.45418 .34782 L
.45418 .34782 L
.45418 .34783 L
.45418 .34783 L
.45417 .34783 L
.45417 .34783 L
.45417 .34783 L
.45417 .34784 L
.45417 .34784 L
.45417 .34784 L
.45417 .34784 L
.45417 .34784 L
.45416 .34785 L
.45416 .34785 L
.45416 .34785 L
.45416 .34785 L
.45416 .34785 L
.45416 .34786 L
.45416 .34786 L
.45416 .34786 L
.45415 .34786 L
.45415 .34786 L
.45415 .34786 L
.45415 .34787 L
Mistroke
.45415 .34787 L
.45415 .34787 L
.45415 .34787 L
.45414 .34787 L
.45414 .34788 L
.45414 .34788 L
.45414 .34788 L
.45414 .34788 L
.45414 .34788 L
.45414 .34789 L
.45414 .34789 L
.45413 .34789 L
.45413 .34789 L
.45413 .34789 L
.45413 .34789 L
.45413 .3479 L
.45413 .3479 L
.45413 .3479 L
.45412 .3479 L
.45412 .3479 L
.45412 .34791 L
.45412 .34791 L
.45412 .34791 L
.45412 .34791 L
.45412 .34791 L
.45412 .34792 L
.45411 .34792 L
.45411 .34792 L
.45411 .34792 L
.45411 .34792 L
.45411 .34792 L
.45411 .34793 L
.45411 .34793 L
.4541 .34793 L
.4541 .34793 L
.4541 .34793 L
.4541 .34794 L
.4541 .34794 L
.4541 .34794 L
.4541 .34794 L
.4541 .34794 L
.45409 .34795 L
.45409 .34795 L
.45409 .34795 L
.45409 .34795 L
.45409 .34795 L
.45409 .34795 L
.45409 .34796 L
.45408 .34796 L
.45408 .34796 L
Mistroke
.45408 .34796 L
.45408 .34796 L
.45408 .34797 L
.45408 .34797 L
.45408 .34797 L
.45407 .34797 L
.45407 .34797 L
.45407 .34797 L
.45407 .34798 L
.45407 .34798 L
.45407 .34798 L
.45407 .34798 L
.45407 .34798 L
.45406 .34799 L
.45406 .34799 L
.45406 .34799 L
.45406 .34799 L
.45406 .34799 L
.45406 .34799 L
.45406 .348 L
.45405 .348 L
.45405 .348 L
.45405 .348 L
.45405 .348 L
.45405 .34801 L
.45405 .34801 L
.45405 .34801 L
.45404 .34801 L
.45404 .34801 L
.45404 .34801 L
.45404 .34802 L
.45404 .34802 L
.45404 .34802 L
.45404 .34802 L
.45403 .34802 L
.45403 .34803 L
.45403 .34803 L
.45403 .34803 L
.45403 .34803 L
.45403 .34803 L
.45403 .34803 L
.45402 .34804 L
.45402 .34804 L
.45402 .34804 L
.45402 .34804 L
.45402 .34804 L
.45402 .34804 L
.45402 .34805 L
.45401 .34805 L
.45401 .34805 L
Mistroke
.45401 .34805 L
.45401 .34805 L
.45401 .34806 L
.45401 .34806 L
.45401 .34806 L
.45401 .34806 L
.454 .34806 L
.454 .34806 L
.454 .34807 L
.454 .34807 L
.454 .34807 L
.454 .34807 L
.454 .34807 L
.45399 .34807 L
.45399 .34808 L
.45399 .34808 L
.45399 .34808 L
.45399 .34808 L
.45399 .34808 L
.45399 .34809 L
.45398 .34809 L
.45398 .34809 L
.45398 .34809 L
.45398 .34809 L
.45398 .34809 L
.45398 .3481 L
.45398 .3481 L
.45397 .3481 L
.45397 .3481 L
.45397 .3481 L
.45397 .3481 L
.45397 .34811 L
.45397 .34811 L
.45397 .34811 L
.45396 .34811 L
.45396 .34811 L
.45396 .34811 L
.45396 .34812 L
.45396 .34812 L
.45396 .34812 L
.45396 .34812 L
.45395 .34812 L
.45395 .34813 L
.45395 .34813 L
.45395 .34813 L
.45395 .34813 L
.45395 .34813 L
.45395 .34813 L
.45394 .34814 L
.45394 .34814 L
Mistroke
.45394 .34814 L
.45394 .34814 L
.45394 .34814 L
.45394 .34814 L
.45394 .34815 L
.45393 .34815 L
.45393 .34815 L
.45393 .34815 L
.45393 .34815 L
.45393 .34815 L
.45393 .34816 L
.45392 .34816 L
.45392 .34816 L
.45392 .34816 L
.45392 .34816 L
.45392 .34816 L
.45392 .34817 L
.45392 .34817 L
.45391 .34817 L
.45391 .34817 L
.45391 .34817 L
.45391 .34817 L
.45391 .34818 L
.45391 .34818 L
.45391 .34818 L
.4539 .34818 L
.4539 .34818 L
.4539 .34818 L
.4539 .34819 L
.4539 .34819 L
.4539 .34819 L
.4539 .34819 L
.45389 .34819 L
.45389 .34819 L
.45389 .3482 L
.45389 .3482 L
.45389 .3482 L
.45389 .3482 L
.45389 .3482 L
.45388 .3482 L
.45388 .34821 L
.45388 .34821 L
.45388 .34821 L
.45388 .34821 L
.45388 .34821 L
.45388 .34821 L
.45387 .34822 L
.45387 .34822 L
.45387 .34822 L
.45387 .34822 L
Mistroke
.45387 .34822 L
.45387 .34822 L
.45387 .34823 L
.45386 .34823 L
.45386 .34823 L
.45386 .34823 L
.45386 .34823 L
.45386 .34823 L
.45386 .34823 L
.45385 .34824 L
.45385 .34824 L
.45385 .34824 L
.45385 .34824 L
.45385 .34824 L
.45385 .34824 L
.45385 .34825 L
.45384 .34825 L
.45384 .34825 L
.45384 .34825 L
.45384 .34825 L
.45384 .34825 L
.45384 .34826 L
.45384 .34826 L
.45383 .34826 L
.45383 .34826 L
.45383 .34826 L
.45383 .34826 L
.45383 .34827 L
.45383 .34827 L
.45383 .34827 L
.45382 .34827 L
.45382 .34827 L
.45382 .34827 L
.45382 .34827 L
.45382 .34828 L
.45382 .34828 L
.45381 .34828 L
.45381 .34828 L
.45381 .34828 L
.45381 .34828 L
.45381 .34829 L
.45381 .34829 L
.45381 .34829 L
.4538 .34829 L
.4538 .34829 L
.4538 .34829 L
.4538 .3483 L
.4538 .3483 L
.4538 .3483 L
.4538 .3483 L
Mistroke
.45379 .3483 L
.45379 .3483 L
.45379 .3483 L
.45379 .34831 L
.45379 .34831 L
.45379 .34831 L
.45378 .34831 L
.45378 .34831 L
.45378 .34831 L
.45378 .34832 L
.45378 .34832 L
.45378 .34832 L
.45378 .34832 L
.45377 .34832 L
.45377 .34832 L
.45377 .34832 L
.45377 .34833 L
.45377 .34833 L
.45377 .34833 L
.45377 .34833 L
.45376 .34833 L
.45376 .34833 L
.45376 .34834 L
.45376 .34834 L
.45376 .34834 L
.45376 .34834 L
.45375 .34834 L
.45375 .34834 L
.45375 .34834 L
.45375 .34835 L
.45375 .34835 L
.45375 .34835 L
.45375 .34835 L
.45374 .34835 L
.45374 .34835 L
.45374 .34836 L
.45374 .34836 L
.45374 .34836 L
.45374 .34836 L
.45374 .34836 L
.45373 .34836 L
.45373 .34836 L
.45373 .34837 L
.45373 .34837 L
.45373 .34837 L
.45373 .34837 L
.45372 .34837 L
.45372 .34837 L
.45372 .34837 L
.45372 .34838 L
Mistroke
.45372 .34838 L
.45372 .34838 L
.45372 .34838 L
.45371 .34838 L
.45371 .34838 L
.45371 .34839 L
.45371 .34839 L
.45371 .34839 L
.45371 .34839 L
.4537 .34839 L
.4537 .34839 L
.4537 .34839 L
.4537 .3484 L
.4537 .3484 L
.4537 .3484 L
.4537 .3484 L
.45369 .3484 L
.45369 .3484 L
.45369 .3484 L
.45369 .34841 L
.45369 .34841 L
.45369 .34841 L
.45369 .34841 L
.45368 .34841 L
.45368 .34841 L
.45368 .34841 L
.45368 .34842 L
.45368 .34842 L
.45368 .34842 L
.45367 .34842 L
.45367 .34842 L
.45367 .34842 L
.45367 .34842 L
.45367 .34843 L
.45367 .34843 L
.45367 .34843 L
.45366 .34843 L
.45366 .34843 L
.45366 .34843 L
.45366 .34843 L
.45366 .34844 L
.45366 .34844 L
.45365 .34844 L
.45365 .34844 L
.45365 .34844 L
.45365 .34844 L
.45365 .34844 L
.45365 .34845 L
.45365 .34845 L
.45364 .34845 L
Mistroke
.45364 .34845 L
.45364 .34845 L
.45364 .34845 L
.45364 .34845 L
.45364 .34846 L
.45363 .34846 L
.45363 .34846 L
.45363 .34846 L
.45363 .34846 L
.45363 .34846 L
.45363 .34846 L
.45363 .34847 L
.45362 .34847 L
.45362 .34847 L
.45362 .34847 L
.45362 .34847 L
.45362 .34847 L
.45362 .34847 L
.45361 .34848 L
.45361 .34848 L
.45361 .34848 L
.45361 .34848 L
.45361 .34848 L
.45361 .34848 L
.45361 .34848 L
.4536 .34848 L
.4536 .34849 L
.4536 .34849 L
.4536 .34849 L
.4536 .34849 L
.4536 .34849 L
.45359 .34849 L
.45359 .34849 L
.45359 .3485 L
.45359 .3485 L
.45359 .3485 L
.45359 .3485 L
.45359 .3485 L
.45358 .3485 L
.45358 .3485 L
.45358 .34851 L
.45358 .34851 L
.45358 .34851 L
.45358 .34851 L
.45357 .34851 L
.45357 .34851 L
.45357 .34851 L
.45357 .34851 L
.45357 .34852 L
.45357 .34852 L
Mistroke
.45357 .34852 L
.45356 .34852 L
.45356 .34852 L
.45356 .34852 L
.45356 .34852 L
.45356 .34853 L
.45356 .34853 L
.45355 .34853 L
.45355 .34853 L
.45355 .34853 L
.45355 .34853 L
.45355 .34853 L
.45355 .34853 L
.45355 .34854 L
.45354 .34854 L
.45354 .34854 L
.45354 .34854 L
.45354 .34854 L
.45354 .34854 L
.45354 .34854 L
.45353 .34855 L
.45353 .34855 L
.45353 .34855 L
.45353 .34855 L
.45353 .34855 L
.45353 .34855 L
.45353 .34855 L
.45352 .34855 L
.45352 .34856 L
.45352 .34856 L
.45352 .34856 L
.45352 .34856 L
.45352 .34856 L
.45351 .34856 L
.45351 .34856 L
.45351 .34856 L
.45351 .34857 L
.45351 .34857 L
.45351 .34857 L
.45351 .34857 L
.4535 .34857 L
.4535 .34857 L
.4535 .34857 L
.4535 .34857 L
.4535 .34858 L
.4535 .34858 L
.45349 .34858 L
.45349 .34858 L
.45349 .34858 L
.45349 .34858 L
Mistroke
.45349 .34858 L
.45349 .34858 L
.45349 .34859 L
.45348 .34859 L
.45348 .34859 L
.45348 .34859 L
.45348 .34859 L
.45348 .34859 L
.45348 .34859 L
.45347 .34859 L
.45347 .3486 L
.45347 .3486 L
.45347 .3486 L
.45347 .3486 L
.45347 .3486 L
.45347 .3486 L
.45346 .3486 L
.45346 .3486 L
.45346 .34861 L
.45346 .34861 L
.45346 .34861 L
.45346 .34861 L
.45345 .34861 L
.45345 .34861 L
.45345 .34861 L
.45345 .34861 L
.45345 .34862 L
.45345 .34862 L
.45345 .34862 L
.45344 .34862 L
.45344 .34862 L
.45344 .34862 L
.45344 .34862 L
.45344 .34862 L
.45344 .34863 L
.45343 .34863 L
.45343 .34863 L
.45343 .34863 L
.45343 .34863 L
.45343 .34863 L
.45343 .34863 L
.45343 .34863 L
.45342 .34864 L
.45342 .34864 L
.45342 .34864 L
.45342 .34864 L
.45342 .34864 L
.45342 .34864 L
.45341 .34864 L
.45341 .34864 L
Mistroke
.45341 .34864 L
.45341 .34865 L
.45341 .34865 L
.45341 .34865 L
.45341 .34865 L
.4534 .34865 L
.4534 .34865 L
.4534 .34865 L
.4534 .34865 L
.4534 .34866 L
.4534 .34866 L
.45339 .34866 L
.45339 .34866 L
.45339 .34866 L
.45339 .34866 L
.45339 .34866 L
.45339 .34866 L
.45339 .34866 L
.45338 .34867 L
.45338 .34867 L
.45338 .34867 L
.45338 .34867 L
.45338 .34867 L
.45338 .34867 L
.45337 .34867 L
.45337 .34867 L
.45337 .34868 L
.45337 .34868 L
.45337 .34868 L
.45337 .34868 L
.45337 .34868 L
.45336 .34868 L
.45336 .34868 L
.45336 .34868 L
.45336 .34868 L
.45336 .34869 L
.45336 .34869 L
.45335 .34869 L
.45335 .34869 L
.45335 .34869 L
.45335 .34869 L
.45335 .34869 L
.45335 .34869 L
.45335 .34869 L
.45334 .3487 L
.45334 .3487 L
.45334 .3487 L
.45334 .3487 L
.45334 .3487 L
.45334 .3487 L
Mistroke
.45334 .3487 L
.45333 .3487 L
.45333 .3487 L
.45333 .34871 L
.45333 .34871 L
.45333 .34871 L
.45333 .34871 L
.45332 .34871 L
.45332 .34871 L
.45332 .34871 L
.45332 .34871 L
.45332 .34871 L
.45332 .34872 L
.45332 .34872 L
.45331 .34872 L
.45331 .34872 L
.45331 .34872 L
.45331 .34872 L
.45331 .34872 L
.45331 .34872 L
.4533 .34872 L
.4533 .34873 L
.4533 .34873 L
.4533 .34873 L
.4533 .34873 L
.4533 .34873 L
.4533 .34873 L
.45329 .34873 L
.45329 .34873 L
.45329 .34873 L
.45329 .34873 L
.45329 .34874 L
.45329 .34874 L
.45328 .34874 L
.45328 .34874 L
.45328 .34874 L
.45328 .34874 L
.45328 .34874 L
.45328 .34874 L
.45328 .34874 L
.45327 .34875 L
.45327 .34875 L
.45327 .34875 L
.45327 .34875 L
.45327 .34875 L
.45327 .34875 L
.45326 .34875 L
.45326 .34875 L
.45326 .34875 L
.45326 .34875 L
Mistroke
.45326 .34876 L
.45326 .34876 L
.45326 .34876 L
.45325 .34876 L
.45325 .34876 L
.45325 .34876 L
.45325 .34876 L
.45325 .34876 L
.45325 .34876 L
.45324 .34877 L
.45324 .34877 L
.45324 .34877 L
.45324 .34877 L
.45324 .34877 L
.45324 .34877 L
.45324 .34877 L
.45323 .34877 L
.45323 .34877 L
.45323 .34877 L
.45323 .34878 L
.45323 .34878 L
.45323 .34878 L
.45323 .34878 L
.45322 .34878 L
.45322 .34878 L
.45322 .34878 L
.45322 .34878 L
.45322 .34878 L
.45322 .34878 L
.45321 .34879 L
.45321 .34879 L
.45321 .34879 L
.45321 .34879 L
.45321 .34879 L
.45321 .34879 L
.45321 .34879 L
.4532 .34879 L
.4532 .34879 L
.4532 .34879 L
.4532 .3488 L
.4532 .3488 L
.4532 .3488 L
.45319 .3488 L
.45319 .3488 L
.45319 .3488 L
.45319 .3488 L
.45319 .3488 L
.45319 .3488 L
.45319 .3488 L
.45318 .3488 L
Mistroke
.45318 .34881 L
.45318 .34881 L
.45318 .34881 L
.45318 .34881 L
.45318 .34881 L
.45318 .34881 L
.45317 .34881 L
.45317 .34881 L
.45317 .34881 L
.45317 .34881 L
.45317 .34882 L
.45317 .34882 L
.45316 .34882 L
.45316 .34882 L
.45316 .34882 L
.45316 .34882 L
.45316 .34882 L
.45316 .34882 L
.45316 .34882 L
.45315 .34882 L
.45315 .34882 L
.45315 .34883 L
.45315 .34883 L
.45315 .34883 L
.45315 .34883 L
.45315 .34883 L
.45314 .34883 L
.45314 .34883 L
.45314 .34883 L
.45314 .34883 L
.45314 .34883 L
.45314 .34883 L
.45313 .34884 L
.45313 .34884 L
.45313 .34884 L
.45313 .34884 L
.45313 .34884 L
.45313 .34884 L
.45313 .34884 L
.45312 .34884 L
.45312 .34884 L
.45312 .34884 L
.45312 .34884 L
.45312 .34885 L
.45312 .34885 L
.45312 .34885 L
.45311 .34885 L
.45311 .34885 L
.45311 .34885 L
.45311 .34885 L
Mistroke
.45311 .34885 L
.45311 .34885 L
.4531 .34885 L
.4531 .34885 L
.4531 .34886 L
.4531 .34886 L
.4531 .34886 L
.4531 .34886 L
.4531 .34886 L
.45309 .34886 L
.45309 .34886 L
.45309 .34886 L
.45309 .34886 L
.45309 .34886 L
.45309 .34886 L
.45309 .34887 L
.45308 .34887 L
.45308 .34887 L
.45308 .34887 L
.45308 .34887 L
.45308 .34887 L
.45308 .34887 L
.45308 .34887 L
.45307 .34887 L
.45307 .34887 L
.45307 .34887 L
.45307 .34887 L
.45307 .34888 L
.45307 .34888 L
.45306 .34888 L
.45306 .34888 L
.45306 .34888 L
.45306 .34888 L
.45306 .34888 L
.45306 .34888 L
.45306 .34888 L
.45305 .34888 L
.45305 .34888 L
.45305 .34888 L
.45305 .34889 L
.45305 .34889 L
.45305 .34889 L
.45305 .34889 L
.45304 .34889 L
.45304 .34889 L
.45304 .34889 L
.45304 .34889 L
.45304 .34889 L
.45304 .34889 L
.45304 .34889 L
Mistroke
.45303 .34889 L
.45303 .3489 L
.45303 .3489 L
.45303 .3489 L
.45303 .3489 L
.45303 .3489 L
.45302 .3489 L
.45302 .3489 L
.45302 .3489 L
.45302 .3489 L
.45302 .3489 L
.45302 .3489 L
.45302 .3489 L
.45301 .34891 L
.45301 .34891 L
.45301 .34891 L
.45301 .34891 L
.45301 .34891 L
.45301 .34891 L
.45301 .34891 L
.453 .34891 L
.453 .34891 L
.453 .34891 L
.453 .34891 L
.453 .34891 L
.453 .34891 L
.453 .34892 L
.45299 .34892 L
.45299 .34892 L
.45299 .34892 L
.45299 .34892 L
.45299 .34892 L
.45299 .34892 L
.45299 .34892 L
.45298 .34892 L
.45298 .34892 L
.45298 .34892 L
.45298 .34892 L
.45298 .34892 L
.45298 .34893 L
.45298 .34893 L
.45297 .34893 L
.45297 .34893 L
.45297 .34893 L
.45297 .34893 L
.45297 .34893 L
.45297 .34893 L
.45297 .34893 L
.45296 .34893 L
.45296 .34893 L
Mistroke
.45296 .34893 L
.45296 .34893 L
.45296 .34894 L
.45296 .34894 L
.45296 .34894 L
.45295 .34894 L
.45295 .34894 L
.45295 .34894 L
.45295 .34894 L
.45295 .34894 L
.45295 .34894 L
.45295 .34894 L
.45294 .34894 L
.45294 .34894 L
.45294 .34894 L
.45294 .34894 L
.45294 .34895 L
.45294 .34895 L
.45293 .34895 L
.45293 .34895 L
.45293 .34895 L
.45293 .34895 L
.45293 .34895 L
.45293 .34895 L
.45293 .34895 L
.45292 .34895 L
.45292 .34895 L
.45292 .34895 L
.45292 .34895 L
.45292 .34895 L
.45292 .34896 L
.45292 .34896 L
.45291 .34896 L
.45291 .34896 L
.45291 .34896 L
.45291 .34896 L
.45291 .34896 L
.45291 .34896 L
.45291 .34896 L
.4529 .34896 L
.4529 .34896 L
.4529 .34896 L
.4529 .34896 L
.4529 .34896 L
.4529 .34896 L
.4529 .34897 L
.45289 .34897 L
.45289 .34897 L
.45289 .34897 L
.45289 .34897 L
Mistroke
.45289 .34897 L
.45289 .34897 L
.45289 .34897 L
.45289 .34897 L
.45288 .34897 L
.45288 .34897 L
.45288 .34897 L
.45288 .34897 L
.45288 .34897 L
.45288 .34898 L
.45288 .34898 L
.45287 .34898 L
.45287 .34898 L
.45287 .34898 L
.45287 .34898 L
.45287 .34898 L
.45287 .34898 L
.45287 .34898 L
.45286 .34898 L
.45286 .34898 L
.45286 .34898 L
.45286 .34898 L
.45286 .34898 L
.45286 .34898 L
.45286 .34898 L
.45285 .34899 L
.45285 .34899 L
.45285 .34899 L
.45285 .34899 L
.45285 .34899 L
.45285 .34899 L
.45285 .34899 L
.45284 .34899 L
.45284 .34899 L
.45284 .34899 L
.45284 .34899 L
.45284 .34899 L
.45284 .34899 L
.45284 .34899 L
.45283 .34899 L
.45283 .34899 L
.45283 .349 L
.45283 .349 L
.45283 .349 L
.45283 .349 L
.45283 .349 L
.45282 .349 L
.45282 .349 L
.45282 .349 L
.45282 .349 L
Mistroke
.45282 .349 L
.45282 .349 L
.45282 .349 L
.45281 .349 L
.45281 .349 L
.45281 .349 L
.45281 .349 L
.45281 .34901 L
.45281 .34901 L
.45281 .34901 L
.45281 .34901 L
.4528 .34901 L
.4528 .34901 L
.4528 .34901 L
.4528 .34901 L
.4528 .34901 L
.4528 .34901 L
.4528 .34901 L
.45279 .34901 L
.45279 .34901 L
.45279 .34901 L
.45279 .34901 L
.45279 .34901 L
.45279 .34901 L
.45279 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45278 .34902 L
.45277 .34902 L
.45277 .34902 L
.45277 .34902 L
.45277 .34902 L
.45277 .34902 L
.45277 .34902 L
.45277 .34902 L
.45276 .34902 L
.45276 .34902 L
.45276 .34903 L
.45276 .34903 L
.45276 .34903 L
.45276 .34903 L
.45276 .34903 L
.45275 .34903 L
.45275 .34903 L
.45275 .34903 L
Mistroke
.45275 .34903 L
.45275 .34903 L
.45275 .34903 L
.45275 .34903 L
.45275 .34903 L
.45274 .34903 L
.45274 .34903 L
.45274 .34903 L
.45274 .34903 L
.45274 .34903 L
.45274 .34903 L
.45274 .34904 L
.45273 .34904 L
.45273 .34904 L
.45273 .34904 L
.45273 .34904 L
.45273 .34904 L
.45273 .34904 L
.45273 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45272 .34904 L
.45271 .34904 L
.45271 .34904 L
.45271 .34904 L
.45271 .34905 L
.45271 .34905 L
.45271 .34905 L
.45271 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.4527 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
.45269 .34905 L
Mistroke
.45268 .34905 L
.45268 .34906 L
.45268 .34906 L
.45268 .34906 L
.45268 .34906 L
.45268 .34906 L
.45268 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45267 .34906 L
.45266 .34906 L
.45266 .34906 L
.45266 .34906 L
.45266 .34906 L
.45266 .34906 L
.45266 .34906 L
.45266 .34906 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45265 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45264 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45263 .34907 L
.45262 .34908 L
.45262 .34908 L
.45262 .34908 L
.45262 .34908 L
Mistroke
.45262 .34908 L
.45262 .34908 L
.45262 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.45261 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.4526 .34908 L
.45259 .34908 L
.45259 .34908 L
.45259 .34909 L
.45259 .34909 L
.45259 .34909 L
.45259 .34909 L
.45259 .34909 L
.45259 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45258 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45257 .34909 L
.45256 .34909 L
.45256 .34909 L
.45256 .34909 L
.45256 .34909 L
.45256 .34909 L
.45256 .3491 L
.45256 .3491 L
Mistroke
.45256 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45255 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45254 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45253 .3491 L
.45252 .3491 L
.45252 .3491 L
.45252 .3491 L
.45252 .34911 L
.45252 .34911 L
.45252 .34911 L
.45252 .34911 L
.45252 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.45251 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
.4525 .34911 L
Mistroke
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45249 .34911 L
.45248 .34911 L
.45248 .34911 L
.45248 .34911 L
.45248 .34911 L
.45248 .34912 L
.45248 .34912 L
.45248 .34912 L
.45248 .34912 L
.45248 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45247 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45246 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45245 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
.45244 .34912 L
Mistroke
.45244 .34912 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45243 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45242 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.45241 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.4524 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45239 .34913 L
.45238 .34913 L
.45238 .34913 L
.45238 .34913 L
.45238 .34913 L
.45238 .34913 L
Mistroke
.45238 .34913 L
.45238 .34914 L
.45238 .34914 L
.45238 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45237 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45236 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45235 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45234 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45233 .34914 L
.45232 .34914 L
Mistroke
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45232 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.45231 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34914 L
.4523 .34915 L
.4523 .34915 L
.4523 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45229 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45228 .34915 L
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
Mistroke
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
.45227 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45226 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45225 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45224 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45223 .34915 L
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
Mistroke
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
.45222 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.45221 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.4522 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45219 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45218 .34915 L
.45217 .34915 L
Mistroke
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45217 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45216 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45215 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45214 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
Mistroke
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45213 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45212 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34915 L
.45211 .34914 L
.45211 .34914 L
.45211 .34914 L
.45211 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.4521 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
.45209 .34914 L
Mistroke
.45209 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45208 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45207 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45206 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
.45205 .34914 L
Mistroke
.45204 .34914 L
.45204 .34914 L
.45204 .34914 L
.45204 .34914 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45204 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45203 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45202 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
Mistroke
.45201 .34913 L
.45201 .34913 L
.45201 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34913 L
.452 .34912 L
.452 .34912 L
.452 .34912 L
.452 .34912 L
.452 .34912 L
.452 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45199 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45198 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
Mistroke
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34912 L
.45197 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45196 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45195 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .34911 L
.45194 .3491 L
Mistroke
.45194 .3491 L
.45194 .3491 L
.45194 .3491 L
.45194 .3491 L
.45194 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45193 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .3491 L
.45192 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
Mistroke
.45191 .34909 L
.45191 .34909 L
.45191 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.4519 .34909 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45189 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
Mistroke
.45188 .34908 L
.45188 .34908 L
.45188 .34908 L
.45188 .34907 L
.45188 .34907 L
.45188 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45187 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34907 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45186 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
Mistroke
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34906 L
.45185 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45184 .34905 L
.45183 .34905 L
.45183 .34905 L
.45183 .34905 L
.45183 .34905 L
.45183 .34905 L
.45183 .34905 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
Mistroke
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45183 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34904 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45182 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34903 L
.45181 .34902 L
.45181 .34902 L
.45181 .34902 L
.45181 .34902 L
.45181 .34902 L
Mistroke
.45181 .34902 L
.45181 .34902 L
.45181 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34902 L
.4518 .34901 L
.4518 .34901 L
.4518 .34901 L
.4518 .34901 L
.4518 .34901 L
.4518 .34901 L
.4518 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .34901 L
.45179 .349 L
.45179 .349 L
.45179 .349 L
.45179 .349 L
Mistroke
.45179 .349 L
.45179 .349 L
.45179 .349 L
.45179 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .349 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45178 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34899 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
Mistroke
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45177 .34898 L
.45176 .34898 L
.45176 .34898 L
.45176 .34898 L
.45176 .34898 L
.45176 .34898 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34897 L
.45176 .34896 L
.45176 .34896 L
.45176 .34896 L
.45176 .34896 L
.45176 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
Mistroke
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34896 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45175 .34895 L
.45174 .34895 L
.45174 .34895 L
.45174 .34895 L
.45174 .34895 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
Mistroke
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34894 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45174 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34893 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
.45173 .34892 L
Mistroke
.45173 .34892 L
.45173 .34892 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45173 .34891 L
.45172 .34891 L
.45172 .34891 L
.45172 .34891 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .3489 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
Mistroke
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34889 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45172 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34888 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
Mistroke
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34887 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34886 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
.45171 .34885 L
Mistroke
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.45171 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34884 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34883 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
Mistroke
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34882 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .34881 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
Mistroke
.4517 .3488 L
.4517 .3488 L
.4517 .3488 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34879 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34878 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
Mistroke
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34877 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34876 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
Mistroke
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34875 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34874 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34873 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
Mistroke
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34872 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .34871 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
.4517 .3487 L
Mistroke
.4517 .3487 L
.45171 .3487 L
.45171 .3487 L
.45171 .3487 L
.45171 .3487 L
.45171 .3487 L
.45171 .3487 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34869 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34868 L
.45171 .34867 L
.45171 .34867 L
Mistroke
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34867 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34866 L
.45171 .34865 L
.45171 .34865 L
.45171 .34865 L
.45171 .34865 L
.45171 .34865 L
.45171 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
Mistroke
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34865 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34864 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
Mistroke
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34863 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45172 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34862 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .34861 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
Mistroke
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .3486 L
.45173 .34859 L
.45173 .34859 L
.45173 .34859 L
.45173 .34859 L
.45173 .34859 L
.45173 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34859 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
Mistroke
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34858 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45174 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34857 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
Mistroke
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34856 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45175 .34855 L
.45176 .34855 L
.45176 .34855 L
.45176 .34855 L
.45176 .34855 L
.45176 .34855 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
Mistroke
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34854 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45176 .34853 L
.45177 .34853 L
.45177 .34853 L
.45177 .34853 L
.45177 .34853 L
.45177 .34853 L
.45177 .34853 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
.45177 .34852 L
Mistroke
.45177 .34852 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45177 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .34851 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .3485 L
.45178 .34849 L
Mistroke
.45178 .34849 L
.45178 .34849 L
.45178 .34849 L
.45178 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34849 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.45179 .34848 L
.4518 .34848 L
.4518 .34848 L
.4518 .34848 L
.4518 .34848 L
.4518 .34848 L
.4518 .34848 L
.4518 .34847 L
Mistroke
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34847 L
.4518 .34846 L
.4518 .34846 L
.4518 .34846 L
.4518 .34846 L
.4518 .34846 L
.4518 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
.45181 .34846 L
Mistroke
.45181 .34846 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45181 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34845 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
Mistroke
.45182 .34844 L
.45182 .34844 L
.45182 .34844 L
.45183 .34844 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34843 L
.45183 .34842 L
.45183 .34842 L
.45183 .34842 L
.45183 .34842 L
.45183 .34842 L
.45183 .34842 L
.45183 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
Mistroke
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34842 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45184 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .34841 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
Mistroke
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45185 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .3484 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45186 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34839 L
.45187 .34838 L
.45187 .34838 L
Mistroke
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45187 .34838 L
.45188 .34838 L
.45188 .34838 L
.45188 .34838 L
.45188 .34838 L
.45188 .34838 L
.45188 .34838 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
Mistroke
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45188 .34837 L
.45189 .34837 L
.45189 .34837 L
.45189 .34837 L
.45189 .34837 L
.45189 .34837 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.45189 .34836 L
.4519 .34836 L
.4519 .34836 L
.4519 .34836 L
.4519 .34836 L
.4519 .34836 L
.4519 .34836 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
Mistroke
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.4519 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34835 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
Mistroke
.45191 .34834 L
.45191 .34834 L
.45191 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34834 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45192 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
.45193 .34833 L
Mistroke
.45193 .34833 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45193 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34832 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45194 .34831 L
.45195 .34831 L
Mistroke
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .34831 L
.45195 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
Mistroke
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45196 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .3483 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45197 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
Mistroke
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34829 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45198 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
Mistroke
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.45199 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34828 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.452 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
Mistroke
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34827 L
.45201 .34826 L
.45201 .34826 L
.45201 .34826 L
.45201 .34826 L
.45201 .34826 L
.45201 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
Mistroke
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45202 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34826 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45203 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
Mistroke
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45204 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34825 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
Mistroke
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45205 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45206 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
Mistroke
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34824 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45207 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
Mistroke
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45208 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34823 L
.45209 .34822 L
Mistroke
.45209 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.4521 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
Mistroke
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45211 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
Mistroke
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34822 L
.45212 .34821 L
.45212 .34821 L
.45212 .34821 L
.45212 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
Mistroke
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45213 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45214 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
Mistroke
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45215 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
Mistroke
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45216 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
.45217 .34821 L
Mistroke
.45217 .34821 L
.45217 .34821 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45217 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
Mistroke
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45218 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
Mistroke
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.45219 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
Mistroke
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.4522 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
Mistroke
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45221 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
Mistroke
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45222 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
Mistroke
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .3482 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45223 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
Mistroke
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
Mistroke
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45224 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
Mistroke
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45225 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
Mistroke
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34821 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
Mistroke
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45226 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
Mistroke
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
Mistroke
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45227 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34822 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
Mistroke
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
Mistroke
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45228 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
Mistroke
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34823 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
Mistroke
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
Mistroke
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34824 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.45229 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
Mistroke
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
Mistroke
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34825 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
Mistroke
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
Mistroke
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34826 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
Mistroke
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
Mistroke
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34827 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
Mistroke
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
Mistroke
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34828 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
Mistroke
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
Mistroke
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .34829 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
Mistroke
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
Mistroke
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .3483 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
Mistroke
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
Mistroke
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34831 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
Mistroke
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.4523 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
Mistroke
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
.45229 .34832 L
Mistroke
.45229 .34832 L
.45229 .34832 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
Mistroke
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
Mistroke
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34833 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45229 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
Mistroke
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
Mistroke
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34834 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
Mistroke
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
Mistroke
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45228 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
Mistroke
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34835 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
Mistroke
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
Mistroke
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45227 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
Mistroke
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34836 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
Mistroke
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
Mistroke
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45226 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
Mistroke
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
Mistroke
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34837 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
Mistroke
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
.45225 .34838 L
Mistroke
.45225 .34838 L
.45225 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
Mistroke
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
Mistroke
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
Mistroke
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45224 .34838 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
Mistroke
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
Mistroke
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
Mistroke
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45223 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
Mistroke
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
Mistroke
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
Mistroke
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
Mistroke
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45222 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
Mistroke
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
Mistroke
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
Mistroke
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .34839 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
Mistroke
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.45221 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
Mistroke
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .3484 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.4522 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
Mistroke
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45219 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
Mistroke
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34839 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
Mistroke
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34838 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
Mistroke
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45218 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
Mistroke
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
Mistroke
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34837 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
Mistroke
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.45219 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
.4522 .34836 L
Mistroke
.4522 .34836 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{576, 355.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000900001Hb000`400?l00000o`00003ooooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoook
JP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oo
nfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX5o`00
0?oooo]ZoooonfXMoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000:cooo]Z
E_oo0=WooookJQ_ooo]Z000PoookJPCo0000S?oonfZEool0fO_ooo]Z000PoookJPCo0000MooonfXg
ool0fE?ooo]Z=?oo0=WWoookJP008?oonfX4o`0006Oooo]Z9ooo0=VAoookJRGoo`3If?oonfX0023o
oo]Z1?l0001IoookJR3oo`3I^_oonfXMool0fLcooo]Z000PoookJPCo0000F?oonfXAool0fMWooo]Z
6Ooo0=W1oookJP008?oonfX4o`0005Sooo]Z0ooo0=WcoookJQKoo`3I^?oonfX0023ooo]Z1?l0003o
oookJU[ooo]Z4ooo0=V`oookJP008?oonfX4o`000?oooo]ZHooonfXAool0fJWooo]Z000PoookJPCo
0000oooonfY[oookJQ3oo`3IX_oonfX0023ooo]Z1?l0003ooookJW?ooo]Z3_oo0=VLoookJP008?oo
nfX4o`000?oooo]ZNOoonfX>ool0fIKooo]Z000PoookJPCo0000oooonfYooookJPgoo`3ITOoonfX0
023ooo]Z1?l0003ooookJXGooo]Z2ooo0=V=oookJP008?oonfX5o`000?oooo]ZROoonfX;ool0fHSo
oo]Z000PoookJPCo0000oooonfZ>oookJP_oo`3IQ?oonfX0023ooo]Z1?l0003ooookJY?ooo]Z2Ooo
0=V1oookJP008?oonfX4o`000?oooo]ZUooonfX9ool0fGgooo]Z000PoookJPCo0000oooonfZKoook
JPSoo`3IN_oonfX0023ooo]Z1?l0003ooookJYkooo]Z2?oo0=UgoookJP008?oonfX4o`000?oooo]Z
XOoonfX8ool0fGCooo]Z000PoookJPCo0000oooonfZToookJPSoo`3ILOoonfX0023ooo]Z1?l0003o
oookJZOooo]Z1ooo0=U_oookJP008?oonfX4o`000?oooo]ZZ_oonfX6ool0fFgooo]Z000PoookJPCo
0000oooonfZ/oookJPOoo`3IJ_oonfX0023ooo]Z1?l0003ooookJZoooo]Z1_oo0=UXoookJP008?oo
nfX4o`000?oooo]Z/OoonfX6ool0fFKooo]Z000PoookJPCo0000=OoonfX5o`00O`Cooo]Z0ol007l0
0ooonf[o001oo`00O`07o`00Ob_ooo]Z1Ol007l4oookJP?o001o1_oonfX3o`00Obcooo]Z1Ol007l4
oookJP?o001o0ooonfX5o`00Obgooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00OcOooo]Z0ol007lg
oookJP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o8OoonfX6ool0f@Kooo]Z0ol007l4
oookJP?o001o1_oonfX3o`00Od_ooo]Z000PoookJPCo0000=?oonfX7o`00O`?ooo]Z0ol007l00ooo
nf[o001oo`00O`07o`00Ob[ooo]Z1ol007l3oookJP?o001o1_oonfX3o`00Ob_ooo]Z1ol007l3oook
JP?o001o0_oonfX7o`00Ob_ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00OcKooo]Z0ol007lgoook
JP?o001o1?oonfX3o`00O`03oookJ_l007oo001o00Oo001o8ooonfX5ool0f@Gooo]Z0ol007l4oook
JP?o001o1_oonfX3o`00Od_ooo]Z000PoookJPCo0000=?oonfX3o`00O`04oookJ_l007oo001oo`00
O`?ooo]Z0ol007l00ooonf[o001oo`00O`02o`00Oboooo]Z0ol007l01?oonf[o001oo`00Ool007l3
oookJP?o001o1_oonfX3o`00Ob_ooo]Z0ol007l01?oonf[o001oo`00Ool007l3oookJP?o001o0_oo
nfX3o`00O`;ooo]Z0ol007lZoookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`04oook
J_l007oo001oo`00O`?ooo]Z0ol007l=oookJPSo:?l08?oonfX3o`00OcOooo]Z0ol007l4oookJP?o
001o00?ooo]Zo`00Ool007l00_l007lZoookJPGoo`3I0ooonfX3o`00O`Cooo]Z0ol007l6oookJP?o
001oBooonfX0023ooo]Z1Ol0000boookJP?o001o0ooonfX3o`00O`Oooo]Z1?l007l]oookJP?o001o
0ooonfX3o`00O`Kooo]Z2Ol007lYoookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o
:OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`gooo]Z3_lXo`0JoookJP?o001o
=ooonfX3o`00O`Wooo]Z1?l007lZoookJPKoo`3I00Cooo]Zo`00Ool007oo001o2?oonfX9o`00Od[o
oo]Z000PoookJPCo0000<ooonfX3o`00O`?ooo]Z0ol007l8oookJPGo001o:ooonfX3o`00O`?ooo]Z
0ol007l6oookJPWo001o:OoonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObWooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lCoookJPko:?l05?oonfX3o`00OcOooo]Z
0ol007l:oookJPGo001o:_oonfX5ool0f@?o001o2?oonfX9o`00Od[ooo]Z000PoookJPCo0000<ooo
nfX3o`00O`?ooo]Z0ol007l:oookJPCo001o:_oonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooo
nfX3o`00Ob[ooo]Z0ol007l3oookJP?o001o1_oonfX4o`00O`;ooo]Z0ol007lYoookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l3oookJP?o001o6OoonfX=obSo00oooo]Z0ol007lgoookJP?o001o3?oo
nfX4o`00Ob_ooo]Z1Ooo0=T00ol007oooo]ZoookJP06oookJP;o001o0ooonfX3o`00Od_ooo]Z000P
oookJPCo0000<ooonfX3o`00O`?ooo]Z0ol007l;oookJP?o001o:_oonfX3o`00O`?ooo]Z0ol007l7
oookJP;o001o0_oonfX3o`00Ob[ooo]Z0ol007l3oookJP?o001o1_oonfX8o`00Ob[ooo]Z0ol007l3
oookJP?o001o1ooonfX7o`00Ob3ooo]Z3?lXo`0:oookJP?o001o=ooonfX3o`00O`gooo]Z0ol007l/
oookJPGoo`3I2OoonfX2o`00O`;ooo]Z0ol007m;oookJP008?oonfX4o`0003?ooo]Z0ol007l3oook
JP?o001o3?oonfX3o`00ObWooo]Z0ol007l3oookJP?o001o1ooonfX3o`00O`04oookJ_l007oo001o
o`00Ob[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`04oookJ_l007oo001oo`00Ob_ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00ObGooo]Z2olXo`06oookJP?o001o=ooonfX3o`00O`kooo]Z0ol0
07l]oookJPCoo`3I2?oonfX3o`00O`04oookJ_l007oo001oo`00Od_ooo]Z000PoookJPCo0000<ooo
nfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00ObWooo]Z0ol007l3oookJP?o001o2?oo
nfX2o`00O`04oookJ_l007oo001oo`00Ob[ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00Oboooo]Z
0ol007l3oookJP?o001o1_oonfX3o`00O`?ooo]Z0ol007lYoookJP[o:?l00_oonfX3o`00OcOooo]Z
0ol007l8oookJP?o001o0ooonfX3o`00Obgooo]Z00?o001oool0fOoo0=T00_oo0=T8oookJP;o001o
00Cooo]Zo`00Ool007oo001oBooonfX0023ooo]Z1?l0000coookJP?o001o0ooonfX3o`00O`Kooo]Z
0ol007l3oookJP?o001o:OoonfX3o`00O`?ooo]Z0ol007l9oookJPGo001o:_oonfX3o`00O`?ooo]Z
0ol007l6oookJP?o001o;ooonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00Obgooo]Z
2_lXo`000ol007oooo]ZoookJP0boookJPKo001o2?oonfX3o`00O`?ooo]Z0ol007lZoookJPGo001o
1?oo0=T8oookJPGo001oBooonfX0023ooo]Z1?l0000doookJP?o001o00Cooo]Zo`00Ool007oo001o
1ooonfX4o`00O`;ooo]Z0ol007lZoookJP?o001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00Ob_o
oo]Z0ol007l01?oonf[o001oo`00Ool007l8oookJP?o001o0_oonfX3o`00Ob[ooo]Z0ol007l01?oo
nf[o001oo`00Ool007l7oookJP?o001o0ooonfX3o`00Oc7ooo]Z2OlXo`0boookJPKo001o2?oonfX4
o`00O`;ooo]Z0ol007lZoookJPKo001o1?oo0=T7oookJPGo001oBooonfX0023ooo]Z1?l0000doook
JPOo001o2?oonfX7o`00Ob_ooo]Z1ol007l;oookJPCo001o:ooonfX7o`00O`Sooo]Z1ol007l[oook
JPOo001o2?oonfX7o`00OcGooo]Z00?o001oobSo0?lXo`001_lXo`0aoookJPCo001o2OoonfX7o`00
Obgooo]Z1?l007l00ooonf[oo`3Iool0f@02ool0f@Oooo]Z1?l007m;oookJP008?oonfX4o`0003Go
oo]Z1Ol007l:oookJPGo001o;OoonfX5o`00O`gooo]Z0ol007l/oookJPGo001o2ooonfX4o`00Obgo
oo]Z1Ol007l:oookJPGo001o=ooonfX3o`00O`So:?l0;ooonfX3o`00O`[ooo]Z1Ol007l_oookJP?o
001o0_oonfX4ool0f@Oooo]Z0ol007m;oookJP008?oonfX4o`000?oooo]ZB_oonfX8obSo07?ooo]Z
1?oo0=UDoookJP008?oonfX4o`000?oooo]ZCOoonfX7obSo07;ooo]Z1?oo0=UCoookJP008?oonfX4
o`000?oooo]ZD?oonfX7obSo073ooo]Z1?oo0=TPoookJP?o001o1?oonfX3o`00O`?ooo]Z1?l007l0
1Ooonf[o001oo`00Ool007oooo]Z00?o001o1?oonfX5o`00O`Gooo]Z1Ol007l6oookJP008?oonfX4
o`000?oooo]ZDooonfX6obSo06oooo]Z0ooo0=TPoookJP?o001o0ooonfX4o`00O`;ooo]Z2?l007l2
oookJP?o001o1?oonfX5o`00O`Cooo]Z1ol007l5oookJP008?oonfX4o`000?oooo]ZEOoonfX6obSo
06kooo]Z0ooo0=TOoookJP?o001o0ooonfX4o`00O`;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00
O`?ooo]Z1ol007l2oookJPCo001o0_oonfX3o`00O`Cooo]Z000PoookJ_oo0000Fol00006obSo06co
00001?oo0=TAo`0000gooo]Z0ol007l2oookJPGo001o0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l:oookJP008?oonf[oo`0005go
00001_lXo`1[o`0000?oo`3I4Ol0000=oookJP?o001o0_oonfX5o`00O`;ooo]Z1?l007l01?oonf[o
001oo`00Ool007l2oookJP?o001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`;ooo]Z2Ol007l4
oookJP008?oonf[oo`0005oo00001_lXo`1Zo`0000?oo`3I4?l0000=oookJP?o001o00?ooo]Zo`00
Ool007l01?l007l3oookJPOo001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00Ool007l2
oookJPWo001o1?oonfX0023ooo]Zool0001Qo`0000Ko:?l0J?l00003ool0fA3o00003OoonfX3o`00
O`04oookJ_l007oo001ooookJP?o001o1ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0ooonfX3
o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l4oookJP008?oonfX4o`00043ooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0noookJP03o`000?oonf[ooo]Z03kooo]Z00?o0000
oookJ_oonfX0?_oonfX00ol0003ooo]ZoookJP0GoookJPGo:?l08_oonfX00ol0003ooo]ZoookJP0n
oookJP03o`000?oonf[ooo]Z00;ooo]Z0ooo0=TLoookJPKo001o00Cooo]Zo`00Ool007oo001o0_oo
nfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l01?oonf[o001oo`00
Ool007l3oookJP?o001o1?oonfX0023ooo]Z1?l0003ooookJV7ooo]Z1OlXo`1VoookJP?oo`3I7?oo
nfX5o`00O`;ooo]Z0ol007l2oookJPSo001o0_oonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oo
nfX7o`00O`Gooo]Z000PoookJPCo0000oooonfYRoookJPGo:?l0I_oonfX2ool0fAcooo]Z1Ol007l2
oookJP?o001o1?oonfX4o`00O`Cooo]Z0ol007l01?oonf[o001oo`00Ool007l5oookJP?o001o0_oo
nfX5o`00O`Kooo]Z000PoookJPCo0000oooonfYToookJPCo:?l0IOoonfX3ool0fA_ooo]Z1?l007l3
oookJP?o001o:?oonfX0023ooo]Z1?l0003ooookJVGooo]Z1OlXo`1SoookJP?oo`3I6ooonfX4o`00
O`?ooo]Z0ol007l<oookJP?o001o6OoonfX0023ooo]Z1?l0003ooookJSKooo]Z0ooo]P0]oookJPGo
:?l0HooonfX2ool0fA_ooo]Z0ol007l4oookJP?o001o3?oonfX3o`00OaWooo]Z000PoookJPCo0000
oooonfXfoookJPGookH0;OoonfX4obSo06;ooo]Z0ooo0=U<oookJP008?oonfX4o`000?oooo]Z=ooo
nfX6oonf02cooo]Z1?lXo`1QoookJP?oo`3IC?oonfX0023ooo]Z1?l0003ooookJSWooo]Z1_oo]P0[
oookJPCo:?l0HOoonfX2ool0fDcooo]Z000PoookJPCo0000oooonfXkoookJPKookH0:_oonfX4obSo
063ooo]Z0_oo0=U<oookJP008?oonfX4o`000?oooo]Z?OoonfX6oonf02Wooo]Z1?lXo`1OoookJP;o
o`3IC?oonfX0023ooo]Z1?l0003ooookJSoooo]Z1Ooo]P0YoookJP?o:?l0GooonfX2ool0fDcooo]Z
000PoookJPCo0000oooonfY1oookJPGookH0:?oonfX3obSo05kooo]Z0_oo0=U<oookJP008?oonfX4
o`000?oooo]Z@_oonfX5oonf02Sooo]Z0olXo`1MoookJP;oo`3IC?oonfX0023ooo]Z1Ol00037oook
JQoo0?mSG?oonfX4oonf02Oooo]Z1?lXo`1LoookJP;oo`3IC?oonfX0023ooo]Z1?l0002koookJSOo
0?mSD_oonfX5oonf02Kooo]Z0olXo`1LoookJP;oo`3IC?oonfX0023ooo]Z1?l0002boookJQSo0?mS
6ooonfXEo`3oHd_ooo]Z1Ooo]P0VoookJP?o:?l0FooonfX2ool0fDcooo]Z000PoookJPCo0000Zooo
nfXBo`3oHc?ooo]Z3ol0of=8oookJPCookH09OoonfX3obSo05_ooo]Z0_oo0=U<oookJP008?oonfX4
o`000:Gooo]Z3ol0of=4oookJPco0?mSA?oonfX4oonf02Gooo]Z0olXo`1JoookJP;oo`3IC?oonfX0
023ooo]Z1?l0002PoookJPgo0?mSD?oonfX;o`3oHd7ooo]Z1?oo]P0ToookJP?o:?l0F_oonfX2ool0
fDcooo]Z000PoookJPCo0000VooonfX<o`3oHe_ooo]Z2_l0of<noookJPCookH09?oonfX3obSo05Wo
oo]Z0_oo0=U<oookJP008?oonfX4o`0009Kooo]Z3?l0of=ToookJPWo0?mS??oonfX4oonf02?ooo]Z
0olXo`1IoookJP;oo`3IC?oonfX0023ooo]Z1?l0002BoookJP_o0?mSKOoonfX8o`3oHc[ooo]Z0ooo
]P0ToookJP?o:?l0F?oonfX2ool0fDcooo]Z000PoookJPCo0000S_oonfX:o`3oHgGooo]Z1ol0of<i
oookJP?ookH08ooonfX3obSo05Sooo]Z0_oo0=U<oookJP008?oonfX4o`0008[ooo]Z2_l0of=loook
JPKo0?mS=ooonfX4oonf02?ooo]Z0_lXo`1HoookJP;oo`3IC?oonfX0023ooo]Z1?l00027oookJPWo
0?mSP_oonfX7o`3oHcGooo]Z0ooo]P0SoookJP;o:?l0EooonfX3ool0fDcooo]Z000PoookJPCo0000
PooonfX9o`3oHhWooo]Z1_l0of<doookJP?ookH08_oonfX3obSo05Kooo]Z0ooo0=U<oookJP008?oo
nfX4o`00083ooo]Z2Ol0of>>oookJPGo0?mS<ooonfX4oonf027ooo]Z0olXo`1FoookJP;oo`3ICOoo
nfX0023ooo]Z1?l0001moookJPSo0?mSU?oonfX5o`3oHc;ooo]Z0ooo]P0RoookJP;o:?l0E_oonfX2
ool0fDgooo]Z000PoookJPCo0000N_oonfX8o`3oHiSooo]Z1_l0of<aoookJP?ookH08OoonfX2obSo
05Gooo]Z0ooo0=U=oookJP008?oonfX5o`0007Kooo]Z2?l0of>MoookJPGo0?mS<?oonfX3oonf027o
oo]Z0_lXo`1EoookJP?oo`3ICOoonfX0023ooo]Z1?l0001doookJPSo0?mSX_oonfX5o`3oHboooo]Z
0_oo]P0QoookJP;o:?l0EOoonfX2ool0fDkooo]Z000PoookJPCo0000L_oonfX7o`3oHjKooo]Z1_l0
of<]oookJP?ookH08?oonfX2obSo05Cooo]Z0ooo0=U>oookJP008?oonfX4o`0006oooo]Z1ol0of>[
oookJPGo0?mS;?oonfX3oonf023ooo]Z0_lXo`1DoookJP?oo`3IC_oonfX0023ooo]Z1?l0001/oook
JPOo0?mS[ooonfX5o`3oHbcooo]Z0_oo]P0PoookJP;o:?l0E?oonfX2ool0fDoooo]Z000PoookJPCo
0000J_oonfX7o`3oHk;ooo]Z1?l0of</oookJP?ookH07ooonfX2obSo05?ooo]Z0ooo0=U?oookJP00
8?oonfX4o`0006Oooo]Z1ol0of>foookJPCo0?mS:ooonfX3oonf01oooo]Z0_lXo`1CoookJP?oo`3I
CooonfX0023ooo]Z1?l0001UoookJPOo0?mS^OoonfX5o`3oHb[ooo]Z0_oo]P0OoookJP;o:?l0Dooo
nfX2ool0fE3ooo]Z000PoookJPCo0000HooonfX6o`3oHkgooo]Z1?l0of<ZoookJP;ookH07ooonfX2
obSo05;ooo]Z0ooo0=U@oookJP008?oonfX4o`00067ooo]Z1_l0of?0oookJPCo0?mS:OoonfX2oonf
01oooo]Z0_lXo`1BoookJP?oo`3ID?oonfX0023ooo]Z1?l0001NoookJPOo0?mS`ooonfX4o`3oHbSo
oo]Z0ooo]P0NoookJP;o:?l0DOoonfX3ool0fE7ooo]Z000PoookJPCo0000G?oonfX7o`3oHfWooo]Z
5_lZ0?m7oookJP?o0?mS:?oonfX3oonf01kooo]Z0_lXo`1AoookJP?oo`3IDOoonfX0023ooo]Z1?l0
001JoookJPKo0?mSH_oonfXYobX0ockooo]Z1?l0of<XoookJP;ookH07_oonfX2obSo057ooo]Z0_oo
0=UBoookJP008?oonfX4o`0005Sooo]Z1_l0of=NoookJQ;o:P3o4_oo0?l@obX0oc[ooo]Z0ol0of<X
oookJP;ookH07_oonfX2obSo053ooo]Z0ooo0=UBoookJP008?oonfX4o`0005Kooo]Z1_l0of=Joook
JPko:P3o9Ooo0?l;obX0ocOooo]Z0ol0of<WoookJP;ookH07OoonfX3obSo053ooo]Z0ooo0=UBoook
JP008?oonfX4o`0005Cooo]Z1_l0of=HoookJPco:P3o2_oo0?lMoookJPWoo`3o2olZ0?lboookJP?o
0?mS9ooonfX2oonf01gooo]Z0olXo`1?oookJP?oo`3IDooonfX0023ooo]Z1Ol0001AoookJPKo0?mS
E_oonfX:obX0o`Woo`3o:ooonfX6ool0o`Wo:P3o<OoonfX3o`3oHbKooo]Z0_oo]P0MoookJP;o:?l0
D?oonfX3ool0fE?ooo]Z000PoookJPCo0000D?oonfX6o`3oHeCooo]Z2_lZ0?l7ool0ocGooo]Z1Ooo
0?l9obX0obkooo]Z0ol0of<VoookJP;ookH07OoonfX2obSo04oooo]Z0ooo0=UDoookJP008?oonfX4
o`0004oooo]Z1Ol0of=BoookJP[o:P3o1_oo0?lmoookJPGoo`3o2?lZ0?l/oookJPCo0?mS9OoonfX2
oonf01cooo]Z0olXo`1?oookJP?oo`3IE?oonfX0023ooo]Z1?l0001=oookJPGo0?mSDOoonfX9obX0
o`Koo`3oA?oonfX5ool0o`Oo:P3o:ooonfX3o`3oHbCooo]Z0ooo]P0LoookJP?o:?l0C_oonfX3ool0
fEGooo]Z000PoookJPCo0000BooonfX5o`3oHe3ooo]Z2?lZ0?l6ool0od_ooo]Z1?oo0?l6obX0ob[o
oo]Z0ol0of<ToookJP?ookH07?oonfX2obSo04oooo]Z0ooo0=UEoookJP008?oonfX4o`0004Wooo]Z
1Ol0of=?oookJPSo:P3o1_oo0?m@oookJPCoo`3o1_lZ0?lXoookJP?o0?mS9?oonfX2oonf01gooo]Z
0_lXo`1>oookJP?oo`3IE_oonfX0023ooo]Z1?l00017oookJPKo0?mSCOoonfX8obX0o`Goo`3oE_oo
nfX3ool0o`Ko:P3o:?oonfX2o`3oHbCooo]Z0_oo]P0LoookJP?o:?l0COoonfX3ool0fEOooo]Z000P
oookJPCo0000A_oonfX5o`3oHdgooo]Z1olZ0?l5ool0obWooo]Z5ooo02TKoookJP?oo`3o1OlZ0?lW
oookJP?o0?mS8ooonfX2oonf01cooo]Z0olXo`1=oookJP?oo`3IEooonfX0023ooo]Z1?l00014oook
JPGo0?mSC?oonfX7obX0o`Goo`3o9?oonfXUool0:AKooo]Z0ooo0?l5obX0obKooo]Z0ol0of<Soook
JP;ookH06ooonfX3obSo04gooo]Z0ooo0=UHoookJP008?oonfX4o`0004;ooo]Z1Ol0of=<oookJPOo
:P3o1?oo0?lQoookJQ3oo`0Y4?oonfX?ool0:ACooo]Z0_oo0?l5obX0obGooo]Z0ol0of<RoookJP?o
okH06ooonfX3obSo04gooo]Z0ooo0=UHoookJP008?oonfX4o`00047ooo]Z1Ol0of=:oookJPOo:P3o
1Ooo0?lOoookJPcoo`0Y7ooonfX;ool0:A;ooo]Z0ooo0?l4obX0obCooo]Z0ol0of<RoookJP?ookH0
6ooonfX2obSo04gooo]Z0ooo0=UIoookJP008?oonfX4o`00043ooo]Z1?l0of=:oookJPOo:P3o1?oo
0?lNoookJP[oo`0Y:_oonfX9ool0:A3ooo]Z0ooo0?l4obX0ob?ooo]Z0ol0of<RoookJP;ookH06ooo
nfX3obSo04cooo]Z1?oo0=UIoookJP001?oonfX5o`00O`Cooo]Z0ol007l6oookJP?o001o1ooonfX4
o`00043ooo]Z0_l0of=:oookJPKo:P3o1Ooo0?lLoookJPWoo`0Y<_oonfX8ool0:@oooo]Z0_oo0?l5
obX0ob?ooo]Z0_l0of<QoookJP?ookH06ooonfX3obSo04cooo]Z0ooo0=UJoookJP000ooonfX7o`00
O`?ooo]Z0ol007l6oookJP?o001o1ooonfX4o`0008[ooo]Z1_lZ0?l4ool0oacooo]Z2?oo02Tioook
JPOoo`0Y3_oonfX2ool0o`Co:P3o8ooonfX2o`3oHb7ooo]Z0ooo]P0JoookJP?o:?l0C?oonfX3ool0
fE_ooo]Z0003oookJP?o001o00Cooo]Zo`00Ool007oo001o0ooonfX3o`00O`Kooo]Z0ol007l7oook
JPCo0000R?oonfX6obX0o`Coo`3o6_oonfX9ool0:Ckooo]Z1_oo02T>oookJP;oo`3o1?lZ0?lRoook
JP;o0?mS8OoonfX2oonf01_ooo]Z0olXo`1<oookJP?oo`3IFooonfX000;ooo]Z0ol007l3oookJP?o
001o1_oonfX9o`00O`Kooo]Z1?l00026oookJPKo:P3o0_oonfX2ool0oa[ooo]Z1ooo02U4oookJPKo
o`0Y3OoonfX2ool0o`?o:P3o8OoonfX3o`3oHb7ooo]Z0_oo]P0KoookJP;o:?l0C?oonfX3ool0fEco
oo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z2Ol007l6oookJPKo0000P_oonfX5obX0oakooo]Z
1ooo02TRoookJQ;o<Ol05OoonfX5ool0:@cooo]Z0_oo0?l4obX0ob3ooo]Z0ol0of<PoookJP?ookH0
6_oonfX3obSo04_ooo]Z0ooo0=UMoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oookJP;o001o0ooo
nfX3o`00O`Oooo]Z1?l00022oookJPGo:P3o7OoonfX7ool0:Agooo]Z7olao`0AoookJPGoo`0Y3?oo
nfX2ool0o`?o:P3o8?oonfX2o`3oHb7ooo]Z0_oo]P0KoookJP;o:?l0C?oonfX3ool0fEgooo]Z0002
oookJP?o001o0ooonfX3o`00O`Oooo]Z0_l007l2oookJP?o001o1ooonfX4o`00083ooo]Z1OlZ0?lM
oookJPOoo`0Y6_oonfX@oc7o00Wooo]Z3olao`0>oookJPGoo`0Y3?oonfX00ooo0?oo:P3oobX0o`02
obX0oaoooo]Z0_l0of<PoookJP?ookH06_oonfX3obSo04_ooo]Z0ooo0=UNoookJP000_oonfX3o`00
O`?ooo]Z0ol007l7oookJP?o001o00Cooo]Zo`00Ool007oo001o1ooonfX4o`0007kooo]Z1OlZ0?lL
oookJPOoo`0Y6?oonfX<oc7o01Wooo]Z2olao`0=oookJPCoo`0Y2ooonfX2ool0o`?o:P3o7ooonfX2
o`3oHb3ooo]Z0ooo]P0IoookJP?o:?l0BooonfX3ool0fEoooo]Z0002oookJP?o001o0ooonfX3o`00
O`Sooo]Z0_l007l01?oonf[o001oo`00Ool007l7oookJPCo0000O?oonfX6obX0oa_ooo]Z1ooo02TJ
oookJPOo<Ol08_oonfX9oc7o00cooo]Z1?oo02T:oookJP;oo`3o0olZ0?lOoookJP;o0?mS8?oonfX2
oonf01[ooo]Z0olXo`1;oookJP?oo`3IGooonfX000;ooo]Z0ol007l3oookJP?o001o2OoonfX5o`00
O`Oooo]Z1?l0001joookJPKo:P3o6ooonfX6ool0:DWooo]Z2?lao`0;oookJPCoo`0Y2_oonfX2ool0
o`?o:P3o7OoonfX3o`3oHaoooo]Z0ooo]P0IoookJP?o:?l0BooonfX3ool0fF3ooo]Z0003oookJP?o
001o00Cooo]Zo`00Ool007oo001o2_oonfX5o`00O`Oooo]Z1?l0001ioookJPGo:P3o6ooonfX6ool0
:Dkooo]Z1_lao`0:oookJPCoo`0Y2_oonfX2ool0o`?o:P3o7OoonfX3o`3oHaoooo]Z0ooo]P0Ioook
JP?o:?l0B_oonfX3ool0fF7ooo]Z0003oookJPOo001o2ooonfX4o`00O`Oooo]Z1?l0001goookJPGo
:P3o6ooonfX6ool0:E;ooo]Z1_lao`09oookJPCoo`0Y2OoonfX2ool0o`?o:P3o7OoonfX2o`3oHaoo
oo]Z0ooo]P0IoookJP?o:?l0B_oonfX4ool0fF7ooo]Z0004oookJPGo001o3OoonfX3o`00O`Oooo]Z
1?l0001eoookJPKo:P3o6_oonfX6ool0:C[ooo]Z1_mk0?lEoookJPKo<Ol02OoonfX3ool0:@[ooo]Z
00Coo`3oobX0oolZ0?oo:P3o7OoonfX2o`3oHaoooo]Z0ooo]P0IoookJP?o:?l0B_oonfX3ool0fF;o
oo]Z000PoookJPCo0000MOoonfX4obX0oa[ooo]Z1_oo02TboookJQSoN`3o3ooonfX5oc7o00Sooo]Z
1?oo02T9oookJP;oo`3o0_lZ0?lLoookJP?o0?mS7_oonfX3oonf01Wooo]Z0olXo`1:oookJP?oo`3I
HooonfX0023ooo]Z1?l0002AoookJPKoo`0Y;ooonfXQog/0o`cooo]Z1Olao`08oookJP?oo`0Y2Ooo
nfX2ool0o`;o:P3o7?oonfX3o`3oHakooo]Z0ooo]P0HoookJPCo:?l0BOoonfX4ool0fF?ooo]Z000P
oookJPCo0000SooonfX6ool0:Bkooo]Z3?mk0?l@oookJP_oN`3o2_oonfX4oc7o00Sooo]Z0ooo02T9
oookJP;oo`3o0_lZ0?lLoookJP;o0?mS7_oonfX3oonf01Wooo]Z0olXo`19oookJPCoo`3II?oonfX0
023ooo]Z1?l0002>oookJPGoo`0Y;?oonfX:og/0oa[ooo]Z2Omk0?l9oookJPCo<Ol02?oonfX3ool0
:@Sooo]Z0_oo0?l2obX0oa_ooo]Z0ol0of<NoookJP?ookH06?oonfX3obSo04[ooo]Z0ooo0=UUoook
JP008?oonfX4o`0008cooo]Z1Ooo02T[oookJPWoN`3o8OoonfX7og/0o`Wooo]Z1?lao`07oookJP?o
o`0Y2?oonfX2ool0o`;o:P3o6ooonfX3o`3oHagooo]Z0ooo]P0IoookJP?o:?l0BOoonfX3ool0fFKo
oo]Z000PoookJPCo0000R_oonfX5ool0:B_ooo]Z2?mk0?lWoookJPKoN`3o1ooonfX4oc7o00Oooo]Z
0ooo02T8oookJP;oo`3o0_lZ0?lKoookJP;o0?mS7OoonfX4oonf01Sooo]Z0olXo`19oookJP?oo`3I
IooonfX0023ooo]Z1?l00029oookJPGoo`0Y:OoonfX7og/0obcooo]Z1_mk0?l7oookJPCo<Ol01_oo
nfX3ool0:@Sooo]Z00Coo`3oobX0oolZ0?oo:P3o6_oonfX3o`3oHagooo]Z0ooo]P0HoookJPCo:?l0
B?oonfX4ool0fFOooo]Z000PoookJPGo0000Q_oonfX5ool0:BWooo]Z1omk0?l`oookJPGoN`3o1ooo
nfX3oc7o00Oooo]Z0_oo02T8oookJP04ool0oolZ0?oo:P3oobX0oa[ooo]Z0_l0of<MoookJP?ookH0
6OoonfX3obSo04Wooo]Z0ooo0=UXoookJP008?oonfX4o`0008Gooo]Z1Ooo02TXoookJPOoN`3o=?oo
nfX4og/0o`Oooo]Z0olao`07oookJP;oo`0Y2?oonfX01?oo0?oo:P3oobX0oolZ0?lIoookJP?o0?mS
7OoonfX3oonf01Sooo]Z0olXo`19oookJP?oo`3IJOoonfX0023ooo]Z1?l00024oookJPGoo`0Y9ooo
nfX6og/0ocSooo]Z1?mk0?l6oookJP?o<Ol01ooonfX2ool0:@Sooo]Z00Coo`3oobX0oolZ0?oo:P3o
6OoonfX3o`3oHacooo]Z0ooo]P0HoookJPCo:?l0B?oonfX3ool0fF[ooo]Z000PoookJPCo0000P_oo
nfX5ool0:BOooo]Z1_mk0?lkoookJPCoN`3o1_oonfX3oc7o00?ooo]Z0_ooe@000ooonf[oo`0Yool0
:@07oookJP;oo`3o0_lZ0?lIoookJP?o0?mS7?oonfX4oonf01Oooo]Z1?lXo`18oookJPCoo`3IJ_oo
nfX0023ooo]Z1?l00021oookJPGoo`0Y9_oonfX6og/0ockooo]Z0omk0?l6oookJP?o<Ol00ooonfX2
oooE0003oookJ_oo02Woo`0Y00Oooo]Z00Coo`3oobX0oolZ0?oo:P3o6OoonfX3o`3oHacooo]Z0ooo
]P0HoookJP?o:?l0B?oonfX4ool0fF_ooo]Z000PoookJPCo0000OooonfX5ool0:BKooo]Z1_mk0?m0
oookJPCoN`3o1OoonfX3oc7o00?ooo]Z0_ooe@000ooonf[oo`0Yool0:@07oookJP04ool0oolZ0?oo
:P3oobX0oaSooo]Z0ol0of<LoookJP?ookH06?oonfX3obSo04Sooo]Z1?oo0=U/oookJP008?oonfX4
o`0007kooo]Z1Ooo02TUoookJPKoN`3o@ooonfX3og/0o`Gooo]Z0olao`02oookJP?oomD00ooo02T6
oookJP;oo`3o0olZ0?lHoookJP?o0?mS6ooonfX4oonf01Oooo]Z1?lXo`18oookJP?oo`3IKOoonfX0
023ooo]Z1?l0001moookJPCoo`0Y9_oonfX5og/0odGooo]Z0omk0?l5oookJP?o<Ol00_oonfX3oooE
00?oo`0Y1_oonfX01?oo0?oo:P3oobX0oolZ0?lHoookJP?o0?mS7?oonfX3oonf01Oooo]Z1?lXo`18
oookJP?oo`3IK_oonfX0023ooo]Z1?l0001koookJPGoo`0Y9OoonfX5og/0odOooo]Z0omk0?l5oook
JP?o<Ol00_oonfX3oooE00?oo`0Y1_oonfX01?oo0?oo:P3oobX0oolZ0?lGoookJPCo0?mS6ooonfX3
oonf01Sooo]Z0olXo`18oookJP?oo`3IKooonfX0023ooo]Z1?l0001joookJPGoo`0Y9?oonfX6og/0
odWooo]Z0_mk0?l5oookJP?o<Ol00_oonfX3oooE00;oo`0Y1_oonfX2ool0o`?o:P3o5ooonfX3o`3o
Ha_ooo]Z1?oo]P0GoookJP?o:?l0B?oonfX4ool0fFoooo]Z000PoookJPCo0000NOoonfX4ool0:BGo
oo]Z1Omk0?m;oookJP;oN`3o1OoonfX3oc7o00;ooo]Z0_ooe@03ool0:@Kooo]Z00Coo`3oobX0oolZ
0?oo:P3o5ooonfX3o`3oHa_ooo]Z1?oo]P0GoookJPCo:?l0AooonfX4ool0fG3ooo]Z000PoookJPCo
0000MooonfX5ool0:BCooo]Z1Omk0?m=oookJP;oN`3o1OoonfX3oc7o0004oookJ_ooe@3oomD0oooE
00?oo`0Y1OoonfX2ool0o`?o:P3o5_oonfX4o`3oHa_ooo]Z0ooo]P0GoookJPCo:?l0AooonfX4ool0
fG7ooo]Z000PoookJPCo0000M_oonfX4ool0:BGooo]Z1Omk0?m>oookJP;oN`3o1OoonfX2oc7o00;o
oo]Z0oooe@03ool0:@Gooo]Z00Coo`3oobX0oolZ0?oo:P3o5ooonfX3o`3oHa_ooo]Z0ooo]P0Hoook
JP?o:?l0AooonfX4ool0fG;ooo]Z000PoookJPCo0000MOoonfX4ool0:BCooo]Z1Omk0?m@oookJP;o
N`3o1?oonfX3oc7o00;ooo]Z0oooe@02ool0:@Kooo]Z00Coo`3oobX0oolZ0?oo:P3o5_oonfX3o`3o
Ha_ooo]Z1?oo]P0GoookJP?o:?l0B?oonfX3ool0fG?ooo]Z000PoookJPCo0000LooonfX5ool0:BGo
oo]Z1?mk0?mAoookJP;oN`3o1?oonfX3oc7o0004oookJ_ooe@3oomD0oooE00?oo`0Y1OoonfX01?oo
0?oo:P3oobX0oolZ0?lFoookJPCo0?mS6_oonfX4oonf01Oooo]Z0olXo`18oookJP?oo`3IM?oonfX0
023ooo]Z1?l0001boookJPGoo`0Y9_oonfX2og/0oe?ooo]Z0_mk0?l4oookJP?o<Ol000Cooo]ZoooE
0?ooe@3oomD00_oo02T5oookJP;oo`3o0olZ0?lFoookJP?o0?mS6ooonfX3oonf01Oooo]Z1?lXo`17
oookJP?oo`3IMOoonfX0023ooo]Z1Ol0001`oookJPCoo`0YG?oonfX=ool0fA?ooo]Z0omk0?l3oook
JP?o<Ol000Cooo]ZoooE0?ooe@3oomD00ooo02T5oookJP04ool0oolZ0?oo:P3oobX0oaKooo]Z0ol0
of<KoookJP?ookH05ooonfX4obSo04Oooo]Z1?oo0=UeoookJP008?oonfX4o`00073ooo]Z1?oo02UJ
oookJQ;oo`3I4OoonfX3og/0o`?ooo]Z0olao`001?oonf[oomD0oooE0?ooe@03ool0:@Cooo]Z00?o
o`3oobX0oolZ0?l00_lZ0?lEoookJPCo0?mS6_oonfX4oonf01Kooo]Z1?lXo`17oookJPCoo`3IM_oo
nfX0023ooo]Z1?l0001_oookJPCoo`0YF?oonfX9ool0f@Kooo]Z1ooo0=T@oookJP?oN`3o0_oonfX3
oc7o0003oookJ_ooe@3oomD000;oomD00_oo02T5oookJP04ool0oolZ0?oo:P3oobX0oaGooo]Z1?l0
of<JoookJPCookH05ooonfX3obSo04Oooo]Z1?oo0=UgoookJP008?oonfX4o`0006gooo]Z1Ooo02UG
oookJPOoo`3I3OoonfX5ool0f@kooo]Z0omk0?l3oookJP?o<Ol000Cooo]ZoooE0?ooe@3oomD00_oo
02T5oookJP04ool0oolZ0?oo:P3oobX0oaKooo]Z0ol0of<JoookJPCookH05ooonfX3obSo04Oooo]Z
1?oo0=UhoookJP008?oonfX4o`0006cooo]Z1?oo02UGoookJPOoo`3I2?oonfX4obSo00Cooo]Z1?oo
0=T>oookJP?oN`3o0_oonfX4oc7o00?oomD00ooo02T4oookJP03ool0oolZ0?oo:P3o00;o:P3o5Ooo
nfX3o`3oHa[ooo]Z1?oo]P0GoookJP?o:?l0AooonfX4ool0fGWooo]Z000PoookJPCo0000JooonfX4
ool0:EKooo]Z1_oo0=T6oookJPco:?l00_oonfX4ool0f@cooo]Z0omk0?l3oookJP?o<Ol000Cooo]Z
oooE0?ooe@3oomD00_oo02T5oookJP04ool0oolZ0?oo:P3oobX0oaGooo]Z1?l0of<JoookJP?ookH0
5ooonfX3obSo04Oooo]Z1?oo0=UjoookJP008?oonfX4o`0006[ooo]Z1?oo02UFoookJPGoo`3I1Ooo
nfXAobSo0004oookJ_oo0=Woo`3Iool0f@cooo]Z0omk0?l2oookJP?o<Ol000Cooo]ZoooE0?ooe@3o
omD00ooo02T4oookJP04ool0oolZ0?oo:P3oobX0oaGooo]Z1?l0of<JoookJP?ookH05ooonfX4obSo
04Kooo]Z1?oo0=UkoookJP008?oonfX4o`0006Wooo]Z1?oo02UEoookJPGoo`3I1OoonfX8obSo00Ko
okH01OlXo`001?oonf[oo`3Iool0fOoo0=T;oookJPCoN`3o00?ooo]Zoc7o0?lao`000_lao`04oooE
00;oo`0Y1?oonfX00ooo0?oo:P3oobX0o`02obX0oaCooo]Z1?l0of<JoookJPCookH05_oonfX4obSo
04Kooo]Z1?oo0=UloookJP008?oonfX4o`0006Sooo]Z1?oo02UEoookJPGoo`3I1OoonfX6obSo00_o
okH00olXo`001?oonf[oo`3Iool0fOoo0=T;oookJP?oN`3o0_oonfX3oc7o00CoomD00_oo02T4oook
JP03ool0oolZ0?oo:P3o00;o:P3o5?oonfX4o`3oHa[ooo]Z1?oo]P0FoookJPCo:?l0A_oonfX4ool0
fGgooo]Z000PoookJPCo0000IooonfX4ool0:ECooo]Z1Ooo0=T5oookJPKo:?l01?oo]P09o`3oH`04
oonf0?lXo`3o:?l0obSo00?oo`3I2_oonfX3og/0o`;ooo]Z1?lao`03oooE00?oo`0Y0ooonfX00ooo
0?oo:P3oobX0o`02obX0oaGooo]Z0ol0of<JoookJPCookH05_oonfX4obSo04Kooo]Z1?oo0=Unoook
JP008?oonfX4o`0006Kooo]Z1?oo02UDoookJPGoo`3I1OoonfX5obSo00CookH02ol0of<01?oo]P3o
:?l0obSo0?lXo`03ool0f@Wooo]Z1?mk0?l00ooonf[o<Ol0oc7o0002oc7o00CoomD00_oo02T4oook
JP04ool0oolZ0?oo:P3oobX0oaGooo]Z0ol0of<JoookJPCookH05_oonfX4obSo04Kooo]Z1?oo0=Uo
oookJP008?oonfX4o`0006Gooo]Z1?oo02UDoookJPCoo`3I1OoonfX5obSo00CookH01Ol0of<7obX0
o`;o0?mS0olXo`02ool0f@Wooo]Z1?mk0?l00ooonf[o<Ol0oc7o0002oc7o00CoomD00_oo02T4oook
JP03ool0oolZ0?oo:P3o00;o:P3o5?oonfX4o`3oHaWooo]Z1?oo]P0FoookJPCo:?l0A_oonfX4ool0
fH3ooo]Z000PoookJPCo0000I?oonfX4ool0:ECooo]Z1?oo0=T5oookJPGo:?l01?oo]P04o`3oH`Wo
:P3o00Co0?mSobSo0?lXo`3o:?l00ooo0=T9oookJP?oN`3o0_oonfX3oc7o00CoomD00_oo02T4oook
JP03ool0oolZ0?oo:P3o00;o:P3o5?oonfX4o`3oHaWooo]Z1?oo]P0FoookJPCo:?l0A_oonfX4ool0
fH7ooo]Z000PoookJPCo0000HooonfX4ool0:ECooo]Z1?oo0=T5oookJPCo:?l01?oo]P000ooonf[o
0?mSo`3oH`02o`3oH`Co:P3o1Omk0?l00olZ0?oo0?mSobSo0002obSo00;oo`3I2OoonfX3og/0o`;o
oo]Z0olao`04oooE00;oo`0Y1?oonfX00ooo0?oo:P3oobX0o`02obX0oaCooo]Z1?l0of<IoookJPCo
okH05_oonfX4obSo04Kooo]Z1?oo0=V2oookJP008?oonfX4o`0006;ooo]Z1?oo02UDoookJPCoo`3I
1OoonfX4obSo00CookH000?ooo]Zo`3oHol0of<00_l0of<3obX0o`OoN`3o00?o:P3oobSo0?lXo`00
0_lXo`02ool0f@Sooo]Z1?mk0?l01?oonf[o<Ol0oc7o0?lao`04oooE00;oo`0Y1?oonfX00ooo0?oo
:P3oobX0o`02obX0oaCooo]Z1?l0of<IoookJPCookH05_oonfX4obSo04Kooo]Z1?oo0=V3oookJP00
8?oonfX4o`00067ooo]Z1?oo02UDoookJPCoo`3I1OoonfX4obSo00CookH000?ooo]Zo`3oHol0of<0
0_l0of<3obX0o`SoN`3o1?lXo`02ool0f@Sooo]Z1?mk0?l01?oonf[o<Ol0oc7o0?lao`04oooE00;o
o`0Y1?oonfX00ooo0?oo:P3oobX0o`02obX0oaCooo]Z1?l0of<IoookJPCookH05_oonfX4obSo04Ko
oo]Z1?oo0=V4oookJP008?oonfX5o`0005oooo]Z0ooo02UEoookJPCoo`3I1OoonfX4obSo00CookH0
00?ooo]Zo`3oHol0of<00_l0of<4obX0o`?oN`3o00?o:?l0og/0oomk0?l00_mk0?l3obSo00;oo`3I
2?oonfX4og/0o`04oookJ_lao`3o<Ol0oc7o00CoomD00_oo02T4oookJP03ool0oolZ0?oo:P3o00;o
:P3o5?oonfX4o`3oHaWooo]Z1?oo]P0FoookJPCo:?l0A_oonfX4ool0fHGooo]Z000PoookJPCo0000
GooonfX3ool0:EGooo]Z1?oo0=T5oookJPCo:?l01?oo]P000ooonf[o0?mSo`3oH`02o`3oH`Co:P3o
1?mk0?l7obSo00;oo`3I1ooonfX5og/0o`Co<Ol01?ooe@02ool0:@Cooo]Z00?oo`3oobX0oolZ0?l0
0_lZ0?lDoookJPCo0?mS6OoonfX4oonf01Kooo]Z1?lXo`16oookJPCoo`3IQ_oonfX0023ooo]Z1?l0
001NoookJPCoo`0YE?oonfX4ool0f@Gooo]Z1?lXo`04oonf0003oookJ_l0of?o0?mS00;o0?mS00Go
oo]ZobX0oolZ0?oo:P3ooooE0003og/0o`03ool0fOlXo`3o:?l000Co:?l00_oo0=T7oookJPGoN`3o
1?lao`04oooE00;oo`0Y1?oonfX00ooo0?oo:P3oobX0o`02obX0oaCooo]Z1?l0of<IoookJPCookH0
5_oonfX4obSo04Kooo]Z1?oo0=V7oookJP008?oonfX4o`0005gooo]Z0ooo02UEoookJPCoo`3I1_oo
nfX3obSo0005oookJ_oo]P3ookH0oonf0?oonfX01?l0of<01_oonf[o:P3oobX0oolZ0?ooo`3ooooE
00;oN`3o0_oonfX6ool0f@Sooo]Z1?mk0?l00ooonf[o<Ol0oc7o0002oc7o00CoomD00_oo02T3oook
JP;oo`3o1?lZ0?lDoookJPCo0?mS6OoonfX4oonf01Kooo]Z1?lXo`16oookJPCoo`3IR?oonfX0023o
oo]Z1?l0001LoookJPCoo`0YE?oonfX4ool0f@Kooo]Z0olXo`001?oonf[ookH0oonf0?oo]P02oook
JP?o0?mS0_oonfX3obX0o`;oomD00_mk0?l>oookJPGoN`3o1?lao`05oooE00;oo`0Y0ooonfX00ooo
0?oo:P3oobX0o`03obX0oa?ooo]Z1Ol0of<IoookJPCookH05_oonfX4obSo04Kooo]Z1?oo0=V9oook
JP008?oonfX4o`0005_ooo]Z1?oo02UDoookJPCoo`3I1_oonfX4obSo00CookH000?ooo]Zo`3oHol0
of<00_l0of<01Ooonf[o:P3oobX0oolZ0?ooo`3o00;oomD00omk0?l;oookJPKoN`3o1?lao`05oooE
00;oo`0Y0ooonfX00ooo0?oo:P3oobX0o`02obX0oaCooo]Z1Ol0of<IoookJPCookH05_oonfX4obSo
04Kooo]Z1?oo0=V:oookJP008?oonfX4o`0005[ooo]Z1?oo02UEoookJP?oo`3I1_oonfX4obSo0004
oookJ_oo]P3ookH0oonf00;ooo]Z0ol0of<2oookJP?o:P3o0oooe@04og/0o`Sooo]Z1_mk0?l4oc7o
00GoomD00ooo02T3oookJP03ool0oolZ0?oo:P3o00;o:P3o5?oonfX4o`3oHa[ooo]Z1?oo]P0Foook
JPCo:?l0A_oonfX4ool0fH_ooo]Z000PoookJPCo0000FOoonfX4ool0:EGooo]Z0ooo0=T7oookJP?o
:?l000Cooo]Zoonf0?oo]P3ookH00_oonfX3o`3oH`?ooo]Z0olZ0?l3oooE00KoN`3o0ooonfX8og/0
o`Co<Ol01Oooe@02ool0:@?ooo]Z00?oo`3oobX0oolZ0?l00olZ0?lDoookJPCo0?mS6_oonfX4oonf
01Kooo]Z1?lXo`16oookJPCoo`3IS?oonfX0023ooo]Z1?l0001HoookJPCoo`0YEOoonfX4ool0f@Ko
oo]Z0olXo`000ooonf[ookH0oonf0002oonf00;ooo]Z0ol0of<3oookJP;o:P3o00Goo`3ooooE0?oo
e@3oomD0oc7o000=og/0o`Go<Ol01Oooe@03ool0:@?ooo]Z00?oo`3oobX0oolZ0?l00olZ0?lDoook
JPCo0?mS6OoonfX5oonf01Kooo]Z1?lXo`16oookJPCoo`3ISOoonfX0023ooo]Z1?l0001GoookJPCo
o`0YEOoonfX4ool0f@Oooo]Z0olXo`001?oonf[ookH0oonf0?oo]P03oookJP?o0?mS0ooonfX2obX0
o`03ool0ooooe@3oomD000;oomD000?o<Ol0og/0oomk0?l02?mk0?l5oc7o00KoomD00_oo02T3oook
JP03ool0oolZ0?oo:P3o00?o:P3o5OoonfX4o`3oHaWooo]Z1?oo]P0GoookJPCo:?l0A_oonfX4ool0
fHkooo]Z000PoookJPCo0000E_oonfX4ool0:EKooo]Z0ooo0=T7oookJP?o:?l000?ooo]Zoonf0?oo
]P000_oo]P02oookJP?o0?mS1?oonfX2obX0o`03ool0oooo02WoomD000?oomD03?lao`07oooE00?o
o`0Y0ooonfX00ooo0?oo:P3oobX0o`03obX0oaCooo]Z1Ol0of<IoookJPCookH05_oonfX4obSo04Oo
oo]Z1?oo0=V?oookJP008?oonfX4o`0005Gooo]Z1?oo02UFoookJPCoo`3I1_oonfX4obSo0004oook
J_oo]P3ookH0oonf00?ooo]Z0ol0of<4oookJP?o:P3o00?oo`0YoooE0?ooe@000oooe@08oc7o00So
omD00ooo02T3oookJP03ool0oolZ0?oo:P3o00?o:P3o5OoonfX4o`3oHa[ooo]Z1?oo]P0FoookJPCo
:?l0AooonfX4ool0fI3ooo]Z000PoookJPCo0000E?oonfX4ool0:EKooo]Z1?oo0=T7oookJP?o:?l0
0_oonfX3oonf00?ooo]Z0ol0of<4oookJP?o:P3o00?oo`3oool0:Oooe@004Oooe@03ool0:@?ooo]Z
00?oo`3oobX0oolZ0?l01?lZ0?lEoookJPCo0?mS6_oonfX4oonf01Kooo]Z1?lXo`17oookJPCoo`3I
TOoonfX000Cooo]Z1Ol007l4oookJP?o001o0ooonfX5o`00O`Sooo]Z1?l0001CoookJPCoo`0YEooo
nfX3ool0f@Sooo]Z0olXo`001?oonf[ookH0oonf0?oo]P04oookJP;o0?mS1OoonfX4obX0o`;oo`0Y
3_ooe@04ool0:@?ooo]Z00?oo`3oobX0oolZ0?l01?lZ0?lEoookJPGo0?mS6OoonfX5oonf01Kooo]Z
1?lXo`17oookJPCoo`3IT_oonfX000?ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z1?l0
001CoookJP?oo`0YEooonfX3ool0f@Sooo]Z0olXo`02oookJP?ookH01?oonfX2o`3oH`Kooo]Z0olZ
0?l00ooo0?oooo]Zool0:@02ool0:@OoomD01Ooo02T4oookJP03ool0oolZ0?oo:P3o00Co:P3o5_oo
nfX5o`3oHaWooo]Z1?oo]P0GoookJPCo:?l0AooonfX4ool0fI?ooo]Z0003oookJP?o001o00Cooo]Z
o`00Ool007oo001o0ooonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o1_oonfX4o`0005;ooo]Z0ooo
02UHoookJP?oo`3I2?oonfX3obSo00;ooo]Z0ooo]P04oookJP;o0?mS1_oonfX4obX0o`03ool0oooo
nf[ooo]Z00Woo`0Y1OoonfX2ool0o`Oo:P3o5OoonfX5o`3oHa[ooo]Z1?oo]P0GoookJPCo:?l0A_oo
nfX4ool0fIGooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX4
o`00057ooo]Z0ooo02UHoookJP?oo`3I2?oonfX3obSo00;ooo]Z0ooo]P05oookJP;o0?mS1ooonfX5
obX0o`03ool0oooonf[ooo]Z00Sooo]Z0ooo0?l7obX0oaOooo]Z1Ol0of<JoookJPCookH05_oonfX5
obSo04Kooo]Z1?oo0=VFoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00
O`Kooo]Z1_l0001>oookJPCoo`0YF?oonfX3ool0f@Sooo]Z0olXo`02oookJP?ookH01OoonfX2o`3o
H`Sooo]Z1olZ0?l6ool0o`[o:P3o5ooonfX5o`3oHa[ooo]Z1Ooo]P0FoookJPCo:?l0AooonfX4ool0
fIOooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l007l2oookJP?o001o1_oonfX4o`0004oo
oo]Z1?oo02UHoookJP?oo`3I2OoonfX2obSo00?ooo]Z0ooo]P05oookJP;o0?mS2OoonfXCobX0oaWo
oo]Z1Ol0of<JoookJPGookH05_oonfX4obSo04Oooo]Z1?oo0=VHoookJP000_oonfX3o`00O`?ooo]Z
0ol007l6oookJPSo001o1ooonfX4o`0004kooo]Z1?oo02UIoookJP?oo`3I2?oonfX3obSo00?ooo]Z
0_oo]P06oookJP?o0?mS2_oonfX>obX0oa[ooo]Z1Ol0of<KoookJPCookH05ooonfX4obSo04Oooo]Z
1?oo0=VIoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o00Cooo]Zo`00Ool007oo001o
2?oonfX4o`0004kooo]Z0ooo02UIoookJP?oo`3I2OoonfX3obSo00?ooo]Z0_oo]P06oookJP?o0?mS
<?oonfX6o`3oHa[ooo]Z1Ooo]P0FoookJPGo:?l0AooonfX4ool0fI[ooo]Z0002oookJP?o001o0ooo
nfX3o`00O`Kooo]Z0ol007l<oookJPCo0000COoonfX3ool0:E[ooo]Z0ooo0=T9oookJP?o:?l00ooo
nfX2oonf00Kooo]Z0ol0of<_oookJPGo0?mS6ooonfX5oonf01Kooo]Z1?lXo`18oookJPCoo`3IVooo
nfX000;ooo]Z0ol007l3oookJP?o001o1_oonfX3o`00O`cooo]Z1?l0001<oookJP?oo`0YF_oonfX3
ool0f@[ooo]Z0_lXo`03oookJP?ookH01_oonfX4o`3oHbcooo]Z1Ol0of<KoookJPGookH05ooonfX4
obSo04Oooo]Z1?oo0=VMoookJP000ooonfX3o`00O`04oookJ_l007oo001oo`00O`Sooo]Z0ol007l2
oookJP?o001o1_oonfX4o`0004_ooo]Z1?oo02UJoookJP?oo`3I2OoonfX3obSo00?ooo]Z0ooo]P07
oookJP?o0?mS:OoonfX7o`3oHa_ooo]Z1Ooo]P0FoookJPGo:?l0AooonfX4ool0fIkooo]Z0003oook
JPOo001o2?oonfX7o`00O`Oooo]Z1?l0001:oookJPCoo`0YF_oonfX3ool0f@[ooo]Z0olXo`03oook
JP?ookH01ooonfX4o`3oHbOooo]Z1_l0of<LoookJPCookH05ooonfX5obSo04Oooo]Z1?oo0=VOoook
JP001?oonfX5o`00O`_ooo]Z1?l007l8oookJPCo0000BOoonfX4ool0:E_ooo]Z0ooo0=T:oookJP?o
:?l00ooonfX3oonf00Sooo]Z1?l0of<ToookJPKo0?mS7?oonfX5oonf01Oooo]Z1?lXo`18oookJPCo
o`3IX?oonfX0023ooo]Z1?l00019oookJP?oo`0YG?oonfX3ool0f@[ooo]Z0_lXo`04oookJP?ookH0
2?oonfX5o`3oHb3ooo]Z1ol0of<MoookJPGookH05_oonfX5obSo04Sooo]Z1?oo0=VQoookJP008?oo
nfX4o`0004Sooo]Z0ooo02ULoookJP?oo`3I2ooonfX2obSo00Cooo]Z0ooo]P09oookJPGo0?mS7?oo
nfX7o`3oHakooo]Z1Ooo]P0GoookJPGo:?l0B?oonfX4ool0fJ;ooo]Z000PoookJPCo0000AooonfX3
ool0:Egooo]Z0ooo0=T;oookJP;o:?l01OoonfX2oonf00[ooo]Z1_l0of<GoookJPSo0?mS7_oonfX5
oonf01Sooo]Z1?lXo`18oookJPCoo`3IY?oonfX0023ooo]Z1?l00016oookJPCoo`0YGOoonfX2ool0
f@cooo]Z0_lXo`05oookJP;ookH02ooonfX7o`3oHa;ooo]Z2Ol0of<OoookJPGookH05ooonfX5obSo
04Sooo]Z1?oo0=VUoookJP008?oonfX4o`0004Gooo]Z1?oo02UMoookJP?oo`3I2ooonfX3obSo00Go
oo]Z0ooo]P0<oookJPWo0?mS2?oonfX<o`3oHb3ooo]Z1Ooo]P0HoookJPGo:?l0B?oonfX4ool0fJKo
oo]Z000PoookJPCo0000AOoonfX3ool0:Ekooo]Z0ooo0=T;oookJP?o:?l01OoonfX3oonf00kooo]Z
5ol0of<RoookJPKookH05ooonfX5obSo04Wooo]Z1?oo0=VWoookJP008?oonfX4o`0004Cooo]Z0ooo
02UOoookJP;oo`3I3?oonfX3obSo00Gooo]Z0ooo]P0AoookJQ3o0?mS9OoonfX5oonf01Sooo]Z1OlX
o`18oookJPGoo`3IZ?oonfX0023ooo]Z1Ol00012oookJPCoo`0YG_oonfX3ool0f@cooo]Z0olXo`06
oookJP?ookH0@ooonfX5oonf01Sooo]Z1OlXo`19oookJPCoo`3IZ_oonfX0023ooo]Z1?l00012oook
JPCoo`0YGooonfX3ool0f@cooo]Z0olXo`06oookJP?ookH0@OoonfX6oonf01Sooo]Z1OlXo`19oook
JPCoo`3IZooonfX0023ooo]Z1?l00012oookJP?oo`0YH?oonfX3ool0f@gooo]Z0_lXo`06oookJPCo
okH0?_oonfX6oonf01Sooo]Z1OlXo`1:oookJPCoo`3I[?oonfX0023ooo]Z1?l00011oookJP?oo`0Y
HOoonfX2ool0f@kooo]Z0_lXo`07oookJP?ookH0??oonfX6oonf01Wooo]Z1OlXo`19oookJPGoo`3I
[OoonfX0023ooo]Z1?l00010oookJPCoo`0YH?oonfX3ool0f@kooo]Z0_lXo`07oookJPCookH0>Ooo
nfX6oonf01Wooo]Z1OlXo`1:oookJPCoo`3I[ooonfX0023ooo]Z1?l0000ooookJPCoo`0YHOoonfX3
ool0f@kooo]Z0olXo`07oookJPCookH0=_oonfX6oonf01[ooo]Z1OlXo`1:oookJPCoo`3I/?oonfX0
023ooo]Z1?l0000ooookJP?oo`0YH_oonfX3ool0f@kooo]Z0olXo`07oookJPGookH0<ooonfX6oonf
01[ooo]Z1OlXo`1:oookJPGoo`3I/OoonfX0023ooo]Z1?l0000noookJP?oo`0YHooonfX2ool0f@oo
oo]Z0olXo`08oookJPGookH0;ooonfX7oonf01[ooo]Z1_lXo`1:oookJPGoo`3I/_oonfX0023ooo]Z
1?l0000moookJP?oo`0YI?oonfX2ool0f@oooo]Z0olXo`09oookJPGookH0;?oonfX7oonf01_ooo]Z
1OlXo`1;oookJPCoo`3I]?oonfX0023ooo]Z1?l0000loookJPCoo`0YHooonfX3ool0fA3ooo]Z0olX
o`09oookJPGookH0:?oonfX7oonf01cooo]Z1OlXo`1<oookJPCoo`3I]OoonfX0023ooo]Z1?l0000l
oookJP?oo`0YI?oonfX3ool0fA3ooo]Z0olXo`0:oookJPKookH08ooonfX8oonf01cooo]Z1_lXo`1;
oookJPGoo`3I]_oonfX0023ooo]Z1?l0000koookJP?oo`0YIOoonfX2ool0fA7ooo]Z0olXo`0;oook
JPOookH07_oonfX8oonf01gooo]Z1_lXo`1<oookJPCoo`3I^?oonfX0023ooo]Z1?l0000joookJPCo
o`0YIOoonfX2ool0fA;ooo]Z0olXo`0<oookJPSookH05ooonfX9oonf01oooo]Z1OlXo`1=oookJPCo
o`3I^OoonfX0023ooo]Z1?l0000joookJP?oo`0YI_oonfX2ool0fA;ooo]Z0olXo`0>oookJPWookH0
4?oonfX:oonf023ooo]Z1OlXo`1=oookJPGoo`3I^_oonfX0023ooo]Z1?l0000ioookJP?oo`0YIooo
nfX2ool0fA;ooo]Z1?lXo`0?oookJQgookH08_oonfX5obSo04kooo]Z1?oo0=VloookJP008?oonfX4
o`0003Sooo]Z0ooo02UXoookJP;oo`3I4ooonfX4obSo01;ooo]Z5Ooo]P0ToookJPKo:?l0C_oonfX4
ool0fKgooo]Z000PoookJPGo0000=_oonfX4ool0:FSooo]Z0_oo0=TCoookJPCo:?l0BOoonfX6obSo
04kooo]Z1Ooo0=VnoookJP008?oonfX4o`0003Oooo]Z0ooo02UYoookJP;oo`3I5?oonfX4obSo04Ko
oo]Z1_lXo`1?oookJPCoo`3I`?oonfX0023ooo]Z1?l0000foookJP?oo`0YJOoonfX3ool0fAGooo]Z
0olXo`14oookJPKo:?l0CooonfX5ool0fL7ooo]Z000PoookJPCo0000=OoonfX4ool0:FWooo]Z0ooo
0=TEoookJPCo:?l0@?oonfX7obSo053ooo]Z1Ooo0=W2oookJP008?oonfX4o`0003Gooo]Z0ooo02UZ
oookJP;oo`3I5ooonfX4obSo03gooo]Z1_lXo`1AoookJPGoo`3Ia?oonfX0023ooo]Z1?l0000doook
JP?oo`0YJooonfX2ool0fASooo]Z1OlXo`0ioookJPKo:?l0D_oonfX5ool0fLGooo]Z000PoookJPCo
0000<ooonfX3ool0:Fcooo]Z0_oo0=TIoookJPGo:?l0=OoonfX7obSo05?ooo]Z1?oo0=W7oookJP00
8?oonfX4o`0003?ooo]Z0ooo02U/oookJP;oo`3I6_oonfX5obSo037ooo]Z1olXo`1DoookJPGoo`3I
b?oonfX0023ooo]Z1?l0000boookJP?oo`0YKOoonfX2ool0fA_ooo]Z1_lXo`0/oookJPSo:?l0EOoo
nfX5ool0fLWooo]Z000PoookJPCo0000<OoonfX3ool0:Fkooo]Z0ooo0=TLoookJPKo:?l09ooonfX8
obSo05Kooo]Z1Ooo0=W;oookJP008?oonfX4o`00037ooo]Z0ooo02U_oookJP;oo`3I7OoonfX8obSo
023ooo]Z2OlXo`1HoookJPGoo`3Ic?oonfX0023ooo]Z1?l0000`oookJP?oo`0YL?oonfX2ool0fAoo
oo]Z2OlXo`0IoookJP[o:?l0FOoonfX5ool0fLkooo]Z000PoookJPCo0000;ooonfX3ool0:G7ooo]Z
0_oo0=TQoookJPWo:?l04_oonfX;obSo05cooo]Z1Ooo0=W?oookJP008?oonfX4o`0002oooo]Z0ooo
02UaoookJP;oo`3I9?oonfXOobSo05kooo]Z1Ooo0=WAoookJP008?oonfX4o`0002kooo]Z0ooo02Ub
oookJP;oo`3I:?oonfXFobSo06;ooo]Z1Ooo0=WBoookJP008?oonfX4o`0002gooo]Z0ooo02Ucoook
JP;oo`3IW_oonfX5ool0fMCooo]Z000PoookJPGo0000;?oonfX3ool0:G?ooo]Z0_oo0=VMoookJPCo
o`3Ie_oonfX0023ooo]Z1?l0000/oookJP?oo`0YM?oonfX2ool0fI_ooo]Z1Ooo0=WGoookJP008?oo
nfX4o`0002_ooo]Z0ooo02UeoookJP?oo`3IV?oonfX5ool0fMWooo]Z000PoookJPCo0000:ooonfX3
ool0:GKooo]Z0_oo0=VGoookJPGoo`3If_oonfX0023ooo]Z1?l0000ZoookJP?oo`0YMooonfX2ool0
fIGooo]Z1Ooo0=WLoookJP008?oonfX4o`0002Wooo]Z0ooo02UhoookJP;oo`3IU?oonfX5ool0fMgo
oo]Z000PoookJPCo0000:OoonfX3ool0:GSooo]Z0ooo0=VAoookJPGoo`3IgooonfX0023ooo]Z1?l0
000XoookJP?oo`0YNOoonfX3ool0fHoooo]Z1Ooo0=WQoookJP008?oonfX4o`0002Oooo]Z1?oo02Uj
oookJP;oo`3ISOoonfX6ool0fN;ooo]Z000PoookJPCo00009ooonfX3ool0:G_ooo]Z0ooo0=V;oook
JPGoo`3Ii?oonfX0023ooo]Z1?l0000VoookJP?oo`0YO?oonfX3ool0fHWooo]Z1Ooo0=WVoookJP00
8?oonfX4o`0002Gooo]Z1?oo02UmoookJP;oo`3IQooonfX6ool0fNOooo]Z0004oookJPGo001o1?oo
nfX3o`00O`?ooo]Z1Ol007l8oookJPCo00009OoonfX3ool0:Gkooo]Z0ooo0=V5oookJPGoo`3IjOoo
nfX000?ooo]Z1ol007l3oookJP?o001o0_oonfX7o`00O`Oooo]Z1?l0000ToookJP?oo`0YOooonfX3
ool0fH?ooo]Z1Ooo0=W[oookJP000ooonfX3o`00O`04oookJ_l007oo001oo`00O`?ooo]Z0ol007l0
1?oonf[o001oo`00Ool007l3oookJP?o001o1_oonfX4o`0002Cooo]Z0ooo02V0oookJP?oo`3IP?oo
nfX5ool0fNgooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX4
o`0002?ooo]Z0ooo02V1oookJP?oo`3IO_oonfX6ool0fNkooo]Z0002oookJP?o001o0ooonfX3o`00
O`Kooo]Z0ol007l3oookJP?o001o1_oonfX6o`00023ooo]Z1?oo02V2oookJP;oo`3IO?oonfX6ool0
fO3ooo]Z0002oookJP?o001o0ooonfX3o`00O`Kooo]Z0ol007l3oookJP?o001o1_oonfX4o`0002;o
oo]Z0ooo02V3oookJP?oo`3INOoonfX6ool0fO;ooo]Z0002oookJP?o001o0ooonfX3o`00O`Oooo]Z
1ol007l7oookJPCo00008OoonfX3ool0:HGooo]Z0ooo0=UfoookJPKoo`3Im?oonfX000;ooo]Z0ol0
07l3oookJP?o001o1ooonfX7o`00O`Oooo]Z1?l0000PoookJPCoo`0YQOoonfX3ool0fGCooo]Z1_oo
0=WfoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oookJP?o001o0ooonfX3o`00O`Kooo]Z1?l0000P
oookJP?oo`0YQooonfX3ool0fG;ooo]Z1Ooo0=WhoookJP000_oonfX3o`00O`?ooo]Z0ol007l6oook
JP?o001o0ooonfX3o`00O`Kooo]Z1?l0000OoookJP?oo`0YR?oonfX3ool0fFoooo]Z1_oo0=Wjoook
JP000ooonfX3o`00O`04oookJ_l007oo001oo`00O`Oooo]Z0ol007l3oookJP?o001o1_oonfX4o`00
01oooo]Z0ooo02V9oookJP?oo`3IK?oonfX6ool0fOcooo]Z0003oookJPOo001o2?oonfX7o`00O`Oo
oo]Z1?l0000NoookJP?oo`0YRooonfX3ool0fFWooo]Z1_oo0=WnoookJP001?oonfX5o`00O`[ooo]Z
1Ol007l8oookJPCo00007_oonfX3ool0:H_ooo]Z1?oo0=UVoookJPKoo`3IoooonfX1oookJP008?oo
nfX4o`0001gooo]Z0ooo02V=oookJPCoo`3IHooonfX6ool0fOoooo]Z0ooonfX0023ooo]Z1?l0000L
oookJP?oo`0YSooonfX3ool0fF7ooo]Z1_oo0=WooookJPGooo]Z000PoookJPCo00007?oonfX3ool0
:I3ooo]Z0ooo0=UMoookJPOoo`3IoooonfX7oookJP008?oonfX4o`0001_ooo]Z0ooo02VAoookJPCo
o`3IF_oonfX6ool0fOoooo]Z2_oonfX0023ooo]Z1?l0000KoookJP?oo`0YT_oonfX4ool0fEKooo]Z
1ooo0=WooookJPcooo]Z000PoookJPCo00006_oonfX3ool0:ICooo]Z1Ooo0=UBoookJPOoo`3Ioooo
nfX>oookJP008?oonfX4o`0001Wooo]Z0ooo02VGoookJPCoo`3IC_oonfX7ool0fOoooo]Z4OoonfX0
023ooo]Z1Ol0000HoookJP?oo`0YV?oonfX4ool0fD_ooo]Z1ooo0=WooookJQ?ooo]Z000PoookJPCo
00006?oonfX3ool0:I[ooo]Z1Ooo0=U6oookJPOoo`3IoooonfXFoookJP008?oonfX4o`0001Sooo]Z
0_oo02VLoookJPGoo`3I@_oonfX7ool0fOoooo]Z6OoonfX0023ooo]Z1?l0000GoookJP?oo`0YW_oo
nfX5ool0fCgooo]Z2?oo0=WooookJQ_ooo]Z000PoookJPCo00005_oonfX3ool0:J7ooo]Z1Ooo0=Tg
oookJPSoo`3IoooonfXOoookJP008?oonfX4o`0001Kooo]Z0ooo02VRoookJPOoo`3I<?oonfX9ool0
fOoooo]Z8_oonfX0023ooo]Z1?l0000EoookJP?oo`0YYOoonfX8ool0fBWooo]Z2_oo0=WooookJRGo
oo]Z000PoookJPCo00005OoonfX2ool0:JWooo]Z2?oo0=TQoookJP_oo`3IoooonfXYoookJP008?oo
nfX4o`0001Cooo]Z0ooo02V/oookJP[oo`3I5_oonfX=ool0fOoooo]Z;OoonfX0023ooo]Z1?l0000C
oookJP?oo`0Y/?oonfXUool0fOoooo]Z<_oonfX0023ooo]Z1?l0000CoookJP?oo`0Y]OoonfXJool0
fOoooo]Z>?oonfX0023ooo]Z1?l0000BoookJP?oo`0Yoooonf[ooookJPWooo]Z000PoookJPCo0000
4_oonfX3ool0:Ooooo]ZoooonfX9oookJP008?oonfX4o`00017ooo]Z0ooo02WooookJ_oooo]Z2_oo
nfX0023ooo]Z1?l0000@oookJPCoo`0Yoooonf[ooookJP[ooo]Z000PoookJPCo00004?oonfX3ool0
:Ooooo]ZoooonfX;oookJP008?oonfX5o`0000kooo]Z0ooo02WooookJ_oooo]Z3?oonfX0023ooo]Z
1?l0000?oookJP?oo`0Yoooonf[ooookJPcooo]Z000PoookJPCo00003_oonfX3ool0:Ooooo]Zoooo
nfX=oookJP008?oonfX4o`0000kooo]Z0ooo02WooookJ_oooo]Z3OoonfX0023ooo]Z1?l0000=oook
JP?oo`0Yoooonf[ooookJPkooo]Z000PoookJPCo00003OoonfX2ool0:Ooooo]ZoooonfX?oookJP00
8?oonfX4o`0000cooo]Z0ooo02WooookJ_oooo]Z3ooonfX0023ooo]Z1?l0000<oookJP;oo`0Yoooo
nf[ooookJQ3ooo]Z000PoookJPCo00003?oonfX2ool0:Ooooo]ZoooonfX@oookJP008?oonfX4o`00
0?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]Z
oooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXN
oookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP008?oonfX4o`000?oooo]ZoooonfXNoookJP00
8?oonfX4o`000?oooo]ZoooonfXNoookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00
oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooook
JT;ooo]Z003ooookJ_oooo]Z@_oonfX000_ooo]Z1?l007l5oookJPCo001o00Cooo]Zo`00Ool007oo
001o0ooonfX3o`00O`04oookJ_l007oo001oo`00O`Cooo]Z1Ol007l6oookJP?o001o00Cooo]Zo`00
Ool007oo001ooooonf[ooookJPKooo]Z000:oookJPKo001o0ooonfX8o`00O`?ooo]Z2?l007l3oook
JPOo001o1?oonfX8o`00Oooooo]ZoooonfX6oookJP002OoonfX3o`00O`;ooo]Z0ol007l2oookJP?o
001o0_oonfX3o`00O`;ooo]Z1?l007l00ooonf[o001oo`00O`02o`00O`;ooo]Z1?l007l2oookJP?o
001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001ooooonf[ooookJPKooo]Z0009oookJP?o001o
0_oonfX3o`00O`;ooo]Z0ol007l2oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2oookJP?o001o
2?oonfX3o`00O`?ooo]Z0ol007oooookJ_oooo]Z1_oonfX000Wooo]Z0ol007l2oookJP?o001o0_oo
nfX4o`00O`04oookJ_l007oo001oo`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX9o`00O`;ooo]Z
0ol007l3oookJP?o001ooooonf[ooookJPKooo]Z000>oookJP?o001o0ooonfX7o`00O`;ooo]Z0ol0
07l3oookJP?o001o0_oonfX9o`00O`;ooo]Z0ol007l3oookJP?o001ooooonf[ooookJPKooo]Z000>
oookJP?o001o1ooonfX3o`00O`;ooo]Z0ol007l3oookJP?o001o0_oonfX3o`00O`?ooo]Z0ol007l2
oookJP?o001o0ooonfX3o`00Oooooo]ZoooonfX6oookJP003_oonfX3o`00O`;ooo]Z0ol007l2oook
JP?o001o0_oonfX4o`00O`03oookJ_l007oo001o00;o001o0_oonfX3o`00O`?ooo]Z0ol007l2oook
JPCo001o00?ooo]Zo`00Ool007l00_l007oooookJ_oooo]Z1_oonfX000kooo]Z0ol007l2oookJPSo
001o0ooonfX8o`00O`?ooo]Z1ol007l4oookJPSo001ooooonf[ooookJPKooo]Z000>oookJP?o001o
1?oonfX4o`00O`Kooo]Z0ol007l01?oonf[o001oo`00Ool007l4oookJPGo001o1_oonfX3o`00O`04
oookJ_l007oo001oo`00Oooooo]ZoooonfX6oookJP003_oonfX3o`00Oa;ooo]Z0ol007lCoookJP?o
001ooooonf[ooookJPKooo]Z000>oookJP?o001o4_oonfX3o`00Oa?ooo]Z0ol007oooookJ_oooo]Z
1_oonfX000kooo]Z0ol007lBoookJP?o001o4ooonfX3o`00Oooooo]ZoooonfX6oookJP00oooonf[o
oookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z
003ooookJ_oooo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oo
oo]Z@_oonfX00?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX0
0?oooo]ZoooonfY2oookJP00oooonf[ooookJT;ooo]Z003ooookJ_oooo]Z@_oonfX00?oooo]Zoooo
nfY2oookJP00oooonf[ooookJT;ooo]Z0000\
\>"],
  ImageRangeCache->{{{0, 575}, {354.938, 0}} -> {-0.107231, -0.0166149, \
0.00307103, 0.00309925}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that all starting points produce trajectories that converge on the \
same critical point. This is an example of a system of equations that \
exhibits a ",
  StyleBox["stable",
    FontWeight->"Bold"],
  " critical point.\nNote also that some of the trajectories take the system \
into unphysical states where one of the populations exceeds a fraction of 1!"
}], "Text"],

Cell["Analysis of Stability of the Predator-Prey Model", "Subtitle",
  CellTags->"mmtag:24:predator_prey_models__stability_of"],

Cell[TextData[{
  "The model above can be written as the system of ODEs:\n",
  Cell[BoxData[
      \(TraditionalForm\`dN\/dt\)]],
  " = \[Alpha] - \[Rho] N J\n",
  Cell[BoxData[
      \(TraditionalForm\`dJ\/dt\)]],
  " = -\[Alpha]J  +  \[Rho] N J  - \[Phi]J"
}], "Text"],

Cell["Find the fixed points:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(Ndot\  = \ \[Alpha] - \[Rho]\ N\ J\), "\[IndentingNewLine]", 
    \(Jdot\  = \ \(-\[Alpha]\)\ J + \[Rho]\ N\ J - \[Phi]\ J\)}], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(Ndot\\)\\\" is similar to existing symbol \\\
\"\\!\\(Not\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\
\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\[Alpha] - J\ N\ \[Rho]\)], "Output"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(Jdot\\)\\\" is similar to existing symbol \\\
\"\\!\\(Ndot\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\(-J\)\ \[Alpha] + J\ N\ \[Rho] - J\ \[Phi]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(fixedpoint\  = \ 
      Solve[{Ndot \[Equal] 0, \ Jdot \[Equal] 0}, {N, J}] // 
        Flatten\)], "Input"],

Cell[BoxData[
    \({J \[Rule] \[Alpha]\/\(\[Alpha] + \[Phi]\), 
      N \[Rule] \(\[Alpha] + \[Phi]\)\/\[Rho]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The next final part of this notebook examines the ",
  StyleBox["stability",
    FontWeight->"Bold"],
  " of the critical point for this problem. This is discussed in Kreyszig ",
  StyleBox["AEM",
    FontSlant->"Italic"],
  ", pp. 170\[Dash]174.  Kreyszig describes the stability analysis in terms \
of an eigenvalue problem. The matrix for which eigenvalues are calculated is \
the \"Jacobian\" defined below. It is the same as the matrix ",
  StyleBox["A",
    FontWeight->"Bold"],
  " in Kreyszig's Eq. (1) on p. 170."
}], "Text"],

Cell["Define the general Jacobian", "Text",
  CellTags->"mmtag:24:jacobian__relation_to_fixed_points"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Jacob\  = \ {\[IndentingNewLine]{D[Ndot, N], \ 
            D[Ndot, J]}, \[IndentingNewLine]{D[Jdot, N], \ 
            D[Jdot, J]}\[IndentingNewLine]};\)\), "\[IndentingNewLine]", 
    \(Jacob // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(-J\)\ \[Rho]\), \(\(-N\)\ \[Rho]\)},
            {\(J\ \[Rho]\), \(\(-\[Alpha]\) + N\ \[Rho] - \[Phi]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell["Find the Jacobian at the fixed point:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(JacobFixedPoint\  = \ 
        Simplify[Jacob /. fixedpoint];\)\), "\[IndentingNewLine]", 
    \(JacobFixedPoint // MatrixForm\)}], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(-\(\(\[Alpha]\ \[Rho]\)\/\(\[Alpha] + \[Phi]\)\)\), \(\(-\
\[Alpha]\) - \[Phi]\)},
            {\(\(\[Alpha]\ \[Rho]\)\/\(\[Alpha] + \[Phi]\)\), "0"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Approach 1: Compute parameters ",
  StyleBox["p",
    FontSlant->"Italic"],
  ", ",
  StyleBox["q",
    FontSlant->"Italic"],
  ", and ",
  StyleBox["\[CapitalDelta]",
    FontSlant->"Italic"],
  " defined in Kreyszig's Eq. (7) on p. 171:"
}], "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kreyszigp = 
      JacobFixedPoint[\([1, 1]\)] + JacobFixedPoint[\([2, 2]\)]\)], "Input"],

Cell[BoxData[
    \(\(-\(\(\[Alpha]\ \[Rho]\)\/\(\[Alpha] + \[Phi]\)\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pValue = 
      Kreyszigp /. {\[Alpha] \[Rule] \ 
            FreshmanEntranceRate, \ \[Rho]\  \[Rule] \ 
            JokeFunniness, \ \[Phi]\  \[Rule] \ 
            PopulationForgetfullness}\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(pValue\\)\\\" is similar to existing symbol \
\\\"\\!\\(Value\\)\\\". \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(\(-0.36000000000000004`\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Kreyszigq\  = \ Simplify[Det[JacobFixedPoint]]\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell1"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(Kreyszigq\\)\\\" is similar to existing \
symbol \\\"\\!\\(Kreyszigp\\)\\\". \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"General::spell1\\\"]\\)\"\>"}]], \
"Message"],

Cell[BoxData[
    \(\[Alpha]\ \[Rho]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(qValue\  = \ 
      Kreyszigq /. {\[Alpha] \[Rule] \ 
            FreshmanEntranceRate, \ \[Rho]\  \[Rule] \ 
            JokeFunniness, \ \[Phi]\  \[Rule] \ 
            PopulationForgetfullness}\)], "Input"],

Cell[BoxData[
    RowBox[{\(General::"spell"\), \(\(:\)\(\ \)\), "\<\"Possible spelling \
error: new symbol name \\\"\\!\\(qValue\\)\\\" is similar to existing symbols \
\\!\\({pValue, Value}\\). \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::spell\\\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    \(0.1584`\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeltaValue = \ pValue\^2 - 4\ qValue\)], "Input"],

Cell[BoxData[
    \(\(-0.504`\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "According to Kreyszig's Eq. (9) on p. 172, when ",
  StyleBox["p ",
    FontSlant->"Italic"],
  "\[NotEqual] 0 and ",
  StyleBox["\[CapitalDelta] ",
    FontSlant->"Italic"],
  "< 0, the critical point will be a ",
  StyleBox["spiral point",
    FontSlant->"Italic"],
  ". In addition, according to ",
  "Kreyszig's Eq. (10) on p. 173, when ",
  StyleBox["p ",
    FontSlant->"Italic"],
  "\[LessEqual] 0 and ",
  StyleBox["q ",
    FontSlant->"Italic"],
  "> 0, the critical point will be ",
  StyleBox["stable",
    FontSlant->"Italic"],
  ". These findings correspond to what we observed on the trajectories \
plotted above."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Approach 2: Compute eigenvalues of the Jacobian at the fixed point \
and use them in a way not described in Kreyszig...\
\>", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[
    \(evals\  = \ Eigenvalues[JacobFixedPoint]\)], "Input",
  CellTags->{
  "mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability", 
    "mmtag:24:eigenvalues__and_fixed_point_stability"}],

Cell[BoxData[
    \({\(\(-\[Alpha]\)\ \[Rho] - \@\(\[Alpha]\^2\ \[Rho]\^2 - 4\ \((\[Alpha] \
+ \[Phi])\)\ \((\[Alpha]\^2\ \[Rho] + \[Alpha]\ \[Rho]\ \[Phi])\)\)\)\/\(2\ \
\((\[Alpha] + \[Phi])\)\), \(\(-\[Alpha]\)\ \[Rho] + \@\(\[Alpha]\^2\ \
\[Rho]\^2 - 4\ \((\[Alpha] + \[Phi])\)\ \((\[Alpha]\^2\ \[Rho] + \[Alpha]\ \
\[Rho]\ \[Phi])\)\)\)\/\(2\ \((\[Alpha] + \[Phi])\)\)}\)], "Output"]
}, Open  ]],

Cell["\<\
The Eigenvalues will always have a negative real part because the \
input parameters are positive real coefficients\
\>", "Text"],

Cell["\<\
Considering the parameters used above, the solution is attracted to \
the fixed point but oscillates\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MitEvals\  = \ 
      evals /. {\[Alpha] \[Rule] \ FreshmanEntranceRate, \ \[Rho]\  \[Rule] \ 
            JokeFunniness, \ \[Phi]\  \[Rule] \ 
            PopulationForgetfullness}\)], "Input"],

Cell[BoxData[
    \({\(-0.18000000000000002`\) - 
        0.354964786985977`\ \[ImaginaryI], \(-0.18000000000000002`\) + 
        0.354964786985977`\ \[ImaginaryI]}\)], "Output"]
}, Open  ]],

Cell["The Oscillation perioid is about 18 years", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(2\ \[Pi]\ /Im[MitEvals[\([1]\)]]\)], "Input",
  CellTags->"mmtag:24:the_MIT_joke_model__goes_around_comes_around_frequency"],

Cell[BoxData[
    \(\(-17.700869318701763`\)\)], "Output"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"JokeFunniness\\\", \\\
\" \\\", \\\"=\\\", \\\" \\\", \\\"0.66\\\"}\\)\\)]\\)\\), \
\\\";\\\"}\\)\\)]\\)\\), \\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 3 \
\[RightSkeleton]\\)\\)}\\)\\)]\\)\\)}\\) is not a valid box structure. The \
first argument in \\!\\(XML`MathML`BoxesToMathML[\\(\\(\[LeftSkeleton] 1 \
\[RightSkeleton]\\)\\)]\\) must be a valid box structure. \\!\\(\\*ButtonBox[\
\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\\\", \
ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\"]\\)\
\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"\
PopulationForgetfullness\\\", \\\" \\\", \\\"=\\\", \\\" \\\", \
\\\"0.2\\\"}\\)\\)]\\)\\), \\\";\\\"}\\)\\)]\\)\\), \
\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\)}\\)\\)]\\)\\), \\(\\(\[LeftSkeleton] 2 \[RightSkeleton]\\)\\), \\(\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)}\\)\\)]\\)\\)}\\) is not a valid box \
structure. The first argument in \\!\\(XML`MathML`BoxesToMathML[\\(\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)\\)]\\) must be a valid box structure. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\
\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(XML`MathML`BoxesToMathML::"notboxes"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\({\\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\\"FreshmanEntranceRate\\\
\", \\\" \\\", \\\"=\\\", \\\"0.24\\\"}\\)\\)]\\)\\), \
\\\";\\\"}\\)\\)]\\)\\), \\(\\(RowBox[\\(\\({\\(\\(RowBox[\\(\\({\\(\
\[LeftSkeleton] 1 \[RightSkeleton]\\)}\\)\\)]\\)\\), \\\";\\\"}\\)\\)]\\)\\)}\
\\) is not a valid box structure. The first argument in \
\\!\\(XML`MathML`BoxesToMathML[\\(\\(\\(\\(\[LeftSkeleton] 1 \[RightSkeleton]\
\\)\\), \\(\\(\\\"UseUnicodePlane1Characters\\\" \[Rule] False\\)\\), \
\\(\\(\\(\\(\\\"Inclu\\\"\[Ellipsis]\\\"ations\\\"\\)\\) \[Rule] \\(\\(\
\[LeftSkeleton] 5 \[RightSkeleton]\\)\\)\\)\\), \\(\\(\\\"Entities\\\" \
\[Rule] \\\"MathML\\\"\\)\\)\\)\\)]\\) must be a valid box structure. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"XML`MathML`BoxesToMathML::notboxes\\\
\"]\\)\"\>"}]], "Message"],

Cell[BoxData[
    RowBox[{\(General::"stop"\), \(\(:\)\(\ \)\), "\<\"Further output of \
\\!\\(XML`MathML`BoxesToMathML :: \\\"notboxes\\\"\\) will be suppressed \
during this calculation. \\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", \
ButtonStyle->\\\"RefGuideLinkText\\\", ButtonFrame->None, \
ButtonData:>\\\"General::stop\\\"]\\)\"\>"}]], "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Macintosh",
ScreenRectangle->{{4, 1920}, {0, 1178}},
WindowSize->{1400, 770},
WindowMargins->{{59, Automatic}, {Automatic, 0}},
WindowTitle->"Lecture 24 MIT 3.016 (Fall 2005)   \[Copyright] W. Craig Carter \
2003-2005",
ShowCellLabel->False,
CellLabelAutoDelete->True,
StyleDefinitions -> "3016_Carter.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "mmtag:24:the_MIT_joke_model"->{
    Cell[2258, 65, 318, 6, 66, "Text",
      CellTags->"mmtag:24:the_MIT_joke_model"]},
  "mmtag:24:predator_prey_models"->{
    Cell[2579, 73, 326, 6, 66, "Text",
      CellTags->"mmtag:24:predator_prey_models"]},
  "mmtag:24:JokeFunniness"->{
    Cell[2908, 81, 191, 4, 67, "Input",
      CellTags->"mmtag:24:JokeFunniness"]},
  "mmtag:24:PolulationForgetFullness"->{
    Cell[3214, 92, 213, 4, 67, "Input",
      CellTags->"mmtag:24:PolulationForgetFullness"]},
  "mmtag:24:NestList[]"->{
    Cell[4995, 141, 124, 2, 63, "Input",
      CellTags->"mmtag:24:NestList[]"]},
  "mmtag:24:the_MIT_joke_model__fixed_point_visualized"->{
    Cell[5786, 166, 328, 5, 80, "Input",
      CellTags->"mmtag:24:the_MIT_joke_model__fixed_point_visualized"]},
  "mmtag:24:graphics_list__example"->{
    Cell[367171, 21610, 370, 7, 80, "Input",
      CellTags->"mmtag:24:graphics_list__example"]},
  "mmtag:24:the_MIT_joke_model__visualized"->{
    Cell[368881, 21656, 201, 3, 64, "Input",
      CellTags->"mmtag:24:the_MIT_joke_model__visualized"]},
  "mmtag:24:predator_prey_models__stability_of"->{
    Cell[3618139, 226875, 127, 1, 61, "Subtitle",
      CellTags->"mmtag:24:predator_prey_models__stability_of"]},
  "mmtag:24:jacobian__relation_to_fixed_points"->{
    Cell[3620483, 226944, 102, 1, 59, "Text",
      CellTags->"mmtag:24:jacobian__relation_to_fixed_points"]},
  "mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability"->{
    Cell[3625437, 227117, 218, 4, 63, "Input",
      CellTags->{
      "mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability", 
        "mmtag:24:eigenvalues__and_fixed_point_stability"}]},
  "mmtag:24:eigenvalues__and_fixed_point_stability"->{
    Cell[3625437, 227117, 218, 4, 63, "Input",
      CellTags->{
      "mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability", 
        "mmtag:24:eigenvalues__and_fixed_point_stability"}]},
  "mmtag:24:the_MIT_joke_model__goes_around_comes_around_frequency"->{
    Cell[3626844, 227159, 144, 2, 63, "Input",
      CellTags->
      "mmtag:24:the_MIT_joke_model__goes_around_comes_around_frequency"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"mmtag:24:the_MIT_joke_model", 3630825, 227239},
  {"mmtag:24:predator_prey_models", 3630950, 227242},
  {"mmtag:24:JokeFunniness", 3631070, 227245},
  {"mmtag:24:PolulationForgetFullness", 3631195, 227248},
  {"mmtag:24:NestList[]", 3631317, 227251},
  {"mmtag:24:the_MIT_joke_model__fixed_point_visualized", 3631458, 227254},
  {"mmtag:24:graphics_list__example", 3631611, 227257},
  {"mmtag:24:the_MIT_joke_model__visualized", 3631756, 227260},
  {"mmtag:24:predator_prey_models__stability_of", 3631913, 227263},
  {"mmtag:24:jacobian__relation_to_fixed_points", 3632079, 227266},
  {"mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability", \
3632266, 227269},
  {"mmtag:24:eigenvalues__and_fixed_point_stability", 3632527, 227274},
  {"mmtag:24:the_MIT_joke_model__goes_around_comes_around_frequency", \
3632804, 227279}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 50, 0, 64, "Title"],
Cell[1807, 53, 41, 0, 48, "Subtitle"],

Cell[CellGroupData[{
Cell[1873, 57, 382, 6, 113, "Section"],
Cell[2258, 65, 318, 6, 66, "Text",
  CellTags->"mmtag:24:the_MIT_joke_model"],
Cell[2579, 73, 326, 6, 66, "Text",
  CellTags->"mmtag:24:predator_prey_models"],
Cell[2908, 81, 191, 4, 67, "Input",
  CellTags->"mmtag:24:JokeFunniness"],
Cell[3102, 87, 109, 3, 46, "Text"],
Cell[3214, 92, 213, 4, 67, "Input",
  CellTags->"mmtag:24:PolulationForgetFullness"],
Cell[3430, 98, 233, 4, 66, "Text"],
Cell[3666, 104, 186, 3, 67, "Input"],
Cell[3855, 109, 69, 0, 46, "Text"],
Cell[3927, 111, 250, 4, 78, "Input"],
Cell[4180, 117, 75, 0, 46, "Text"],
Cell[4258, 119, 294, 5, 94, "Input"],
Cell[4555, 126, 50, 0, 46, "Text"],
Cell[4608, 128, 198, 3, 50, "Input"],
Cell[4809, 133, 161, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[4995, 141, 124, 2, 63, "Input",
  CellTags->"mmtag:24:NestList[]"],
Cell[5122, 145, 171, 4, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5330, 154, 431, 8, 66, "Subsubsection"],

Cell[CellGroupData[{
Cell[5786, 166, 328, 5, 80, "Input",
  CellTags->"mmtag:24:the_MIT_joke_model__fixed_point_visualized"],
Cell[6117, 173, 360688, 21421, 364, 334773, 21097, "GraphicsData", \
"PostScript", "Graphics"],
Cell[366808, 21596, 130, 3, 55, "Output"]
}, Open  ]],
Cell[366953, 21602, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[367171, 21610, 370, 7, 80, "Input",
  CellTags->"mmtag:24:graphics_list__example"],
Cell[367544, 21619, 1300, 32, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368881, 21656, 201, 3, 64, "Input",
  CellTags->"mmtag:24:the_MIT_joke_model__visualized"],
Cell[369085, 21661, 3248510, 205196, 364, 3206999, 204679, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3617598, 226859, 130, 3, 55, "Output"]
}, Open  ]],
Cell[3617743, 226865, 393, 8, 78, "Text"],
Cell[3618139, 226875, 127, 1, 61, "Subtitle",
  CellTags->"mmtag:24:predator_prey_models__stability_of"],
Cell[3618269, 226878, 270, 8, 144, "Text"],
Cell[3618542, 226888, 38, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[3618605, 226892, 157, 2, 67, "Input"],
Cell[3618765, 226896, 355, 5, 24, "Message"],
Cell[3619123, 226903, 57, 1, 55, "Output"],
Cell[3619183, 226906, 356, 5, 24, "Message"],
Cell[3619542, 226913, 77, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3619656, 226919, 128, 3, 50, "Input"],
Cell[3619787, 226924, 125, 2, 84, "Output"]
}, Open  ]],
Cell[3619927, 226929, 553, 13, 66, "Text"],
Cell[3620483, 226944, 102, 1, 59, "Text",
  CellTags->"mmtag:24:jacobian__relation_to_fixed_points"],

Cell[CellGroupData[{
Cell[3620610, 226949, 244, 4, 118, "Input"],
Cell[3620857, 226955, 393, 10, 78, "Output"]
}, Open  ]],
Cell[3621265, 226968, 53, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[3621343, 226972, 163, 3, 67, "Input"],
Cell[3621509, 226977, 436, 11, 104, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3621994, 226994, 279, 11, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3622298, 227009, 109, 2, 50, "Input"],
Cell[3622410, 227013, 86, 1, 80, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3622533, 227019, 225, 5, 50, "Input"],
Cell[3622761, 227026, 359, 5, 24, "Message"],
Cell[3623123, 227033, 59, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3623219, 227039, 79, 1, 50, "Input"],
Cell[3623301, 227042, 368, 6, 24, "Message"],
Cell[3623672, 227050, 50, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3623759, 227056, 229, 5, 50, "Input"],
Cell[3623991, 227063, 360, 5, 24, "Message"],
Cell[3624354, 227070, 41, 1, 55, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3624432, 227076, 69, 1, 55, "Input"],
Cell[3624504, 227079, 45, 1, 55, "Output"]
}, Open  ]],
Cell[3624564, 227083, 659, 22, 66, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3625260, 227110, 152, 3, 43, "Subsubsection"],

Cell[CellGroupData[{
Cell[3625437, 227117, 218, 4, 63, "Input",
  CellTags->{
  "mmtag:24:predator_prey_models__eigenvalues_and_fixed_point_stability", 
    "mmtag:24:eigenvalues__and_fixed_point_stability"}],
Cell[3625658, 227123, 388, 5, 100, "Output"]
}, Open  ]],
Cell[3626061, 227131, 139, 3, 46, "Text"],
Cell[3626203, 227136, 124, 3, 46, "Text"],

Cell[CellGroupData[{
Cell[3626352, 227143, 214, 4, 50, "Input"],
Cell[3626569, 227149, 178, 3, 55, "Output"]
}, Open  ]],
Cell[3626762, 227155, 57, 0, 46, "Text"],

Cell[CellGroupData[{
Cell[3626844, 227159, 144, 2, 63, "Input",
  CellTags->
  "mmtag:24:the_MIT_joke_model__goes_around_comes_around_frequency"],
Cell[3626991, 227163, 58, 1, 55, "Output"],
Cell[3627052, 227166, 772, 11, 39, "Message"],
Cell[3627827, 227179, 832, 12, 39, "Message"],
Cell[3628662, 227193, 983, 14, 39, "Message"],
Cell[3629648, 227209, 352, 5, 24, "Message"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

